from .type_defs import BuiltinNode, DataType, NodeInstance


def levenshtein_distance(x: str, y: str) -> int:
    """Find the amount of inserts deletes and replaces needed to get from x to y."""
    n = len(x)
    m = len(y)

    A = [[i + j for j in range(m + 1)] for i in range(n + 1)]

    for i in range(n):
        for j in range(m):
            A[i + 1][j + 1] = min(
                A[i][j + 1] + 1,  # insert
                A[i + 1][j] + 1,  # delete
                A[i][j] + int(x[i] != y[j]),  # replace
            )

    return A[n][m]


# Start auto generated

# fmt: off
nodes = {
	'FunctionNodeAlignEulerToVector' : BuiltinNode([('rotation', DataType.VEC3), ('factor', DataType.FLOAT), ('vector', DataType.VEC3)],
		[('rotation', DataType.VEC3)]),
	'FunctionNodeAlignRotationToVector' : BuiltinNode([('rotation', DataType.ROTATION), ('factor', DataType.FLOAT), ('vector', DataType.VEC3)],
		[('rotation', DataType.ROTATION)]),
	'FunctionNodeAxesToRotation' : BuiltinNode([('primary_axis', DataType.VEC3), ('secondary_axis', DataType.VEC3)],
		[('rotation', DataType.ROTATION)]),
	'FunctionNodeAxisAngleToRotation' : BuiltinNode([('axis', DataType.VEC3), ('angle', DataType.FLOAT)],
		[('rotation', DataType.ROTATION)]),
	'FunctionNodeBooleanMath' : BuiltinNode([('boolean', DataType.BOOL), ('boolean', DataType.BOOL)],
		[('boolean', DataType.BOOL)]),
	'FunctionNodeCombineColor' : BuiltinNode([('red', DataType.FLOAT), ('green', DataType.FLOAT), ('blue', DataType.FLOAT), ('alpha', DataType.FLOAT)],
		[('color', DataType.RGBA)]),
	'FunctionNodeCombineMatrix' : BuiltinNode([('column_1_row_1', DataType.FLOAT), ('column_1_row_2', DataType.FLOAT), ('column_1_row_3', DataType.FLOAT), ('column_1_row_4', DataType.FLOAT), ('column_2_row_1', DataType.FLOAT), ('column_2_row_2', DataType.FLOAT), ('column_2_row_3', DataType.FLOAT), ('column_2_row_4', DataType.FLOAT), ('column_3_row_1', DataType.FLOAT), ('column_3_row_2', DataType.FLOAT), ('column_3_row_3', DataType.FLOAT), ('column_3_row_4', DataType.FLOAT), ('column_4_row_1', DataType.FLOAT), ('column_4_row_2', DataType.FLOAT), ('column_4_row_3', DataType.FLOAT), ('column_4_row_4', DataType.FLOAT)],
		[('matrix', DataType.MATRIX)]),
	'FunctionNodeCombineTransform' : BuiltinNode([('translation', DataType.VEC3), ('rotation', DataType.ROTATION), ('scale', DataType.VEC3)],
		[('transform', DataType.MATRIX)]),
	'FunctionNodeCompare' : BuiltinNode([('a', DataType.FLOAT), ('b', DataType.FLOAT), ('a', DataType.INT), ('b', DataType.INT), ('a', DataType.VEC3), ('b', DataType.VEC3), ('a', DataType.RGBA), ('b', DataType.RGBA), ('a', DataType.STRING), ('b', DataType.STRING), ('c', DataType.FLOAT), ('angle', DataType.FLOAT), ('epsilon', DataType.FLOAT)],
		[('result', DataType.BOOL)]),
	'FunctionNodeEulerToRotation' : BuiltinNode([('euler', DataType.VEC3)],
		[('rotation', DataType.ROTATION)]),
	'FunctionNodeFindInString' : BuiltinNode([('string', DataType.STRING), ('search', DataType.STRING)],
		[('first_found', DataType.INT), ('count', DataType.INT)]),
	'FunctionNodeFloatToInt' : BuiltinNode([('float', DataType.FLOAT)],
		[('integer', DataType.INT)]),
	'FunctionNodeHashValue' : BuiltinNode([('value', DataType.INT), ('seed', DataType.INT)],
		[('hash', DataType.INT)]),
	'FunctionNodeInputBool' : BuiltinNode([],
		[('boolean', DataType.BOOL)]),
	'FunctionNodeInputColor' : BuiltinNode([],
		[('color', DataType.RGBA)]),
	'FunctionNodeInputInt' : BuiltinNode([],
		[('integer', DataType.INT)]),
	'FunctionNodeInputRotation' : BuiltinNode([],
		[('rotation', DataType.ROTATION)]),
	'FunctionNodeInputSpecialCharacters' : BuiltinNode([],
		[('line_break', DataType.STRING), ('tab', DataType.STRING)]),
	'FunctionNodeInputString' : BuiltinNode([],
		[('string', DataType.STRING)]),
	'FunctionNodeInputVector' : BuiltinNode([],
		[('vector', DataType.VEC3)]),
	'FunctionNodeIntegerMath' : BuiltinNode([('value', DataType.INT), ('value', DataType.INT), ('value', DataType.INT)],
		[('value', DataType.INT)]),
	'FunctionNodeInvertMatrix' : BuiltinNode([('matrix', DataType.MATRIX)],
		[('matrix', DataType.MATRIX), ('invertible', DataType.BOOL)]),
	'FunctionNodeInvertRotation' : BuiltinNode([('rotation', DataType.ROTATION)],
		[('rotation', DataType.ROTATION)]),
	'FunctionNodeMatrixDeterminant' : BuiltinNode([('matrix', DataType.MATRIX)],
		[('determinant', DataType.FLOAT)]),
	'FunctionNodeMatrixMultiply' : BuiltinNode([('matrix', DataType.MATRIX), ('matrix', DataType.MATRIX)],
		[('matrix', DataType.MATRIX)]),
	'FunctionNodeProjectPoint' : BuiltinNode([('vector', DataType.VEC3), ('transform', DataType.MATRIX)],
		[('vector', DataType.VEC3)]),
	'FunctionNodeQuaternionToRotation' : BuiltinNode([('w', DataType.FLOAT), ('x', DataType.FLOAT), ('y', DataType.FLOAT), ('z', DataType.FLOAT)],
		[('rotation', DataType.ROTATION)]),
	'FunctionNodeRandomValue' : BuiltinNode([('min', DataType.VEC3), ('max', DataType.VEC3), ('min', DataType.FLOAT), ('max', DataType.FLOAT), ('min', DataType.INT), ('max', DataType.INT), ('probability', DataType.FLOAT), ('id', DataType.INT), ('seed', DataType.INT)],
		[('value', DataType.VEC3), ('value', DataType.FLOAT), ('value', DataType.INT), ('value', DataType.BOOL)]),
	'FunctionNodeReplaceString' : BuiltinNode([('string', DataType.STRING), ('find', DataType.STRING), ('replace', DataType.STRING)],
		[('string', DataType.STRING)]),
	'FunctionNodeRotateEuler' : BuiltinNode([('rotation', DataType.VEC3), ('rotate_by', DataType.VEC3), ('axis', DataType.VEC3), ('angle', DataType.FLOAT)],
		[('rotation', DataType.VEC3)]),
	'FunctionNodeRotateRotation' : BuiltinNode([('rotation', DataType.ROTATION), ('rotate_by', DataType.ROTATION)],
		[('rotation', DataType.ROTATION)]),
	'FunctionNodeRotateVector' : BuiltinNode([('vector', DataType.VEC3), ('rotation', DataType.ROTATION)],
		[('vector', DataType.VEC3)]),
	'FunctionNodeRotationToAxisAngle' : BuiltinNode([('rotation', DataType.ROTATION)],
		[('axis', DataType.VEC3), ('angle', DataType.FLOAT)]),
	'FunctionNodeRotationToEuler' : BuiltinNode([('rotation', DataType.ROTATION)],
		[('euler', DataType.VEC3)]),
	'FunctionNodeRotationToQuaternion' : BuiltinNode([('rotation', DataType.ROTATION)],
		[('w', DataType.FLOAT), ('x', DataType.FLOAT), ('y', DataType.FLOAT), ('z', DataType.FLOAT)]),
	'FunctionNodeSeparateColor' : BuiltinNode([('color', DataType.RGBA)],
		[('red', DataType.FLOAT), ('green', DataType.FLOAT), ('blue', DataType.FLOAT), ('alpha', DataType.FLOAT)]),
	'FunctionNodeSeparateMatrix' : BuiltinNode([('matrix', DataType.MATRIX)],
		[('column_1_row_1', DataType.FLOAT), ('column_1_row_2', DataType.FLOAT), ('column_1_row_3', DataType.FLOAT), ('column_1_row_4', DataType.FLOAT), ('column_2_row_1', DataType.FLOAT), ('column_2_row_2', DataType.FLOAT), ('column_2_row_3', DataType.FLOAT), ('column_2_row_4', DataType.FLOAT), ('column_3_row_1', DataType.FLOAT), ('column_3_row_2', DataType.FLOAT), ('column_3_row_3', DataType.FLOAT), ('column_3_row_4', DataType.FLOAT), ('column_4_row_1', DataType.FLOAT), ('column_4_row_2', DataType.FLOAT), ('column_4_row_3', DataType.FLOAT), ('column_4_row_4', DataType.FLOAT)]),
	'FunctionNodeSeparateTransform' : BuiltinNode([('transform', DataType.MATRIX)],
		[('translation', DataType.VEC3), ('rotation', DataType.ROTATION), ('scale', DataType.VEC3)]),
	'FunctionNodeSliceString' : BuiltinNode([('string', DataType.STRING), ('position', DataType.INT), ('length', DataType.INT)],
		[('string', DataType.STRING)]),
	'FunctionNodeStringLength' : BuiltinNode([('string', DataType.STRING)],
		[('length', DataType.INT)]),
	'FunctionNodeTransformDirection' : BuiltinNode([('direction', DataType.VEC3), ('transform', DataType.MATRIX)],
		[('direction', DataType.VEC3)]),
	'FunctionNodeTransformPoint' : BuiltinNode([('vector', DataType.VEC3), ('transform', DataType.MATRIX)],
		[('vector', DataType.VEC3)]),
	'FunctionNodeTransposeMatrix' : BuiltinNode([('matrix', DataType.MATRIX)],
		[('matrix', DataType.MATRIX)]),
	'FunctionNodeValueToString' : BuiltinNode([('value', DataType.FLOAT), ('decimals', DataType.INT)],
		[('string', DataType.STRING)]),
	'GeometryNodeAccumulateField' : BuiltinNode([('value', DataType.FLOAT), ('group_id', DataType.INT)],
		[('leading', DataType.FLOAT), ('trailing', DataType.FLOAT), ('total', DataType.FLOAT)]),
	'GeometryNodeAttributeDomainSize' : BuiltinNode([('geometry', DataType.GEOMETRY)],
		[('point_count', DataType.INT), ('edge_count', DataType.INT), ('face_count', DataType.INT), ('face_corner_count', DataType.INT), ('spline_count', DataType.INT), ('instance_count', DataType.INT), ('layer_count', DataType.INT)]),
	'GeometryNodeAttributeStatistic' : BuiltinNode([('geometry', DataType.GEOMETRY), ('selection', DataType.BOOL), ('attribute', DataType.FLOAT)],
		[('mean', DataType.FLOAT), ('median', DataType.FLOAT), ('sum', DataType.FLOAT), ('min', DataType.FLOAT), ('max', DataType.FLOAT), ('range', DataType.FLOAT), ('standard_deviation', DataType.FLOAT), ('variance', DataType.FLOAT)]),
	'GeometryNodeBake' : BuiltinNode([('geometry', DataType.GEOMETRY)],
		[('geometry', DataType.GEOMETRY)]),
	'GeometryNodeBlurAttribute' : BuiltinNode([('value', DataType.FLOAT), ('iterations', DataType.INT), ('weight', DataType.FLOAT)],
		[('value', DataType.FLOAT)]),
	'GeometryNodeBoundBox' : BuiltinNode([('geometry', DataType.GEOMETRY)],
		[('bounding_box', DataType.GEOMETRY), ('min', DataType.VEC3), ('max', DataType.VEC3)]),
	'GeometryNodeCaptureAttribute' : BuiltinNode([('geometry', DataType.GEOMETRY)],
		[('geometry', DataType.GEOMETRY)]),
	'GeometryNodeCollectionInfo' : BuiltinNode([('collection', DataType.COLLECTION), ('separate_children', DataType.BOOL), ('reset_children', DataType.BOOL)],
		[('instances', DataType.GEOMETRY)]),
	'GeometryNodeConvexHull' : BuiltinNode([('geometry', DataType.GEOMETRY)],
		[('convex_hull', DataType.GEOMETRY)]),
	'GeometryNodeCornersOfEdge' : BuiltinNode([('edge_index', DataType.INT), ('weights', DataType.FLOAT), ('sort_index', DataType.INT)],
		[('corner_index', DataType.INT), ('total', DataType.INT)]),
	'GeometryNodeCornersOfFace' : BuiltinNode([('face_index', DataType.INT), ('weights', DataType.FLOAT), ('sort_index', DataType.INT)],
		[('corner_index', DataType.INT), ('total', DataType.INT)]),
	'GeometryNodeCornersOfVertex' : BuiltinNode([('vertex_index', DataType.INT), ('weights', DataType.FLOAT), ('sort_index', DataType.INT)],
		[('corner_index', DataType.INT), ('total', DataType.INT)]),
	'GeometryNodeCurveArc' : BuiltinNode([('resolution', DataType.INT), ('start', DataType.VEC3), ('middle', DataType.VEC3), ('end', DataType.VEC3), ('radius', DataType.FLOAT), ('start_angle', DataType.FLOAT), ('sweep_angle', DataType.FLOAT), ('offset_angle', DataType.FLOAT), ('connect_center', DataType.BOOL), ('invert_arc', DataType.BOOL)],
		[('curve', DataType.GEOMETRY), ('center', DataType.VEC3), ('normal', DataType.VEC3), ('radius', DataType.FLOAT)]),
	'GeometryNodeCurveEndpointSelection' : BuiltinNode([('start_size', DataType.INT), ('end_size', DataType.INT)],
		[('selection', DataType.BOOL)]),
	'GeometryNodeCurveHandleTypeSelection' : BuiltinNode([],
		[('selection', DataType.BOOL)]),
	'GeometryNodeCurveLength' : BuiltinNode([('curve', DataType.GEOMETRY)],
		[('length', DataType.FLOAT)]),
	'GeometryNodeCurveOfPoint' : BuiltinNode([('point_index', DataType.INT)],
		[('curve_index', DataType.INT), ('index_in_curve', DataType.INT)]),
	'GeometryNodeCurvePrimitiveBezierSegment' : BuiltinNode([('resolution', DataType.INT), ('start', DataType.VEC3), ('start_handle', DataType.VEC3), ('end_handle', DataType.VEC3), ('end', DataType.VEC3)],
		[('curve', DataType.GEOMETRY)]),
	'GeometryNodeCurvePrimitiveCircle' : BuiltinNode([('resolution', DataType.INT), ('point_1', DataType.VEC3), ('point_2', DataType.VEC3), ('point_3', DataType.VEC3), ('radius', DataType.FLOAT)],
		[('curve', DataType.GEOMETRY), ('center', DataType.VEC3)]),
	'GeometryNodeCurvePrimitiveLine' : BuiltinNode([('start', DataType.VEC3), ('end', DataType.VEC3), ('direction', DataType.VEC3), ('length', DataType.FLOAT)],
		[('curve', DataType.GEOMETRY)]),
	'GeometryNodeCurvePrimitiveQuadrilateral' : BuiltinNode([('width', DataType.FLOAT), ('height', DataType.FLOAT), ('bottom_width', DataType.FLOAT), ('top_width', DataType.FLOAT), ('offset', DataType.FLOAT), ('bottom_height', DataType.FLOAT), ('top_height', DataType.FLOAT), ('point_1', DataType.VEC3), ('point_2', DataType.VEC3), ('point_3', DataType.VEC3), ('point_4', DataType.VEC3)],
		[('curve', DataType.GEOMETRY)]),
	'GeometryNodeCurveQuadraticBezier' : BuiltinNode([('resolution', DataType.INT), ('start', DataType.VEC3), ('middle', DataType.VEC3), ('end', DataType.VEC3)],
		[('curve', DataType.GEOMETRY)]),
	'GeometryNodeCurveSetHandles' : BuiltinNode([('curve', DataType.GEOMETRY), ('selection', DataType.BOOL)],
		[('curve', DataType.GEOMETRY)]),
	'GeometryNodeCurveSpiral' : BuiltinNode([('resolution', DataType.INT), ('rotations', DataType.FLOAT), ('start_radius', DataType.FLOAT), ('end_radius', DataType.FLOAT), ('height', DataType.FLOAT), ('reverse', DataType.BOOL)],
		[('curve', DataType.GEOMETRY)]),
	'GeometryNodeCurveSplineType' : BuiltinNode([('curve', DataType.GEOMETRY), ('selection', DataType.BOOL)],
		[('curve', DataType.GEOMETRY)]),
	'GeometryNodeCurveStar' : BuiltinNode([('points', DataType.INT), ('inner_radius', DataType.FLOAT), ('outer_radius', DataType.FLOAT), ('twist', DataType.FLOAT)],
		[('curve', DataType.GEOMETRY), ('outer_points', DataType.BOOL)]),
	'GeometryNodeCurveToMesh' : BuiltinNode([('curve', DataType.GEOMETRY), ('profile_curve', DataType.GEOMETRY), ('fill_caps', DataType.BOOL)],
		[('mesh', DataType.GEOMETRY)]),
	'GeometryNodeCurveToPoints' : BuiltinNode([('curve', DataType.GEOMETRY), ('count', DataType.INT), ('length', DataType.FLOAT)],
		[('points', DataType.GEOMETRY), ('tangent', DataType.VEC3), ('normal', DataType.VEC3), ('rotation', DataType.ROTATION)]),
	'GeometryNodeCurvesToGreasePencil' : BuiltinNode([('curves', DataType.GEOMETRY), ('selection', DataType.BOOL), ('instances_as_layers', DataType.BOOL)],
		[('grease_pencil', DataType.GEOMETRY)]),
	'GeometryNodeDeformCurvesOnSurface' : BuiltinNode([('curves', DataType.GEOMETRY)],
		[('curves', DataType.GEOMETRY)]),
	'GeometryNodeDeleteGeometry' : BuiltinNode([('geometry', DataType.GEOMETRY), ('selection', DataType.BOOL)],
		[('geometry', DataType.GEOMETRY)]),
	'GeometryNodeDistributePointsInGrid' : BuiltinNode([('grid', DataType.FLOAT), ('density', DataType.FLOAT), ('seed', DataType.INT), ('spacing', DataType.VEC3), ('threshold', DataType.FLOAT)],
		[('points', DataType.GEOMETRY)]),
	'GeometryNodeDistributePointsInVolume' : BuiltinNode([('volume', DataType.GEOMETRY), ('density', DataType.FLOAT), ('seed', DataType.INT), ('spacing', DataType.VEC3), ('threshold', DataType.FLOAT)],
		[('points', DataType.GEOMETRY)]),
	'GeometryNodeDistributePointsOnFaces' : BuiltinNode([('mesh', DataType.GEOMETRY), ('selection', DataType.BOOL), ('distance_min', DataType.FLOAT), ('density_max', DataType.FLOAT), ('density', DataType.FLOAT), ('density_factor', DataType.FLOAT), ('seed', DataType.INT)],
		[('points', DataType.GEOMETRY), ('normal', DataType.VEC3), ('rotation', DataType.ROTATION)]),
	'GeometryNodeDualMesh' : BuiltinNode([('mesh', DataType.GEOMETRY), ('keep_boundaries', DataType.BOOL)],
		[('dual_mesh', DataType.GEOMETRY)]),
	'GeometryNodeDuplicateElements' : BuiltinNode([('geometry', DataType.GEOMETRY), ('selection', DataType.BOOL), ('amount', DataType.INT)],
		[('geometry', DataType.GEOMETRY), ('duplicate_index', DataType.INT)]),
	'GeometryNodeEdgePathsToCurves' : BuiltinNode([('mesh', DataType.GEOMETRY), ('start_vertices', DataType.BOOL), ('next_vertex_index', DataType.INT)],
		[('curves', DataType.GEOMETRY)]),
	'GeometryNodeEdgePathsToSelection' : BuiltinNode([('start_vertices', DataType.BOOL), ('next_vertex_index', DataType.INT)],
		[('selection', DataType.BOOL)]),
	'GeometryNodeEdgesOfCorner' : BuiltinNode([('corner_index', DataType.INT)],
		[('next_edge_index', DataType.INT), ('previous_edge_index', DataType.INT)]),
	'GeometryNodeEdgesOfVertex' : BuiltinNode([('vertex_index', DataType.INT), ('weights', DataType.FLOAT), ('sort_index', DataType.INT)],
		[('edge_index', DataType.INT), ('total', DataType.INT)]),
	'GeometryNodeExtrudeMesh' : BuiltinNode([('mesh', DataType.GEOMETRY), ('selection', DataType.BOOL), ('offset', DataType.VEC3), ('offset_scale', DataType.FLOAT), ('individual', DataType.BOOL)],
		[('mesh', DataType.GEOMETRY), ('top', DataType.BOOL), ('side', DataType.BOOL)]),
	'GeometryNodeFaceOfCorner' : BuiltinNode([('corner_index', DataType.INT)],
		[('face_index', DataType.INT), ('index_in_face', DataType.INT)]),
	'GeometryNodeFieldAtIndex' : BuiltinNode([('index', DataType.INT), ('value', DataType.FLOAT)],
		[('value', DataType.FLOAT)]),
	'GeometryNodeFieldOnDomain' : BuiltinNode([('value', DataType.FLOAT)],
		[('value', DataType.FLOAT)]),
	'GeometryNodeFillCurve' : BuiltinNode([('curve', DataType.GEOMETRY), ('group_id', DataType.INT)],
		[('mesh', DataType.GEOMETRY)]),
	'GeometryNodeFilletCurve' : BuiltinNode([('curve', DataType.GEOMETRY), ('count', DataType.INT), ('radius', DataType.FLOAT), ('limit_radius', DataType.BOOL)],
		[('curve', DataType.GEOMETRY)]),
	'GeometryNodeFlipFaces' : BuiltinNode([('mesh', DataType.GEOMETRY), ('selection', DataType.BOOL)],
		[('mesh', DataType.GEOMETRY)]),
	'GeometryNodeForeachGeometryElementInput' : BuiltinNode([('geometry', DataType.GEOMETRY), ('selection', DataType.BOOL)],
		[('index', DataType.INT), ('element', DataType.GEOMETRY)]),
	'GeometryNodeForeachGeometryElementOutput' : BuiltinNode([('geometry', DataType.GEOMETRY)],
		[('geometry', DataType.GEOMETRY), ('geometry', DataType.GEOMETRY)]),
	'GeometryNodeGeometryToInstance' : BuiltinNode([('geometry', DataType.GEOMETRY)],
		[('instances', DataType.GEOMETRY)]),
	'GeometryNodeGetNamedGrid' : BuiltinNode([('volume', DataType.GEOMETRY), ('name', DataType.STRING), ('remove', DataType.BOOL)],
		[('volume', DataType.GEOMETRY), ('grid', DataType.FLOAT)]),
	'GeometryNodeGizmoDial' : BuiltinNode([('value', DataType.FLOAT), ('position', DataType.VEC3), ('up', DataType.VEC3), ('screen_space', DataType.BOOL), ('radius', DataType.FLOAT)],
		[('transform', DataType.GEOMETRY)]),
	'GeometryNodeGizmoLinear' : BuiltinNode([('value', DataType.FLOAT), ('position', DataType.VEC3), ('direction', DataType.VEC3)],
		[('transform', DataType.GEOMETRY)]),
	'GeometryNodeGizmoTransform' : BuiltinNode([('value', DataType.MATRIX), ('position', DataType.VEC3), ('rotation', DataType.ROTATION)],
		[('transform', DataType.GEOMETRY)]),
	'GeometryNodeGreasePencilToCurves' : BuiltinNode([('grease_pencil', DataType.GEOMETRY), ('selection', DataType.BOOL), ('layers_as_instances', DataType.BOOL)],
		[('curves', DataType.GEOMETRY)]),
	'GeometryNodeGridToMesh' : BuiltinNode([('grid', DataType.FLOAT), ('threshold', DataType.FLOAT), ('adaptivity', DataType.FLOAT)],
		[('mesh', DataType.GEOMETRY)]),
	'GeometryNodeImageInfo' : BuiltinNode([('image', DataType.IMAGE), ('frame', DataType.INT)],
		[('width', DataType.INT), ('height', DataType.INT), ('has_alpha', DataType.BOOL), ('frame_count', DataType.INT), ('fps', DataType.FLOAT)]),
	'GeometryNodeImageTexture' : BuiltinNode([('image', DataType.IMAGE), ('vector', DataType.VEC3), ('frame', DataType.INT)],
		[('color', DataType.RGBA), ('alpha', DataType.FLOAT)]),
	'GeometryNodeImportOBJ' : BuiltinNode([('path', DataType.STRING)],
		[('instances', DataType.GEOMETRY)]),
	'GeometryNodeImportPLY' : BuiltinNode([('path', DataType.STRING)],
		[('mesh', DataType.GEOMETRY)]),
	'GeometryNodeImportSTL' : BuiltinNode([('path', DataType.STRING)],
		[('mesh', DataType.GEOMETRY)]),
	'GeometryNodeIndexOfNearest' : BuiltinNode([('position', DataType.VEC3), ('group_id', DataType.INT)],
		[('index', DataType.INT), ('has_neighbor', DataType.BOOL)]),
	'GeometryNodeIndexSwitch' : BuiltinNode([('index', DataType.INT), ('0', DataType.GEOMETRY), ('1', DataType.GEOMETRY)],
		[('output', DataType.GEOMETRY)]),
	'GeometryNodeInputActiveCamera' : BuiltinNode([],
		[('active_camera', DataType.OBJECT)]),
	'GeometryNodeInputCollection' : BuiltinNode([],
		[('collection', DataType.COLLECTION)]),
	'GeometryNodeInputCurveHandlePositions' : BuiltinNode([('relative', DataType.BOOL)],
		[('left', DataType.VEC3), ('right', DataType.VEC3)]),
	'GeometryNodeInputCurveTilt' : BuiltinNode([],
		[('tilt', DataType.FLOAT)]),
	'GeometryNodeInputEdgeSmooth' : BuiltinNode([],
		[('smooth', DataType.BOOL)]),
	'GeometryNodeInputID' : BuiltinNode([],
		[('id', DataType.INT)]),
	'GeometryNodeInputImage' : BuiltinNode([],
		[('image', DataType.IMAGE)]),
	'GeometryNodeInputIndex' : BuiltinNode([],
		[('index', DataType.INT)]),
	'GeometryNodeInputInstanceRotation' : BuiltinNode([],
		[('rotation', DataType.ROTATION)]),
	'GeometryNodeInputInstanceScale' : BuiltinNode([],
		[('scale', DataType.VEC3)]),
	'GeometryNodeInputMaterial' : BuiltinNode([],
		[('material', DataType.MATERIAL)]),
	'GeometryNodeInputMaterialIndex' : BuiltinNode([],
		[('material_index', DataType.INT)]),
	'GeometryNodeInputMeshEdgeAngle' : BuiltinNode([],
		[('unsigned_angle', DataType.FLOAT), ('signed_angle', DataType.FLOAT)]),
	'GeometryNodeInputMeshEdgeNeighbors' : BuiltinNode([],
		[('face_count', DataType.INT)]),
	'GeometryNodeInputMeshEdgeVertices' : BuiltinNode([],
		[('vertex_index_1', DataType.INT), ('vertex_index_2', DataType.INT), ('position_1', DataType.VEC3), ('position_2', DataType.VEC3)]),
	'GeometryNodeInputMeshFaceArea' : BuiltinNode([],
		[('area', DataType.FLOAT)]),
	'GeometryNodeInputMeshFaceIsPlanar' : BuiltinNode([('threshold', DataType.FLOAT)],
		[('planar', DataType.BOOL)]),
	'GeometryNodeInputMeshFaceNeighbors' : BuiltinNode([],
		[('vertex_count', DataType.INT), ('face_count', DataType.INT)]),
	'GeometryNodeInputMeshIsland' : BuiltinNode([],
		[('island_index', DataType.INT), ('island_count', DataType.INT)]),
	'GeometryNodeInputMeshVertexNeighbors' : BuiltinNode([],
		[('vertex_count', DataType.INT), ('face_count', DataType.INT)]),
	'GeometryNodeInputNamedAttribute' : BuiltinNode([('name', DataType.STRING)],
		[('attribute', DataType.FLOAT), ('exists', DataType.BOOL)]),
	'GeometryNodeInputNamedLayerSelection' : BuiltinNode([('name', DataType.STRING)],
		[('selection', DataType.BOOL)]),
	'GeometryNodeInputNormal' : BuiltinNode([],
		[('normal', DataType.VEC3)]),
	'GeometryNodeInputObject' : BuiltinNode([],
		[('object', DataType.OBJECT)]),
	'GeometryNodeInputPosition' : BuiltinNode([],
		[('position', DataType.VEC3)]),
	'GeometryNodeInputRadius' : BuiltinNode([],
		[('radius', DataType.FLOAT)]),
	'GeometryNodeInputSceneTime' : BuiltinNode([],
		[('seconds', DataType.FLOAT), ('frame', DataType.FLOAT)]),
	'GeometryNodeInputShadeSmooth' : BuiltinNode([],
		[('smooth', DataType.BOOL)]),
	'GeometryNodeInputShortestEdgePaths' : BuiltinNode([('end_vertex', DataType.BOOL), ('edge_cost', DataType.FLOAT)],
		[('next_vertex_index', DataType.INT), ('total_cost', DataType.FLOAT)]),
	'GeometryNodeInputSplineCyclic' : BuiltinNode([],
		[('cyclic', DataType.BOOL)]),
	'GeometryNodeInputSplineResolution' : BuiltinNode([],
		[('resolution', DataType.INT)]),
	'GeometryNodeInputTangent' : BuiltinNode([],
		[('tangent', DataType.VEC3)]),
	'GeometryNodeInstanceOnPoints' : BuiltinNode([('points', DataType.GEOMETRY), ('selection', DataType.BOOL), ('instance', DataType.GEOMETRY), ('pick_instance', DataType.BOOL), ('instance_index', DataType.INT), ('rotation', DataType.ROTATION), ('scale', DataType.VEC3)],
		[('instances', DataType.GEOMETRY)]),
	'GeometryNodeInstanceTransform' : BuiltinNode([],
		[('transform', DataType.MATRIX)]),
	'GeometryNodeInstancesToPoints' : BuiltinNode([('instances', DataType.GEOMETRY), ('selection', DataType.BOOL), ('position', DataType.VEC3), ('radius', DataType.FLOAT)],
		[('points', DataType.GEOMETRY)]),
	'GeometryNodeInterpolateCurves' : BuiltinNode([('guide_curves', DataType.GEOMETRY), ('guide_up', DataType.VEC3), ('guide_group_id', DataType.INT), ('points', DataType.GEOMETRY), ('point_up', DataType.VEC3), ('point_group_id', DataType.INT), ('max_neighbors', DataType.INT)],
		[('curves', DataType.GEOMETRY), ('closest_index', DataType.INT), ('closest_weight', DataType.FLOAT)]),
	'GeometryNodeIsViewport' : BuiltinNode([],
		[('is_viewport', DataType.BOOL)]),
	'GeometryNodeJoinGeometry' : BuiltinNode([('geometry', DataType.GEOMETRY)],
		[('geometry', DataType.GEOMETRY)]),
	'GeometryNodeMaterialSelection' : BuiltinNode([('material', DataType.MATERIAL)],
		[('selection', DataType.BOOL)]),
	'GeometryNodeMenuSwitch' : BuiltinNode([('menu', DataType.MENU), ('a', DataType.GEOMETRY), ('b', DataType.GEOMETRY)],
		[('output', DataType.GEOMETRY)]),
	'GeometryNodeMergeByDistance' : BuiltinNode([('geometry', DataType.GEOMETRY), ('selection', DataType.BOOL), ('distance', DataType.FLOAT)],
		[('geometry', DataType.GEOMETRY)]),
	'GeometryNodeMergeLayers' : BuiltinNode([('grease_pencil', DataType.GEOMETRY), ('selection', DataType.BOOL), ('group_id', DataType.INT)],
		[('grease_pencil', DataType.GEOMETRY)]),
	'GeometryNodeMeshBoolean' : BuiltinNode([('mesh_1', DataType.GEOMETRY), ('mesh_2', DataType.GEOMETRY), ('self_intersection', DataType.BOOL), ('hole_tolerant', DataType.BOOL)],
		[('mesh', DataType.GEOMETRY), ('intersecting_edges', DataType.BOOL)]),
	'GeometryNodeMeshCircle' : BuiltinNode([('vertices', DataType.INT), ('radius', DataType.FLOAT)],
		[('mesh', DataType.GEOMETRY)]),
	'GeometryNodeMeshCone' : BuiltinNode([('vertices', DataType.INT), ('side_segments', DataType.INT), ('fill_segments', DataType.INT), ('radius_top', DataType.FLOAT), ('radius_bottom', DataType.FLOAT), ('depth', DataType.FLOAT)],
		[('mesh', DataType.GEOMETRY), ('top', DataType.BOOL), ('bottom', DataType.BOOL), ('side', DataType.BOOL), ('uv_map', DataType.VEC3)]),
	'GeometryNodeMeshCube' : BuiltinNode([('size', DataType.VEC3), ('vertices_x', DataType.INT), ('vertices_y', DataType.INT), ('vertices_z', DataType.INT)],
		[('mesh', DataType.GEOMETRY), ('uv_map', DataType.VEC3)]),
	'GeometryNodeMeshCylinder' : BuiltinNode([('vertices', DataType.INT), ('side_segments', DataType.INT), ('fill_segments', DataType.INT), ('radius', DataType.FLOAT), ('depth', DataType.FLOAT)],
		[('mesh', DataType.GEOMETRY), ('top', DataType.BOOL), ('side', DataType.BOOL), ('bottom', DataType.BOOL), ('uv_map', DataType.VEC3)]),
	'GeometryNodeMeshFaceSetBoundaries' : BuiltinNode([('face_group_id', DataType.INT)],
		[('boundary_edges', DataType.BOOL)]),
	'GeometryNodeMeshGrid' : BuiltinNode([('size_x', DataType.FLOAT), ('size_y', DataType.FLOAT), ('vertices_x', DataType.INT), ('vertices_y', DataType.INT)],
		[('mesh', DataType.GEOMETRY), ('uv_map', DataType.VEC3)]),
	'GeometryNodeMeshIcoSphere' : BuiltinNode([('radius', DataType.FLOAT), ('subdivisions', DataType.INT)],
		[('mesh', DataType.GEOMETRY), ('uv_map', DataType.VEC3)]),
	'GeometryNodeMeshLine' : BuiltinNode([('count', DataType.INT), ('resolution', DataType.FLOAT), ('start_location', DataType.VEC3), ('offset', DataType.VEC3)],
		[('mesh', DataType.GEOMETRY)]),
	'GeometryNodeMeshToCurve' : BuiltinNode([('mesh', DataType.GEOMETRY), ('selection', DataType.BOOL)],
		[('curve', DataType.GEOMETRY)]),
	'GeometryNodeMeshToDensityGrid' : BuiltinNode([('mesh', DataType.GEOMETRY), ('density', DataType.FLOAT), ('voxel_size', DataType.FLOAT), ('gradient_width', DataType.FLOAT)],
		[('density_grid', DataType.FLOAT)]),
	'GeometryNodeMeshToPoints' : BuiltinNode([('mesh', DataType.GEOMETRY), ('selection', DataType.BOOL), ('position', DataType.VEC3), ('radius', DataType.FLOAT)],
		[('points', DataType.GEOMETRY)]),
	'GeometryNodeMeshToSDFGrid' : BuiltinNode([('mesh', DataType.GEOMETRY), ('voxel_size', DataType.FLOAT), ('band_width', DataType.INT)],
		[('sdf_grid', DataType.FLOAT)]),
	'GeometryNodeMeshToVolume' : BuiltinNode([('mesh', DataType.GEOMETRY), ('density', DataType.FLOAT), ('voxel_size', DataType.FLOAT), ('voxel_amount', DataType.FLOAT), ('interior_band_width', DataType.FLOAT)],
		[('volume', DataType.GEOMETRY)]),
	'GeometryNodeMeshUVSphere' : BuiltinNode([('segments', DataType.INT), ('rings', DataType.INT), ('radius', DataType.FLOAT)],
		[('mesh', DataType.GEOMETRY), ('uv_map', DataType.VEC3)]),
	'GeometryNodeObjectInfo' : BuiltinNode([('object', DataType.OBJECT), ('as_instance', DataType.BOOL)],
		[('transform', DataType.MATRIX), ('location', DataType.VEC3), ('rotation', DataType.ROTATION), ('scale', DataType.VEC3), ('geometry', DataType.GEOMETRY)]),
	'GeometryNodeOffsetCornerInFace' : BuiltinNode([('corner_index', DataType.INT), ('offset', DataType.INT)],
		[('corner_index', DataType.INT)]),
	'GeometryNodeOffsetPointInCurve' : BuiltinNode([('point_index', DataType.INT), ('offset', DataType.INT)],
		[('is_valid_offset', DataType.BOOL), ('point_index', DataType.INT)]),
	'GeometryNodePoints' : BuiltinNode([('count', DataType.INT), ('position', DataType.VEC3), ('radius', DataType.FLOAT)],
		[('points', DataType.GEOMETRY)]),
	'GeometryNodePointsOfCurve' : BuiltinNode([('curve_index', DataType.INT), ('weights', DataType.FLOAT), ('sort_index', DataType.INT)],
		[('point_index', DataType.INT), ('total', DataType.INT)]),
	'GeometryNodePointsToCurves' : BuiltinNode([('points', DataType.GEOMETRY), ('curve_group_id', DataType.INT), ('weight', DataType.FLOAT)],
		[('curves', DataType.GEOMETRY)]),
	'GeometryNodePointsToSDFGrid' : BuiltinNode([('points', DataType.GEOMETRY), ('radius', DataType.FLOAT), ('voxel_size', DataType.FLOAT)],
		[('sdf_grid', DataType.FLOAT)]),
	'GeometryNodePointsToVertices' : BuiltinNode([('points', DataType.GEOMETRY), ('selection', DataType.BOOL)],
		[('mesh', DataType.GEOMETRY)]),
	'GeometryNodePointsToVolume' : BuiltinNode([('points', DataType.GEOMETRY), ('density', DataType.FLOAT), ('voxel_size', DataType.FLOAT), ('voxel_amount', DataType.FLOAT), ('radius', DataType.FLOAT)],
		[('volume', DataType.GEOMETRY)]),
	'GeometryNodeProximity' : BuiltinNode([('geometry', DataType.GEOMETRY), ('group_id', DataType.INT), ('sample_position', DataType.VEC3), ('sample_group_id', DataType.INT)],
		[('position', DataType.VEC3), ('distance', DataType.FLOAT), ('is_valid', DataType.BOOL)]),
	'GeometryNodeRaycast' : BuiltinNode([('target_geometry', DataType.GEOMETRY), ('attribute', DataType.FLOAT), ('source_position', DataType.VEC3), ('ray_direction', DataType.VEC3), ('ray_length', DataType.FLOAT)],
		[('is_hit', DataType.BOOL), ('hit_position', DataType.VEC3), ('hit_normal', DataType.VEC3), ('hit_distance', DataType.FLOAT), ('attribute', DataType.FLOAT)]),
	'GeometryNodeRealizeInstances' : BuiltinNode([('geometry', DataType.GEOMETRY), ('selection', DataType.BOOL), ('realize_all', DataType.BOOL), ('depth', DataType.INT)],
		[('geometry', DataType.GEOMETRY)]),
	'GeometryNodeRemoveAttribute' : BuiltinNode([('geometry', DataType.GEOMETRY), ('name', DataType.STRING)],
		[('geometry', DataType.GEOMETRY)]),
	'GeometryNodeRepeatInput' : BuiltinNode([('iterations', DataType.INT)],
		[('iteration', DataType.INT)]),
	'GeometryNodeRepeatOutput' : BuiltinNode([('geometry', DataType.GEOMETRY)],
		[('geometry', DataType.GEOMETRY)]),
	'GeometryNodeReplaceMaterial' : BuiltinNode([('geometry', DataType.GEOMETRY), ('old', DataType.MATERIAL), ('new', DataType.MATERIAL)],
		[('geometry', DataType.GEOMETRY)]),
	'GeometryNodeResampleCurve' : BuiltinNode([('curve', DataType.GEOMETRY), ('selection', DataType.BOOL), ('count', DataType.INT), ('length', DataType.FLOAT)],
		[('curve', DataType.GEOMETRY)]),
	'GeometryNodeReverseCurve' : BuiltinNode([('curve', DataType.GEOMETRY), ('selection', DataType.BOOL)],
		[('curve', DataType.GEOMETRY)]),
	'GeometryNodeRotateInstances' : BuiltinNode([('instances', DataType.GEOMETRY), ('selection', DataType.BOOL), ('rotation', DataType.ROTATION), ('pivot_point', DataType.VEC3), ('local_space', DataType.BOOL)],
		[('instances', DataType.GEOMETRY)]),
	'GeometryNodeSDFGridBoolean' : BuiltinNode([('grid_1', DataType.FLOAT), ('grid_2', DataType.FLOAT)],
		[('grid', DataType.FLOAT)]),
	'GeometryNodeSampleCurve' : BuiltinNode([('curves', DataType.GEOMETRY), ('value', DataType.FLOAT), ('factor', DataType.FLOAT), ('length', DataType.FLOAT), ('curve_index', DataType.INT)],
		[('value', DataType.FLOAT), ('position', DataType.VEC3), ('tangent', DataType.VEC3), ('normal', DataType.VEC3)]),
	'GeometryNodeSampleGrid' : BuiltinNode([('grid', DataType.FLOAT), ('position', DataType.VEC3)],
		[('value', DataType.FLOAT)]),
	'GeometryNodeSampleGridIndex' : BuiltinNode([('grid', DataType.FLOAT), ('x', DataType.INT), ('y', DataType.INT), ('z', DataType.INT)],
		[('value', DataType.FLOAT)]),
	'GeometryNodeSampleIndex' : BuiltinNode([('geometry', DataType.GEOMETRY), ('value', DataType.FLOAT), ('index', DataType.INT)],
		[('value', DataType.FLOAT)]),
	'GeometryNodeSampleNearest' : BuiltinNode([('geometry', DataType.GEOMETRY), ('sample_position', DataType.VEC3)],
		[('index', DataType.INT)]),
	'GeometryNodeSampleNearestSurface' : BuiltinNode([('mesh', DataType.GEOMETRY), ('value', DataType.FLOAT), ('group_id', DataType.INT), ('sample_position', DataType.VEC3), ('sample_group_id', DataType.INT)],
		[('value', DataType.FLOAT), ('is_valid', DataType.BOOL)]),
	'GeometryNodeSampleUVSurface' : BuiltinNode([('mesh', DataType.GEOMETRY), ('value', DataType.FLOAT), ('uv_map', DataType.VEC3), ('sample_uv', DataType.VEC3)],
		[('value', DataType.FLOAT), ('is_valid', DataType.BOOL)]),
	'GeometryNodeScaleElements' : BuiltinNode([('geometry', DataType.GEOMETRY), ('selection', DataType.BOOL), ('scale', DataType.FLOAT), ('center', DataType.VEC3), ('axis', DataType.VEC3)],
		[('geometry', DataType.GEOMETRY)]),
	'GeometryNodeScaleInstances' : BuiltinNode([('instances', DataType.GEOMETRY), ('selection', DataType.BOOL), ('scale', DataType.VEC3), ('center', DataType.VEC3), ('local_space', DataType.BOOL)],
		[('instances', DataType.GEOMETRY)]),
	'GeometryNodeSelfObject' : BuiltinNode([],
		[('self_object', DataType.OBJECT)]),
	'GeometryNodeSeparateComponents' : BuiltinNode([('geometry', DataType.GEOMETRY)],
		[('mesh', DataType.GEOMETRY), ('curve', DataType.GEOMETRY), ('grease_pencil', DataType.GEOMETRY), ('point_cloud', DataType.GEOMETRY), ('volume', DataType.GEOMETRY), ('instances', DataType.GEOMETRY)]),
	'GeometryNodeSeparateGeometry' : BuiltinNode([('geometry', DataType.GEOMETRY), ('selection', DataType.BOOL)],
		[('selection', DataType.GEOMETRY), ('inverted', DataType.GEOMETRY)]),
	'GeometryNodeSetCurveHandlePositions' : BuiltinNode([('curve', DataType.GEOMETRY), ('selection', DataType.BOOL), ('position', DataType.VEC3), ('offset', DataType.VEC3)],
		[('curve', DataType.GEOMETRY)]),
	'GeometryNodeSetCurveNormal' : BuiltinNode([('curve', DataType.GEOMETRY), ('selection', DataType.BOOL), ('normal', DataType.VEC3)],
		[('curve', DataType.GEOMETRY)]),
	'GeometryNodeSetCurveRadius' : BuiltinNode([('curve', DataType.GEOMETRY), ('selection', DataType.BOOL), ('radius', DataType.FLOAT)],
		[('curve', DataType.GEOMETRY)]),
	'GeometryNodeSetCurveTilt' : BuiltinNode([('curve', DataType.GEOMETRY), ('selection', DataType.BOOL), ('tilt', DataType.FLOAT)],
		[('curve', DataType.GEOMETRY)]),
	'GeometryNodeSetGeometryName' : BuiltinNode([('geometry', DataType.GEOMETRY), ('name', DataType.STRING)],
		[('geometry', DataType.GEOMETRY)]),
	'GeometryNodeSetID' : BuiltinNode([('geometry', DataType.GEOMETRY), ('selection', DataType.BOOL), ('id', DataType.INT)],
		[('geometry', DataType.GEOMETRY)]),
	'GeometryNodeSetInstanceTransform' : BuiltinNode([('instances', DataType.GEOMETRY), ('selection', DataType.BOOL), ('transform', DataType.MATRIX)],
		[('instances', DataType.GEOMETRY)]),
	'GeometryNodeSetMaterial' : BuiltinNode([('geometry', DataType.GEOMETRY), ('selection', DataType.BOOL), ('material', DataType.MATERIAL)],
		[('geometry', DataType.GEOMETRY)]),
	'GeometryNodeSetMaterialIndex' : BuiltinNode([('geometry', DataType.GEOMETRY), ('selection', DataType.BOOL), ('material_index', DataType.INT)],
		[('geometry', DataType.GEOMETRY)]),
	'GeometryNodeSetPointRadius' : BuiltinNode([('points', DataType.GEOMETRY), ('selection', DataType.BOOL), ('radius', DataType.FLOAT)],
		[('points', DataType.GEOMETRY)]),
	'GeometryNodeSetPosition' : BuiltinNode([('geometry', DataType.GEOMETRY), ('selection', DataType.BOOL), ('position', DataType.VEC3), ('offset', DataType.VEC3)],
		[('geometry', DataType.GEOMETRY)]),
	'GeometryNodeSetShadeSmooth' : BuiltinNode([('geometry', DataType.GEOMETRY), ('selection', DataType.BOOL), ('shade_smooth', DataType.BOOL)],
		[('geometry', DataType.GEOMETRY)]),
	'GeometryNodeSetSplineCyclic' : BuiltinNode([('geometry', DataType.GEOMETRY), ('selection', DataType.BOOL), ('cyclic', DataType.BOOL)],
		[('geometry', DataType.GEOMETRY)]),
	'GeometryNodeSetSplineResolution' : BuiltinNode([('geometry', DataType.GEOMETRY), ('selection', DataType.BOOL), ('resolution', DataType.INT)],
		[('geometry', DataType.GEOMETRY)]),
	'GeometryNodeSimulationInput' : BuiltinNode([],
		[('delta_time', DataType.FLOAT)]),
	'GeometryNodeSimulationOutput' : BuiltinNode([('skip', DataType.BOOL), ('geometry', DataType.GEOMETRY)],
		[('geometry', DataType.GEOMETRY)]),
	'GeometryNodeSortElements' : BuiltinNode([('geometry', DataType.GEOMETRY), ('selection', DataType.BOOL), ('group_id', DataType.INT), ('sort_weight', DataType.FLOAT)],
		[('geometry', DataType.GEOMETRY)]),
	'GeometryNodeSplineLength' : BuiltinNode([],
		[('length', DataType.FLOAT), ('point_count', DataType.INT)]),
	'GeometryNodeSplineParameter' : BuiltinNode([],
		[('factor', DataType.FLOAT), ('length', DataType.FLOAT), ('index', DataType.INT)]),
	'GeometryNodeSplitEdges' : BuiltinNode([('mesh', DataType.GEOMETRY), ('selection', DataType.BOOL)],
		[('mesh', DataType.GEOMETRY)]),
	'GeometryNodeSplitToInstances' : BuiltinNode([('geometry', DataType.GEOMETRY), ('selection', DataType.BOOL), ('group_id', DataType.INT)],
		[('instances', DataType.GEOMETRY), ('group_id', DataType.INT)]),
	'GeometryNodeStoreNamedAttribute' : BuiltinNode([('geometry', DataType.GEOMETRY), ('selection', DataType.BOOL), ('name', DataType.STRING), ('value', DataType.FLOAT)],
		[('geometry', DataType.GEOMETRY)]),
	'GeometryNodeStoreNamedGrid' : BuiltinNode([('volume', DataType.GEOMETRY), ('name', DataType.STRING), ('grid', DataType.FLOAT)],
		[('volume', DataType.GEOMETRY)]),
	'GeometryNodeStringJoin' : BuiltinNode([('delimiter', DataType.STRING), ('strings', DataType.STRING)],
		[('string', DataType.STRING)]),
	'GeometryNodeStringToCurves' : BuiltinNode([('string', DataType.STRING), ('size', DataType.FLOAT), ('character_spacing', DataType.FLOAT), ('word_spacing', DataType.FLOAT), ('line_spacing', DataType.FLOAT), ('text_box_width', DataType.FLOAT), ('text_box_height', DataType.FLOAT)],
		[('curve_instances', DataType.GEOMETRY), ('remainder', DataType.STRING), ('line', DataType.INT), ('pivot_point', DataType.VEC3)]),
	'GeometryNodeSubdivideCurve' : BuiltinNode([('curve', DataType.GEOMETRY), ('cuts', DataType.INT)],
		[('curve', DataType.GEOMETRY)]),
	'GeometryNodeSubdivideMesh' : BuiltinNode([('mesh', DataType.GEOMETRY), ('level', DataType.INT)],
		[('mesh', DataType.GEOMETRY)]),
	'GeometryNodeSubdivisionSurface' : BuiltinNode([('mesh', DataType.GEOMETRY), ('level', DataType.INT), ('edge_crease', DataType.FLOAT), ('vertex_crease', DataType.FLOAT), ('limit_surface', DataType.BOOL)],
		[('mesh', DataType.GEOMETRY)]),
	'GeometryNodeSwitch' : BuiltinNode([('switch', DataType.BOOL), ('false', DataType.GEOMETRY), ('true', DataType.GEOMETRY)],
		[('output', DataType.GEOMETRY)]),
	'GeometryNodeTool3DCursor' : BuiltinNode([],
		[('location', DataType.VEC3), ('rotation', DataType.ROTATION)]),
	'GeometryNodeToolActiveElement' : BuiltinNode([],
		[('index', DataType.INT), ('exists', DataType.BOOL)]),
	'GeometryNodeToolFaceSet' : BuiltinNode([],
		[('face_set', DataType.INT), ('exists', DataType.BOOL)]),
	'GeometryNodeToolMousePosition' : BuiltinNode([],
		[('mouse_x', DataType.INT), ('mouse_y', DataType.INT), ('region_width', DataType.INT), ('region_height', DataType.INT)]),
	'GeometryNodeToolSelection' : BuiltinNode([],
		[('boolean', DataType.BOOL), ('float', DataType.FLOAT)]),
	'GeometryNodeToolSetFaceSet' : BuiltinNode([('mesh', DataType.GEOMETRY), ('selection', DataType.BOOL), ('face_set', DataType.INT)],
		[('mesh', DataType.GEOMETRY)]),
	'GeometryNodeToolSetSelection' : BuiltinNode([('geometry', DataType.GEOMETRY), ('selection', DataType.BOOL)],
		[('geometry', DataType.GEOMETRY)]),
	'GeometryNodeTransform' : BuiltinNode([('geometry', DataType.GEOMETRY), ('translation', DataType.VEC3), ('rotation', DataType.ROTATION), ('scale', DataType.VEC3), ('transform', DataType.MATRIX)],
		[('geometry', DataType.GEOMETRY)]),
	'GeometryNodeTranslateInstances' : BuiltinNode([('instances', DataType.GEOMETRY), ('selection', DataType.BOOL), ('translation', DataType.VEC3), ('local_space', DataType.BOOL)],
		[('instances', DataType.GEOMETRY)]),
	'GeometryNodeTriangulate' : BuiltinNode([('mesh', DataType.GEOMETRY), ('selection', DataType.BOOL)],
		[('mesh', DataType.GEOMETRY)]),
	'GeometryNodeTrimCurve' : BuiltinNode([('curve', DataType.GEOMETRY), ('selection', DataType.BOOL), ('start', DataType.FLOAT), ('end', DataType.FLOAT), ('start', DataType.FLOAT), ('end', DataType.FLOAT)],
		[('curve', DataType.GEOMETRY)]),
	'GeometryNodeUVPackIslands' : BuiltinNode([('uv', DataType.VEC3), ('selection', DataType.BOOL), ('margin', DataType.FLOAT), ('rotate', DataType.BOOL)],
		[('uv', DataType.VEC3)]),
	'GeometryNodeUVUnwrap' : BuiltinNode([('selection', DataType.BOOL), ('seam', DataType.BOOL), ('margin', DataType.FLOAT), ('fill_holes', DataType.BOOL)],
		[('uv', DataType.VEC3)]),
	'GeometryNodeVertexOfCorner' : BuiltinNode([('corner_index', DataType.INT)],
		[('vertex_index', DataType.INT)]),
	'GeometryNodeViewer' : BuiltinNode([('geometry', DataType.GEOMETRY), ('value', DataType.FLOAT)],
		[]),
	'GeometryNodeViewportTransform' : BuiltinNode([],
		[('projection', DataType.MATRIX), ('view', DataType.MATRIX), ('is_orthographic', DataType.BOOL)]),
	'GeometryNodeVolumeCube' : BuiltinNode([('density', DataType.FLOAT), ('background', DataType.FLOAT), ('min', DataType.VEC3), ('max', DataType.VEC3), ('resolution_x', DataType.INT), ('resolution_y', DataType.INT), ('resolution_z', DataType.INT)],
		[('volume', DataType.GEOMETRY)]),
	'GeometryNodeVolumeToMesh' : BuiltinNode([('volume', DataType.GEOMETRY), ('voxel_size', DataType.FLOAT), ('voxel_amount', DataType.FLOAT), ('threshold', DataType.FLOAT), ('adaptivity', DataType.FLOAT)],
		[('mesh', DataType.GEOMETRY)]),
	'GeometryNodeWarning' : BuiltinNode([('show', DataType.BOOL), ('message', DataType.STRING)],
		[('show', DataType.BOOL)]),
	'ShaderNodeAddShader' : BuiltinNode([('shader', DataType.SHADER), ('shader', DataType.SHADER)],
		[('shader', DataType.SHADER)]),
	'ShaderNodeAmbientOcclusion' : BuiltinNode([('color', DataType.RGBA), ('distance', DataType.FLOAT), ('normal', DataType.VEC3)],
		[('color', DataType.RGBA), ('ao', DataType.FLOAT)]),
	'ShaderNodeAttribute' : BuiltinNode([],
		[('color', DataType.RGBA), ('vector', DataType.VEC3), ('fac', DataType.FLOAT), ('alpha', DataType.FLOAT)]),
	'ShaderNodeBackground' : BuiltinNode([('color', DataType.RGBA), ('strength', DataType.FLOAT), ('weight', DataType.FLOAT)],
		[('background', DataType.SHADER)]),
	'ShaderNodeBevel' : BuiltinNode([('radius', DataType.FLOAT), ('normal', DataType.VEC3)],
		[('normal', DataType.VEC3)]),
	'ShaderNodeBlackbody' : BuiltinNode([('temperature', DataType.FLOAT)],
		[('color', DataType.RGBA)]),
	'ShaderNodeBrightContrast' : BuiltinNode([('color', DataType.RGBA), ('bright', DataType.FLOAT), ('contrast', DataType.FLOAT)],
		[('color', DataType.RGBA)]),
	'ShaderNodeBsdfAnisotropic' : BuiltinNode([('color', DataType.RGBA), ('roughness', DataType.FLOAT), ('anisotropy', DataType.FLOAT), ('rotation', DataType.FLOAT), ('normal', DataType.VEC3), ('tangent', DataType.VEC3), ('weight', DataType.FLOAT)],
		[('bsdf', DataType.SHADER)]),
	'ShaderNodeBsdfDiffuse' : BuiltinNode([('color', DataType.RGBA), ('roughness', DataType.FLOAT), ('normal', DataType.VEC3), ('weight', DataType.FLOAT)],
		[('bsdf', DataType.SHADER)]),
	'ShaderNodeBsdfGlass' : BuiltinNode([('color', DataType.RGBA), ('roughness', DataType.FLOAT), ('ior', DataType.FLOAT), ('normal', DataType.VEC3), ('weight', DataType.FLOAT)],
		[('bsdf', DataType.SHADER)]),
	'ShaderNodeBsdfHair' : BuiltinNode([('color', DataType.RGBA), ('offset', DataType.FLOAT), ('roughnessu', DataType.FLOAT), ('roughnessv', DataType.FLOAT), ('tangent', DataType.VEC3), ('weight', DataType.FLOAT)],
		[('bsdf', DataType.SHADER)]),
	'ShaderNodeBsdfHairPrincipled' : BuiltinNode([('color', DataType.RGBA), ('melanin', DataType.FLOAT), ('melanin_redness', DataType.FLOAT), ('tint', DataType.RGBA), ('absorption_coefficient', DataType.VEC3), ('aspect_ratio', DataType.FLOAT), ('roughness', DataType.FLOAT), ('radial_roughness', DataType.FLOAT), ('coat', DataType.FLOAT), ('ior', DataType.FLOAT), ('offset', DataType.FLOAT), ('random_color', DataType.FLOAT), ('random_roughness', DataType.FLOAT), ('random', DataType.FLOAT), ('weight', DataType.FLOAT), ('reflection', DataType.FLOAT), ('transmission', DataType.FLOAT), ('secondary_reflection', DataType.FLOAT)],
		[('bsdf', DataType.SHADER)]),
	'ShaderNodeBsdfMetallic' : BuiltinNode([('base_color', DataType.RGBA), ('edge_tint', DataType.RGBA), ('ior', DataType.VEC3), ('extinction', DataType.VEC3), ('roughness', DataType.FLOAT), ('anisotropy', DataType.FLOAT), ('rotation', DataType.FLOAT), ('normal', DataType.VEC3), ('tangent', DataType.VEC3), ('weight', DataType.FLOAT)],
		[('bsdf', DataType.SHADER)]),
	'ShaderNodeBsdfPrincipled' : BuiltinNode([('base_color', DataType.RGBA), ('metallic', DataType.FLOAT), ('roughness', DataType.FLOAT), ('ior', DataType.FLOAT), ('alpha', DataType.FLOAT), ('normal', DataType.VEC3), ('weight', DataType.FLOAT), ('diffuse_roughness', DataType.FLOAT), ('subsurface_weight', DataType.FLOAT), ('subsurface_radius', DataType.VEC3), ('subsurface_scale', DataType.FLOAT), ('subsurface_ior', DataType.FLOAT), ('subsurface_anisotropy', DataType.FLOAT), ('specular_ior_level', DataType.FLOAT), ('specular_tint', DataType.RGBA), ('anisotropic', DataType.FLOAT), ('anisotropic_rotation', DataType.FLOAT), ('tangent', DataType.VEC3), ('transmission_weight', DataType.FLOAT), ('coat_weight', DataType.FLOAT), ('coat_roughness', DataType.FLOAT), ('coat_ior', DataType.FLOAT), ('coat_tint', DataType.RGBA), ('coat_normal', DataType.VEC3), ('sheen_weight', DataType.FLOAT), ('sheen_roughness', DataType.FLOAT), ('sheen_tint', DataType.RGBA), ('emission_color', DataType.RGBA), ('emission_strength', DataType.FLOAT), ('thin_film_thickness', DataType.FLOAT), ('thin_film_ior', DataType.FLOAT)],
		[('bsdf', DataType.SHADER)]),
	'ShaderNodeBsdfRayPortal' : BuiltinNode([('color', DataType.RGBA), ('position', DataType.VEC3), ('direction', DataType.VEC3), ('weight', DataType.FLOAT)],
		[('bsdf', DataType.SHADER)]),
	'ShaderNodeBsdfRefraction' : BuiltinNode([('color', DataType.RGBA), ('roughness', DataType.FLOAT), ('ior', DataType.FLOAT), ('normal', DataType.VEC3), ('weight', DataType.FLOAT)],
		[('bsdf', DataType.SHADER)]),
	'ShaderNodeBsdfSheen' : BuiltinNode([('color', DataType.RGBA), ('roughness', DataType.FLOAT), ('normal', DataType.VEC3), ('weight', DataType.FLOAT)],
		[('bsdf', DataType.SHADER)]),
	'ShaderNodeBsdfToon' : BuiltinNode([('color', DataType.RGBA), ('size', DataType.FLOAT), ('smooth', DataType.FLOAT), ('normal', DataType.VEC3), ('weight', DataType.FLOAT)],
		[('bsdf', DataType.SHADER)]),
	'ShaderNodeBsdfTranslucent' : BuiltinNode([('color', DataType.RGBA), ('normal', DataType.VEC3), ('weight', DataType.FLOAT)],
		[('bsdf', DataType.SHADER)]),
	'ShaderNodeBsdfTransparent' : BuiltinNode([('color', DataType.RGBA), ('weight', DataType.FLOAT)],
		[('bsdf', DataType.SHADER)]),
	'ShaderNodeBump' : BuiltinNode([('strength', DataType.FLOAT), ('distance', DataType.FLOAT), ('height', DataType.FLOAT), ('normal', DataType.VEC3)],
		[('normal', DataType.VEC3)]),
	'ShaderNodeCameraData' : BuiltinNode([],
		[('view_vector', DataType.VEC3), ('view_z_depth', DataType.FLOAT), ('view_distance', DataType.FLOAT)]),
	'ShaderNodeClamp' : BuiltinNode([('value', DataType.FLOAT), ('min', DataType.FLOAT), ('max', DataType.FLOAT)],
		[('result', DataType.FLOAT)]),
	'ShaderNodeCombineColor' : BuiltinNode([('red', DataType.FLOAT), ('green', DataType.FLOAT), ('blue', DataType.FLOAT)],
		[('color', DataType.RGBA)]),
	'ShaderNodeCombineXYZ' : BuiltinNode([('x', DataType.FLOAT), ('y', DataType.FLOAT), ('z', DataType.FLOAT)],
		[('vector', DataType.VEC3)]),
	'ShaderNodeDisplacement' : BuiltinNode([('height', DataType.FLOAT), ('midlevel', DataType.FLOAT), ('scale', DataType.FLOAT), ('normal', DataType.VEC3)],
		[('displacement', DataType.VEC3)]),
	'ShaderNodeEeveeSpecular' : BuiltinNode([('base_color', DataType.RGBA), ('specular', DataType.RGBA), ('roughness', DataType.FLOAT), ('emissive_color', DataType.RGBA), ('transparency', DataType.FLOAT), ('normal', DataType.VEC3), ('clear_coat', DataType.FLOAT), ('clear_coat_roughness', DataType.FLOAT), ('clear_coat_normal', DataType.VEC3), ('weight', DataType.FLOAT)],
		[('bsdf', DataType.SHADER)]),
	'ShaderNodeEmission' : BuiltinNode([('color', DataType.RGBA), ('strength', DataType.FLOAT), ('weight', DataType.FLOAT)],
		[('emission', DataType.SHADER)]),
	'ShaderNodeFloatCurve' : BuiltinNode([('factor', DataType.FLOAT), ('value', DataType.FLOAT)],
		[('value', DataType.FLOAT)]),
	'ShaderNodeFresnel' : BuiltinNode([('ior', DataType.FLOAT), ('normal', DataType.VEC3)],
		[('fac', DataType.FLOAT)]),
	'ShaderNodeGamma' : BuiltinNode([('color', DataType.RGBA), ('gamma', DataType.FLOAT)],
		[('color', DataType.RGBA)]),
	'ShaderNodeHairInfo' : BuiltinNode([],
		[('is_strand', DataType.FLOAT), ('intercept', DataType.FLOAT), ('length', DataType.FLOAT), ('thickness', DataType.FLOAT), ('tangent_normal', DataType.VEC3), ('random', DataType.FLOAT)]),
	'ShaderNodeHoldout' : BuiltinNode([('weight', DataType.FLOAT)],
		[('holdout', DataType.SHADER)]),
	'ShaderNodeHueSaturation' : BuiltinNode([('hue', DataType.FLOAT), ('saturation', DataType.FLOAT), ('value', DataType.FLOAT), ('fac', DataType.FLOAT), ('color', DataType.RGBA)],
		[('color', DataType.RGBA)]),
	'ShaderNodeInvert' : BuiltinNode([('fac', DataType.FLOAT), ('color', DataType.RGBA)],
		[('color', DataType.RGBA)]),
	'ShaderNodeLayerWeight' : BuiltinNode([('blend', DataType.FLOAT), ('normal', DataType.VEC3)],
		[('fresnel', DataType.FLOAT), ('facing', DataType.FLOAT)]),
	'ShaderNodeLightFalloff' : BuiltinNode([('strength', DataType.FLOAT), ('smooth', DataType.FLOAT)],
		[('quadratic', DataType.FLOAT), ('linear', DataType.FLOAT), ('constant', DataType.FLOAT)]),
	'ShaderNodeLightPath' : BuiltinNode([],
		[('is_camera_ray', DataType.FLOAT), ('is_shadow_ray', DataType.FLOAT), ('is_diffuse_ray', DataType.FLOAT), ('is_glossy_ray', DataType.FLOAT), ('is_singular_ray', DataType.FLOAT), ('is_reflection_ray', DataType.FLOAT), ('is_transmission_ray', DataType.FLOAT), ('ray_length', DataType.FLOAT), ('ray_depth', DataType.FLOAT), ('diffuse_depth', DataType.FLOAT), ('glossy_depth', DataType.FLOAT), ('transparent_depth', DataType.FLOAT), ('transmission_depth', DataType.FLOAT)]),
	'ShaderNodeMapRange' : BuiltinNode([('value', DataType.FLOAT), ('from_min', DataType.FLOAT), ('from_max', DataType.FLOAT), ('to_min', DataType.FLOAT), ('to_max', DataType.FLOAT), ('steps', DataType.FLOAT), ('vector', DataType.VEC3), ('from_min', DataType.VEC3), ('from_max', DataType.VEC3), ('to_min', DataType.VEC3), ('to_max', DataType.VEC3), ('steps', DataType.VEC3)],
		[('result', DataType.FLOAT), ('vector', DataType.VEC3)]),
	'ShaderNodeMapping' : BuiltinNode([('vector', DataType.VEC3), ('location', DataType.VEC3), ('rotation', DataType.VEC3), ('scale', DataType.VEC3)],
		[('vector', DataType.VEC3)]),
	'ShaderNodeMath' : BuiltinNode([('value', DataType.FLOAT), ('value', DataType.FLOAT), ('value', DataType.FLOAT)],
		[('value', DataType.FLOAT)]),
	'ShaderNodeMix' : BuiltinNode([('factor', DataType.FLOAT), ('factor', DataType.VEC3), ('a', DataType.FLOAT), ('b', DataType.FLOAT), ('a', DataType.VEC3), ('b', DataType.VEC3), ('a', DataType.RGBA), ('b', DataType.RGBA), ('a', DataType.ROTATION), ('b', DataType.ROTATION)],
		[('result', DataType.FLOAT), ('result', DataType.VEC3), ('result', DataType.RGBA), ('result', DataType.ROTATION)]),
	'ShaderNodeMixShader' : BuiltinNode([('fac', DataType.FLOAT), ('shader', DataType.SHADER), ('shader', DataType.SHADER)],
		[('shader', DataType.SHADER)]),
	'ShaderNodeNewGeometry' : BuiltinNode([],
		[('position', DataType.VEC3), ('normal', DataType.VEC3), ('tangent', DataType.VEC3), ('true_normal', DataType.VEC3), ('incoming', DataType.VEC3), ('parametric', DataType.VEC3), ('backfacing', DataType.FLOAT), ('pointiness', DataType.FLOAT), ('random_per_island', DataType.FLOAT)]),
	'ShaderNodeNormal' : BuiltinNode([('normal', DataType.VEC3)],
		[('normal', DataType.VEC3), ('dot', DataType.FLOAT)]),
	'ShaderNodeNormalMap' : BuiltinNode([('strength', DataType.FLOAT), ('color', DataType.RGBA)],
		[('normal', DataType.VEC3)]),
	'ShaderNodeObjectInfo' : BuiltinNode([],
		[('location', DataType.VEC3), ('color', DataType.RGBA), ('alpha', DataType.FLOAT), ('object_index', DataType.FLOAT), ('material_index', DataType.FLOAT), ('random', DataType.FLOAT)]),
	'ShaderNodeOutputAOV' : BuiltinNode([('color', DataType.RGBA), ('value', DataType.FLOAT)],
		[]),
	'ShaderNodeOutputLight' : BuiltinNode([('surface', DataType.SHADER)],
		[]),
	'ShaderNodeOutputLineStyle' : BuiltinNode([('color', DataType.RGBA), ('color_fac', DataType.FLOAT), ('alpha', DataType.FLOAT), ('alpha_fac', DataType.FLOAT)],
		[]),
	'ShaderNodeOutputMaterial' : BuiltinNode([('surface', DataType.SHADER), ('volume', DataType.SHADER), ('displacement', DataType.VEC3), ('thickness', DataType.FLOAT)],
		[]),
	'ShaderNodeOutputWorld' : BuiltinNode([('surface', DataType.SHADER), ('volume', DataType.SHADER)],
		[]),
	'ShaderNodeParticleInfo' : BuiltinNode([],
		[('index', DataType.FLOAT), ('random', DataType.FLOAT), ('age', DataType.FLOAT), ('lifetime', DataType.FLOAT), ('location', DataType.VEC3), ('size', DataType.FLOAT), ('velocity', DataType.VEC3), ('angular_velocity', DataType.VEC3)]),
	'ShaderNodePointInfo' : BuiltinNode([],
		[('position', DataType.VEC3), ('radius', DataType.FLOAT), ('random', DataType.FLOAT)]),
	'ShaderNodeRGB' : BuiltinNode([],
		[('color', DataType.RGBA)]),
	'ShaderNodeRGBCurve' : BuiltinNode([('fac', DataType.FLOAT), ('color', DataType.RGBA)],
		[('color', DataType.RGBA)]),
	'ShaderNodeRGBToBW' : BuiltinNode([('color', DataType.RGBA)],
		[('val', DataType.FLOAT)]),
	'ShaderNodeScript' : BuiltinNode([],
		[]),
	'ShaderNodeSeparateColor' : BuiltinNode([('color', DataType.RGBA)],
		[('red', DataType.FLOAT), ('green', DataType.FLOAT), ('blue', DataType.FLOAT)]),
	'ShaderNodeSeparateXYZ' : BuiltinNode([('vector', DataType.VEC3)],
		[('x', DataType.FLOAT), ('y', DataType.FLOAT), ('z', DataType.FLOAT)]),
	'ShaderNodeShaderToRGB' : BuiltinNode([('shader', DataType.SHADER)],
		[('color', DataType.RGBA), ('alpha', DataType.FLOAT)]),
	'ShaderNodeSubsurfaceScattering' : BuiltinNode([('color', DataType.RGBA), ('scale', DataType.FLOAT), ('radius', DataType.VEC3), ('ior', DataType.FLOAT), ('roughness', DataType.FLOAT), ('anisotropy', DataType.FLOAT), ('normal', DataType.VEC3), ('weight', DataType.FLOAT)],
		[('bssrdf', DataType.SHADER)]),
	'ShaderNodeTangent' : BuiltinNode([],
		[('tangent', DataType.VEC3)]),
	'ShaderNodeTexBrick' : BuiltinNode([('vector', DataType.VEC3), ('color1', DataType.RGBA), ('color2', DataType.RGBA), ('mortar', DataType.RGBA), ('scale', DataType.FLOAT), ('mortar_size', DataType.FLOAT), ('mortar_smooth', DataType.FLOAT), ('bias', DataType.FLOAT), ('brick_width', DataType.FLOAT), ('row_height', DataType.FLOAT)],
		[('color', DataType.RGBA), ('fac', DataType.FLOAT)]),
	'ShaderNodeTexChecker' : BuiltinNode([('vector', DataType.VEC3), ('color1', DataType.RGBA), ('color2', DataType.RGBA), ('scale', DataType.FLOAT)],
		[('color', DataType.RGBA), ('fac', DataType.FLOAT)]),
	'ShaderNodeTexCoord' : BuiltinNode([],
		[('generated', DataType.VEC3), ('normal', DataType.VEC3), ('uv', DataType.VEC3), ('object', DataType.VEC3), ('camera', DataType.VEC3), ('window', DataType.VEC3), ('reflection', DataType.VEC3)]),
	'ShaderNodeTexEnvironment' : BuiltinNode([('vector', DataType.VEC3)],
		[('color', DataType.RGBA)]),
	'ShaderNodeTexGabor' : BuiltinNode([('vector', DataType.VEC3), ('scale', DataType.FLOAT), ('frequency', DataType.FLOAT), ('anisotropy', DataType.FLOAT), ('orientation', DataType.FLOAT), ('orientation', DataType.VEC3)],
		[('value', DataType.FLOAT), ('phase', DataType.FLOAT), ('intensity', DataType.FLOAT)]),
	'ShaderNodeTexGradient' : BuiltinNode([('vector', DataType.VEC3)],
		[('color', DataType.RGBA), ('fac', DataType.FLOAT)]),
	'ShaderNodeTexIES' : BuiltinNode([('vector', DataType.VEC3), ('strength', DataType.FLOAT)],
		[('fac', DataType.FLOAT)]),
	'ShaderNodeTexImage' : BuiltinNode([('vector', DataType.VEC3)],
		[('color', DataType.RGBA), ('alpha', DataType.FLOAT)]),
	'ShaderNodeTexMagic' : BuiltinNode([('vector', DataType.VEC3), ('scale', DataType.FLOAT), ('distortion', DataType.FLOAT)],
		[('color', DataType.RGBA), ('fac', DataType.FLOAT)]),
	'ShaderNodeTexNoise' : BuiltinNode([('vector', DataType.VEC3), ('w', DataType.FLOAT), ('scale', DataType.FLOAT), ('detail', DataType.FLOAT), ('roughness', DataType.FLOAT), ('lacunarity', DataType.FLOAT), ('offset', DataType.FLOAT), ('gain', DataType.FLOAT), ('distortion', DataType.FLOAT)],
		[('fac', DataType.FLOAT), ('color', DataType.RGBA)]),
	'ShaderNodeTexPointDensity' : BuiltinNode([('vector', DataType.VEC3)],
		[('color', DataType.RGBA), ('density', DataType.FLOAT)]),
	'ShaderNodeTexSky' : BuiltinNode([('vector', DataType.VEC3)],
		[('color', DataType.RGBA)]),
	'ShaderNodeTexVoronoi' : BuiltinNode([('vector', DataType.VEC3), ('w', DataType.FLOAT), ('scale', DataType.FLOAT), ('detail', DataType.FLOAT), ('roughness', DataType.FLOAT), ('lacunarity', DataType.FLOAT), ('smoothness', DataType.FLOAT), ('exponent', DataType.FLOAT), ('randomness', DataType.FLOAT)],
		[('distance', DataType.FLOAT), ('color', DataType.RGBA), ('position', DataType.VEC3), ('w', DataType.FLOAT), ('radius', DataType.FLOAT)]),
	'ShaderNodeTexWave' : BuiltinNode([('vector', DataType.VEC3), ('scale', DataType.FLOAT), ('distortion', DataType.FLOAT), ('detail', DataType.FLOAT), ('detail_scale', DataType.FLOAT), ('detail_roughness', DataType.FLOAT), ('phase_offset', DataType.FLOAT)],
		[('color', DataType.RGBA), ('fac', DataType.FLOAT)]),
	'ShaderNodeTexWhiteNoise' : BuiltinNode([('vector', DataType.VEC3), ('w', DataType.FLOAT)],
		[('value', DataType.FLOAT), ('color', DataType.RGBA)]),
	'ShaderNodeUVAlongStroke' : BuiltinNode([],
		[('uv', DataType.VEC3)]),
	'ShaderNodeUVMap' : BuiltinNode([],
		[('uv', DataType.VEC3)]),
	'ShaderNodeValToRGB' : BuiltinNode([('fac', DataType.FLOAT)],
		[('color', DataType.RGBA), ('alpha', DataType.FLOAT)]),
	'ShaderNodeValue' : BuiltinNode([],
		[('value', DataType.FLOAT)]),
	'ShaderNodeVectorCurve' : BuiltinNode([('fac', DataType.FLOAT), ('vector', DataType.VEC3)],
		[('vector', DataType.VEC3)]),
	'ShaderNodeVectorDisplacement' : BuiltinNode([('vector', DataType.RGBA), ('midlevel', DataType.FLOAT), ('scale', DataType.FLOAT)],
		[('displacement', DataType.VEC3)]),
	'ShaderNodeVectorMath' : BuiltinNode([('vector', DataType.VEC3), ('vector', DataType.VEC3), ('vector', DataType.VEC3), ('scale', DataType.FLOAT)],
		[('vector', DataType.VEC3), ('value', DataType.FLOAT)]),
	'ShaderNodeVectorRotate' : BuiltinNode([('vector', DataType.VEC3), ('center', DataType.VEC3), ('axis', DataType.VEC3), ('angle', DataType.FLOAT), ('rotation', DataType.VEC3)],
		[('vector', DataType.VEC3)]),
	'ShaderNodeVectorTransform' : BuiltinNode([('vector', DataType.VEC3)],
		[('vector', DataType.VEC3)]),
	'ShaderNodeVertexColor' : BuiltinNode([],
		[('color', DataType.RGBA), ('alpha', DataType.FLOAT)]),
	'ShaderNodeVolumeAbsorption' : BuiltinNode([('color', DataType.RGBA), ('density', DataType.FLOAT), ('weight', DataType.FLOAT)],
		[('volume', DataType.SHADER)]),
	'ShaderNodeVolumeInfo' : BuiltinNode([],
		[('color', DataType.RGBA), ('density', DataType.FLOAT), ('flame', DataType.FLOAT), ('temperature', DataType.FLOAT)]),
	'ShaderNodeVolumePrincipled' : BuiltinNode([('color', DataType.RGBA), ('color_attribute', DataType.STRING), ('density', DataType.FLOAT), ('density_attribute', DataType.STRING), ('anisotropy', DataType.FLOAT), ('absorption_color', DataType.RGBA), ('emission_strength', DataType.FLOAT), ('emission_color', DataType.RGBA), ('blackbody_intensity', DataType.FLOAT), ('blackbody_tint', DataType.RGBA), ('temperature', DataType.FLOAT), ('temperature_attribute', DataType.STRING), ('weight', DataType.FLOAT)],
		[('volume', DataType.SHADER)]),
	'ShaderNodeVolumeScatter' : BuiltinNode([('color', DataType.RGBA), ('density', DataType.FLOAT), ('anisotropy', DataType.FLOAT), ('ior', DataType.FLOAT), ('backscatter', DataType.FLOAT), ('alpha', DataType.FLOAT), ('diameter', DataType.FLOAT), ('weight', DataType.FLOAT)],
		[('volume', DataType.SHADER)]),
	'ShaderNodeWavelength' : BuiltinNode([('wavelength', DataType.FLOAT)],
		[('color', DataType.RGBA)]),
	'ShaderNodeWireframe' : BuiltinNode([('size', DataType.FLOAT)],
		[('fac', DataType.FLOAT)]),
}

shader_geo_node_aliases = {
	'blackbody' : NodeInstance('ShaderNodeBlackbody', [0], [0], []), 
	'brick_texture' : NodeInstance('ShaderNodeTexBrick', [0, 1, 2, 3, 4, 5, 6, 7, 8, 9], [0, 1], []), 
	'checker_texture' : NodeInstance('ShaderNodeTexChecker', [0, 1, 2, 3], [0, 1], []), 
	'clamp' : NodeInstance('ShaderNodeClamp', [0, 1, 2], [0], []), 
	'clamp_min_max' : NodeInstance('ShaderNodeClamp', [0, 1, 2], [0], [('clamp_type', 'MINMAX')]), 
	'clamp_range' : NodeInstance('ShaderNodeClamp', [0, 1, 2], [0], [('clamp_type', 'RANGE')]), 
	'color_ramp' : NodeInstance('ShaderNodeValToRGB', [0], [0, 1], []), 
	'combine_xyz' : NodeInstance('ShaderNodeCombineXYZ', [0, 1, 2], [0], []), 
	'float_curve' : NodeInstance('ShaderNodeFloatCurve', [0, 1], [0], []), 
	'gabor_texture' : NodeInstance('ShaderNodeTexGabor', [0, 1, 2, 3, 4], [0, 1, 2], []), 
	'gabor_texture_2d' : NodeInstance('ShaderNodeTexGabor', [0, 1, 2, 3, 4], [0, 1, 2], [('gabor_type', '2D')]), 
	'gabor_texture_3d' : NodeInstance('ShaderNodeTexGabor', [0, 1, 2, 3, 5], [0, 1, 2], [('gabor_type', '3D')]), 
	'gradient_texture' : NodeInstance('ShaderNodeTexGradient', [0], [0, 1], []), 
	'gradient_texture_diagonal' : NodeInstance('ShaderNodeTexGradient', [0], [0, 1], [('gradient_type', 'DIAGONAL')]), 
	'gradient_texture_easing' : NodeInstance('ShaderNodeTexGradient', [0], [0, 1], [('gradient_type', 'EASING')]), 
	'gradient_texture_linear' : NodeInstance('ShaderNodeTexGradient', [0], [0, 1], [('gradient_type', 'LINEAR')]), 
	'gradient_texture_quadratic' : NodeInstance('ShaderNodeTexGradient', [0], [0, 1], [('gradient_type', 'QUADRATIC')]), 
	'gradient_texture_quadratic_sphere' : NodeInstance('ShaderNodeTexGradient', [0], [0, 1], [('gradient_type', 'QUADRATIC_SPHERE')]), 
	'gradient_texture_radial' : NodeInstance('ShaderNodeTexGradient', [0], [0, 1], [('gradient_type', 'RADIAL')]), 
	'gradient_texture_spherical' : NodeInstance('ShaderNodeTexGradient', [0], [0, 1], [('gradient_type', 'SPHERICAL')]), 
	'magic_texture' : NodeInstance('ShaderNodeTexMagic', [0, 1, 2], [0, 1], []), 
	'map_range' : NodeInstance('ShaderNodeMapRange', [0, 1, 2, 3, 4], [0], []), 
	'map_range_linear_float' : NodeInstance('ShaderNodeMapRange', [0, 1, 2, 3, 4], [0], [('interpolation_type', 'LINEAR'), ('data_type', 'FLOAT')]), 
	'map_range_linear_vector' : NodeInstance('ShaderNodeMapRange', [6, 7, 8, 9, 10], [1], [('interpolation_type', 'LINEAR'), ('data_type', 'FLOAT_VECTOR')]), 
	'map_range_smooth_step_float' : NodeInstance('ShaderNodeMapRange', [0, 1, 2, 3, 4], [0], [('interpolation_type', 'SMOOTHSTEP'), ('data_type', 'FLOAT')]), 
	'map_range_smooth_step_vector' : NodeInstance('ShaderNodeMapRange', [6, 7, 8, 9, 10], [1], [('interpolation_type', 'SMOOTHSTEP'), ('data_type', 'FLOAT_VECTOR')]), 
	'map_range_smoother_step_float' : NodeInstance('ShaderNodeMapRange', [0, 1, 2, 3, 4], [0], [('interpolation_type', 'SMOOTHERSTEP'), ('data_type', 'FLOAT')]), 
	'map_range_smoother_step_vector' : NodeInstance('ShaderNodeMapRange', [6, 7, 8, 9, 10], [1], [('interpolation_type', 'SMOOTHERSTEP'), ('data_type', 'FLOAT_VECTOR')]), 
	'map_range_stepped_linear_float' : NodeInstance('ShaderNodeMapRange', [0, 1, 2, 3, 4, 5], [0], [('interpolation_type', 'STEPPED'), ('data_type', 'FLOAT')]), 
	'map_range_stepped_linear_vector' : NodeInstance('ShaderNodeMapRange', [6, 7, 8, 9, 10, 11], [1], [('interpolation_type', 'STEPPED'), ('data_type', 'FLOAT_VECTOR')]), 
	'math' : NodeInstance('ShaderNodeMath', [0, 1], [0], []), 
	'math_absolute' : NodeInstance('ShaderNodeMath', [0], [0], [('operation', 'ABSOLUTE')]), 
	'math_add' : NodeInstance('ShaderNodeMath', [0, 1], [0], [('operation', 'ADD')]), 
	'math_arccosine' : NodeInstance('ShaderNodeMath', [0], [0], [('operation', 'ARCCOSINE')]), 
	'math_arcsine' : NodeInstance('ShaderNodeMath', [0], [0], [('operation', 'ARCSINE')]), 
	'math_arctan2' : NodeInstance('ShaderNodeMath', [0, 1], [0], [('operation', 'ARCTAN2')]), 
	'math_arctangent' : NodeInstance('ShaderNodeMath', [0], [0], [('operation', 'ARCTANGENT')]), 
	'math_ceil' : NodeInstance('ShaderNodeMath', [0], [0], [('operation', 'CEIL')]), 
	'math_compare' : NodeInstance('ShaderNodeMath', [0, 1, 2], [0], [('operation', 'COMPARE')]), 
	'math_cosine' : NodeInstance('ShaderNodeMath', [0], [0], [('operation', 'COSINE')]), 
	'math_divide' : NodeInstance('ShaderNodeMath', [0, 1], [0], [('operation', 'DIVIDE')]), 
	'math_exponent' : NodeInstance('ShaderNodeMath', [0], [0], [('operation', 'EXPONENT')]), 
	'math_floor' : NodeInstance('ShaderNodeMath', [0], [0], [('operation', 'FLOOR')]), 
	'math_floored_modulo' : NodeInstance('ShaderNodeMath', [0, 1], [0], [('operation', 'FLOORED_MODULO')]), 
	'math_fraction' : NodeInstance('ShaderNodeMath', [0], [0], [('operation', 'FRACT')]), 
	'math_greater_than' : NodeInstance('ShaderNodeMath', [0, 1], [0], [('operation', 'GREATER_THAN')]), 
	'math_hyperbolic_cosine' : NodeInstance('ShaderNodeMath', [0], [0], [('operation', 'COSH')]), 
	'math_hyperbolic_sine' : NodeInstance('ShaderNodeMath', [0], [0], [('operation', 'SINH')]), 
	'math_hyperbolic_tangent' : NodeInstance('ShaderNodeMath', [0], [0], [('operation', 'TANH')]), 
	'math_inverse_square_root' : NodeInstance('ShaderNodeMath', [0], [0], [('operation', 'INVERSE_SQRT')]), 
	'math_less_than' : NodeInstance('ShaderNodeMath', [0, 1], [0], [('operation', 'LESS_THAN')]), 
	'math_logarithm' : NodeInstance('ShaderNodeMath', [0, 1], [0], [('operation', 'LOGARITHM')]), 
	'math_maximum' : NodeInstance('ShaderNodeMath', [0, 1], [0], [('operation', 'MAXIMUM')]), 
	'math_minimum' : NodeInstance('ShaderNodeMath', [0, 1], [0], [('operation', 'MINIMUM')]), 
	'math_multiply' : NodeInstance('ShaderNodeMath', [0, 1], [0], [('operation', 'MULTIPLY')]), 
	'math_multiply_add' : NodeInstance('ShaderNodeMath', [0, 1, 2], [0], [('operation', 'MULTIPLY_ADD')]), 
	'math_ping_pong' : NodeInstance('ShaderNodeMath', [0, 1], [0], [('operation', 'PINGPONG')]), 
	'math_power' : NodeInstance('ShaderNodeMath', [0, 1], [0], [('operation', 'POWER')]), 
	'math_round' : NodeInstance('ShaderNodeMath', [0], [0], [('operation', 'ROUND')]), 
	'math_sign' : NodeInstance('ShaderNodeMath', [0], [0], [('operation', 'SIGN')]), 
	'math_sine' : NodeInstance('ShaderNodeMath', [0], [0], [('operation', 'SINE')]), 
	'math_smooth_maximum' : NodeInstance('ShaderNodeMath', [0, 1, 2], [0], [('operation', 'SMOOTH_MAX')]), 
	'math_smooth_minimum' : NodeInstance('ShaderNodeMath', [0, 1, 2], [0], [('operation', 'SMOOTH_MIN')]), 
	'math_snap' : NodeInstance('ShaderNodeMath', [0, 1], [0], [('operation', 'SNAP')]), 
	'math_square_root' : NodeInstance('ShaderNodeMath', [0], [0], [('operation', 'SQRT')]), 
	'math_subtract' : NodeInstance('ShaderNodeMath', [0, 1], [0], [('operation', 'SUBTRACT')]), 
	'math_tangent' : NodeInstance('ShaderNodeMath', [0], [0], [('operation', 'TANGENT')]), 
	'math_to_degrees' : NodeInstance('ShaderNodeMath', [0], [0], [('operation', 'DEGREES')]), 
	'math_to_radians' : NodeInstance('ShaderNodeMath', [0], [0], [('operation', 'RADIANS')]), 
	'math_truncate' : NodeInstance('ShaderNodeMath', [0], [0], [('operation', 'TRUNC')]), 
	'math_truncated_modulo' : NodeInstance('ShaderNodeMath', [0, 1], [0], [('operation', 'MODULO')]), 
	'math_wrap' : NodeInstance('ShaderNodeMath', [0, 1, 2], [0], [('operation', 'WRAP')]), 
	'mix' : NodeInstance('ShaderNodeMix', [0, 2, 3], [0], []), 
	'mix_color_non_uniform_add' : NodeInstance('ShaderNodeMix', [0, 6, 7], [2], [('data_type', 'RGBA'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'ADD')]), 
	'mix_color_non_uniform_color' : NodeInstance('ShaderNodeMix', [0, 6, 7], [2], [('data_type', 'RGBA'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'COLOR')]), 
	'mix_color_non_uniform_color_burn' : NodeInstance('ShaderNodeMix', [0, 6, 7], [2], [('data_type', 'RGBA'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'BURN')]), 
	'mix_color_non_uniform_color_dodge' : NodeInstance('ShaderNodeMix', [0, 6, 7], [2], [('data_type', 'RGBA'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'DODGE')]), 
	'mix_color_non_uniform_darken' : NodeInstance('ShaderNodeMix', [0, 6, 7], [2], [('data_type', 'RGBA'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'DARKEN')]), 
	'mix_color_non_uniform_difference' : NodeInstance('ShaderNodeMix', [0, 6, 7], [2], [('data_type', 'RGBA'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'DIFFERENCE')]), 
	'mix_color_non_uniform_divide' : NodeInstance('ShaderNodeMix', [0, 6, 7], [2], [('data_type', 'RGBA'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'DIVIDE')]), 
	'mix_color_non_uniform_exclusion' : NodeInstance('ShaderNodeMix', [0, 6, 7], [2], [('data_type', 'RGBA'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'EXCLUSION')]), 
	'mix_color_non_uniform_hue' : NodeInstance('ShaderNodeMix', [0, 6, 7], [2], [('data_type', 'RGBA'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'HUE')]), 
	'mix_color_non_uniform_lighten' : NodeInstance('ShaderNodeMix', [0, 6, 7], [2], [('data_type', 'RGBA'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'LIGHTEN')]), 
	'mix_color_non_uniform_linear_light' : NodeInstance('ShaderNodeMix', [0, 6, 7], [2], [('data_type', 'RGBA'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'LINEAR_LIGHT')]), 
	'mix_color_non_uniform_mix' : NodeInstance('ShaderNodeMix', [0, 6, 7], [2], [('data_type', 'RGBA'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'MIX')]), 
	'mix_color_non_uniform_multiply' : NodeInstance('ShaderNodeMix', [0, 6, 7], [2], [('data_type', 'RGBA'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'MULTIPLY')]), 
	'mix_color_non_uniform_overlay' : NodeInstance('ShaderNodeMix', [0, 6, 7], [2], [('data_type', 'RGBA'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'OVERLAY')]), 
	'mix_color_non_uniform_saturation' : NodeInstance('ShaderNodeMix', [0, 6, 7], [2], [('data_type', 'RGBA'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'SATURATION')]), 
	'mix_color_non_uniform_screen' : NodeInstance('ShaderNodeMix', [0, 6, 7], [2], [('data_type', 'RGBA'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'SCREEN')]), 
	'mix_color_non_uniform_soft_light' : NodeInstance('ShaderNodeMix', [0, 6, 7], [2], [('data_type', 'RGBA'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'SOFT_LIGHT')]), 
	'mix_color_non_uniform_subtract' : NodeInstance('ShaderNodeMix', [0, 6, 7], [2], [('data_type', 'RGBA'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'SUBTRACT')]), 
	'mix_color_non_uniform_value' : NodeInstance('ShaderNodeMix', [0, 6, 7], [2], [('data_type', 'RGBA'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'VALUE')]), 
	'mix_color_uniform_add' : NodeInstance('ShaderNodeMix', [0, 6, 7], [2], [('data_type', 'RGBA'), ('factor_mode', 'UNIFORM'), ('blend_type', 'ADD')]), 
	'mix_color_uniform_color' : NodeInstance('ShaderNodeMix', [0, 6, 7], [2], [('data_type', 'RGBA'), ('factor_mode', 'UNIFORM'), ('blend_type', 'COLOR')]), 
	'mix_color_uniform_color_burn' : NodeInstance('ShaderNodeMix', [0, 6, 7], [2], [('data_type', 'RGBA'), ('factor_mode', 'UNIFORM'), ('blend_type', 'BURN')]), 
	'mix_color_uniform_color_dodge' : NodeInstance('ShaderNodeMix', [0, 6, 7], [2], [('data_type', 'RGBA'), ('factor_mode', 'UNIFORM'), ('blend_type', 'DODGE')]), 
	'mix_color_uniform_darken' : NodeInstance('ShaderNodeMix', [0, 6, 7], [2], [('data_type', 'RGBA'), ('factor_mode', 'UNIFORM'), ('blend_type', 'DARKEN')]), 
	'mix_color_uniform_difference' : NodeInstance('ShaderNodeMix', [0, 6, 7], [2], [('data_type', 'RGBA'), ('factor_mode', 'UNIFORM'), ('blend_type', 'DIFFERENCE')]), 
	'mix_color_uniform_divide' : NodeInstance('ShaderNodeMix', [0, 6, 7], [2], [('data_type', 'RGBA'), ('factor_mode', 'UNIFORM'), ('blend_type', 'DIVIDE')]), 
	'mix_color_uniform_exclusion' : NodeInstance('ShaderNodeMix', [0, 6, 7], [2], [('data_type', 'RGBA'), ('factor_mode', 'UNIFORM'), ('blend_type', 'EXCLUSION')]), 
	'mix_color_uniform_hue' : NodeInstance('ShaderNodeMix', [0, 6, 7], [2], [('data_type', 'RGBA'), ('factor_mode', 'UNIFORM'), ('blend_type', 'HUE')]), 
	'mix_color_uniform_lighten' : NodeInstance('ShaderNodeMix', [0, 6, 7], [2], [('data_type', 'RGBA'), ('factor_mode', 'UNIFORM'), ('blend_type', 'LIGHTEN')]), 
	'mix_color_uniform_linear_light' : NodeInstance('ShaderNodeMix', [0, 6, 7], [2], [('data_type', 'RGBA'), ('factor_mode', 'UNIFORM'), ('blend_type', 'LINEAR_LIGHT')]), 
	'mix_color_uniform_mix' : NodeInstance('ShaderNodeMix', [0, 6, 7], [2], [('data_type', 'RGBA'), ('factor_mode', 'UNIFORM'), ('blend_type', 'MIX')]), 
	'mix_color_uniform_multiply' : NodeInstance('ShaderNodeMix', [0, 6, 7], [2], [('data_type', 'RGBA'), ('factor_mode', 'UNIFORM'), ('blend_type', 'MULTIPLY')]), 
	'mix_color_uniform_overlay' : NodeInstance('ShaderNodeMix', [0, 6, 7], [2], [('data_type', 'RGBA'), ('factor_mode', 'UNIFORM'), ('blend_type', 'OVERLAY')]), 
	'mix_color_uniform_saturation' : NodeInstance('ShaderNodeMix', [0, 6, 7], [2], [('data_type', 'RGBA'), ('factor_mode', 'UNIFORM'), ('blend_type', 'SATURATION')]), 
	'mix_color_uniform_screen' : NodeInstance('ShaderNodeMix', [0, 6, 7], [2], [('data_type', 'RGBA'), ('factor_mode', 'UNIFORM'), ('blend_type', 'SCREEN')]), 
	'mix_color_uniform_soft_light' : NodeInstance('ShaderNodeMix', [0, 6, 7], [2], [('data_type', 'RGBA'), ('factor_mode', 'UNIFORM'), ('blend_type', 'SOFT_LIGHT')]), 
	'mix_color_uniform_subtract' : NodeInstance('ShaderNodeMix', [0, 6, 7], [2], [('data_type', 'RGBA'), ('factor_mode', 'UNIFORM'), ('blend_type', 'SUBTRACT')]), 
	'mix_color_uniform_value' : NodeInstance('ShaderNodeMix', [0, 6, 7], [2], [('data_type', 'RGBA'), ('factor_mode', 'UNIFORM'), ('blend_type', 'VALUE')]), 
	'mix_float_non_uniform_add' : NodeInstance('ShaderNodeMix', [0, 2, 3], [0], [('data_type', 'FLOAT'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'ADD')]), 
	'mix_float_non_uniform_color' : NodeInstance('ShaderNodeMix', [0, 2, 3], [0], [('data_type', 'FLOAT'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'COLOR')]), 
	'mix_float_non_uniform_color_burn' : NodeInstance('ShaderNodeMix', [0, 2, 3], [0], [('data_type', 'FLOAT'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'BURN')]), 
	'mix_float_non_uniform_color_dodge' : NodeInstance('ShaderNodeMix', [0, 2, 3], [0], [('data_type', 'FLOAT'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'DODGE')]), 
	'mix_float_non_uniform_darken' : NodeInstance('ShaderNodeMix', [0, 2, 3], [0], [('data_type', 'FLOAT'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'DARKEN')]), 
	'mix_float_non_uniform_difference' : NodeInstance('ShaderNodeMix', [0, 2, 3], [0], [('data_type', 'FLOAT'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'DIFFERENCE')]), 
	'mix_float_non_uniform_divide' : NodeInstance('ShaderNodeMix', [0, 2, 3], [0], [('data_type', 'FLOAT'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'DIVIDE')]), 
	'mix_float_non_uniform_exclusion' : NodeInstance('ShaderNodeMix', [0, 2, 3], [0], [('data_type', 'FLOAT'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'EXCLUSION')]), 
	'mix_float_non_uniform_hue' : NodeInstance('ShaderNodeMix', [0, 2, 3], [0], [('data_type', 'FLOAT'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'HUE')]), 
	'mix_float_non_uniform_lighten' : NodeInstance('ShaderNodeMix', [0, 2, 3], [0], [('data_type', 'FLOAT'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'LIGHTEN')]), 
	'mix_float_non_uniform_linear_light' : NodeInstance('ShaderNodeMix', [0, 2, 3], [0], [('data_type', 'FLOAT'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'LINEAR_LIGHT')]), 
	'mix_float_non_uniform_mix' : NodeInstance('ShaderNodeMix', [0, 2, 3], [0], [('data_type', 'FLOAT'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'MIX')]), 
	'mix_float_non_uniform_multiply' : NodeInstance('ShaderNodeMix', [0, 2, 3], [0], [('data_type', 'FLOAT'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'MULTIPLY')]), 
	'mix_float_non_uniform_overlay' : NodeInstance('ShaderNodeMix', [0, 2, 3], [0], [('data_type', 'FLOAT'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'OVERLAY')]), 
	'mix_float_non_uniform_saturation' : NodeInstance('ShaderNodeMix', [0, 2, 3], [0], [('data_type', 'FLOAT'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'SATURATION')]), 
	'mix_float_non_uniform_screen' : NodeInstance('ShaderNodeMix', [0, 2, 3], [0], [('data_type', 'FLOAT'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'SCREEN')]), 
	'mix_float_non_uniform_soft_light' : NodeInstance('ShaderNodeMix', [0, 2, 3], [0], [('data_type', 'FLOAT'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'SOFT_LIGHT')]), 
	'mix_float_non_uniform_subtract' : NodeInstance('ShaderNodeMix', [0, 2, 3], [0], [('data_type', 'FLOAT'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'SUBTRACT')]), 
	'mix_float_non_uniform_value' : NodeInstance('ShaderNodeMix', [0, 2, 3], [0], [('data_type', 'FLOAT'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'VALUE')]), 
	'mix_float_uniform_add' : NodeInstance('ShaderNodeMix', [0, 2, 3], [0], [('data_type', 'FLOAT'), ('factor_mode', 'UNIFORM'), ('blend_type', 'ADD')]), 
	'mix_float_uniform_color' : NodeInstance('ShaderNodeMix', [0, 2, 3], [0], [('data_type', 'FLOAT'), ('factor_mode', 'UNIFORM'), ('blend_type', 'COLOR')]), 
	'mix_float_uniform_color_burn' : NodeInstance('ShaderNodeMix', [0, 2, 3], [0], [('data_type', 'FLOAT'), ('factor_mode', 'UNIFORM'), ('blend_type', 'BURN')]), 
	'mix_float_uniform_color_dodge' : NodeInstance('ShaderNodeMix', [0, 2, 3], [0], [('data_type', 'FLOAT'), ('factor_mode', 'UNIFORM'), ('blend_type', 'DODGE')]), 
	'mix_float_uniform_darken' : NodeInstance('ShaderNodeMix', [0, 2, 3], [0], [('data_type', 'FLOAT'), ('factor_mode', 'UNIFORM'), ('blend_type', 'DARKEN')]), 
	'mix_float_uniform_difference' : NodeInstance('ShaderNodeMix', [0, 2, 3], [0], [('data_type', 'FLOAT'), ('factor_mode', 'UNIFORM'), ('blend_type', 'DIFFERENCE')]), 
	'mix_float_uniform_divide' : NodeInstance('ShaderNodeMix', [0, 2, 3], [0], [('data_type', 'FLOAT'), ('factor_mode', 'UNIFORM'), ('blend_type', 'DIVIDE')]), 
	'mix_float_uniform_exclusion' : NodeInstance('ShaderNodeMix', [0, 2, 3], [0], [('data_type', 'FLOAT'), ('factor_mode', 'UNIFORM'), ('blend_type', 'EXCLUSION')]), 
	'mix_float_uniform_hue' : NodeInstance('ShaderNodeMix', [0, 2, 3], [0], [('data_type', 'FLOAT'), ('factor_mode', 'UNIFORM'), ('blend_type', 'HUE')]), 
	'mix_float_uniform_lighten' : NodeInstance('ShaderNodeMix', [0, 2, 3], [0], [('data_type', 'FLOAT'), ('factor_mode', 'UNIFORM'), ('blend_type', 'LIGHTEN')]), 
	'mix_float_uniform_linear_light' : NodeInstance('ShaderNodeMix', [0, 2, 3], [0], [('data_type', 'FLOAT'), ('factor_mode', 'UNIFORM'), ('blend_type', 'LINEAR_LIGHT')]), 
	'mix_float_uniform_mix' : NodeInstance('ShaderNodeMix', [0, 2, 3], [0], [('data_type', 'FLOAT'), ('factor_mode', 'UNIFORM'), ('blend_type', 'MIX')]), 
	'mix_float_uniform_multiply' : NodeInstance('ShaderNodeMix', [0, 2, 3], [0], [('data_type', 'FLOAT'), ('factor_mode', 'UNIFORM'), ('blend_type', 'MULTIPLY')]), 
	'mix_float_uniform_overlay' : NodeInstance('ShaderNodeMix', [0, 2, 3], [0], [('data_type', 'FLOAT'), ('factor_mode', 'UNIFORM'), ('blend_type', 'OVERLAY')]), 
	'mix_float_uniform_saturation' : NodeInstance('ShaderNodeMix', [0, 2, 3], [0], [('data_type', 'FLOAT'), ('factor_mode', 'UNIFORM'), ('blend_type', 'SATURATION')]), 
	'mix_float_uniform_screen' : NodeInstance('ShaderNodeMix', [0, 2, 3], [0], [('data_type', 'FLOAT'), ('factor_mode', 'UNIFORM'), ('blend_type', 'SCREEN')]), 
	'mix_float_uniform_soft_light' : NodeInstance('ShaderNodeMix', [0, 2, 3], [0], [('data_type', 'FLOAT'), ('factor_mode', 'UNIFORM'), ('blend_type', 'SOFT_LIGHT')]), 
	'mix_float_uniform_subtract' : NodeInstance('ShaderNodeMix', [0, 2, 3], [0], [('data_type', 'FLOAT'), ('factor_mode', 'UNIFORM'), ('blend_type', 'SUBTRACT')]), 
	'mix_float_uniform_value' : NodeInstance('ShaderNodeMix', [0, 2, 3], [0], [('data_type', 'FLOAT'), ('factor_mode', 'UNIFORM'), ('blend_type', 'VALUE')]), 
	'mix_vector_non_uniform_add' : NodeInstance('ShaderNodeMix', [1, 4, 5], [1], [('data_type', 'VECTOR'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'ADD')]), 
	'mix_vector_non_uniform_color' : NodeInstance('ShaderNodeMix', [1, 4, 5], [1], [('data_type', 'VECTOR'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'COLOR')]), 
	'mix_vector_non_uniform_color_burn' : NodeInstance('ShaderNodeMix', [1, 4, 5], [1], [('data_type', 'VECTOR'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'BURN')]), 
	'mix_vector_non_uniform_color_dodge' : NodeInstance('ShaderNodeMix', [1, 4, 5], [1], [('data_type', 'VECTOR'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'DODGE')]), 
	'mix_vector_non_uniform_darken' : NodeInstance('ShaderNodeMix', [1, 4, 5], [1], [('data_type', 'VECTOR'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'DARKEN')]), 
	'mix_vector_non_uniform_difference' : NodeInstance('ShaderNodeMix', [1, 4, 5], [1], [('data_type', 'VECTOR'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'DIFFERENCE')]), 
	'mix_vector_non_uniform_divide' : NodeInstance('ShaderNodeMix', [1, 4, 5], [1], [('data_type', 'VECTOR'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'DIVIDE')]), 
	'mix_vector_non_uniform_exclusion' : NodeInstance('ShaderNodeMix', [1, 4, 5], [1], [('data_type', 'VECTOR'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'EXCLUSION')]), 
	'mix_vector_non_uniform_hue' : NodeInstance('ShaderNodeMix', [1, 4, 5], [1], [('data_type', 'VECTOR'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'HUE')]), 
	'mix_vector_non_uniform_lighten' : NodeInstance('ShaderNodeMix', [1, 4, 5], [1], [('data_type', 'VECTOR'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'LIGHTEN')]), 
	'mix_vector_non_uniform_linear_light' : NodeInstance('ShaderNodeMix', [1, 4, 5], [1], [('data_type', 'VECTOR'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'LINEAR_LIGHT')]), 
	'mix_vector_non_uniform_mix' : NodeInstance('ShaderNodeMix', [1, 4, 5], [1], [('data_type', 'VECTOR'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'MIX')]), 
	'mix_vector_non_uniform_multiply' : NodeInstance('ShaderNodeMix', [1, 4, 5], [1], [('data_type', 'VECTOR'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'MULTIPLY')]), 
	'mix_vector_non_uniform_overlay' : NodeInstance('ShaderNodeMix', [1, 4, 5], [1], [('data_type', 'VECTOR'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'OVERLAY')]), 
	'mix_vector_non_uniform_saturation' : NodeInstance('ShaderNodeMix', [1, 4, 5], [1], [('data_type', 'VECTOR'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'SATURATION')]), 
	'mix_vector_non_uniform_screen' : NodeInstance('ShaderNodeMix', [1, 4, 5], [1], [('data_type', 'VECTOR'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'SCREEN')]), 
	'mix_vector_non_uniform_soft_light' : NodeInstance('ShaderNodeMix', [1, 4, 5], [1], [('data_type', 'VECTOR'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'SOFT_LIGHT')]), 
	'mix_vector_non_uniform_subtract' : NodeInstance('ShaderNodeMix', [1, 4, 5], [1], [('data_type', 'VECTOR'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'SUBTRACT')]), 
	'mix_vector_non_uniform_value' : NodeInstance('ShaderNodeMix', [1, 4, 5], [1], [('data_type', 'VECTOR'), ('factor_mode', 'NON_UNIFORM'), ('blend_type', 'VALUE')]), 
	'mix_vector_uniform_add' : NodeInstance('ShaderNodeMix', [0, 4, 5], [1], [('data_type', 'VECTOR'), ('factor_mode', 'UNIFORM'), ('blend_type', 'ADD')]), 
	'mix_vector_uniform_color' : NodeInstance('ShaderNodeMix', [0, 4, 5], [1], [('data_type', 'VECTOR'), ('factor_mode', 'UNIFORM'), ('blend_type', 'COLOR')]), 
	'mix_vector_uniform_color_burn' : NodeInstance('ShaderNodeMix', [0, 4, 5], [1], [('data_type', 'VECTOR'), ('factor_mode', 'UNIFORM'), ('blend_type', 'BURN')]), 
	'mix_vector_uniform_color_dodge' : NodeInstance('ShaderNodeMix', [0, 4, 5], [1], [('data_type', 'VECTOR'), ('factor_mode', 'UNIFORM'), ('blend_type', 'DODGE')]), 
	'mix_vector_uniform_darken' : NodeInstance('ShaderNodeMix', [0, 4, 5], [1], [('data_type', 'VECTOR'), ('factor_mode', 'UNIFORM'), ('blend_type', 'DARKEN')]), 
	'mix_vector_uniform_difference' : NodeInstance('ShaderNodeMix', [0, 4, 5], [1], [('data_type', 'VECTOR'), ('factor_mode', 'UNIFORM'), ('blend_type', 'DIFFERENCE')]), 
	'mix_vector_uniform_divide' : NodeInstance('ShaderNodeMix', [0, 4, 5], [1], [('data_type', 'VECTOR'), ('factor_mode', 'UNIFORM'), ('blend_type', 'DIVIDE')]), 
	'mix_vector_uniform_exclusion' : NodeInstance('ShaderNodeMix', [0, 4, 5], [1], [('data_type', 'VECTOR'), ('factor_mode', 'UNIFORM'), ('blend_type', 'EXCLUSION')]), 
	'mix_vector_uniform_hue' : NodeInstance('ShaderNodeMix', [0, 4, 5], [1], [('data_type', 'VECTOR'), ('factor_mode', 'UNIFORM'), ('blend_type', 'HUE')]), 
	'mix_vector_uniform_lighten' : NodeInstance('ShaderNodeMix', [0, 4, 5], [1], [('data_type', 'VECTOR'), ('factor_mode', 'UNIFORM'), ('blend_type', 'LIGHTEN')]), 
	'mix_vector_uniform_linear_light' : NodeInstance('ShaderNodeMix', [0, 4, 5], [1], [('data_type', 'VECTOR'), ('factor_mode', 'UNIFORM'), ('blend_type', 'LINEAR_LIGHT')]), 
	'mix_vector_uniform_mix' : NodeInstance('ShaderNodeMix', [0, 4, 5], [1], [('data_type', 'VECTOR'), ('factor_mode', 'UNIFORM'), ('blend_type', 'MIX')]), 
	'mix_vector_uniform_multiply' : NodeInstance('ShaderNodeMix', [0, 4, 5], [1], [('data_type', 'VECTOR'), ('factor_mode', 'UNIFORM'), ('blend_type', 'MULTIPLY')]), 
	'mix_vector_uniform_overlay' : NodeInstance('ShaderNodeMix', [0, 4, 5], [1], [('data_type', 'VECTOR'), ('factor_mode', 'UNIFORM'), ('blend_type', 'OVERLAY')]), 
	'mix_vector_uniform_saturation' : NodeInstance('ShaderNodeMix', [0, 4, 5], [1], [('data_type', 'VECTOR'), ('factor_mode', 'UNIFORM'), ('blend_type', 'SATURATION')]), 
	'mix_vector_uniform_screen' : NodeInstance('ShaderNodeMix', [0, 4, 5], [1], [('data_type', 'VECTOR'), ('factor_mode', 'UNIFORM'), ('blend_type', 'SCREEN')]), 
	'mix_vector_uniform_soft_light' : NodeInstance('ShaderNodeMix', [0, 4, 5], [1], [('data_type', 'VECTOR'), ('factor_mode', 'UNIFORM'), ('blend_type', 'SOFT_LIGHT')]), 
	'mix_vector_uniform_subtract' : NodeInstance('ShaderNodeMix', [0, 4, 5], [1], [('data_type', 'VECTOR'), ('factor_mode', 'UNIFORM'), ('blend_type', 'SUBTRACT')]), 
	'mix_vector_uniform_value' : NodeInstance('ShaderNodeMix', [0, 4, 5], [1], [('data_type', 'VECTOR'), ('factor_mode', 'UNIFORM'), ('blend_type', 'VALUE')]), 
	'noise_texture' : NodeInstance('ShaderNodeTexNoise', [0, 2, 3, 4, 5, 8], [0, 1], []), 
	'noise_texture_1d_fbm' : NodeInstance('ShaderNodeTexNoise', [1, 2, 3, 4, 5, 8], [0, 1], [('noise_dimensions', '1D'), ('noise_type', 'FBM')]), 
	'noise_texture_1d_hetero_terrain' : NodeInstance('ShaderNodeTexNoise', [1, 2, 3, 4, 5, 6, 8], [0, 1], [('noise_dimensions', '1D'), ('noise_type', 'HETERO_TERRAIN')]), 
	'noise_texture_1d_hybrid_multifractal' : NodeInstance('ShaderNodeTexNoise', [1, 2, 3, 4, 5, 6, 7, 8], [0, 1], [('noise_dimensions', '1D'), ('noise_type', 'HYBRID_MULTIFRACTAL')]), 
	'noise_texture_1d_multifractal' : NodeInstance('ShaderNodeTexNoise', [1, 2, 3, 4, 5, 8], [0, 1], [('noise_dimensions', '1D'), ('noise_type', 'MULTIFRACTAL')]), 
	'noise_texture_1d_ridged_multifractal' : NodeInstance('ShaderNodeTexNoise', [1, 2, 3, 4, 5, 6, 7, 8], [0, 1], [('noise_dimensions', '1D'), ('noise_type', 'RIDGED_MULTIFRACTAL')]), 
	'noise_texture_2d_fbm' : NodeInstance('ShaderNodeTexNoise', [0, 2, 3, 4, 5, 8], [0, 1], [('noise_dimensions', '2D'), ('noise_type', 'FBM')]), 
	'noise_texture_2d_hetero_terrain' : NodeInstance('ShaderNodeTexNoise', [0, 2, 3, 4, 5, 6, 8], [0, 1], [('noise_dimensions', '2D'), ('noise_type', 'HETERO_TERRAIN')]), 
	'noise_texture_2d_hybrid_multifractal' : NodeInstance('ShaderNodeTexNoise', [0, 2, 3, 4, 5, 6, 7, 8], [0, 1], [('noise_dimensions', '2D'), ('noise_type', 'HYBRID_MULTIFRACTAL')]), 
	'noise_texture_2d_multifractal' : NodeInstance('ShaderNodeTexNoise', [0, 2, 3, 4, 5, 8], [0, 1], [('noise_dimensions', '2D'), ('noise_type', 'MULTIFRACTAL')]), 
	'noise_texture_2d_ridged_multifractal' : NodeInstance('ShaderNodeTexNoise', [0, 2, 3, 4, 5, 6, 7, 8], [0, 1], [('noise_dimensions', '2D'), ('noise_type', 'RIDGED_MULTIFRACTAL')]), 
	'noise_texture_3d_fbm' : NodeInstance('ShaderNodeTexNoise', [0, 2, 3, 4, 5, 8], [0, 1], [('noise_dimensions', '3D'), ('noise_type', 'FBM')]), 
	'noise_texture_3d_hetero_terrain' : NodeInstance('ShaderNodeTexNoise', [0, 2, 3, 4, 5, 6, 8], [0, 1], [('noise_dimensions', '3D'), ('noise_type', 'HETERO_TERRAIN')]), 
	'noise_texture_3d_hybrid_multifractal' : NodeInstance('ShaderNodeTexNoise', [0, 2, 3, 4, 5, 6, 7, 8], [0, 1], [('noise_dimensions', '3D'), ('noise_type', 'HYBRID_MULTIFRACTAL')]), 
	'noise_texture_3d_multifractal' : NodeInstance('ShaderNodeTexNoise', [0, 2, 3, 4, 5, 8], [0, 1], [('noise_dimensions', '3D'), ('noise_type', 'MULTIFRACTAL')]), 
	'noise_texture_3d_ridged_multifractal' : NodeInstance('ShaderNodeTexNoise', [0, 2, 3, 4, 5, 6, 7, 8], [0, 1], [('noise_dimensions', '3D'), ('noise_type', 'RIDGED_MULTIFRACTAL')]), 
	'noise_texture_4d_fbm' : NodeInstance('ShaderNodeTexNoise', [0, 1, 2, 3, 4, 5, 8], [0, 1], [('noise_dimensions', '4D'), ('noise_type', 'FBM')]), 
	'noise_texture_4d_hetero_terrain' : NodeInstance('ShaderNodeTexNoise', [0, 1, 2, 3, 4, 5, 6, 8], [0, 1], [('noise_dimensions', '4D'), ('noise_type', 'HETERO_TERRAIN')]), 
	'noise_texture_4d_hybrid_multifractal' : NodeInstance('ShaderNodeTexNoise', [0, 1, 2, 3, 4, 5, 6, 7, 8], [0, 1], [('noise_dimensions', '4D'), ('noise_type', 'HYBRID_MULTIFRACTAL')]), 
	'noise_texture_4d_multifractal' : NodeInstance('ShaderNodeTexNoise', [0, 1, 2, 3, 4, 5, 8], [0, 1], [('noise_dimensions', '4D'), ('noise_type', 'MULTIFRACTAL')]), 
	'noise_texture_4d_ridged_multifractal' : NodeInstance('ShaderNodeTexNoise', [0, 1, 2, 3, 4, 5, 6, 7, 8], [0, 1], [('noise_dimensions', '4D'), ('noise_type', 'RIDGED_MULTIFRACTAL')]), 
	'rgb_curves' : NodeInstance('ShaderNodeRGBCurve', [0, 1], [0], []), 
	'separate_xyz' : NodeInstance('ShaderNodeSeparateXYZ', [0], [0, 1, 2], []), 
	'value' : NodeInstance('ShaderNodeValue', [], [0], []), 
	'vector_curves' : NodeInstance('ShaderNodeVectorCurve', [0, 1], [0], []), 
	'vector_math' : NodeInstance('ShaderNodeVectorMath', [0, 1], [0], []), 
	'vector_math_absolute' : NodeInstance('ShaderNodeVectorMath', [0], [0], [('operation', 'ABSOLUTE')]), 
	'vector_math_add' : NodeInstance('ShaderNodeVectorMath', [0, 1], [0], [('operation', 'ADD')]), 
	'vector_math_ceil' : NodeInstance('ShaderNodeVectorMath', [0], [0], [('operation', 'CEIL')]), 
	'vector_math_cosine' : NodeInstance('ShaderNodeVectorMath', [0], [0], [('operation', 'COSINE')]), 
	'vector_math_cross_product' : NodeInstance('ShaderNodeVectorMath', [0, 1], [0], [('operation', 'CROSS_PRODUCT')]), 
	'vector_math_distance' : NodeInstance('ShaderNodeVectorMath', [0, 1], [1], [('operation', 'DISTANCE')]), 
	'vector_math_divide' : NodeInstance('ShaderNodeVectorMath', [0, 1], [0], [('operation', 'DIVIDE')]), 
	'vector_math_dot_product' : NodeInstance('ShaderNodeVectorMath', [0, 1], [1], [('operation', 'DOT_PRODUCT')]), 
	'vector_math_faceforward' : NodeInstance('ShaderNodeVectorMath', [0, 1, 2], [0], [('operation', 'FACEFORWARD')]), 
	'vector_math_floor' : NodeInstance('ShaderNodeVectorMath', [0], [0], [('operation', 'FLOOR')]), 
	'vector_math_fraction' : NodeInstance('ShaderNodeVectorMath', [0], [0], [('operation', 'FRACTION')]), 
	'vector_math_length' : NodeInstance('ShaderNodeVectorMath', [0], [1], [('operation', 'LENGTH')]), 
	'vector_math_maximum' : NodeInstance('ShaderNodeVectorMath', [0, 1], [0], [('operation', 'MAXIMUM')]), 
	'vector_math_minimum' : NodeInstance('ShaderNodeVectorMath', [0, 1], [0], [('operation', 'MINIMUM')]), 
	'vector_math_modulo' : NodeInstance('ShaderNodeVectorMath', [0, 1], [0], [('operation', 'MODULO')]), 
	'vector_math_multiply' : NodeInstance('ShaderNodeVectorMath', [0, 1], [0], [('operation', 'MULTIPLY')]), 
	'vector_math_multiply_add' : NodeInstance('ShaderNodeVectorMath', [0, 1, 2], [0], [('operation', 'MULTIPLY_ADD')]), 
	'vector_math_normalize' : NodeInstance('ShaderNodeVectorMath', [0], [0], [('operation', 'NORMALIZE')]), 
	'vector_math_project' : NodeInstance('ShaderNodeVectorMath', [0, 1], [0], [('operation', 'PROJECT')]), 
	'vector_math_reflect' : NodeInstance('ShaderNodeVectorMath', [0, 1], [0], [('operation', 'REFLECT')]), 
	'vector_math_refract' : NodeInstance('ShaderNodeVectorMath', [0, 1, 3], [0], [('operation', 'REFRACT')]), 
	'vector_math_scale' : NodeInstance('ShaderNodeVectorMath', [0, 3], [0], [('operation', 'SCALE')]), 
	'vector_math_sine' : NodeInstance('ShaderNodeVectorMath', [0], [0], [('operation', 'SINE')]), 
	'vector_math_snap' : NodeInstance('ShaderNodeVectorMath', [0, 1], [0], [('operation', 'SNAP')]), 
	'vector_math_subtract' : NodeInstance('ShaderNodeVectorMath', [0, 1], [0], [('operation', 'SUBTRACT')]), 
	'vector_math_tangent' : NodeInstance('ShaderNodeVectorMath', [0], [0], [('operation', 'TANGENT')]), 
	'vector_math_wrap' : NodeInstance('ShaderNodeVectorMath', [0, 1, 2], [0], [('operation', 'WRAP')]), 
	'vector_rotate' : NodeInstance('ShaderNodeVectorRotate', [0, 1, 2, 3], [0], []), 
	'vector_rotate_axis_angle' : NodeInstance('ShaderNodeVectorRotate', [0, 1, 2, 3], [0], [('rotation_type', 'AXIS_ANGLE')]), 
	'vector_rotate_euler' : NodeInstance('ShaderNodeVectorRotate', [0, 1, 4], [0], [('rotation_type', 'EULER_XYZ')]), 
	'vector_rotate_x_axis' : NodeInstance('ShaderNodeVectorRotate', [0, 1, 3], [0], [('rotation_type', 'X_AXIS')]), 
	'vector_rotate_y_axis' : NodeInstance('ShaderNodeVectorRotate', [0, 1, 3], [0], [('rotation_type', 'Y_AXIS')]), 
	'vector_rotate_z_axis' : NodeInstance('ShaderNodeVectorRotate', [0, 1, 3], [0], [('rotation_type', 'Z_AXIS')]), 
	'voronoi_texture' : NodeInstance('ShaderNodeTexVoronoi', [0, 2, 3, 4, 5, 8], [0, 1, 2], []), 
	'voronoi_texture_1d_chebychev_distance_to_edge' : NodeInstance('ShaderNodeTexVoronoi', [1, 2, 3, 4, 5, 8], [0], [('voronoi_dimensions', '1D'), ('distance', 'CHEBYCHEV'), ('feature', 'DISTANCE_TO_EDGE')]), 
	'voronoi_texture_1d_chebychev_f1' : NodeInstance('ShaderNodeTexVoronoi', [1, 2, 3, 4, 5, 8], [0, 1, 3], [('voronoi_dimensions', '1D'), ('distance', 'CHEBYCHEV'), ('feature', 'F1')]), 
	'voronoi_texture_1d_chebychev_f2' : NodeInstance('ShaderNodeTexVoronoi', [1, 2, 3, 4, 5, 8], [0, 1, 3], [('voronoi_dimensions', '1D'), ('distance', 'CHEBYCHEV'), ('feature', 'F2')]), 
	'voronoi_texture_1d_chebychev_n_sphere_radius' : NodeInstance('ShaderNodeTexVoronoi', [1, 2, 8], [4], [('voronoi_dimensions', '1D'), ('distance', 'CHEBYCHEV'), ('feature', 'N_SPHERE_RADIUS')]), 
	'voronoi_texture_1d_chebychev_smooth_f1' : NodeInstance('ShaderNodeTexVoronoi', [1, 2, 3, 4, 5, 6, 8], [0, 1, 3], [('voronoi_dimensions', '1D'), ('distance', 'CHEBYCHEV'), ('feature', 'SMOOTH_F1')]), 
	'voronoi_texture_1d_euclidean_distance_to_edge' : NodeInstance('ShaderNodeTexVoronoi', [1, 2, 3, 4, 5, 8], [0], [('voronoi_dimensions', '1D'), ('distance', 'EUCLIDEAN'), ('feature', 'DISTANCE_TO_EDGE')]), 
	'voronoi_texture_1d_euclidean_f1' : NodeInstance('ShaderNodeTexVoronoi', [1, 2, 3, 4, 5, 8], [0, 1, 3], [('voronoi_dimensions', '1D'), ('distance', 'EUCLIDEAN'), ('feature', 'F1')]), 
	'voronoi_texture_1d_euclidean_f2' : NodeInstance('ShaderNodeTexVoronoi', [1, 2, 3, 4, 5, 8], [0, 1, 3], [('voronoi_dimensions', '1D'), ('distance', 'EUCLIDEAN'), ('feature', 'F2')]), 
	'voronoi_texture_1d_euclidean_n_sphere_radius' : NodeInstance('ShaderNodeTexVoronoi', [1, 2, 8], [4], [('voronoi_dimensions', '1D'), ('distance', 'EUCLIDEAN'), ('feature', 'N_SPHERE_RADIUS')]), 
	'voronoi_texture_1d_euclidean_smooth_f1' : NodeInstance('ShaderNodeTexVoronoi', [1, 2, 3, 4, 5, 6, 8], [0, 1, 3], [('voronoi_dimensions', '1D'), ('distance', 'EUCLIDEAN'), ('feature', 'SMOOTH_F1')]), 
	'voronoi_texture_1d_manhattan_distance_to_edge' : NodeInstance('ShaderNodeTexVoronoi', [1, 2, 3, 4, 5, 8], [0], [('voronoi_dimensions', '1D'), ('distance', 'MANHATTAN'), ('feature', 'DISTANCE_TO_EDGE')]), 
	'voronoi_texture_1d_manhattan_f1' : NodeInstance('ShaderNodeTexVoronoi', [1, 2, 3, 4, 5, 8], [0, 1, 3], [('voronoi_dimensions', '1D'), ('distance', 'MANHATTAN'), ('feature', 'F1')]), 
	'voronoi_texture_1d_manhattan_f2' : NodeInstance('ShaderNodeTexVoronoi', [1, 2, 3, 4, 5, 8], [0, 1, 3], [('voronoi_dimensions', '1D'), ('distance', 'MANHATTAN'), ('feature', 'F2')]), 
	'voronoi_texture_1d_manhattan_n_sphere_radius' : NodeInstance('ShaderNodeTexVoronoi', [1, 2, 8], [4], [('voronoi_dimensions', '1D'), ('distance', 'MANHATTAN'), ('feature', 'N_SPHERE_RADIUS')]), 
	'voronoi_texture_1d_manhattan_smooth_f1' : NodeInstance('ShaderNodeTexVoronoi', [1, 2, 3, 4, 5, 6, 8], [0, 1, 3], [('voronoi_dimensions', '1D'), ('distance', 'MANHATTAN'), ('feature', 'SMOOTH_F1')]), 
	'voronoi_texture_1d_minkowski_distance_to_edge' : NodeInstance('ShaderNodeTexVoronoi', [1, 2, 3, 4, 5, 8], [0], [('voronoi_dimensions', '1D'), ('distance', 'MINKOWSKI'), ('feature', 'DISTANCE_TO_EDGE')]), 
	'voronoi_texture_1d_minkowski_f1' : NodeInstance('ShaderNodeTexVoronoi', [1, 2, 3, 4, 5, 8], [0, 1, 3], [('voronoi_dimensions', '1D'), ('distance', 'MINKOWSKI'), ('feature', 'F1')]), 
	'voronoi_texture_1d_minkowski_f2' : NodeInstance('ShaderNodeTexVoronoi', [1, 2, 3, 4, 5, 8], [0, 1, 3], [('voronoi_dimensions', '1D'), ('distance', 'MINKOWSKI'), ('feature', 'F2')]), 
	'voronoi_texture_1d_minkowski_n_sphere_radius' : NodeInstance('ShaderNodeTexVoronoi', [1, 2, 8], [4], [('voronoi_dimensions', '1D'), ('distance', 'MINKOWSKI'), ('feature', 'N_SPHERE_RADIUS')]), 
	'voronoi_texture_1d_minkowski_smooth_f1' : NodeInstance('ShaderNodeTexVoronoi', [1, 2, 3, 4, 5, 6, 8], [0, 1, 3], [('voronoi_dimensions', '1D'), ('distance', 'MINKOWSKI'), ('feature', 'SMOOTH_F1')]), 
	'voronoi_texture_2d_chebychev_distance_to_edge' : NodeInstance('ShaderNodeTexVoronoi', [0, 2, 3, 4, 5, 8], [0], [('voronoi_dimensions', '2D'), ('distance', 'CHEBYCHEV'), ('feature', 'DISTANCE_TO_EDGE')]), 
	'voronoi_texture_2d_chebychev_f1' : NodeInstance('ShaderNodeTexVoronoi', [0, 2, 3, 4, 5, 8], [0, 1, 2], [('voronoi_dimensions', '2D'), ('distance', 'CHEBYCHEV'), ('feature', 'F1')]), 
	'voronoi_texture_2d_chebychev_f2' : NodeInstance('ShaderNodeTexVoronoi', [0, 2, 3, 4, 5, 8], [0, 1, 2], [('voronoi_dimensions', '2D'), ('distance', 'CHEBYCHEV'), ('feature', 'F2')]), 
	'voronoi_texture_2d_chebychev_n_sphere_radius' : NodeInstance('ShaderNodeTexVoronoi', [0, 2, 8], [4], [('voronoi_dimensions', '2D'), ('distance', 'CHEBYCHEV'), ('feature', 'N_SPHERE_RADIUS')]), 
	'voronoi_texture_2d_chebychev_smooth_f1' : NodeInstance('ShaderNodeTexVoronoi', [0, 2, 3, 4, 5, 6, 8], [0, 1, 2], [('voronoi_dimensions', '2D'), ('distance', 'CHEBYCHEV'), ('feature', 'SMOOTH_F1')]), 
	'voronoi_texture_2d_euclidean_distance_to_edge' : NodeInstance('ShaderNodeTexVoronoi', [0, 2, 3, 4, 5, 8], [0], [('voronoi_dimensions', '2D'), ('distance', 'EUCLIDEAN'), ('feature', 'DISTANCE_TO_EDGE')]), 
	'voronoi_texture_2d_euclidean_f1' : NodeInstance('ShaderNodeTexVoronoi', [0, 2, 3, 4, 5, 8], [0, 1, 2], [('voronoi_dimensions', '2D'), ('distance', 'EUCLIDEAN'), ('feature', 'F1')]), 
	'voronoi_texture_2d_euclidean_f2' : NodeInstance('ShaderNodeTexVoronoi', [0, 2, 3, 4, 5, 8], [0, 1, 2], [('voronoi_dimensions', '2D'), ('distance', 'EUCLIDEAN'), ('feature', 'F2')]), 
	'voronoi_texture_2d_euclidean_n_sphere_radius' : NodeInstance('ShaderNodeTexVoronoi', [0, 2, 8], [4], [('voronoi_dimensions', '2D'), ('distance', 'EUCLIDEAN'), ('feature', 'N_SPHERE_RADIUS')]), 
	'voronoi_texture_2d_euclidean_smooth_f1' : NodeInstance('ShaderNodeTexVoronoi', [0, 2, 3, 4, 5, 6, 8], [0, 1, 2], [('voronoi_dimensions', '2D'), ('distance', 'EUCLIDEAN'), ('feature', 'SMOOTH_F1')]), 
	'voronoi_texture_2d_manhattan_distance_to_edge' : NodeInstance('ShaderNodeTexVoronoi', [0, 2, 3, 4, 5, 8], [0], [('voronoi_dimensions', '2D'), ('distance', 'MANHATTAN'), ('feature', 'DISTANCE_TO_EDGE')]), 
	'voronoi_texture_2d_manhattan_f1' : NodeInstance('ShaderNodeTexVoronoi', [0, 2, 3, 4, 5, 8], [0, 1, 2], [('voronoi_dimensions', '2D'), ('distance', 'MANHATTAN'), ('feature', 'F1')]), 
	'voronoi_texture_2d_manhattan_f2' : NodeInstance('ShaderNodeTexVoronoi', [0, 2, 3, 4, 5, 8], [0, 1, 2], [('voronoi_dimensions', '2D'), ('distance', 'MANHATTAN'), ('feature', 'F2')]), 
	'voronoi_texture_2d_manhattan_n_sphere_radius' : NodeInstance('ShaderNodeTexVoronoi', [0, 2, 8], [4], [('voronoi_dimensions', '2D'), ('distance', 'MANHATTAN'), ('feature', 'N_SPHERE_RADIUS')]), 
	'voronoi_texture_2d_manhattan_smooth_f1' : NodeInstance('ShaderNodeTexVoronoi', [0, 2, 3, 4, 5, 6, 8], [0, 1, 2], [('voronoi_dimensions', '2D'), ('distance', 'MANHATTAN'), ('feature', 'SMOOTH_F1')]), 
	'voronoi_texture_2d_minkowski_distance_to_edge' : NodeInstance('ShaderNodeTexVoronoi', [0, 2, 3, 4, 5, 8], [0], [('voronoi_dimensions', '2D'), ('distance', 'MINKOWSKI'), ('feature', 'DISTANCE_TO_EDGE')]), 
	'voronoi_texture_2d_minkowski_f1' : NodeInstance('ShaderNodeTexVoronoi', [0, 2, 3, 4, 5, 7, 8], [0, 1, 2], [('voronoi_dimensions', '2D'), ('distance', 'MINKOWSKI'), ('feature', 'F1')]), 
	'voronoi_texture_2d_minkowski_f2' : NodeInstance('ShaderNodeTexVoronoi', [0, 2, 3, 4, 5, 7, 8], [0, 1, 2], [('voronoi_dimensions', '2D'), ('distance', 'MINKOWSKI'), ('feature', 'F2')]), 
	'voronoi_texture_2d_minkowski_n_sphere_radius' : NodeInstance('ShaderNodeTexVoronoi', [0, 2, 8], [4], [('voronoi_dimensions', '2D'), ('distance', 'MINKOWSKI'), ('feature', 'N_SPHERE_RADIUS')]), 
	'voronoi_texture_2d_minkowski_smooth_f1' : NodeInstance('ShaderNodeTexVoronoi', [0, 2, 3, 4, 5, 6, 7, 8], [0, 1, 2], [('voronoi_dimensions', '2D'), ('distance', 'MINKOWSKI'), ('feature', 'SMOOTH_F1')]), 
	'voronoi_texture_3d_chebychev_distance_to_edge' : NodeInstance('ShaderNodeTexVoronoi', [0, 2, 3, 4, 5, 8], [0], [('voronoi_dimensions', '3D'), ('distance', 'CHEBYCHEV'), ('feature', 'DISTANCE_TO_EDGE')]), 
	'voronoi_texture_3d_chebychev_f1' : NodeInstance('ShaderNodeTexVoronoi', [0, 2, 3, 4, 5, 8], [0, 1, 2], [('voronoi_dimensions', '3D'), ('distance', 'CHEBYCHEV'), ('feature', 'F1')]), 
	'voronoi_texture_3d_chebychev_f2' : NodeInstance('ShaderNodeTexVoronoi', [0, 2, 3, 4, 5, 8], [0, 1, 2], [('voronoi_dimensions', '3D'), ('distance', 'CHEBYCHEV'), ('feature', 'F2')]), 
	'voronoi_texture_3d_chebychev_n_sphere_radius' : NodeInstance('ShaderNodeTexVoronoi', [0, 2, 8], [4], [('voronoi_dimensions', '3D'), ('distance', 'CHEBYCHEV'), ('feature', 'N_SPHERE_RADIUS')]), 
	'voronoi_texture_3d_chebychev_smooth_f1' : NodeInstance('ShaderNodeTexVoronoi', [0, 2, 3, 4, 5, 6, 8], [0, 1, 2], [('voronoi_dimensions', '3D'), ('distance', 'CHEBYCHEV'), ('feature', 'SMOOTH_F1')]), 
	'voronoi_texture_3d_euclidean_distance_to_edge' : NodeInstance('ShaderNodeTexVoronoi', [0, 2, 3, 4, 5, 8], [0], [('voronoi_dimensions', '3D'), ('distance', 'EUCLIDEAN'), ('feature', 'DISTANCE_TO_EDGE')]), 
	'voronoi_texture_3d_euclidean_f1' : NodeInstance('ShaderNodeTexVoronoi', [0, 2, 3, 4, 5, 8], [0, 1, 2], [('voronoi_dimensions', '3D'), ('distance', 'EUCLIDEAN'), ('feature', 'F1')]), 
	'voronoi_texture_3d_euclidean_f2' : NodeInstance('ShaderNodeTexVoronoi', [0, 2, 3, 4, 5, 8], [0, 1, 2], [('voronoi_dimensions', '3D'), ('distance', 'EUCLIDEAN'), ('feature', 'F2')]), 
	'voronoi_texture_3d_euclidean_n_sphere_radius' : NodeInstance('ShaderNodeTexVoronoi', [0, 2, 8], [4], [('voronoi_dimensions', '3D'), ('distance', 'EUCLIDEAN'), ('feature', 'N_SPHERE_RADIUS')]), 
	'voronoi_texture_3d_euclidean_smooth_f1' : NodeInstance('ShaderNodeTexVoronoi', [0, 2, 3, 4, 5, 6, 8], [0, 1, 2], [('voronoi_dimensions', '3D'), ('distance', 'EUCLIDEAN'), ('feature', 'SMOOTH_F1')]), 
	'voronoi_texture_3d_manhattan_distance_to_edge' : NodeInstance('ShaderNodeTexVoronoi', [0, 2, 3, 4, 5, 8], [0], [('voronoi_dimensions', '3D'), ('distance', 'MANHATTAN'), ('feature', 'DISTANCE_TO_EDGE')]), 
	'voronoi_texture_3d_manhattan_f1' : NodeInstance('ShaderNodeTexVoronoi', [0, 2, 3, 4, 5, 8], [0, 1, 2], [('voronoi_dimensions', '3D'), ('distance', 'MANHATTAN'), ('feature', 'F1')]), 
	'voronoi_texture_3d_manhattan_f2' : NodeInstance('ShaderNodeTexVoronoi', [0, 2, 3, 4, 5, 8], [0, 1, 2], [('voronoi_dimensions', '3D'), ('distance', 'MANHATTAN'), ('feature', 'F2')]), 
	'voronoi_texture_3d_manhattan_n_sphere_radius' : NodeInstance('ShaderNodeTexVoronoi', [0, 2, 8], [4], [('voronoi_dimensions', '3D'), ('distance', 'MANHATTAN'), ('feature', 'N_SPHERE_RADIUS')]), 
	'voronoi_texture_3d_manhattan_smooth_f1' : NodeInstance('ShaderNodeTexVoronoi', [0, 2, 3, 4, 5, 6, 8], [0, 1, 2], [('voronoi_dimensions', '3D'), ('distance', 'MANHATTAN'), ('feature', 'SMOOTH_F1')]), 
	'voronoi_texture_3d_minkowski_distance_to_edge' : NodeInstance('ShaderNodeTexVoronoi', [0, 2, 3, 4, 5, 8], [0], [('voronoi_dimensions', '3D'), ('distance', 'MINKOWSKI'), ('feature', 'DISTANCE_TO_EDGE')]), 
	'voronoi_texture_3d_minkowski_f1' : NodeInstance('ShaderNodeTexVoronoi', [0, 2, 3, 4, 5, 7, 8], [0, 1, 2], [('voronoi_dimensions', '3D'), ('distance', 'MINKOWSKI'), ('feature', 'F1')]), 
	'voronoi_texture_3d_minkowski_f2' : NodeInstance('ShaderNodeTexVoronoi', [0, 2, 3, 4, 5, 7, 8], [0, 1, 2], [('voronoi_dimensions', '3D'), ('distance', 'MINKOWSKI'), ('feature', 'F2')]), 
	'voronoi_texture_3d_minkowski_n_sphere_radius' : NodeInstance('ShaderNodeTexVoronoi', [0, 2, 8], [4], [('voronoi_dimensions', '3D'), ('distance', 'MINKOWSKI'), ('feature', 'N_SPHERE_RADIUS')]), 
	'voronoi_texture_3d_minkowski_smooth_f1' : NodeInstance('ShaderNodeTexVoronoi', [0, 2, 3, 4, 5, 6, 7, 8], [0, 1, 2], [('voronoi_dimensions', '3D'), ('distance', 'MINKOWSKI'), ('feature', 'SMOOTH_F1')]), 
	'voronoi_texture_4d_chebychev_distance_to_edge' : NodeInstance('ShaderNodeTexVoronoi', [0, 1, 2, 3, 4, 5, 8], [0], [('voronoi_dimensions', '4D'), ('distance', 'CHEBYCHEV'), ('feature', 'DISTANCE_TO_EDGE')]), 
	'voronoi_texture_4d_chebychev_f1' : NodeInstance('ShaderNodeTexVoronoi', [0, 1, 2, 3, 4, 5, 8], [0, 1, 2, 3], [('voronoi_dimensions', '4D'), ('distance', 'CHEBYCHEV'), ('feature', 'F1')]), 
	'voronoi_texture_4d_chebychev_f2' : NodeInstance('ShaderNodeTexVoronoi', [0, 1, 2, 3, 4, 5, 8], [0, 1, 2, 3], [('voronoi_dimensions', '4D'), ('distance', 'CHEBYCHEV'), ('feature', 'F2')]), 
	'voronoi_texture_4d_chebychev_n_sphere_radius' : NodeInstance('ShaderNodeTexVoronoi', [0, 1, 2, 8], [4], [('voronoi_dimensions', '4D'), ('distance', 'CHEBYCHEV'), ('feature', 'N_SPHERE_RADIUS')]), 
	'voronoi_texture_4d_chebychev_smooth_f1' : NodeInstance('ShaderNodeTexVoronoi', [0, 1, 2, 3, 4, 5, 6, 8], [0, 1, 2, 3], [('voronoi_dimensions', '4D'), ('distance', 'CHEBYCHEV'), ('feature', 'SMOOTH_F1')]), 
	'voronoi_texture_4d_euclidean_distance_to_edge' : NodeInstance('ShaderNodeTexVoronoi', [0, 1, 2, 3, 4, 5, 8], [0], [('voronoi_dimensions', '4D'), ('distance', 'EUCLIDEAN'), ('feature', 'DISTANCE_TO_EDGE')]), 
	'voronoi_texture_4d_euclidean_f1' : NodeInstance('ShaderNodeTexVoronoi', [0, 1, 2, 3, 4, 5, 8], [0, 1, 2, 3], [('voronoi_dimensions', '4D'), ('distance', 'EUCLIDEAN'), ('feature', 'F1')]), 
	'voronoi_texture_4d_euclidean_f2' : NodeInstance('ShaderNodeTexVoronoi', [0, 1, 2, 3, 4, 5, 8], [0, 1, 2, 3], [('voronoi_dimensions', '4D'), ('distance', 'EUCLIDEAN'), ('feature', 'F2')]), 
	'voronoi_texture_4d_euclidean_n_sphere_radius' : NodeInstance('ShaderNodeTexVoronoi', [0, 1, 2, 8], [4], [('voronoi_dimensions', '4D'), ('distance', 'EUCLIDEAN'), ('feature', 'N_SPHERE_RADIUS')]), 
	'voronoi_texture_4d_euclidean_smooth_f1' : NodeInstance('ShaderNodeTexVoronoi', [0, 1, 2, 3, 4, 5, 6, 8], [0, 1, 2, 3], [('voronoi_dimensions', '4D'), ('distance', 'EUCLIDEAN'), ('feature', 'SMOOTH_F1')]), 
	'voronoi_texture_4d_manhattan_distance_to_edge' : NodeInstance('ShaderNodeTexVoronoi', [0, 1, 2, 3, 4, 5, 8], [0], [('voronoi_dimensions', '4D'), ('distance', 'MANHATTAN'), ('feature', 'DISTANCE_TO_EDGE')]), 
	'voronoi_texture_4d_manhattan_f1' : NodeInstance('ShaderNodeTexVoronoi', [0, 1, 2, 3, 4, 5, 8], [0, 1, 2, 3], [('voronoi_dimensions', '4D'), ('distance', 'MANHATTAN'), ('feature', 'F1')]), 
	'voronoi_texture_4d_manhattan_f2' : NodeInstance('ShaderNodeTexVoronoi', [0, 1, 2, 3, 4, 5, 8], [0, 1, 2, 3], [('voronoi_dimensions', '4D'), ('distance', 'MANHATTAN'), ('feature', 'F2')]), 
	'voronoi_texture_4d_manhattan_n_sphere_radius' : NodeInstance('ShaderNodeTexVoronoi', [0, 1, 2, 8], [4], [('voronoi_dimensions', '4D'), ('distance', 'MANHATTAN'), ('feature', 'N_SPHERE_RADIUS')]), 
	'voronoi_texture_4d_manhattan_smooth_f1' : NodeInstance('ShaderNodeTexVoronoi', [0, 1, 2, 3, 4, 5, 6, 8], [0, 1, 2, 3], [('voronoi_dimensions', '4D'), ('distance', 'MANHATTAN'), ('feature', 'SMOOTH_F1')]), 
	'voronoi_texture_4d_minkowski_distance_to_edge' : NodeInstance('ShaderNodeTexVoronoi', [0, 1, 2, 3, 4, 5, 8], [0], [('voronoi_dimensions', '4D'), ('distance', 'MINKOWSKI'), ('feature', 'DISTANCE_TO_EDGE')]), 
	'voronoi_texture_4d_minkowski_f1' : NodeInstance('ShaderNodeTexVoronoi', [0, 1, 2, 3, 4, 5, 7, 8], [0, 1, 2, 3], [('voronoi_dimensions', '4D'), ('distance', 'MINKOWSKI'), ('feature', 'F1')]), 
	'voronoi_texture_4d_minkowski_f2' : NodeInstance('ShaderNodeTexVoronoi', [0, 1, 2, 3, 4, 5, 7, 8], [0, 1, 2, 3], [('voronoi_dimensions', '4D'), ('distance', 'MINKOWSKI'), ('feature', 'F2')]), 
	'voronoi_texture_4d_minkowski_n_sphere_radius' : NodeInstance('ShaderNodeTexVoronoi', [0, 1, 2, 8], [4], [('voronoi_dimensions', '4D'), ('distance', 'MINKOWSKI'), ('feature', 'N_SPHERE_RADIUS')]), 
	'voronoi_texture_4d_minkowski_smooth_f1' : NodeInstance('ShaderNodeTexVoronoi', [0, 1, 2, 3, 4, 5, 6, 7, 8], [0, 1, 2, 3], [('voronoi_dimensions', '4D'), ('distance', 'MINKOWSKI'), ('feature', 'SMOOTH_F1')]), 
	'wave_texture' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], []), 
	'wave_texture_bands_diagonal_spherical_saw' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'BANDS'), ('bands_direction', 'DIAGONAL'), ('rings_direction', 'SPHERICAL'), ('wave_profile', 'SAW')]), 
	'wave_texture_bands_diagonal_spherical_sine' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'BANDS'), ('bands_direction', 'DIAGONAL'), ('rings_direction', 'SPHERICAL'), ('wave_profile', 'SIN')]), 
	'wave_texture_bands_diagonal_spherical_triangle' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'BANDS'), ('bands_direction', 'DIAGONAL'), ('rings_direction', 'SPHERICAL'), ('wave_profile', 'TRI')]), 
	'wave_texture_bands_diagonal_x_saw' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'BANDS'), ('bands_direction', 'DIAGONAL'), ('rings_direction', 'X'), ('wave_profile', 'SAW')]), 
	'wave_texture_bands_diagonal_x_sine' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'BANDS'), ('bands_direction', 'DIAGONAL'), ('rings_direction', 'X'), ('wave_profile', 'SIN')]), 
	'wave_texture_bands_diagonal_x_triangle' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'BANDS'), ('bands_direction', 'DIAGONAL'), ('rings_direction', 'X'), ('wave_profile', 'TRI')]), 
	'wave_texture_bands_diagonal_y_saw' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'BANDS'), ('bands_direction', 'DIAGONAL'), ('rings_direction', 'Y'), ('wave_profile', 'SAW')]), 
	'wave_texture_bands_diagonal_y_sine' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'BANDS'), ('bands_direction', 'DIAGONAL'), ('rings_direction', 'Y'), ('wave_profile', 'SIN')]), 
	'wave_texture_bands_diagonal_y_triangle' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'BANDS'), ('bands_direction', 'DIAGONAL'), ('rings_direction', 'Y'), ('wave_profile', 'TRI')]), 
	'wave_texture_bands_diagonal_z_saw' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'BANDS'), ('bands_direction', 'DIAGONAL'), ('rings_direction', 'Z'), ('wave_profile', 'SAW')]), 
	'wave_texture_bands_diagonal_z_sine' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'BANDS'), ('bands_direction', 'DIAGONAL'), ('rings_direction', 'Z'), ('wave_profile', 'SIN')]), 
	'wave_texture_bands_diagonal_z_triangle' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'BANDS'), ('bands_direction', 'DIAGONAL'), ('rings_direction', 'Z'), ('wave_profile', 'TRI')]), 
	'wave_texture_bands_x_spherical_saw' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'BANDS'), ('bands_direction', 'X'), ('rings_direction', 'SPHERICAL'), ('wave_profile', 'SAW')]), 
	'wave_texture_bands_x_spherical_sine' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'BANDS'), ('bands_direction', 'X'), ('rings_direction', 'SPHERICAL'), ('wave_profile', 'SIN')]), 
	'wave_texture_bands_x_spherical_triangle' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'BANDS'), ('bands_direction', 'X'), ('rings_direction', 'SPHERICAL'), ('wave_profile', 'TRI')]), 
	'wave_texture_bands_x_x_saw' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'BANDS'), ('bands_direction', 'X'), ('rings_direction', 'X'), ('wave_profile', 'SAW')]), 
	'wave_texture_bands_x_x_sine' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'BANDS'), ('bands_direction', 'X'), ('rings_direction', 'X'), ('wave_profile', 'SIN')]), 
	'wave_texture_bands_x_x_triangle' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'BANDS'), ('bands_direction', 'X'), ('rings_direction', 'X'), ('wave_profile', 'TRI')]), 
	'wave_texture_bands_x_y_saw' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'BANDS'), ('bands_direction', 'X'), ('rings_direction', 'Y'), ('wave_profile', 'SAW')]), 
	'wave_texture_bands_x_y_sine' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'BANDS'), ('bands_direction', 'X'), ('rings_direction', 'Y'), ('wave_profile', 'SIN')]), 
	'wave_texture_bands_x_y_triangle' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'BANDS'), ('bands_direction', 'X'), ('rings_direction', 'Y'), ('wave_profile', 'TRI')]), 
	'wave_texture_bands_x_z_saw' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'BANDS'), ('bands_direction', 'X'), ('rings_direction', 'Z'), ('wave_profile', 'SAW')]), 
	'wave_texture_bands_x_z_sine' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'BANDS'), ('bands_direction', 'X'), ('rings_direction', 'Z'), ('wave_profile', 'SIN')]), 
	'wave_texture_bands_x_z_triangle' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'BANDS'), ('bands_direction', 'X'), ('rings_direction', 'Z'), ('wave_profile', 'TRI')]), 
	'wave_texture_bands_y_spherical_saw' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'BANDS'), ('bands_direction', 'Y'), ('rings_direction', 'SPHERICAL'), ('wave_profile', 'SAW')]), 
	'wave_texture_bands_y_spherical_sine' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'BANDS'), ('bands_direction', 'Y'), ('rings_direction', 'SPHERICAL'), ('wave_profile', 'SIN')]), 
	'wave_texture_bands_y_spherical_triangle' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'BANDS'), ('bands_direction', 'Y'), ('rings_direction', 'SPHERICAL'), ('wave_profile', 'TRI')]), 
	'wave_texture_bands_y_x_saw' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'BANDS'), ('bands_direction', 'Y'), ('rings_direction', 'X'), ('wave_profile', 'SAW')]), 
	'wave_texture_bands_y_x_sine' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'BANDS'), ('bands_direction', 'Y'), ('rings_direction', 'X'), ('wave_profile', 'SIN')]), 
	'wave_texture_bands_y_x_triangle' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'BANDS'), ('bands_direction', 'Y'), ('rings_direction', 'X'), ('wave_profile', 'TRI')]), 
	'wave_texture_bands_y_y_saw' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'BANDS'), ('bands_direction', 'Y'), ('rings_direction', 'Y'), ('wave_profile', 'SAW')]), 
	'wave_texture_bands_y_y_sine' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'BANDS'), ('bands_direction', 'Y'), ('rings_direction', 'Y'), ('wave_profile', 'SIN')]), 
	'wave_texture_bands_y_y_triangle' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'BANDS'), ('bands_direction', 'Y'), ('rings_direction', 'Y'), ('wave_profile', 'TRI')]), 
	'wave_texture_bands_y_z_saw' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'BANDS'), ('bands_direction', 'Y'), ('rings_direction', 'Z'), ('wave_profile', 'SAW')]), 
	'wave_texture_bands_y_z_sine' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'BANDS'), ('bands_direction', 'Y'), ('rings_direction', 'Z'), ('wave_profile', 'SIN')]), 
	'wave_texture_bands_y_z_triangle' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'BANDS'), ('bands_direction', 'Y'), ('rings_direction', 'Z'), ('wave_profile', 'TRI')]), 
	'wave_texture_bands_z_spherical_saw' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'BANDS'), ('bands_direction', 'Z'), ('rings_direction', 'SPHERICAL'), ('wave_profile', 'SAW')]), 
	'wave_texture_bands_z_spherical_sine' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'BANDS'), ('bands_direction', 'Z'), ('rings_direction', 'SPHERICAL'), ('wave_profile', 'SIN')]), 
	'wave_texture_bands_z_spherical_triangle' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'BANDS'), ('bands_direction', 'Z'), ('rings_direction', 'SPHERICAL'), ('wave_profile', 'TRI')]), 
	'wave_texture_bands_z_x_saw' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'BANDS'), ('bands_direction', 'Z'), ('rings_direction', 'X'), ('wave_profile', 'SAW')]), 
	'wave_texture_bands_z_x_sine' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'BANDS'), ('bands_direction', 'Z'), ('rings_direction', 'X'), ('wave_profile', 'SIN')]), 
	'wave_texture_bands_z_x_triangle' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'BANDS'), ('bands_direction', 'Z'), ('rings_direction', 'X'), ('wave_profile', 'TRI')]), 
	'wave_texture_bands_z_y_saw' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'BANDS'), ('bands_direction', 'Z'), ('rings_direction', 'Y'), ('wave_profile', 'SAW')]), 
	'wave_texture_bands_z_y_sine' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'BANDS'), ('bands_direction', 'Z'), ('rings_direction', 'Y'), ('wave_profile', 'SIN')]), 
	'wave_texture_bands_z_y_triangle' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'BANDS'), ('bands_direction', 'Z'), ('rings_direction', 'Y'), ('wave_profile', 'TRI')]), 
	'wave_texture_bands_z_z_saw' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'BANDS'), ('bands_direction', 'Z'), ('rings_direction', 'Z'), ('wave_profile', 'SAW')]), 
	'wave_texture_bands_z_z_sine' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'BANDS'), ('bands_direction', 'Z'), ('rings_direction', 'Z'), ('wave_profile', 'SIN')]), 
	'wave_texture_bands_z_z_triangle' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'BANDS'), ('bands_direction', 'Z'), ('rings_direction', 'Z'), ('wave_profile', 'TRI')]), 
	'wave_texture_rings_diagonal_spherical_saw' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'RINGS'), ('bands_direction', 'DIAGONAL'), ('rings_direction', 'SPHERICAL'), ('wave_profile', 'SAW')]), 
	'wave_texture_rings_diagonal_spherical_sine' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'RINGS'), ('bands_direction', 'DIAGONAL'), ('rings_direction', 'SPHERICAL'), ('wave_profile', 'SIN')]), 
	'wave_texture_rings_diagonal_spherical_triangle' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'RINGS'), ('bands_direction', 'DIAGONAL'), ('rings_direction', 'SPHERICAL'), ('wave_profile', 'TRI')]), 
	'wave_texture_rings_diagonal_x_saw' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'RINGS'), ('bands_direction', 'DIAGONAL'), ('rings_direction', 'X'), ('wave_profile', 'SAW')]), 
	'wave_texture_rings_diagonal_x_sine' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'RINGS'), ('bands_direction', 'DIAGONAL'), ('rings_direction', 'X'), ('wave_profile', 'SIN')]), 
	'wave_texture_rings_diagonal_x_triangle' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'RINGS'), ('bands_direction', 'DIAGONAL'), ('rings_direction', 'X'), ('wave_profile', 'TRI')]), 
	'wave_texture_rings_diagonal_y_saw' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'RINGS'), ('bands_direction', 'DIAGONAL'), ('rings_direction', 'Y'), ('wave_profile', 'SAW')]), 
	'wave_texture_rings_diagonal_y_sine' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'RINGS'), ('bands_direction', 'DIAGONAL'), ('rings_direction', 'Y'), ('wave_profile', 'SIN')]), 
	'wave_texture_rings_diagonal_y_triangle' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'RINGS'), ('bands_direction', 'DIAGONAL'), ('rings_direction', 'Y'), ('wave_profile', 'TRI')]), 
	'wave_texture_rings_diagonal_z_saw' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'RINGS'), ('bands_direction', 'DIAGONAL'), ('rings_direction', 'Z'), ('wave_profile', 'SAW')]), 
	'wave_texture_rings_diagonal_z_sine' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'RINGS'), ('bands_direction', 'DIAGONAL'), ('rings_direction', 'Z'), ('wave_profile', 'SIN')]), 
	'wave_texture_rings_diagonal_z_triangle' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'RINGS'), ('bands_direction', 'DIAGONAL'), ('rings_direction', 'Z'), ('wave_profile', 'TRI')]), 
	'wave_texture_rings_x_spherical_saw' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'RINGS'), ('bands_direction', 'X'), ('rings_direction', 'SPHERICAL'), ('wave_profile', 'SAW')]), 
	'wave_texture_rings_x_spherical_sine' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'RINGS'), ('bands_direction', 'X'), ('rings_direction', 'SPHERICAL'), ('wave_profile', 'SIN')]), 
	'wave_texture_rings_x_spherical_triangle' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'RINGS'), ('bands_direction', 'X'), ('rings_direction', 'SPHERICAL'), ('wave_profile', 'TRI')]), 
	'wave_texture_rings_x_x_saw' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'RINGS'), ('bands_direction', 'X'), ('rings_direction', 'X'), ('wave_profile', 'SAW')]), 
	'wave_texture_rings_x_x_sine' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'RINGS'), ('bands_direction', 'X'), ('rings_direction', 'X'), ('wave_profile', 'SIN')]), 
	'wave_texture_rings_x_x_triangle' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'RINGS'), ('bands_direction', 'X'), ('rings_direction', 'X'), ('wave_profile', 'TRI')]), 
	'wave_texture_rings_x_y_saw' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'RINGS'), ('bands_direction', 'X'), ('rings_direction', 'Y'), ('wave_profile', 'SAW')]), 
	'wave_texture_rings_x_y_sine' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'RINGS'), ('bands_direction', 'X'), ('rings_direction', 'Y'), ('wave_profile', 'SIN')]), 
	'wave_texture_rings_x_y_triangle' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'RINGS'), ('bands_direction', 'X'), ('rings_direction', 'Y'), ('wave_profile', 'TRI')]), 
	'wave_texture_rings_x_z_saw' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'RINGS'), ('bands_direction', 'X'), ('rings_direction', 'Z'), ('wave_profile', 'SAW')]), 
	'wave_texture_rings_x_z_sine' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'RINGS'), ('bands_direction', 'X'), ('rings_direction', 'Z'), ('wave_profile', 'SIN')]), 
	'wave_texture_rings_x_z_triangle' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'RINGS'), ('bands_direction', 'X'), ('rings_direction', 'Z'), ('wave_profile', 'TRI')]), 
	'wave_texture_rings_y_spherical_saw' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'RINGS'), ('bands_direction', 'Y'), ('rings_direction', 'SPHERICAL'), ('wave_profile', 'SAW')]), 
	'wave_texture_rings_y_spherical_sine' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'RINGS'), ('bands_direction', 'Y'), ('rings_direction', 'SPHERICAL'), ('wave_profile', 'SIN')]), 
	'wave_texture_rings_y_spherical_triangle' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'RINGS'), ('bands_direction', 'Y'), ('rings_direction', 'SPHERICAL'), ('wave_profile', 'TRI')]), 
	'wave_texture_rings_y_x_saw' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'RINGS'), ('bands_direction', 'Y'), ('rings_direction', 'X'), ('wave_profile', 'SAW')]), 
	'wave_texture_rings_y_x_sine' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'RINGS'), ('bands_direction', 'Y'), ('rings_direction', 'X'), ('wave_profile', 'SIN')]), 
	'wave_texture_rings_y_x_triangle' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'RINGS'), ('bands_direction', 'Y'), ('rings_direction', 'X'), ('wave_profile', 'TRI')]), 
	'wave_texture_rings_y_y_saw' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'RINGS'), ('bands_direction', 'Y'), ('rings_direction', 'Y'), ('wave_profile', 'SAW')]), 
	'wave_texture_rings_y_y_sine' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'RINGS'), ('bands_direction', 'Y'), ('rings_direction', 'Y'), ('wave_profile', 'SIN')]), 
	'wave_texture_rings_y_y_triangle' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'RINGS'), ('bands_direction', 'Y'), ('rings_direction', 'Y'), ('wave_profile', 'TRI')]), 
	'wave_texture_rings_y_z_saw' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'RINGS'), ('bands_direction', 'Y'), ('rings_direction', 'Z'), ('wave_profile', 'SAW')]), 
	'wave_texture_rings_y_z_sine' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'RINGS'), ('bands_direction', 'Y'), ('rings_direction', 'Z'), ('wave_profile', 'SIN')]), 
	'wave_texture_rings_y_z_triangle' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'RINGS'), ('bands_direction', 'Y'), ('rings_direction', 'Z'), ('wave_profile', 'TRI')]), 
	'wave_texture_rings_z_spherical_saw' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'RINGS'), ('bands_direction', 'Z'), ('rings_direction', 'SPHERICAL'), ('wave_profile', 'SAW')]), 
	'wave_texture_rings_z_spherical_sine' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'RINGS'), ('bands_direction', 'Z'), ('rings_direction', 'SPHERICAL'), ('wave_profile', 'SIN')]), 
	'wave_texture_rings_z_spherical_triangle' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'RINGS'), ('bands_direction', 'Z'), ('rings_direction', 'SPHERICAL'), ('wave_profile', 'TRI')]), 
	'wave_texture_rings_z_x_saw' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'RINGS'), ('bands_direction', 'Z'), ('rings_direction', 'X'), ('wave_profile', 'SAW')]), 
	'wave_texture_rings_z_x_sine' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'RINGS'), ('bands_direction', 'Z'), ('rings_direction', 'X'), ('wave_profile', 'SIN')]), 
	'wave_texture_rings_z_x_triangle' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'RINGS'), ('bands_direction', 'Z'), ('rings_direction', 'X'), ('wave_profile', 'TRI')]), 
	'wave_texture_rings_z_y_saw' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'RINGS'), ('bands_direction', 'Z'), ('rings_direction', 'Y'), ('wave_profile', 'SAW')]), 
	'wave_texture_rings_z_y_sine' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'RINGS'), ('bands_direction', 'Z'), ('rings_direction', 'Y'), ('wave_profile', 'SIN')]), 
	'wave_texture_rings_z_y_triangle' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'RINGS'), ('bands_direction', 'Z'), ('rings_direction', 'Y'), ('wave_profile', 'TRI')]), 
	'wave_texture_rings_z_z_saw' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'RINGS'), ('bands_direction', 'Z'), ('rings_direction', 'Z'), ('wave_profile', 'SAW')]), 
	'wave_texture_rings_z_z_sine' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'RINGS'), ('bands_direction', 'Z'), ('rings_direction', 'Z'), ('wave_profile', 'SIN')]), 
	'wave_texture_rings_z_z_triangle' : NodeInstance('ShaderNodeTexWave', [0, 1, 2, 3, 4, 5, 6], [0, 1], [('wave_type', 'RINGS'), ('bands_direction', 'Z'), ('rings_direction', 'Z'), ('wave_profile', 'TRI')]), 
	'white_noise_texture' : NodeInstance('ShaderNodeTexWhiteNoise', [0], [0, 1], []), 
	'white_noise_texture_1d' : NodeInstance('ShaderNodeTexWhiteNoise', [1], [0, 1], [('noise_dimensions', '1D')]), 
	'white_noise_texture_2d' : NodeInstance('ShaderNodeTexWhiteNoise', [0], [0, 1], [('noise_dimensions', '2D')]), 
	'white_noise_texture_3d' : NodeInstance('ShaderNodeTexWhiteNoise', [0], [0, 1], [('noise_dimensions', '3D')]), 
	'white_noise_texture_4d' : NodeInstance('ShaderNodeTexWhiteNoise', [0, 1], [0, 1], [('noise_dimensions', '4D')]), 
}

geometry_node_aliases = {
	'3d_cursor' : NodeInstance('GeometryNodeTool3DCursor', [], [0, 1], []), 
	'accumulate_field' : NodeInstance('GeometryNodeAccumulateField', [0, 1], [0, 1, 2], []), 
	'accumulate_field_float_edge' : NodeInstance('GeometryNodeAccumulateField', [0, 1], [0, 1, 2], [('data_type', 'FLOAT'), ('domain', 'EDGE')]), 
	'accumulate_field_float_face' : NodeInstance('GeometryNodeAccumulateField', [0, 1], [0, 1, 2], [('data_type', 'FLOAT'), ('domain', 'FACE')]), 
	'accumulate_field_float_face_corner' : NodeInstance('GeometryNodeAccumulateField', [0, 1], [0, 1, 2], [('data_type', 'FLOAT'), ('domain', 'CORNER')]), 
	'accumulate_field_float_instance' : NodeInstance('GeometryNodeAccumulateField', [0, 1], [0, 1, 2], [('data_type', 'FLOAT'), ('domain', 'INSTANCE')]), 
	'accumulate_field_float_layer' : NodeInstance('GeometryNodeAccumulateField', [0, 1], [0, 1, 2], [('data_type', 'FLOAT'), ('domain', 'LAYER')]), 
	'accumulate_field_float_point' : NodeInstance('GeometryNodeAccumulateField', [0, 1], [0, 1, 2], [('data_type', 'FLOAT'), ('domain', 'POINT')]), 
	'accumulate_field_float_spline' : NodeInstance('GeometryNodeAccumulateField', [0, 1], [0, 1, 2], [('data_type', 'FLOAT'), ('domain', 'CURVE')]), 
	'accumulate_field_integer_edge' : NodeInstance('GeometryNodeAccumulateField', [0, 1], [0, 1, 2], [('data_type', 'INT'), ('domain', 'EDGE')]), 
	'accumulate_field_integer_face' : NodeInstance('GeometryNodeAccumulateField', [0, 1], [0, 1, 2], [('data_type', 'INT'), ('domain', 'FACE')]), 
	'accumulate_field_integer_face_corner' : NodeInstance('GeometryNodeAccumulateField', [0, 1], [0, 1, 2], [('data_type', 'INT'), ('domain', 'CORNER')]), 
	'accumulate_field_integer_instance' : NodeInstance('GeometryNodeAccumulateField', [0, 1], [0, 1, 2], [('data_type', 'INT'), ('domain', 'INSTANCE')]), 
	'accumulate_field_integer_layer' : NodeInstance('GeometryNodeAccumulateField', [0, 1], [0, 1, 2], [('data_type', 'INT'), ('domain', 'LAYER')]), 
	'accumulate_field_integer_point' : NodeInstance('GeometryNodeAccumulateField', [0, 1], [0, 1, 2], [('data_type', 'INT'), ('domain', 'POINT')]), 
	'accumulate_field_integer_spline' : NodeInstance('GeometryNodeAccumulateField', [0, 1], [0, 1, 2], [('data_type', 'INT'), ('domain', 'CURVE')]), 
	'accumulate_field_transform_edge' : NodeInstance('GeometryNodeAccumulateField', [0, 1], [0, 1, 2], [('data_type', 'TRANSFORM'), ('domain', 'EDGE')]), 
	'accumulate_field_transform_face' : NodeInstance('GeometryNodeAccumulateField', [0, 1], [0, 1, 2], [('data_type', 'TRANSFORM'), ('domain', 'FACE')]), 
	'accumulate_field_transform_face_corner' : NodeInstance('GeometryNodeAccumulateField', [0, 1], [0, 1, 2], [('data_type', 'TRANSFORM'), ('domain', 'CORNER')]), 
	'accumulate_field_transform_instance' : NodeInstance('GeometryNodeAccumulateField', [0, 1], [0, 1, 2], [('data_type', 'TRANSFORM'), ('domain', 'INSTANCE')]), 
	'accumulate_field_transform_layer' : NodeInstance('GeometryNodeAccumulateField', [0, 1], [0, 1, 2], [('data_type', 'TRANSFORM'), ('domain', 'LAYER')]), 
	'accumulate_field_transform_point' : NodeInstance('GeometryNodeAccumulateField', [0, 1], [0, 1, 2], [('data_type', 'TRANSFORM'), ('domain', 'POINT')]), 
	'accumulate_field_transform_spline' : NodeInstance('GeometryNodeAccumulateField', [0, 1], [0, 1, 2], [('data_type', 'TRANSFORM'), ('domain', 'CURVE')]), 
	'accumulate_field_vector_edge' : NodeInstance('GeometryNodeAccumulateField', [0, 1], [0, 1, 2], [('data_type', 'FLOAT_VECTOR'), ('domain', 'EDGE')]), 
	'accumulate_field_vector_face' : NodeInstance('GeometryNodeAccumulateField', [0, 1], [0, 1, 2], [('data_type', 'FLOAT_VECTOR'), ('domain', 'FACE')]), 
	'accumulate_field_vector_face_corner' : NodeInstance('GeometryNodeAccumulateField', [0, 1], [0, 1, 2], [('data_type', 'FLOAT_VECTOR'), ('domain', 'CORNER')]), 
	'accumulate_field_vector_instance' : NodeInstance('GeometryNodeAccumulateField', [0, 1], [0, 1, 2], [('data_type', 'FLOAT_VECTOR'), ('domain', 'INSTANCE')]), 
	'accumulate_field_vector_layer' : NodeInstance('GeometryNodeAccumulateField', [0, 1], [0, 1, 2], [('data_type', 'FLOAT_VECTOR'), ('domain', 'LAYER')]), 
	'accumulate_field_vector_point' : NodeInstance('GeometryNodeAccumulateField', [0, 1], [0, 1, 2], [('data_type', 'FLOAT_VECTOR'), ('domain', 'POINT')]), 
	'accumulate_field_vector_spline' : NodeInstance('GeometryNodeAccumulateField', [0, 1], [0, 1, 2], [('data_type', 'FLOAT_VECTOR'), ('domain', 'CURVE')]), 
	'active_camera' : NodeInstance('GeometryNodeInputActiveCamera', [], [0], []), 
	'active_element' : NodeInstance('GeometryNodeToolActiveElement', [], [0, 1], []), 
	'active_element_edge' : NodeInstance('GeometryNodeToolActiveElement', [], [0, 1], [('domain', 'EDGE')]), 
	'active_element_face' : NodeInstance('GeometryNodeToolActiveElement', [], [0, 1], [('domain', 'FACE')]), 
	'active_element_point' : NodeInstance('GeometryNodeToolActiveElement', [], [0, 1], [('domain', 'POINT')]), 
	'align_euler_to_vector' : NodeInstance('FunctionNodeAlignEulerToVector', [0, 1, 2], [0], []), 
	'align_euler_to_vector_x_auto' : NodeInstance('FunctionNodeAlignEulerToVector', [0, 1, 2], [0], [('axis', 'X'), ('pivot_axis', 'AUTO')]), 
	'align_euler_to_vector_x_x' : NodeInstance('FunctionNodeAlignEulerToVector', [0, 1, 2], [0], [('axis', 'X'), ('pivot_axis', 'X')]), 
	'align_euler_to_vector_x_y' : NodeInstance('FunctionNodeAlignEulerToVector', [0, 1, 2], [0], [('axis', 'X'), ('pivot_axis', 'Y')]), 
	'align_euler_to_vector_x_z' : NodeInstance('FunctionNodeAlignEulerToVector', [0, 1, 2], [0], [('axis', 'X'), ('pivot_axis', 'Z')]), 
	'align_euler_to_vector_y_auto' : NodeInstance('FunctionNodeAlignEulerToVector', [0, 1, 2], [0], [('axis', 'Y'), ('pivot_axis', 'AUTO')]), 
	'align_euler_to_vector_y_x' : NodeInstance('FunctionNodeAlignEulerToVector', [0, 1, 2], [0], [('axis', 'Y'), ('pivot_axis', 'X')]), 
	'align_euler_to_vector_y_y' : NodeInstance('FunctionNodeAlignEulerToVector', [0, 1, 2], [0], [('axis', 'Y'), ('pivot_axis', 'Y')]), 
	'align_euler_to_vector_y_z' : NodeInstance('FunctionNodeAlignEulerToVector', [0, 1, 2], [0], [('axis', 'Y'), ('pivot_axis', 'Z')]), 
	'align_euler_to_vector_z_auto' : NodeInstance('FunctionNodeAlignEulerToVector', [0, 1, 2], [0], [('axis', 'Z'), ('pivot_axis', 'AUTO')]), 
	'align_euler_to_vector_z_x' : NodeInstance('FunctionNodeAlignEulerToVector', [0, 1, 2], [0], [('axis', 'Z'), ('pivot_axis', 'X')]), 
	'align_euler_to_vector_z_y' : NodeInstance('FunctionNodeAlignEulerToVector', [0, 1, 2], [0], [('axis', 'Z'), ('pivot_axis', 'Y')]), 
	'align_euler_to_vector_z_z' : NodeInstance('FunctionNodeAlignEulerToVector', [0, 1, 2], [0], [('axis', 'Z'), ('pivot_axis', 'Z')]), 
	'align_rotation_to_vector' : NodeInstance('FunctionNodeAlignRotationToVector', [0, 1, 2], [0], []), 
	'align_rotation_to_vector_x_auto' : NodeInstance('FunctionNodeAlignRotationToVector', [0, 1, 2], [0], [('axis', 'X'), ('pivot_axis', 'AUTO')]), 
	'align_rotation_to_vector_x_x' : NodeInstance('FunctionNodeAlignRotationToVector', [0, 1, 2], [0], [('axis', 'X'), ('pivot_axis', 'X')]), 
	'align_rotation_to_vector_x_y' : NodeInstance('FunctionNodeAlignRotationToVector', [0, 1, 2], [0], [('axis', 'X'), ('pivot_axis', 'Y')]), 
	'align_rotation_to_vector_x_z' : NodeInstance('FunctionNodeAlignRotationToVector', [0, 1, 2], [0], [('axis', 'X'), ('pivot_axis', 'Z')]), 
	'align_rotation_to_vector_y_auto' : NodeInstance('FunctionNodeAlignRotationToVector', [0, 1, 2], [0], [('axis', 'Y'), ('pivot_axis', 'AUTO')]), 
	'align_rotation_to_vector_y_x' : NodeInstance('FunctionNodeAlignRotationToVector', [0, 1, 2], [0], [('axis', 'Y'), ('pivot_axis', 'X')]), 
	'align_rotation_to_vector_y_y' : NodeInstance('FunctionNodeAlignRotationToVector', [0, 1, 2], [0], [('axis', 'Y'), ('pivot_axis', 'Y')]), 
	'align_rotation_to_vector_y_z' : NodeInstance('FunctionNodeAlignRotationToVector', [0, 1, 2], [0], [('axis', 'Y'), ('pivot_axis', 'Z')]), 
	'align_rotation_to_vector_z_auto' : NodeInstance('FunctionNodeAlignRotationToVector', [0, 1, 2], [0], [('axis', 'Z'), ('pivot_axis', 'AUTO')]), 
	'align_rotation_to_vector_z_x' : NodeInstance('FunctionNodeAlignRotationToVector', [0, 1, 2], [0], [('axis', 'Z'), ('pivot_axis', 'X')]), 
	'align_rotation_to_vector_z_y' : NodeInstance('FunctionNodeAlignRotationToVector', [0, 1, 2], [0], [('axis', 'Z'), ('pivot_axis', 'Y')]), 
	'align_rotation_to_vector_z_z' : NodeInstance('FunctionNodeAlignRotationToVector', [0, 1, 2], [0], [('axis', 'Z'), ('pivot_axis', 'Z')]), 
	'arc' : NodeInstance('GeometryNodeCurveArc', [0, 4, 5, 6, 8, 9], [0], []), 
	'arc_points' : NodeInstance('GeometryNodeCurveArc', [0, 1, 2, 3, 7, 8, 9], [0, 1, 2, 3], [('mode', 'POINTS')]), 
	'arc_radius' : NodeInstance('GeometryNodeCurveArc', [0, 4, 5, 6, 8, 9], [0], [('mode', 'RADIUS')]), 
	'attribute_statistic' : NodeInstance('GeometryNodeAttributeStatistic', [0, 1, 2], [0, 1, 2, 3, 4, 5, 6, 7], []), 
	'attribute_statistic_float_edge' : NodeInstance('GeometryNodeAttributeStatistic', [0, 1, 2], [0, 1, 2, 3, 4, 5, 6, 7], [('data_type', 'FLOAT'), ('domain', 'EDGE')]), 
	'attribute_statistic_float_face' : NodeInstance('GeometryNodeAttributeStatistic', [0, 1, 2], [0, 1, 2, 3, 4, 5, 6, 7], [('data_type', 'FLOAT'), ('domain', 'FACE')]), 
	'attribute_statistic_float_face_corner' : NodeInstance('GeometryNodeAttributeStatistic', [0, 1, 2], [0, 1, 2, 3, 4, 5, 6, 7], [('data_type', 'FLOAT'), ('domain', 'CORNER')]), 
	'attribute_statistic_float_instance' : NodeInstance('GeometryNodeAttributeStatistic', [0, 1, 2], [0, 1, 2, 3, 4, 5, 6, 7], [('data_type', 'FLOAT'), ('domain', 'INSTANCE')]), 
	'attribute_statistic_float_layer' : NodeInstance('GeometryNodeAttributeStatistic', [0, 1, 2], [0, 1, 2, 3, 4, 5, 6, 7], [('data_type', 'FLOAT'), ('domain', 'LAYER')]), 
	'attribute_statistic_float_point' : NodeInstance('GeometryNodeAttributeStatistic', [0, 1, 2], [0, 1, 2, 3, 4, 5, 6, 7], [('data_type', 'FLOAT'), ('domain', 'POINT')]), 
	'attribute_statistic_float_spline' : NodeInstance('GeometryNodeAttributeStatistic', [0, 1, 2], [0, 1, 2, 3, 4, 5, 6, 7], [('data_type', 'FLOAT'), ('domain', 'CURVE')]), 
	'attribute_statistic_vector_edge' : NodeInstance('GeometryNodeAttributeStatistic', [0, 1, 2], [0, 1, 2, 3, 4, 5, 6, 7], [('data_type', 'FLOAT_VECTOR'), ('domain', 'EDGE')]), 
	'attribute_statistic_vector_face' : NodeInstance('GeometryNodeAttributeStatistic', [0, 1, 2], [0, 1, 2, 3, 4, 5, 6, 7], [('data_type', 'FLOAT_VECTOR'), ('domain', 'FACE')]), 
	'attribute_statistic_vector_face_corner' : NodeInstance('GeometryNodeAttributeStatistic', [0, 1, 2], [0, 1, 2, 3, 4, 5, 6, 7], [('data_type', 'FLOAT_VECTOR'), ('domain', 'CORNER')]), 
	'attribute_statistic_vector_instance' : NodeInstance('GeometryNodeAttributeStatistic', [0, 1, 2], [0, 1, 2, 3, 4, 5, 6, 7], [('data_type', 'FLOAT_VECTOR'), ('domain', 'INSTANCE')]), 
	'attribute_statistic_vector_layer' : NodeInstance('GeometryNodeAttributeStatistic', [0, 1, 2], [0, 1, 2, 3, 4, 5, 6, 7], [('data_type', 'FLOAT_VECTOR'), ('domain', 'LAYER')]), 
	'attribute_statistic_vector_point' : NodeInstance('GeometryNodeAttributeStatistic', [0, 1, 2], [0, 1, 2, 3, 4, 5, 6, 7], [('data_type', 'FLOAT_VECTOR'), ('domain', 'POINT')]), 
	'attribute_statistic_vector_spline' : NodeInstance('GeometryNodeAttributeStatistic', [0, 1, 2], [0, 1, 2, 3, 4, 5, 6, 7], [('data_type', 'FLOAT_VECTOR'), ('domain', 'CURVE')]), 
	'axes_to_rotation' : NodeInstance('FunctionNodeAxesToRotation', [0, 1], [0], []), 
	'axes_to_rotation_x_x' : NodeInstance('FunctionNodeAxesToRotation', [0, 1], [0], [('primary_axis', 'X'), ('secondary_axis', 'X')]), 
	'axes_to_rotation_x_y' : NodeInstance('FunctionNodeAxesToRotation', [0, 1], [0], [('primary_axis', 'X'), ('secondary_axis', 'Y')]), 
	'axes_to_rotation_x_z' : NodeInstance('FunctionNodeAxesToRotation', [0, 1], [0], [('primary_axis', 'X'), ('secondary_axis', 'Z')]), 
	'axes_to_rotation_y_x' : NodeInstance('FunctionNodeAxesToRotation', [0, 1], [0], [('primary_axis', 'Y'), ('secondary_axis', 'X')]), 
	'axes_to_rotation_y_y' : NodeInstance('FunctionNodeAxesToRotation', [0, 1], [0], [('primary_axis', 'Y'), ('secondary_axis', 'Y')]), 
	'axes_to_rotation_y_z' : NodeInstance('FunctionNodeAxesToRotation', [0, 1], [0], [('primary_axis', 'Y'), ('secondary_axis', 'Z')]), 
	'axes_to_rotation_z_x' : NodeInstance('FunctionNodeAxesToRotation', [0, 1], [0], [('primary_axis', 'Z'), ('secondary_axis', 'X')]), 
	'axes_to_rotation_z_y' : NodeInstance('FunctionNodeAxesToRotation', [0, 1], [0], [('primary_axis', 'Z'), ('secondary_axis', 'Y')]), 
	'axes_to_rotation_z_z' : NodeInstance('FunctionNodeAxesToRotation', [0, 1], [0], [('primary_axis', 'Z'), ('secondary_axis', 'Z')]), 
	'axis_angle_to_rotation' : NodeInstance('FunctionNodeAxisAngleToRotation', [0, 1], [0], []), 
	'bake' : NodeInstance('GeometryNodeBake', [0, 1], [0, 1], []), 
	'blur_attribute' : NodeInstance('GeometryNodeBlurAttribute', [0, 1, 2], [0], []), 
	'blur_attribute_color' : NodeInstance('GeometryNodeBlurAttribute', [0, 1, 2], [0], [('data_type', 'FLOAT_COLOR')]), 
	'blur_attribute_float' : NodeInstance('GeometryNodeBlurAttribute', [0, 1, 2], [0], [('data_type', 'FLOAT')]), 
	'blur_attribute_integer' : NodeInstance('GeometryNodeBlurAttribute', [0, 1, 2], [0], [('data_type', 'INT')]), 
	'blur_attribute_vector' : NodeInstance('GeometryNodeBlurAttribute', [0, 1, 2], [0], [('data_type', 'FLOAT_VECTOR')]), 
	'boolean' : NodeInstance('FunctionNodeInputBool', [], [0], []), 
	'boolean_math' : NodeInstance('FunctionNodeBooleanMath', [0, 1], [0], []), 
	'boolean_math_and' : NodeInstance('FunctionNodeBooleanMath', [0, 1], [0], [('operation', 'AND')]), 
	'boolean_math_equal' : NodeInstance('FunctionNodeBooleanMath', [0, 1], [0], [('operation', 'XNOR')]), 
	'boolean_math_imply' : NodeInstance('FunctionNodeBooleanMath', [0, 1], [0], [('operation', 'IMPLY')]), 
	'boolean_math_nor' : NodeInstance('FunctionNodeBooleanMath', [0, 1], [0], [('operation', 'NOR')]), 
	'boolean_math_not' : NodeInstance('FunctionNodeBooleanMath', [0], [0], [('operation', 'NOT')]), 
	'boolean_math_not_and' : NodeInstance('FunctionNodeBooleanMath', [0, 1], [0], [('operation', 'NAND')]), 
	'boolean_math_not_equal' : NodeInstance('FunctionNodeBooleanMath', [0, 1], [0], [('operation', 'XOR')]), 
	'boolean_math_or' : NodeInstance('FunctionNodeBooleanMath', [0, 1], [0], [('operation', 'OR')]), 
	'boolean_math_subtract' : NodeInstance('FunctionNodeBooleanMath', [0, 1], [0], [('operation', 'NIMPLY')]), 
	'bounding_box' : NodeInstance('GeometryNodeBoundBox', [0], [0, 1, 2], []), 
	'bézier_segment' : NodeInstance('GeometryNodeCurvePrimitiveBezierSegment', [0, 1, 2, 3, 4], [0], []), 
	'bézier_segment_offset' : NodeInstance('GeometryNodeCurvePrimitiveBezierSegment', [0, 1, 2, 3, 4], [0], [('mode', 'OFFSET')]), 
	'bézier_segment_position' : NodeInstance('GeometryNodeCurvePrimitiveBezierSegment', [0, 1, 2, 3, 4], [0], [('mode', 'POSITION')]), 
	'capture_attribute' : NodeInstance('GeometryNodeCaptureAttribute', [0, 1], [0, 1], []), 
	'capture_attribute_edge' : NodeInstance('GeometryNodeCaptureAttribute', [0, 1], [0, 1], [('domain', 'EDGE')]), 
	'capture_attribute_face' : NodeInstance('GeometryNodeCaptureAttribute', [0, 1], [0, 1], [('domain', 'FACE')]), 
	'capture_attribute_face_corner' : NodeInstance('GeometryNodeCaptureAttribute', [0, 1], [0, 1], [('domain', 'CORNER')]), 
	'capture_attribute_instance' : NodeInstance('GeometryNodeCaptureAttribute', [0, 1], [0, 1], [('domain', 'INSTANCE')]), 
	'capture_attribute_layer' : NodeInstance('GeometryNodeCaptureAttribute', [0, 1], [0, 1], [('domain', 'LAYER')]), 
	'capture_attribute_point' : NodeInstance('GeometryNodeCaptureAttribute', [0, 1], [0, 1], [('domain', 'POINT')]), 
	'capture_attribute_spline' : NodeInstance('GeometryNodeCaptureAttribute', [0, 1], [0, 1], [('domain', 'CURVE')]), 
	'collection' : NodeInstance('GeometryNodeInputCollection', [], [0], []), 
	'collection_info' : NodeInstance('GeometryNodeCollectionInfo', [0, 1, 2], [0], []), 
	'collection_info_original' : NodeInstance('GeometryNodeCollectionInfo', [0, 1, 2], [0], [('transform_space', 'ORIGINAL')]), 
	'collection_info_relative' : NodeInstance('GeometryNodeCollectionInfo', [0, 1, 2], [0], [('transform_space', 'RELATIVE')]), 
	'color' : NodeInstance('FunctionNodeInputColor', [], [0], []), 
	'combine_color' : NodeInstance('FunctionNodeCombineColor', [0, 1, 2, 3], [0], []), 
	'combine_color_hsl' : NodeInstance('FunctionNodeCombineColor', [0, 1, 2, 3], [0], [('mode', 'HSL')]), 
	'combine_color_hsv' : NodeInstance('FunctionNodeCombineColor', [0, 1, 2, 3], [0], [('mode', 'HSV')]), 
	'combine_color_rgb' : NodeInstance('FunctionNodeCombineColor', [0, 1, 2, 3], [0], [('mode', 'RGB')]), 
	'combine_matrix' : NodeInstance('FunctionNodeCombineMatrix', [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15], [0], []), 
	'combine_transform' : NodeInstance('FunctionNodeCombineTransform', [0, 1, 2], [0], []), 
	'compare' : NodeInstance('FunctionNodeCompare', [0, 1], [0], []), 
	'compare_color_brighter_average' : NodeInstance('FunctionNodeCompare', [6, 7], [0], [('data_type', 'RGBA'), ('operation', 'BRIGHTER'), ('mode', 'AVERAGE')]), 
	'compare_color_brighter_direction' : NodeInstance('FunctionNodeCompare', [6, 7], [0], [('data_type', 'RGBA'), ('operation', 'BRIGHTER'), ('mode', 'DIRECTION')]), 
	'compare_color_brighter_dot_product' : NodeInstance('FunctionNodeCompare', [6, 7], [0], [('data_type', 'RGBA'), ('operation', 'BRIGHTER'), ('mode', 'DOT_PRODUCT')]), 
	'compare_color_brighter_element_wise' : NodeInstance('FunctionNodeCompare', [6, 7], [0], [('data_type', 'RGBA'), ('operation', 'BRIGHTER'), ('mode', 'ELEMENT')]), 
	'compare_color_brighter_length' : NodeInstance('FunctionNodeCompare', [6, 7], [0], [('data_type', 'RGBA'), ('operation', 'BRIGHTER'), ('mode', 'LENGTH')]), 
	'compare_color_darker_average' : NodeInstance('FunctionNodeCompare', [6, 7], [0], [('data_type', 'RGBA'), ('operation', 'DARKER'), ('mode', 'AVERAGE')]), 
	'compare_color_darker_direction' : NodeInstance('FunctionNodeCompare', [6, 7], [0], [('data_type', 'RGBA'), ('operation', 'DARKER'), ('mode', 'DIRECTION')]), 
	'compare_color_darker_dot_product' : NodeInstance('FunctionNodeCompare', [6, 7], [0], [('data_type', 'RGBA'), ('operation', 'DARKER'), ('mode', 'DOT_PRODUCT')]), 
	'compare_color_darker_element_wise' : NodeInstance('FunctionNodeCompare', [6, 7], [0], [('data_type', 'RGBA'), ('operation', 'DARKER'), ('mode', 'ELEMENT')]), 
	'compare_color_darker_length' : NodeInstance('FunctionNodeCompare', [6, 7], [0], [('data_type', 'RGBA'), ('operation', 'DARKER'), ('mode', 'LENGTH')]), 
	'compare_equal_color_average' : NodeInstance('FunctionNodeCompare', [6, 7, 12], [0], [('operation', 'EQUAL'), ('data_type', 'RGBA'), ('mode', 'AVERAGE')]), 
	'compare_equal_color_direction' : NodeInstance('FunctionNodeCompare', [6, 7, 12], [0], [('operation', 'EQUAL'), ('data_type', 'RGBA'), ('mode', 'DIRECTION')]), 
	'compare_equal_color_dot_product' : NodeInstance('FunctionNodeCompare', [6, 7, 12], [0], [('operation', 'EQUAL'), ('data_type', 'RGBA'), ('mode', 'DOT_PRODUCT')]), 
	'compare_equal_color_element_wise' : NodeInstance('FunctionNodeCompare', [6, 7, 12], [0], [('operation', 'EQUAL'), ('data_type', 'RGBA'), ('mode', 'ELEMENT')]), 
	'compare_equal_color_length' : NodeInstance('FunctionNodeCompare', [6, 7, 12], [0], [('operation', 'EQUAL'), ('data_type', 'RGBA'), ('mode', 'LENGTH')]), 
	'compare_equal_float_average' : NodeInstance('FunctionNodeCompare', [0, 1, 12], [0], [('operation', 'EQUAL'), ('data_type', 'FLOAT'), ('mode', 'AVERAGE')]), 
	'compare_equal_float_direction' : NodeInstance('FunctionNodeCompare', [0, 1, 12], [0], [('operation', 'EQUAL'), ('data_type', 'FLOAT'), ('mode', 'DIRECTION')]), 
	'compare_equal_float_dot_product' : NodeInstance('FunctionNodeCompare', [0, 1, 12], [0], [('operation', 'EQUAL'), ('data_type', 'FLOAT'), ('mode', 'DOT_PRODUCT')]), 
	'compare_equal_float_element_wise' : NodeInstance('FunctionNodeCompare', [0, 1, 12], [0], [('operation', 'EQUAL'), ('data_type', 'FLOAT'), ('mode', 'ELEMENT')]), 
	'compare_equal_float_length' : NodeInstance('FunctionNodeCompare', [0, 1, 12], [0], [('operation', 'EQUAL'), ('data_type', 'FLOAT'), ('mode', 'LENGTH')]), 
	'compare_equal_integer_average' : NodeInstance('FunctionNodeCompare', [2, 3], [0], [('operation', 'EQUAL'), ('data_type', 'INT'), ('mode', 'AVERAGE')]), 
	'compare_equal_integer_direction' : NodeInstance('FunctionNodeCompare', [2, 3], [0], [('operation', 'EQUAL'), ('data_type', 'INT'), ('mode', 'DIRECTION')]), 
	'compare_equal_integer_dot_product' : NodeInstance('FunctionNodeCompare', [2, 3], [0], [('operation', 'EQUAL'), ('data_type', 'INT'), ('mode', 'DOT_PRODUCT')]), 
	'compare_equal_integer_element_wise' : NodeInstance('FunctionNodeCompare', [2, 3], [0], [('operation', 'EQUAL'), ('data_type', 'INT'), ('mode', 'ELEMENT')]), 
	'compare_equal_integer_length' : NodeInstance('FunctionNodeCompare', [2, 3], [0], [('operation', 'EQUAL'), ('data_type', 'INT'), ('mode', 'LENGTH')]), 
	'compare_equal_string_average' : NodeInstance('FunctionNodeCompare', [8, 9], [0], [('operation', 'EQUAL'), ('data_type', 'STRING'), ('mode', 'AVERAGE')]), 
	'compare_equal_string_direction' : NodeInstance('FunctionNodeCompare', [8, 9], [0], [('operation', 'EQUAL'), ('data_type', 'STRING'), ('mode', 'DIRECTION')]), 
	'compare_equal_string_dot_product' : NodeInstance('FunctionNodeCompare', [8, 9], [0], [('operation', 'EQUAL'), ('data_type', 'STRING'), ('mode', 'DOT_PRODUCT')]), 
	'compare_equal_string_element_wise' : NodeInstance('FunctionNodeCompare', [8, 9], [0], [('operation', 'EQUAL'), ('data_type', 'STRING'), ('mode', 'ELEMENT')]), 
	'compare_equal_string_length' : NodeInstance('FunctionNodeCompare', [8, 9], [0], [('operation', 'EQUAL'), ('data_type', 'STRING'), ('mode', 'LENGTH')]), 
	'compare_equal_vector_average' : NodeInstance('FunctionNodeCompare', [4, 5, 12], [0], [('operation', 'EQUAL'), ('data_type', 'VECTOR'), ('mode', 'AVERAGE')]), 
	'compare_equal_vector_direction' : NodeInstance('FunctionNodeCompare', [4, 5, 11, 12], [0], [('operation', 'EQUAL'), ('data_type', 'VECTOR'), ('mode', 'DIRECTION')]), 
	'compare_equal_vector_dot_product' : NodeInstance('FunctionNodeCompare', [4, 5, 10, 12], [0], [('operation', 'EQUAL'), ('data_type', 'VECTOR'), ('mode', 'DOT_PRODUCT')]), 
	'compare_equal_vector_element_wise' : NodeInstance('FunctionNodeCompare', [4, 5, 12], [0], [('operation', 'EQUAL'), ('data_type', 'VECTOR'), ('mode', 'ELEMENT')]), 
	'compare_equal_vector_length' : NodeInstance('FunctionNodeCompare', [4, 5, 12], [0], [('operation', 'EQUAL'), ('data_type', 'VECTOR'), ('mode', 'LENGTH')]), 
	'compare_greater_than_color_average' : NodeInstance('FunctionNodeCompare', [6, 7, 12], [0], [('operation', 'GREATER_THAN'), ('data_type', 'RGBA'), ('mode', 'AVERAGE')]), 
	'compare_greater_than_color_direction' : NodeInstance('FunctionNodeCompare', [6, 7, 12], [0], [('operation', 'GREATER_THAN'), ('data_type', 'RGBA'), ('mode', 'DIRECTION')]), 
	'compare_greater_than_color_dot_product' : NodeInstance('FunctionNodeCompare', [6, 7, 12], [0], [('operation', 'GREATER_THAN'), ('data_type', 'RGBA'), ('mode', 'DOT_PRODUCT')]), 
	'compare_greater_than_color_element_wise' : NodeInstance('FunctionNodeCompare', [6, 7, 12], [0], [('operation', 'GREATER_THAN'), ('data_type', 'RGBA'), ('mode', 'ELEMENT')]), 
	'compare_greater_than_color_length' : NodeInstance('FunctionNodeCompare', [6, 7, 12], [0], [('operation', 'GREATER_THAN'), ('data_type', 'RGBA'), ('mode', 'LENGTH')]), 
	'compare_greater_than_float_average' : NodeInstance('FunctionNodeCompare', [0, 1], [0], [('operation', 'GREATER_THAN'), ('data_type', 'FLOAT'), ('mode', 'AVERAGE')]), 
	'compare_greater_than_float_direction' : NodeInstance('FunctionNodeCompare', [0, 1], [0], [('operation', 'GREATER_THAN'), ('data_type', 'FLOAT'), ('mode', 'DIRECTION')]), 
	'compare_greater_than_float_dot_product' : NodeInstance('FunctionNodeCompare', [0, 1], [0], [('operation', 'GREATER_THAN'), ('data_type', 'FLOAT'), ('mode', 'DOT_PRODUCT')]), 
	'compare_greater_than_float_element_wise' : NodeInstance('FunctionNodeCompare', [0, 1], [0], [('operation', 'GREATER_THAN'), ('data_type', 'FLOAT'), ('mode', 'ELEMENT')]), 
	'compare_greater_than_float_length' : NodeInstance('FunctionNodeCompare', [0, 1], [0], [('operation', 'GREATER_THAN'), ('data_type', 'FLOAT'), ('mode', 'LENGTH')]), 
	'compare_greater_than_integer_average' : NodeInstance('FunctionNodeCompare', [2, 3], [0], [('operation', 'GREATER_THAN'), ('data_type', 'INT'), ('mode', 'AVERAGE')]), 
	'compare_greater_than_integer_direction' : NodeInstance('FunctionNodeCompare', [2, 3], [0], [('operation', 'GREATER_THAN'), ('data_type', 'INT'), ('mode', 'DIRECTION')]), 
	'compare_greater_than_integer_dot_product' : NodeInstance('FunctionNodeCompare', [2, 3], [0], [('operation', 'GREATER_THAN'), ('data_type', 'INT'), ('mode', 'DOT_PRODUCT')]), 
	'compare_greater_than_integer_element_wise' : NodeInstance('FunctionNodeCompare', [2, 3], [0], [('operation', 'GREATER_THAN'), ('data_type', 'INT'), ('mode', 'ELEMENT')]), 
	'compare_greater_than_integer_length' : NodeInstance('FunctionNodeCompare', [2, 3], [0], [('operation', 'GREATER_THAN'), ('data_type', 'INT'), ('mode', 'LENGTH')]), 
	'compare_greater_than_or_equal_color_average' : NodeInstance('FunctionNodeCompare', [6, 7, 12], [0], [('operation', 'GREATER_EQUAL'), ('data_type', 'RGBA'), ('mode', 'AVERAGE')]), 
	'compare_greater_than_or_equal_color_direction' : NodeInstance('FunctionNodeCompare', [6, 7, 12], [0], [('operation', 'GREATER_EQUAL'), ('data_type', 'RGBA'), ('mode', 'DIRECTION')]), 
	'compare_greater_than_or_equal_color_dot_product' : NodeInstance('FunctionNodeCompare', [6, 7, 12], [0], [('operation', 'GREATER_EQUAL'), ('data_type', 'RGBA'), ('mode', 'DOT_PRODUCT')]), 
	'compare_greater_than_or_equal_color_element_wise' : NodeInstance('FunctionNodeCompare', [6, 7, 12], [0], [('operation', 'GREATER_EQUAL'), ('data_type', 'RGBA'), ('mode', 'ELEMENT')]), 
	'compare_greater_than_or_equal_color_length' : NodeInstance('FunctionNodeCompare', [6, 7, 12], [0], [('operation', 'GREATER_EQUAL'), ('data_type', 'RGBA'), ('mode', 'LENGTH')]), 
	'compare_greater_than_or_equal_float_average' : NodeInstance('FunctionNodeCompare', [0, 1], [0], [('operation', 'GREATER_EQUAL'), ('data_type', 'FLOAT'), ('mode', 'AVERAGE')]), 
	'compare_greater_than_or_equal_float_direction' : NodeInstance('FunctionNodeCompare', [0, 1], [0], [('operation', 'GREATER_EQUAL'), ('data_type', 'FLOAT'), ('mode', 'DIRECTION')]), 
	'compare_greater_than_or_equal_float_dot_product' : NodeInstance('FunctionNodeCompare', [0, 1], [0], [('operation', 'GREATER_EQUAL'), ('data_type', 'FLOAT'), ('mode', 'DOT_PRODUCT')]), 
	'compare_greater_than_or_equal_float_element_wise' : NodeInstance('FunctionNodeCompare', [0, 1], [0], [('operation', 'GREATER_EQUAL'), ('data_type', 'FLOAT'), ('mode', 'ELEMENT')]), 
	'compare_greater_than_or_equal_float_length' : NodeInstance('FunctionNodeCompare', [0, 1], [0], [('operation', 'GREATER_EQUAL'), ('data_type', 'FLOAT'), ('mode', 'LENGTH')]), 
	'compare_greater_than_or_equal_integer_average' : NodeInstance('FunctionNodeCompare', [2, 3], [0], [('operation', 'GREATER_EQUAL'), ('data_type', 'INT'), ('mode', 'AVERAGE')]), 
	'compare_greater_than_or_equal_integer_direction' : NodeInstance('FunctionNodeCompare', [2, 3], [0], [('operation', 'GREATER_EQUAL'), ('data_type', 'INT'), ('mode', 'DIRECTION')]), 
	'compare_greater_than_or_equal_integer_dot_product' : NodeInstance('FunctionNodeCompare', [2, 3], [0], [('operation', 'GREATER_EQUAL'), ('data_type', 'INT'), ('mode', 'DOT_PRODUCT')]), 
	'compare_greater_than_or_equal_integer_element_wise' : NodeInstance('FunctionNodeCompare', [2, 3], [0], [('operation', 'GREATER_EQUAL'), ('data_type', 'INT'), ('mode', 'ELEMENT')]), 
	'compare_greater_than_or_equal_integer_length' : NodeInstance('FunctionNodeCompare', [2, 3], [0], [('operation', 'GREATER_EQUAL'), ('data_type', 'INT'), ('mode', 'LENGTH')]), 
	'compare_greater_than_or_equal_string_average' : NodeInstance('FunctionNodeCompare', [8, 9], [0], [('operation', 'GREATER_EQUAL'), ('data_type', 'STRING'), ('mode', 'AVERAGE')]), 
	'compare_greater_than_or_equal_string_direction' : NodeInstance('FunctionNodeCompare', [8, 9], [0], [('operation', 'GREATER_EQUAL'), ('data_type', 'STRING'), ('mode', 'DIRECTION')]), 
	'compare_greater_than_or_equal_string_dot_product' : NodeInstance('FunctionNodeCompare', [8, 9], [0], [('operation', 'GREATER_EQUAL'), ('data_type', 'STRING'), ('mode', 'DOT_PRODUCT')]), 
	'compare_greater_than_or_equal_string_element_wise' : NodeInstance('FunctionNodeCompare', [8, 9], [0], [('operation', 'GREATER_EQUAL'), ('data_type', 'STRING'), ('mode', 'ELEMENT')]), 
	'compare_greater_than_or_equal_string_length' : NodeInstance('FunctionNodeCompare', [8, 9], [0], [('operation', 'GREATER_EQUAL'), ('data_type', 'STRING'), ('mode', 'LENGTH')]), 
	'compare_greater_than_or_equal_vector_average' : NodeInstance('FunctionNodeCompare', [4, 5], [0], [('operation', 'GREATER_EQUAL'), ('data_type', 'VECTOR'), ('mode', 'AVERAGE')]), 
	'compare_greater_than_or_equal_vector_direction' : NodeInstance('FunctionNodeCompare', [4, 5, 11], [0], [('operation', 'GREATER_EQUAL'), ('data_type', 'VECTOR'), ('mode', 'DIRECTION')]), 
	'compare_greater_than_or_equal_vector_dot_product' : NodeInstance('FunctionNodeCompare', [4, 5, 10], [0], [('operation', 'GREATER_EQUAL'), ('data_type', 'VECTOR'), ('mode', 'DOT_PRODUCT')]), 
	'compare_greater_than_or_equal_vector_element_wise' : NodeInstance('FunctionNodeCompare', [4, 5], [0], [('operation', 'GREATER_EQUAL'), ('data_type', 'VECTOR'), ('mode', 'ELEMENT')]), 
	'compare_greater_than_or_equal_vector_length' : NodeInstance('FunctionNodeCompare', [4, 5], [0], [('operation', 'GREATER_EQUAL'), ('data_type', 'VECTOR'), ('mode', 'LENGTH')]), 
	'compare_greater_than_string_average' : NodeInstance('FunctionNodeCompare', [8, 9], [0], [('operation', 'GREATER_THAN'), ('data_type', 'STRING'), ('mode', 'AVERAGE')]), 
	'compare_greater_than_string_direction' : NodeInstance('FunctionNodeCompare', [8, 9], [0], [('operation', 'GREATER_THAN'), ('data_type', 'STRING'), ('mode', 'DIRECTION')]), 
	'compare_greater_than_string_dot_product' : NodeInstance('FunctionNodeCompare', [8, 9], [0], [('operation', 'GREATER_THAN'), ('data_type', 'STRING'), ('mode', 'DOT_PRODUCT')]), 
	'compare_greater_than_string_element_wise' : NodeInstance('FunctionNodeCompare', [8, 9], [0], [('operation', 'GREATER_THAN'), ('data_type', 'STRING'), ('mode', 'ELEMENT')]), 
	'compare_greater_than_string_length' : NodeInstance('FunctionNodeCompare', [8, 9], [0], [('operation', 'GREATER_THAN'), ('data_type', 'STRING'), ('mode', 'LENGTH')]), 
	'compare_greater_than_vector_average' : NodeInstance('FunctionNodeCompare', [4, 5], [0], [('operation', 'GREATER_THAN'), ('data_type', 'VECTOR'), ('mode', 'AVERAGE')]), 
	'compare_greater_than_vector_direction' : NodeInstance('FunctionNodeCompare', [4, 5, 11], [0], [('operation', 'GREATER_THAN'), ('data_type', 'VECTOR'), ('mode', 'DIRECTION')]), 
	'compare_greater_than_vector_dot_product' : NodeInstance('FunctionNodeCompare', [4, 5, 10], [0], [('operation', 'GREATER_THAN'), ('data_type', 'VECTOR'), ('mode', 'DOT_PRODUCT')]), 
	'compare_greater_than_vector_element_wise' : NodeInstance('FunctionNodeCompare', [4, 5], [0], [('operation', 'GREATER_THAN'), ('data_type', 'VECTOR'), ('mode', 'ELEMENT')]), 
	'compare_greater_than_vector_length' : NodeInstance('FunctionNodeCompare', [4, 5], [0], [('operation', 'GREATER_THAN'), ('data_type', 'VECTOR'), ('mode', 'LENGTH')]), 
	'compare_less_than_color_average' : NodeInstance('FunctionNodeCompare', [6, 7, 12], [0], [('operation', 'LESS_THAN'), ('data_type', 'RGBA'), ('mode', 'AVERAGE')]), 
	'compare_less_than_color_direction' : NodeInstance('FunctionNodeCompare', [6, 7, 12], [0], [('operation', 'LESS_THAN'), ('data_type', 'RGBA'), ('mode', 'DIRECTION')]), 
	'compare_less_than_color_dot_product' : NodeInstance('FunctionNodeCompare', [6, 7, 12], [0], [('operation', 'LESS_THAN'), ('data_type', 'RGBA'), ('mode', 'DOT_PRODUCT')]), 
	'compare_less_than_color_element_wise' : NodeInstance('FunctionNodeCompare', [6, 7, 12], [0], [('operation', 'LESS_THAN'), ('data_type', 'RGBA'), ('mode', 'ELEMENT')]), 
	'compare_less_than_color_length' : NodeInstance('FunctionNodeCompare', [6, 7, 12], [0], [('operation', 'LESS_THAN'), ('data_type', 'RGBA'), ('mode', 'LENGTH')]), 
	'compare_less_than_float_average' : NodeInstance('FunctionNodeCompare', [0, 1], [0], [('operation', 'LESS_THAN'), ('data_type', 'FLOAT'), ('mode', 'AVERAGE')]), 
	'compare_less_than_float_direction' : NodeInstance('FunctionNodeCompare', [0, 1], [0], [('operation', 'LESS_THAN'), ('data_type', 'FLOAT'), ('mode', 'DIRECTION')]), 
	'compare_less_than_float_dot_product' : NodeInstance('FunctionNodeCompare', [0, 1], [0], [('operation', 'LESS_THAN'), ('data_type', 'FLOAT'), ('mode', 'DOT_PRODUCT')]), 
	'compare_less_than_float_element_wise' : NodeInstance('FunctionNodeCompare', [0, 1], [0], [('operation', 'LESS_THAN'), ('data_type', 'FLOAT'), ('mode', 'ELEMENT')]), 
	'compare_less_than_float_length' : NodeInstance('FunctionNodeCompare', [0, 1], [0], [('operation', 'LESS_THAN'), ('data_type', 'FLOAT'), ('mode', 'LENGTH')]), 
	'compare_less_than_integer_average' : NodeInstance('FunctionNodeCompare', [2, 3], [0], [('operation', 'LESS_THAN'), ('data_type', 'INT'), ('mode', 'AVERAGE')]), 
	'compare_less_than_integer_direction' : NodeInstance('FunctionNodeCompare', [2, 3], [0], [('operation', 'LESS_THAN'), ('data_type', 'INT'), ('mode', 'DIRECTION')]), 
	'compare_less_than_integer_dot_product' : NodeInstance('FunctionNodeCompare', [2, 3], [0], [('operation', 'LESS_THAN'), ('data_type', 'INT'), ('mode', 'DOT_PRODUCT')]), 
	'compare_less_than_integer_element_wise' : NodeInstance('FunctionNodeCompare', [2, 3], [0], [('operation', 'LESS_THAN'), ('data_type', 'INT'), ('mode', 'ELEMENT')]), 
	'compare_less_than_integer_length' : NodeInstance('FunctionNodeCompare', [2, 3], [0], [('operation', 'LESS_THAN'), ('data_type', 'INT'), ('mode', 'LENGTH')]), 
	'compare_less_than_or_equal_color_average' : NodeInstance('FunctionNodeCompare', [6, 7, 12], [0], [('operation', 'LESS_EQUAL'), ('data_type', 'RGBA'), ('mode', 'AVERAGE')]), 
	'compare_less_than_or_equal_color_direction' : NodeInstance('FunctionNodeCompare', [6, 7, 12], [0], [('operation', 'LESS_EQUAL'), ('data_type', 'RGBA'), ('mode', 'DIRECTION')]), 
	'compare_less_than_or_equal_color_dot_product' : NodeInstance('FunctionNodeCompare', [6, 7, 12], [0], [('operation', 'LESS_EQUAL'), ('data_type', 'RGBA'), ('mode', 'DOT_PRODUCT')]), 
	'compare_less_than_or_equal_color_element_wise' : NodeInstance('FunctionNodeCompare', [6, 7, 12], [0], [('operation', 'LESS_EQUAL'), ('data_type', 'RGBA'), ('mode', 'ELEMENT')]), 
	'compare_less_than_or_equal_color_length' : NodeInstance('FunctionNodeCompare', [6, 7, 12], [0], [('operation', 'LESS_EQUAL'), ('data_type', 'RGBA'), ('mode', 'LENGTH')]), 
	'compare_less_than_or_equal_float_average' : NodeInstance('FunctionNodeCompare', [0, 1], [0], [('operation', 'LESS_EQUAL'), ('data_type', 'FLOAT'), ('mode', 'AVERAGE')]), 
	'compare_less_than_or_equal_float_direction' : NodeInstance('FunctionNodeCompare', [0, 1], [0], [('operation', 'LESS_EQUAL'), ('data_type', 'FLOAT'), ('mode', 'DIRECTION')]), 
	'compare_less_than_or_equal_float_dot_product' : NodeInstance('FunctionNodeCompare', [0, 1], [0], [('operation', 'LESS_EQUAL'), ('data_type', 'FLOAT'), ('mode', 'DOT_PRODUCT')]), 
	'compare_less_than_or_equal_float_element_wise' : NodeInstance('FunctionNodeCompare', [0, 1], [0], [('operation', 'LESS_EQUAL'), ('data_type', 'FLOAT'), ('mode', 'ELEMENT')]), 
	'compare_less_than_or_equal_float_length' : NodeInstance('FunctionNodeCompare', [0, 1], [0], [('operation', 'LESS_EQUAL'), ('data_type', 'FLOAT'), ('mode', 'LENGTH')]), 
	'compare_less_than_or_equal_integer_average' : NodeInstance('FunctionNodeCompare', [2, 3], [0], [('operation', 'LESS_EQUAL'), ('data_type', 'INT'), ('mode', 'AVERAGE')]), 
	'compare_less_than_or_equal_integer_direction' : NodeInstance('FunctionNodeCompare', [2, 3], [0], [('operation', 'LESS_EQUAL'), ('data_type', 'INT'), ('mode', 'DIRECTION')]), 
	'compare_less_than_or_equal_integer_dot_product' : NodeInstance('FunctionNodeCompare', [2, 3], [0], [('operation', 'LESS_EQUAL'), ('data_type', 'INT'), ('mode', 'DOT_PRODUCT')]), 
	'compare_less_than_or_equal_integer_element_wise' : NodeInstance('FunctionNodeCompare', [2, 3], [0], [('operation', 'LESS_EQUAL'), ('data_type', 'INT'), ('mode', 'ELEMENT')]), 
	'compare_less_than_or_equal_integer_length' : NodeInstance('FunctionNodeCompare', [2, 3], [0], [('operation', 'LESS_EQUAL'), ('data_type', 'INT'), ('mode', 'LENGTH')]), 
	'compare_less_than_or_equal_string_average' : NodeInstance('FunctionNodeCompare', [8, 9], [0], [('operation', 'LESS_EQUAL'), ('data_type', 'STRING'), ('mode', 'AVERAGE')]), 
	'compare_less_than_or_equal_string_direction' : NodeInstance('FunctionNodeCompare', [8, 9], [0], [('operation', 'LESS_EQUAL'), ('data_type', 'STRING'), ('mode', 'DIRECTION')]), 
	'compare_less_than_or_equal_string_dot_product' : NodeInstance('FunctionNodeCompare', [8, 9], [0], [('operation', 'LESS_EQUAL'), ('data_type', 'STRING'), ('mode', 'DOT_PRODUCT')]), 
	'compare_less_than_or_equal_string_element_wise' : NodeInstance('FunctionNodeCompare', [8, 9], [0], [('operation', 'LESS_EQUAL'), ('data_type', 'STRING'), ('mode', 'ELEMENT')]), 
	'compare_less_than_or_equal_string_length' : NodeInstance('FunctionNodeCompare', [8, 9], [0], [('operation', 'LESS_EQUAL'), ('data_type', 'STRING'), ('mode', 'LENGTH')]), 
	'compare_less_than_or_equal_vector_average' : NodeInstance('FunctionNodeCompare', [4, 5], [0], [('operation', 'LESS_EQUAL'), ('data_type', 'VECTOR'), ('mode', 'AVERAGE')]), 
	'compare_less_than_or_equal_vector_direction' : NodeInstance('FunctionNodeCompare', [4, 5, 11], [0], [('operation', 'LESS_EQUAL'), ('data_type', 'VECTOR'), ('mode', 'DIRECTION')]), 
	'compare_less_than_or_equal_vector_dot_product' : NodeInstance('FunctionNodeCompare', [4, 5, 10], [0], [('operation', 'LESS_EQUAL'), ('data_type', 'VECTOR'), ('mode', 'DOT_PRODUCT')]), 
	'compare_less_than_or_equal_vector_element_wise' : NodeInstance('FunctionNodeCompare', [4, 5], [0], [('operation', 'LESS_EQUAL'), ('data_type', 'VECTOR'), ('mode', 'ELEMENT')]), 
	'compare_less_than_or_equal_vector_length' : NodeInstance('FunctionNodeCompare', [4, 5], [0], [('operation', 'LESS_EQUAL'), ('data_type', 'VECTOR'), ('mode', 'LENGTH')]), 
	'compare_less_than_string_average' : NodeInstance('FunctionNodeCompare', [8, 9], [0], [('operation', 'LESS_THAN'), ('data_type', 'STRING'), ('mode', 'AVERAGE')]), 
	'compare_less_than_string_direction' : NodeInstance('FunctionNodeCompare', [8, 9], [0], [('operation', 'LESS_THAN'), ('data_type', 'STRING'), ('mode', 'DIRECTION')]), 
	'compare_less_than_string_dot_product' : NodeInstance('FunctionNodeCompare', [8, 9], [0], [('operation', 'LESS_THAN'), ('data_type', 'STRING'), ('mode', 'DOT_PRODUCT')]), 
	'compare_less_than_string_element_wise' : NodeInstance('FunctionNodeCompare', [8, 9], [0], [('operation', 'LESS_THAN'), ('data_type', 'STRING'), ('mode', 'ELEMENT')]), 
	'compare_less_than_string_length' : NodeInstance('FunctionNodeCompare', [8, 9], [0], [('operation', 'LESS_THAN'), ('data_type', 'STRING'), ('mode', 'LENGTH')]), 
	'compare_less_than_vector_average' : NodeInstance('FunctionNodeCompare', [4, 5], [0], [('operation', 'LESS_THAN'), ('data_type', 'VECTOR'), ('mode', 'AVERAGE')]), 
	'compare_less_than_vector_direction' : NodeInstance('FunctionNodeCompare', [4, 5, 11], [0], [('operation', 'LESS_THAN'), ('data_type', 'VECTOR'), ('mode', 'DIRECTION')]), 
	'compare_less_than_vector_dot_product' : NodeInstance('FunctionNodeCompare', [4, 5, 10], [0], [('operation', 'LESS_THAN'), ('data_type', 'VECTOR'), ('mode', 'DOT_PRODUCT')]), 
	'compare_less_than_vector_element_wise' : NodeInstance('FunctionNodeCompare', [4, 5], [0], [('operation', 'LESS_THAN'), ('data_type', 'VECTOR'), ('mode', 'ELEMENT')]), 
	'compare_less_than_vector_length' : NodeInstance('FunctionNodeCompare', [4, 5], [0], [('operation', 'LESS_THAN'), ('data_type', 'VECTOR'), ('mode', 'LENGTH')]), 
	'compare_not_equal_color_average' : NodeInstance('FunctionNodeCompare', [6, 7, 12], [0], [('operation', 'NOT_EQUAL'), ('data_type', 'RGBA'), ('mode', 'AVERAGE')]), 
	'compare_not_equal_color_direction' : NodeInstance('FunctionNodeCompare', [6, 7, 12], [0], [('operation', 'NOT_EQUAL'), ('data_type', 'RGBA'), ('mode', 'DIRECTION')]), 
	'compare_not_equal_color_dot_product' : NodeInstance('FunctionNodeCompare', [6, 7, 12], [0], [('operation', 'NOT_EQUAL'), ('data_type', 'RGBA'), ('mode', 'DOT_PRODUCT')]), 
	'compare_not_equal_color_element_wise' : NodeInstance('FunctionNodeCompare', [6, 7, 12], [0], [('operation', 'NOT_EQUAL'), ('data_type', 'RGBA'), ('mode', 'ELEMENT')]), 
	'compare_not_equal_color_length' : NodeInstance('FunctionNodeCompare', [6, 7, 12], [0], [('operation', 'NOT_EQUAL'), ('data_type', 'RGBA'), ('mode', 'LENGTH')]), 
	'compare_not_equal_float_average' : NodeInstance('FunctionNodeCompare', [0, 1, 12], [0], [('operation', 'NOT_EQUAL'), ('data_type', 'FLOAT'), ('mode', 'AVERAGE')]), 
	'compare_not_equal_float_direction' : NodeInstance('FunctionNodeCompare', [0, 1, 12], [0], [('operation', 'NOT_EQUAL'), ('data_type', 'FLOAT'), ('mode', 'DIRECTION')]), 
	'compare_not_equal_float_dot_product' : NodeInstance('FunctionNodeCompare', [0, 1, 12], [0], [('operation', 'NOT_EQUAL'), ('data_type', 'FLOAT'), ('mode', 'DOT_PRODUCT')]), 
	'compare_not_equal_float_element_wise' : NodeInstance('FunctionNodeCompare', [0, 1, 12], [0], [('operation', 'NOT_EQUAL'), ('data_type', 'FLOAT'), ('mode', 'ELEMENT')]), 
	'compare_not_equal_float_length' : NodeInstance('FunctionNodeCompare', [0, 1, 12], [0], [('operation', 'NOT_EQUAL'), ('data_type', 'FLOAT'), ('mode', 'LENGTH')]), 
	'compare_not_equal_integer_average' : NodeInstance('FunctionNodeCompare', [2, 3], [0], [('operation', 'NOT_EQUAL'), ('data_type', 'INT'), ('mode', 'AVERAGE')]), 
	'compare_not_equal_integer_direction' : NodeInstance('FunctionNodeCompare', [2, 3], [0], [('operation', 'NOT_EQUAL'), ('data_type', 'INT'), ('mode', 'DIRECTION')]), 
	'compare_not_equal_integer_dot_product' : NodeInstance('FunctionNodeCompare', [2, 3], [0], [('operation', 'NOT_EQUAL'), ('data_type', 'INT'), ('mode', 'DOT_PRODUCT')]), 
	'compare_not_equal_integer_element_wise' : NodeInstance('FunctionNodeCompare', [2, 3], [0], [('operation', 'NOT_EQUAL'), ('data_type', 'INT'), ('mode', 'ELEMENT')]), 
	'compare_not_equal_integer_length' : NodeInstance('FunctionNodeCompare', [2, 3], [0], [('operation', 'NOT_EQUAL'), ('data_type', 'INT'), ('mode', 'LENGTH')]), 
	'compare_not_equal_string_average' : NodeInstance('FunctionNodeCompare', [8, 9], [0], [('operation', 'NOT_EQUAL'), ('data_type', 'STRING'), ('mode', 'AVERAGE')]), 
	'compare_not_equal_string_direction' : NodeInstance('FunctionNodeCompare', [8, 9], [0], [('operation', 'NOT_EQUAL'), ('data_type', 'STRING'), ('mode', 'DIRECTION')]), 
	'compare_not_equal_string_dot_product' : NodeInstance('FunctionNodeCompare', [8, 9], [0], [('operation', 'NOT_EQUAL'), ('data_type', 'STRING'), ('mode', 'DOT_PRODUCT')]), 
	'compare_not_equal_string_element_wise' : NodeInstance('FunctionNodeCompare', [8, 9], [0], [('operation', 'NOT_EQUAL'), ('data_type', 'STRING'), ('mode', 'ELEMENT')]), 
	'compare_not_equal_string_length' : NodeInstance('FunctionNodeCompare', [8, 9], [0], [('operation', 'NOT_EQUAL'), ('data_type', 'STRING'), ('mode', 'LENGTH')]), 
	'compare_not_equal_vector_average' : NodeInstance('FunctionNodeCompare', [4, 5, 12], [0], [('operation', 'NOT_EQUAL'), ('data_type', 'VECTOR'), ('mode', 'AVERAGE')]), 
	'compare_not_equal_vector_direction' : NodeInstance('FunctionNodeCompare', [4, 5, 11, 12], [0], [('operation', 'NOT_EQUAL'), ('data_type', 'VECTOR'), ('mode', 'DIRECTION')]), 
	'compare_not_equal_vector_dot_product' : NodeInstance('FunctionNodeCompare', [4, 5, 10, 12], [0], [('operation', 'NOT_EQUAL'), ('data_type', 'VECTOR'), ('mode', 'DOT_PRODUCT')]), 
	'compare_not_equal_vector_element_wise' : NodeInstance('FunctionNodeCompare', [4, 5, 12], [0], [('operation', 'NOT_EQUAL'), ('data_type', 'VECTOR'), ('mode', 'ELEMENT')]), 
	'compare_not_equal_vector_length' : NodeInstance('FunctionNodeCompare', [4, 5, 12], [0], [('operation', 'NOT_EQUAL'), ('data_type', 'VECTOR'), ('mode', 'LENGTH')]), 
	'cone' : NodeInstance('GeometryNodeMeshCone', [0, 1, 2, 3, 4, 5], [0, 1, 2, 3, 4], []), 
	'cone_n_gon' : NodeInstance('GeometryNodeMeshCone', [0, 1, 2, 3, 4, 5], [0, 1, 2, 3, 4], [('fill_type', 'NGON')]), 
	'cone_none' : NodeInstance('GeometryNodeMeshCone', [0, 1, 3, 4, 5], [0, 1, 2, 3, 4], [('fill_type', 'NONE')]), 
	'cone_triangles' : NodeInstance('GeometryNodeMeshCone', [0, 1, 2, 3, 4, 5], [0, 1, 2, 3, 4], [('fill_type', 'TRIANGLE_FAN')]), 
	'convex_hull' : NodeInstance('GeometryNodeConvexHull', [0], [0], []), 
	'corners_of_edge' : NodeInstance('GeometryNodeCornersOfEdge', [0, 1, 2], [0, 1], []), 
	'corners_of_face' : NodeInstance('GeometryNodeCornersOfFace', [0, 1, 2], [0, 1], []), 
	'corners_of_vertex' : NodeInstance('GeometryNodeCornersOfVertex', [0, 1, 2], [0, 1], []), 
	'cube' : NodeInstance('GeometryNodeMeshCube', [0, 1, 2, 3], [0, 1], []), 
	'curve_circle' : NodeInstance('GeometryNodeCurvePrimitiveCircle', [0, 4], [0], []), 
	'curve_circle_points' : NodeInstance('GeometryNodeCurvePrimitiveCircle', [0, 1, 2, 3], [0, 1], [('mode', 'POINTS')]), 
	'curve_circle_radius' : NodeInstance('GeometryNodeCurvePrimitiveCircle', [0, 4], [0], [('mode', 'RADIUS')]), 
	'curve_handle_positions' : NodeInstance('GeometryNodeInputCurveHandlePositions', [0], [0, 1], []), 
	'curve_length' : NodeInstance('GeometryNodeCurveLength', [0], [0], []), 
	'curve_line' : NodeInstance('GeometryNodeCurvePrimitiveLine', [0, 1], [0], []), 
	'curve_line_direction' : NodeInstance('GeometryNodeCurvePrimitiveLine', [0, 2, 3], [0], [('mode', 'DIRECTION')]), 
	'curve_line_points' : NodeInstance('GeometryNodeCurvePrimitiveLine', [0, 1], [0], [('mode', 'POINTS')]), 
	'curve_of_point' : NodeInstance('GeometryNodeCurveOfPoint', [0], [0, 1], []), 
	'curve_tangent' : NodeInstance('GeometryNodeInputTangent', [], [0], []), 
	'curve_tilt' : NodeInstance('GeometryNodeInputCurveTilt', [], [0], []), 
	'curve_to_mesh' : NodeInstance('GeometryNodeCurveToMesh', [0, 1, 2], [0], []), 
	'curve_to_points' : NodeInstance('GeometryNodeCurveToPoints', [0, 1], [0, 1, 2, 3], []), 
	'curve_to_points_count' : NodeInstance('GeometryNodeCurveToPoints', [0, 1], [0, 1, 2, 3], [('mode', 'COUNT')]), 
	'curve_to_points_evaluated' : NodeInstance('GeometryNodeCurveToPoints', [0], [0, 1, 2, 3], [('mode', 'EVALUATED')]), 
	'curve_to_points_length' : NodeInstance('GeometryNodeCurveToPoints', [0, 2], [0, 1, 2, 3], [('mode', 'LENGTH')]), 
	'curves_to_grease_pencil' : NodeInstance('GeometryNodeCurvesToGreasePencil', [0, 1, 2], [0], []), 
	'cylinder' : NodeInstance('GeometryNodeMeshCylinder', [0, 1, 2, 3, 4], [0, 1, 2, 3, 4], []), 
	'cylinder_n_gon' : NodeInstance('GeometryNodeMeshCylinder', [0, 1, 2, 3, 4], [0, 1, 2, 3, 4], [('fill_type', 'NGON')]), 
	'cylinder_none' : NodeInstance('GeometryNodeMeshCylinder', [0, 1, 3, 4], [0, 1, 2, 3, 4], [('fill_type', 'NONE')]), 
	'cylinder_triangles' : NodeInstance('GeometryNodeMeshCylinder', [0, 1, 2, 3, 4], [0, 1, 2, 3, 4], [('fill_type', 'TRIANGLE_FAN')]), 
	'deform_curves_on_surface' : NodeInstance('GeometryNodeDeformCurvesOnSurface', [0], [0], []), 
	'delete_geometry' : NodeInstance('GeometryNodeDeleteGeometry', [0, 1], [0], []), 
	'delete_geometry_all_edge' : NodeInstance('GeometryNodeDeleteGeometry', [0, 1], [0], [('mode', 'ALL'), ('domain', 'EDGE')]), 
	'delete_geometry_all_face' : NodeInstance('GeometryNodeDeleteGeometry', [0, 1], [0], [('mode', 'ALL'), ('domain', 'FACE')]), 
	'delete_geometry_all_instance' : NodeInstance('GeometryNodeDeleteGeometry', [0, 1], [0], [('mode', 'ALL'), ('domain', 'INSTANCE')]), 
	'delete_geometry_all_layer' : NodeInstance('GeometryNodeDeleteGeometry', [0, 1], [0], [('mode', 'ALL'), ('domain', 'LAYER')]), 
	'delete_geometry_all_point' : NodeInstance('GeometryNodeDeleteGeometry', [0, 1], [0], [('mode', 'ALL'), ('domain', 'POINT')]), 
	'delete_geometry_all_spline' : NodeInstance('GeometryNodeDeleteGeometry', [0, 1], [0], [('mode', 'ALL'), ('domain', 'CURVE')]), 
	'delete_geometry_only_edges___faces_edge' : NodeInstance('GeometryNodeDeleteGeometry', [0, 1], [0], [('mode', 'EDGE_FACE'), ('domain', 'EDGE')]), 
	'delete_geometry_only_edges___faces_face' : NodeInstance('GeometryNodeDeleteGeometry', [0, 1], [0], [('mode', 'EDGE_FACE'), ('domain', 'FACE')]), 
	'delete_geometry_only_edges___faces_instance' : NodeInstance('GeometryNodeDeleteGeometry', [0, 1], [0], [('mode', 'EDGE_FACE'), ('domain', 'INSTANCE')]), 
	'delete_geometry_only_edges___faces_layer' : NodeInstance('GeometryNodeDeleteGeometry', [0, 1], [0], [('mode', 'EDGE_FACE'), ('domain', 'LAYER')]), 
	'delete_geometry_only_edges___faces_point' : NodeInstance('GeometryNodeDeleteGeometry', [0, 1], [0], [('mode', 'EDGE_FACE'), ('domain', 'POINT')]), 
	'delete_geometry_only_edges___faces_spline' : NodeInstance('GeometryNodeDeleteGeometry', [0, 1], [0], [('mode', 'EDGE_FACE'), ('domain', 'CURVE')]), 
	'delete_geometry_only_faces_edge' : NodeInstance('GeometryNodeDeleteGeometry', [0, 1], [0], [('mode', 'ONLY_FACE'), ('domain', 'EDGE')]), 
	'delete_geometry_only_faces_face' : NodeInstance('GeometryNodeDeleteGeometry', [0, 1], [0], [('mode', 'ONLY_FACE'), ('domain', 'FACE')]), 
	'delete_geometry_only_faces_instance' : NodeInstance('GeometryNodeDeleteGeometry', [0, 1], [0], [('mode', 'ONLY_FACE'), ('domain', 'INSTANCE')]), 
	'delete_geometry_only_faces_layer' : NodeInstance('GeometryNodeDeleteGeometry', [0, 1], [0], [('mode', 'ONLY_FACE'), ('domain', 'LAYER')]), 
	'delete_geometry_only_faces_point' : NodeInstance('GeometryNodeDeleteGeometry', [0, 1], [0], [('mode', 'ONLY_FACE'), ('domain', 'POINT')]), 
	'delete_geometry_only_faces_spline' : NodeInstance('GeometryNodeDeleteGeometry', [0, 1], [0], [('mode', 'ONLY_FACE'), ('domain', 'CURVE')]), 
	'dial_gizmo' : NodeInstance('GeometryNodeGizmoDial', [0, 1, 2, 3, 4], [0], []), 
	'dial_gizmo_primary' : NodeInstance('GeometryNodeGizmoDial', [0, 1, 2, 3, 4], [0], [('color_id', 'PRIMARY')]), 
	'dial_gizmo_secondary' : NodeInstance('GeometryNodeGizmoDial', [0, 1, 2, 3, 4], [0], [('color_id', 'SECONDARY')]), 
	'dial_gizmo_x' : NodeInstance('GeometryNodeGizmoDial', [0, 1, 2, 3, 4], [0], [('color_id', 'X')]), 
	'dial_gizmo_y' : NodeInstance('GeometryNodeGizmoDial', [0, 1, 2, 3, 4], [0], [('color_id', 'Y')]), 
	'dial_gizmo_z' : NodeInstance('GeometryNodeGizmoDial', [0, 1, 2, 3, 4], [0], [('color_id', 'Z')]), 
	'distribute_points_in_grid' : NodeInstance('GeometryNodeDistributePointsInGrid', [0, 1, 2], [0], []), 
	'distribute_points_in_grid_grid' : NodeInstance('GeometryNodeDistributePointsInGrid', [0, 3, 4], [0], [('mode', 'DENSITY_GRID')]), 
	'distribute_points_in_grid_random' : NodeInstance('GeometryNodeDistributePointsInGrid', [0, 1, 2], [0], [('mode', 'DENSITY_RANDOM')]), 
	'distribute_points_in_volume' : NodeInstance('GeometryNodeDistributePointsInVolume', [0, 1, 2], [0], []), 
	'distribute_points_in_volume_grid' : NodeInstance('GeometryNodeDistributePointsInVolume', [0, 3, 4], [0], [('mode', 'DENSITY_GRID')]), 
	'distribute_points_in_volume_random' : NodeInstance('GeometryNodeDistributePointsInVolume', [0, 1, 2], [0], [('mode', 'DENSITY_RANDOM')]), 
	'distribute_points_on_faces' : NodeInstance('GeometryNodeDistributePointsOnFaces', [0, 1, 4, 6], [0, 1, 2], []), 
	'distribute_points_on_faces_poisson_disk' : NodeInstance('GeometryNodeDistributePointsOnFaces', [0, 1, 2, 3, 5, 6], [0, 1, 2], [('distribute_method', 'POISSON')]), 
	'distribute_points_on_faces_random' : NodeInstance('GeometryNodeDistributePointsOnFaces', [0, 1, 4, 6], [0, 1, 2], [('distribute_method', 'RANDOM')]), 
	'domain_size' : NodeInstance('GeometryNodeAttributeDomainSize', [0], [0, 1, 2, 3], []), 
	'domain_size_curve' : NodeInstance('GeometryNodeAttributeDomainSize', [0], [0, 4], [('component', 'CURVE')]), 
	'domain_size_grease_pencil' : NodeInstance('GeometryNodeAttributeDomainSize', [0], [6], [('component', 'GREASEPENCIL')]), 
	'domain_size_instances' : NodeInstance('GeometryNodeAttributeDomainSize', [0], [5], [('component', 'INSTANCES')]), 
	'domain_size_mesh' : NodeInstance('GeometryNodeAttributeDomainSize', [0], [0, 1, 2, 3], [('component', 'MESH')]), 
	'domain_size_point_cloud' : NodeInstance('GeometryNodeAttributeDomainSize', [0], [0], [('component', 'POINTCLOUD')]), 
	'dual_mesh' : NodeInstance('GeometryNodeDualMesh', [0, 1], [0], []), 
	'duplicate_elements' : NodeInstance('GeometryNodeDuplicateElements', [0, 1, 2], [0, 1], []), 
	'duplicate_elements_edge' : NodeInstance('GeometryNodeDuplicateElements', [0, 1, 2], [0, 1], [('domain', 'EDGE')]), 
	'duplicate_elements_face' : NodeInstance('GeometryNodeDuplicateElements', [0, 1, 2], [0, 1], [('domain', 'FACE')]), 
	'duplicate_elements_instance' : NodeInstance('GeometryNodeDuplicateElements', [0, 1, 2], [0, 1], [('domain', 'INSTANCE')]), 
	'duplicate_elements_layer' : NodeInstance('GeometryNodeDuplicateElements', [0, 1, 2], [0, 1], [('domain', 'LAYER')]), 
	'duplicate_elements_point' : NodeInstance('GeometryNodeDuplicateElements', [0, 1, 2], [0, 1], [('domain', 'POINT')]), 
	'duplicate_elements_spline' : NodeInstance('GeometryNodeDuplicateElements', [0, 1, 2], [0, 1], [('domain', 'SPLINE')]), 
	'edge_angle' : NodeInstance('GeometryNodeInputMeshEdgeAngle', [], [0, 1], []), 
	'edge_neighbors' : NodeInstance('GeometryNodeInputMeshEdgeNeighbors', [], [0], []), 
	'edge_paths_to_curves' : NodeInstance('GeometryNodeEdgePathsToCurves', [0, 1, 2], [0], []), 
	'edge_paths_to_selection' : NodeInstance('GeometryNodeEdgePathsToSelection', [0, 1], [0], []), 
	'edge_vertices' : NodeInstance('GeometryNodeInputMeshEdgeVertices', [], [0, 1, 2, 3], []), 
	'edges_of_corner' : NodeInstance('GeometryNodeEdgesOfCorner', [0], [0, 1], []), 
	'edges_of_vertex' : NodeInstance('GeometryNodeEdgesOfVertex', [0, 1, 2], [0, 1], []), 
	'endpoint_selection' : NodeInstance('GeometryNodeCurveEndpointSelection', [0, 1], [0], []), 
	'euler_to_rotation' : NodeInstance('FunctionNodeEulerToRotation', [0], [0], []), 
	'evaluate_at_index' : NodeInstance('GeometryNodeFieldAtIndex', [0, 1], [0], []), 
	'evaluate_at_index_edge_4x4_matrix' : NodeInstance('GeometryNodeFieldAtIndex', [0, 1], [0], [('domain', 'EDGE'), ('data_type', 'FLOAT4X4')]), 
	'evaluate_at_index_edge_boolean' : NodeInstance('GeometryNodeFieldAtIndex', [0, 1], [0], [('domain', 'EDGE'), ('data_type', 'BOOLEAN')]), 
	'evaluate_at_index_edge_color' : NodeInstance('GeometryNodeFieldAtIndex', [0, 1], [0], [('domain', 'EDGE'), ('data_type', 'FLOAT_COLOR')]), 
	'evaluate_at_index_edge_float' : NodeInstance('GeometryNodeFieldAtIndex', [0, 1], [0], [('domain', 'EDGE'), ('data_type', 'FLOAT')]), 
	'evaluate_at_index_edge_integer' : NodeInstance('GeometryNodeFieldAtIndex', [0, 1], [0], [('domain', 'EDGE'), ('data_type', 'INT')]), 
	'evaluate_at_index_edge_quaternion' : NodeInstance('GeometryNodeFieldAtIndex', [0, 1], [0], [('domain', 'EDGE'), ('data_type', 'QUATERNION')]), 
	'evaluate_at_index_edge_vector' : NodeInstance('GeometryNodeFieldAtIndex', [0, 1], [0], [('domain', 'EDGE'), ('data_type', 'FLOAT_VECTOR')]), 
	'evaluate_at_index_face_4x4_matrix' : NodeInstance('GeometryNodeFieldAtIndex', [0, 1], [0], [('domain', 'FACE'), ('data_type', 'FLOAT4X4')]), 
	'evaluate_at_index_face_boolean' : NodeInstance('GeometryNodeFieldAtIndex', [0, 1], [0], [('domain', 'FACE'), ('data_type', 'BOOLEAN')]), 
	'evaluate_at_index_face_color' : NodeInstance('GeometryNodeFieldAtIndex', [0, 1], [0], [('domain', 'FACE'), ('data_type', 'FLOAT_COLOR')]), 
	'evaluate_at_index_face_corner_4x4_matrix' : NodeInstance('GeometryNodeFieldAtIndex', [0, 1], [0], [('domain', 'CORNER'), ('data_type', 'FLOAT4X4')]), 
	'evaluate_at_index_face_corner_boolean' : NodeInstance('GeometryNodeFieldAtIndex', [0, 1], [0], [('domain', 'CORNER'), ('data_type', 'BOOLEAN')]), 
	'evaluate_at_index_face_corner_color' : NodeInstance('GeometryNodeFieldAtIndex', [0, 1], [0], [('domain', 'CORNER'), ('data_type', 'FLOAT_COLOR')]), 
	'evaluate_at_index_face_corner_float' : NodeInstance('GeometryNodeFieldAtIndex', [0, 1], [0], [('domain', 'CORNER'), ('data_type', 'FLOAT')]), 
	'evaluate_at_index_face_corner_integer' : NodeInstance('GeometryNodeFieldAtIndex', [0, 1], [0], [('domain', 'CORNER'), ('data_type', 'INT')]), 
	'evaluate_at_index_face_corner_quaternion' : NodeInstance('GeometryNodeFieldAtIndex', [0, 1], [0], [('domain', 'CORNER'), ('data_type', 'QUATERNION')]), 
	'evaluate_at_index_face_corner_vector' : NodeInstance('GeometryNodeFieldAtIndex', [0, 1], [0], [('domain', 'CORNER'), ('data_type', 'FLOAT_VECTOR')]), 
	'evaluate_at_index_face_float' : NodeInstance('GeometryNodeFieldAtIndex', [0, 1], [0], [('domain', 'FACE'), ('data_type', 'FLOAT')]), 
	'evaluate_at_index_face_integer' : NodeInstance('GeometryNodeFieldAtIndex', [0, 1], [0], [('domain', 'FACE'), ('data_type', 'INT')]), 
	'evaluate_at_index_face_quaternion' : NodeInstance('GeometryNodeFieldAtIndex', [0, 1], [0], [('domain', 'FACE'), ('data_type', 'QUATERNION')]), 
	'evaluate_at_index_face_vector' : NodeInstance('GeometryNodeFieldAtIndex', [0, 1], [0], [('domain', 'FACE'), ('data_type', 'FLOAT_VECTOR')]), 
	'evaluate_at_index_instance_4x4_matrix' : NodeInstance('GeometryNodeFieldAtIndex', [0, 1], [0], [('domain', 'INSTANCE'), ('data_type', 'FLOAT4X4')]), 
	'evaluate_at_index_instance_boolean' : NodeInstance('GeometryNodeFieldAtIndex', [0, 1], [0], [('domain', 'INSTANCE'), ('data_type', 'BOOLEAN')]), 
	'evaluate_at_index_instance_color' : NodeInstance('GeometryNodeFieldAtIndex', [0, 1], [0], [('domain', 'INSTANCE'), ('data_type', 'FLOAT_COLOR')]), 
	'evaluate_at_index_instance_float' : NodeInstance('GeometryNodeFieldAtIndex', [0, 1], [0], [('domain', 'INSTANCE'), ('data_type', 'FLOAT')]), 
	'evaluate_at_index_instance_integer' : NodeInstance('GeometryNodeFieldAtIndex', [0, 1], [0], [('domain', 'INSTANCE'), ('data_type', 'INT')]), 
	'evaluate_at_index_instance_quaternion' : NodeInstance('GeometryNodeFieldAtIndex', [0, 1], [0], [('domain', 'INSTANCE'), ('data_type', 'QUATERNION')]), 
	'evaluate_at_index_instance_vector' : NodeInstance('GeometryNodeFieldAtIndex', [0, 1], [0], [('domain', 'INSTANCE'), ('data_type', 'FLOAT_VECTOR')]), 
	'evaluate_at_index_layer_4x4_matrix' : NodeInstance('GeometryNodeFieldAtIndex', [0, 1], [0], [('domain', 'LAYER'), ('data_type', 'FLOAT4X4')]), 
	'evaluate_at_index_layer_boolean' : NodeInstance('GeometryNodeFieldAtIndex', [0, 1], [0], [('domain', 'LAYER'), ('data_type', 'BOOLEAN')]), 
	'evaluate_at_index_layer_color' : NodeInstance('GeometryNodeFieldAtIndex', [0, 1], [0], [('domain', 'LAYER'), ('data_type', 'FLOAT_COLOR')]), 
	'evaluate_at_index_layer_float' : NodeInstance('GeometryNodeFieldAtIndex', [0, 1], [0], [('domain', 'LAYER'), ('data_type', 'FLOAT')]), 
	'evaluate_at_index_layer_integer' : NodeInstance('GeometryNodeFieldAtIndex', [0, 1], [0], [('domain', 'LAYER'), ('data_type', 'INT')]), 
	'evaluate_at_index_layer_quaternion' : NodeInstance('GeometryNodeFieldAtIndex', [0, 1], [0], [('domain', 'LAYER'), ('data_type', 'QUATERNION')]), 
	'evaluate_at_index_layer_vector' : NodeInstance('GeometryNodeFieldAtIndex', [0, 1], [0], [('domain', 'LAYER'), ('data_type', 'FLOAT_VECTOR')]), 
	'evaluate_at_index_point_4x4_matrix' : NodeInstance('GeometryNodeFieldAtIndex', [0, 1], [0], [('domain', 'POINT'), ('data_type', 'FLOAT4X4')]), 
	'evaluate_at_index_point_boolean' : NodeInstance('GeometryNodeFieldAtIndex', [0, 1], [0], [('domain', 'POINT'), ('data_type', 'BOOLEAN')]), 
	'evaluate_at_index_point_color' : NodeInstance('GeometryNodeFieldAtIndex', [0, 1], [0], [('domain', 'POINT'), ('data_type', 'FLOAT_COLOR')]), 
	'evaluate_at_index_point_float' : NodeInstance('GeometryNodeFieldAtIndex', [0, 1], [0], [('domain', 'POINT'), ('data_type', 'FLOAT')]), 
	'evaluate_at_index_point_integer' : NodeInstance('GeometryNodeFieldAtIndex', [0, 1], [0], [('domain', 'POINT'), ('data_type', 'INT')]), 
	'evaluate_at_index_point_quaternion' : NodeInstance('GeometryNodeFieldAtIndex', [0, 1], [0], [('domain', 'POINT'), ('data_type', 'QUATERNION')]), 
	'evaluate_at_index_point_vector' : NodeInstance('GeometryNodeFieldAtIndex', [0, 1], [0], [('domain', 'POINT'), ('data_type', 'FLOAT_VECTOR')]), 
	'evaluate_at_index_spline_4x4_matrix' : NodeInstance('GeometryNodeFieldAtIndex', [0, 1], [0], [('domain', 'CURVE'), ('data_type', 'FLOAT4X4')]), 
	'evaluate_at_index_spline_boolean' : NodeInstance('GeometryNodeFieldAtIndex', [0, 1], [0], [('domain', 'CURVE'), ('data_type', 'BOOLEAN')]), 
	'evaluate_at_index_spline_color' : NodeInstance('GeometryNodeFieldAtIndex', [0, 1], [0], [('domain', 'CURVE'), ('data_type', 'FLOAT_COLOR')]), 
	'evaluate_at_index_spline_float' : NodeInstance('GeometryNodeFieldAtIndex', [0, 1], [0], [('domain', 'CURVE'), ('data_type', 'FLOAT')]), 
	'evaluate_at_index_spline_integer' : NodeInstance('GeometryNodeFieldAtIndex', [0, 1], [0], [('domain', 'CURVE'), ('data_type', 'INT')]), 
	'evaluate_at_index_spline_quaternion' : NodeInstance('GeometryNodeFieldAtIndex', [0, 1], [0], [('domain', 'CURVE'), ('data_type', 'QUATERNION')]), 
	'evaluate_at_index_spline_vector' : NodeInstance('GeometryNodeFieldAtIndex', [0, 1], [0], [('domain', 'CURVE'), ('data_type', 'FLOAT_VECTOR')]), 
	'evaluate_on_domain' : NodeInstance('GeometryNodeFieldOnDomain', [0], [0], []), 
	'evaluate_on_domain_edge_4x4_matrix' : NodeInstance('GeometryNodeFieldOnDomain', [0], [0], [('domain', 'EDGE'), ('data_type', 'FLOAT4X4')]), 
	'evaluate_on_domain_edge_boolean' : NodeInstance('GeometryNodeFieldOnDomain', [0], [0], [('domain', 'EDGE'), ('data_type', 'BOOLEAN')]), 
	'evaluate_on_domain_edge_color' : NodeInstance('GeometryNodeFieldOnDomain', [0], [0], [('domain', 'EDGE'), ('data_type', 'FLOAT_COLOR')]), 
	'evaluate_on_domain_edge_float' : NodeInstance('GeometryNodeFieldOnDomain', [0], [0], [('domain', 'EDGE'), ('data_type', 'FLOAT')]), 
	'evaluate_on_domain_edge_integer' : NodeInstance('GeometryNodeFieldOnDomain', [0], [0], [('domain', 'EDGE'), ('data_type', 'INT')]), 
	'evaluate_on_domain_edge_quaternion' : NodeInstance('GeometryNodeFieldOnDomain', [0], [0], [('domain', 'EDGE'), ('data_type', 'QUATERNION')]), 
	'evaluate_on_domain_edge_vector' : NodeInstance('GeometryNodeFieldOnDomain', [0], [0], [('domain', 'EDGE'), ('data_type', 'FLOAT_VECTOR')]), 
	'evaluate_on_domain_face_4x4_matrix' : NodeInstance('GeometryNodeFieldOnDomain', [0], [0], [('domain', 'FACE'), ('data_type', 'FLOAT4X4')]), 
	'evaluate_on_domain_face_boolean' : NodeInstance('GeometryNodeFieldOnDomain', [0], [0], [('domain', 'FACE'), ('data_type', 'BOOLEAN')]), 
	'evaluate_on_domain_face_color' : NodeInstance('GeometryNodeFieldOnDomain', [0], [0], [('domain', 'FACE'), ('data_type', 'FLOAT_COLOR')]), 
	'evaluate_on_domain_face_corner_4x4_matrix' : NodeInstance('GeometryNodeFieldOnDomain', [0], [0], [('domain', 'CORNER'), ('data_type', 'FLOAT4X4')]), 
	'evaluate_on_domain_face_corner_boolean' : NodeInstance('GeometryNodeFieldOnDomain', [0], [0], [('domain', 'CORNER'), ('data_type', 'BOOLEAN')]), 
	'evaluate_on_domain_face_corner_color' : NodeInstance('GeometryNodeFieldOnDomain', [0], [0], [('domain', 'CORNER'), ('data_type', 'FLOAT_COLOR')]), 
	'evaluate_on_domain_face_corner_float' : NodeInstance('GeometryNodeFieldOnDomain', [0], [0], [('domain', 'CORNER'), ('data_type', 'FLOAT')]), 
	'evaluate_on_domain_face_corner_integer' : NodeInstance('GeometryNodeFieldOnDomain', [0], [0], [('domain', 'CORNER'), ('data_type', 'INT')]), 
	'evaluate_on_domain_face_corner_quaternion' : NodeInstance('GeometryNodeFieldOnDomain', [0], [0], [('domain', 'CORNER'), ('data_type', 'QUATERNION')]), 
	'evaluate_on_domain_face_corner_vector' : NodeInstance('GeometryNodeFieldOnDomain', [0], [0], [('domain', 'CORNER'), ('data_type', 'FLOAT_VECTOR')]), 
	'evaluate_on_domain_face_float' : NodeInstance('GeometryNodeFieldOnDomain', [0], [0], [('domain', 'FACE'), ('data_type', 'FLOAT')]), 
	'evaluate_on_domain_face_integer' : NodeInstance('GeometryNodeFieldOnDomain', [0], [0], [('domain', 'FACE'), ('data_type', 'INT')]), 
	'evaluate_on_domain_face_quaternion' : NodeInstance('GeometryNodeFieldOnDomain', [0], [0], [('domain', 'FACE'), ('data_type', 'QUATERNION')]), 
	'evaluate_on_domain_face_vector' : NodeInstance('GeometryNodeFieldOnDomain', [0], [0], [('domain', 'FACE'), ('data_type', 'FLOAT_VECTOR')]), 
	'evaluate_on_domain_instance_4x4_matrix' : NodeInstance('GeometryNodeFieldOnDomain', [0], [0], [('domain', 'INSTANCE'), ('data_type', 'FLOAT4X4')]), 
	'evaluate_on_domain_instance_boolean' : NodeInstance('GeometryNodeFieldOnDomain', [0], [0], [('domain', 'INSTANCE'), ('data_type', 'BOOLEAN')]), 
	'evaluate_on_domain_instance_color' : NodeInstance('GeometryNodeFieldOnDomain', [0], [0], [('domain', 'INSTANCE'), ('data_type', 'FLOAT_COLOR')]), 
	'evaluate_on_domain_instance_float' : NodeInstance('GeometryNodeFieldOnDomain', [0], [0], [('domain', 'INSTANCE'), ('data_type', 'FLOAT')]), 
	'evaluate_on_domain_instance_integer' : NodeInstance('GeometryNodeFieldOnDomain', [0], [0], [('domain', 'INSTANCE'), ('data_type', 'INT')]), 
	'evaluate_on_domain_instance_quaternion' : NodeInstance('GeometryNodeFieldOnDomain', [0], [0], [('domain', 'INSTANCE'), ('data_type', 'QUATERNION')]), 
	'evaluate_on_domain_instance_vector' : NodeInstance('GeometryNodeFieldOnDomain', [0], [0], [('domain', 'INSTANCE'), ('data_type', 'FLOAT_VECTOR')]), 
	'evaluate_on_domain_layer_4x4_matrix' : NodeInstance('GeometryNodeFieldOnDomain', [0], [0], [('domain', 'LAYER'), ('data_type', 'FLOAT4X4')]), 
	'evaluate_on_domain_layer_boolean' : NodeInstance('GeometryNodeFieldOnDomain', [0], [0], [('domain', 'LAYER'), ('data_type', 'BOOLEAN')]), 
	'evaluate_on_domain_layer_color' : NodeInstance('GeometryNodeFieldOnDomain', [0], [0], [('domain', 'LAYER'), ('data_type', 'FLOAT_COLOR')]), 
	'evaluate_on_domain_layer_float' : NodeInstance('GeometryNodeFieldOnDomain', [0], [0], [('domain', 'LAYER'), ('data_type', 'FLOAT')]), 
	'evaluate_on_domain_layer_integer' : NodeInstance('GeometryNodeFieldOnDomain', [0], [0], [('domain', 'LAYER'), ('data_type', 'INT')]), 
	'evaluate_on_domain_layer_quaternion' : NodeInstance('GeometryNodeFieldOnDomain', [0], [0], [('domain', 'LAYER'), ('data_type', 'QUATERNION')]), 
	'evaluate_on_domain_layer_vector' : NodeInstance('GeometryNodeFieldOnDomain', [0], [0], [('domain', 'LAYER'), ('data_type', 'FLOAT_VECTOR')]), 
	'evaluate_on_domain_point_4x4_matrix' : NodeInstance('GeometryNodeFieldOnDomain', [0], [0], [('domain', 'POINT'), ('data_type', 'FLOAT4X4')]), 
	'evaluate_on_domain_point_boolean' : NodeInstance('GeometryNodeFieldOnDomain', [0], [0], [('domain', 'POINT'), ('data_type', 'BOOLEAN')]), 
	'evaluate_on_domain_point_color' : NodeInstance('GeometryNodeFieldOnDomain', [0], [0], [('domain', 'POINT'), ('data_type', 'FLOAT_COLOR')]), 
	'evaluate_on_domain_point_float' : NodeInstance('GeometryNodeFieldOnDomain', [0], [0], [('domain', 'POINT'), ('data_type', 'FLOAT')]), 
	'evaluate_on_domain_point_integer' : NodeInstance('GeometryNodeFieldOnDomain', [0], [0], [('domain', 'POINT'), ('data_type', 'INT')]), 
	'evaluate_on_domain_point_quaternion' : NodeInstance('GeometryNodeFieldOnDomain', [0], [0], [('domain', 'POINT'), ('data_type', 'QUATERNION')]), 
	'evaluate_on_domain_point_vector' : NodeInstance('GeometryNodeFieldOnDomain', [0], [0], [('domain', 'POINT'), ('data_type', 'FLOAT_VECTOR')]), 
	'evaluate_on_domain_spline_4x4_matrix' : NodeInstance('GeometryNodeFieldOnDomain', [0], [0], [('domain', 'CURVE'), ('data_type', 'FLOAT4X4')]), 
	'evaluate_on_domain_spline_boolean' : NodeInstance('GeometryNodeFieldOnDomain', [0], [0], [('domain', 'CURVE'), ('data_type', 'BOOLEAN')]), 
	'evaluate_on_domain_spline_color' : NodeInstance('GeometryNodeFieldOnDomain', [0], [0], [('domain', 'CURVE'), ('data_type', 'FLOAT_COLOR')]), 
	'evaluate_on_domain_spline_float' : NodeInstance('GeometryNodeFieldOnDomain', [0], [0], [('domain', 'CURVE'), ('data_type', 'FLOAT')]), 
	'evaluate_on_domain_spline_integer' : NodeInstance('GeometryNodeFieldOnDomain', [0], [0], [('domain', 'CURVE'), ('data_type', 'INT')]), 
	'evaluate_on_domain_spline_quaternion' : NodeInstance('GeometryNodeFieldOnDomain', [0], [0], [('domain', 'CURVE'), ('data_type', 'QUATERNION')]), 
	'evaluate_on_domain_spline_vector' : NodeInstance('GeometryNodeFieldOnDomain', [0], [0], [('domain', 'CURVE'), ('data_type', 'FLOAT_VECTOR')]), 
	'extrude_mesh' : NodeInstance('GeometryNodeExtrudeMesh', [0, 1, 2, 3, 4], [0, 1, 2], []), 
	'extrude_mesh_edges' : NodeInstance('GeometryNodeExtrudeMesh', [0, 1, 2, 3], [0, 1, 2], [('mode', 'EDGES')]), 
	'extrude_mesh_faces' : NodeInstance('GeometryNodeExtrudeMesh', [0, 1, 2, 3, 4], [0, 1, 2], [('mode', 'FACES')]), 
	'extrude_mesh_vertices' : NodeInstance('GeometryNodeExtrudeMesh', [0, 1, 2, 3], [0, 1, 2], [('mode', 'VERTICES')]), 
	'face_area' : NodeInstance('GeometryNodeInputMeshFaceArea', [], [0], []), 
	'face_group_boundaries' : NodeInstance('GeometryNodeMeshFaceSetBoundaries', [0], [0], []), 
	'face_neighbors' : NodeInstance('GeometryNodeInputMeshFaceNeighbors', [], [0, 1], []), 
	'face_of_corner' : NodeInstance('GeometryNodeFaceOfCorner', [0], [0, 1], []), 
	'face_set' : NodeInstance('GeometryNodeToolFaceSet', [], [0, 1], []), 
	'fill_curve' : NodeInstance('GeometryNodeFillCurve', [0, 1], [0], []), 
	'fill_curve_n_gons' : NodeInstance('GeometryNodeFillCurve', [0, 1], [0], [('mode', 'NGONS')]), 
	'fill_curve_triangles' : NodeInstance('GeometryNodeFillCurve', [0, 1], [0], [('mode', 'TRIANGLES')]), 
	'fillet_curve' : NodeInstance('GeometryNodeFilletCurve', [0, 2, 3], [0], []), 
	'fillet_curve_bézier' : NodeInstance('GeometryNodeFilletCurve', [0, 2, 3], [0], [('mode', 'BEZIER')]), 
	'fillet_curve_poly' : NodeInstance('GeometryNodeFilletCurve', [0, 1, 2, 3], [0], [('mode', 'POLY')]), 
	'find_in_string' : NodeInstance('FunctionNodeFindInString', [0, 1], [0, 1], []), 
	'flip_faces' : NodeInstance('GeometryNodeFlipFaces', [0, 1], [0], []), 
	'float_to_integer' : NodeInstance('FunctionNodeFloatToInt', [0], [0], []), 
	'float_to_integer_ceiling' : NodeInstance('FunctionNodeFloatToInt', [0], [0], [('rounding_mode', 'CEILING')]), 
	'float_to_integer_floor' : NodeInstance('FunctionNodeFloatToInt', [0], [0], [('rounding_mode', 'FLOOR')]), 
	'float_to_integer_round' : NodeInstance('FunctionNodeFloatToInt', [0], [0], [('rounding_mode', 'ROUND')]), 
	'float_to_integer_truncate' : NodeInstance('FunctionNodeFloatToInt', [0], [0], [('rounding_mode', 'TRUNCATE')]), 
	'for_each_geometry_element_input' : NodeInstance('GeometryNodeForeachGeometryElementInput', [0, 1, 2], [0, 2], []), 
	'for_each_geometry_element_output' : NodeInstance('GeometryNodeForeachGeometryElementOutput', [0, 1, 2], [0, 1, 2, 3], []), 
	'for_each_geometry_element_output_edge' : NodeInstance('GeometryNodeForeachGeometryElementOutput', [0, 1, 2], [0, 1, 2, 3], [('domain', 'EDGE')]), 
	'for_each_geometry_element_output_face' : NodeInstance('GeometryNodeForeachGeometryElementOutput', [0, 1, 2], [0, 1, 2, 3], [('domain', 'FACE')]), 
	'for_each_geometry_element_output_face_corner' : NodeInstance('GeometryNodeForeachGeometryElementOutput', [0, 1, 2], [0, 1, 2, 3], [('domain', 'CORNER')]), 
	'for_each_geometry_element_output_instance' : NodeInstance('GeometryNodeForeachGeometryElementOutput', [0, 1, 2], [0, 1, 2, 3], [('domain', 'INSTANCE')]), 
	'for_each_geometry_element_output_layer' : NodeInstance('GeometryNodeForeachGeometryElementOutput', [0, 1, 2], [0, 1, 2, 3], [('domain', 'LAYER')]), 
	'for_each_geometry_element_output_point' : NodeInstance('GeometryNodeForeachGeometryElementOutput', [0, 1, 2], [0, 1, 2, 3], [('domain', 'POINT')]), 
	'for_each_geometry_element_output_spline' : NodeInstance('GeometryNodeForeachGeometryElementOutput', [0, 1, 2], [0, 1, 2, 3], [('domain', 'CURVE')]), 
	'geometry_proximity' : NodeInstance('GeometryNodeProximity', [0, 1, 2, 3], [0, 1, 2], []), 
	'geometry_proximity_edges' : NodeInstance('GeometryNodeProximity', [0, 1, 2, 3], [0, 1, 2], [('target_element', 'EDGES')]), 
	'geometry_proximity_faces' : NodeInstance('GeometryNodeProximity', [0, 1, 2, 3], [0, 1, 2], [('target_element', 'FACES')]), 
	'geometry_proximity_points' : NodeInstance('GeometryNodeProximity', [0, 1, 2, 3], [0, 1, 2], [('target_element', 'POINTS')]), 
	'geometry_to_instance' : NodeInstance('GeometryNodeGeometryToInstance', [0], [0], []), 
	'get_named_grid' : NodeInstance('GeometryNodeGetNamedGrid', [0, 1, 2], [0, 1], []), 
	'get_named_grid_float' : NodeInstance('GeometryNodeGetNamedGrid', [0, 1, 2], [0, 1], [('data_type', 'FLOAT')]), 
	'get_named_grid_vector' : NodeInstance('GeometryNodeGetNamedGrid', [0, 1, 2], [0, 1], [('data_type', 'VECTOR')]), 
	'grease_pencil_to_curves' : NodeInstance('GeometryNodeGreasePencilToCurves', [0, 1, 2], [0], []), 
	'grid' : NodeInstance('GeometryNodeMeshGrid', [0, 1, 2, 3], [0, 1], []), 
	'grid_to_mesh' : NodeInstance('GeometryNodeGridToMesh', [0, 1, 2], [0], []), 
	'handle_type_selection' : NodeInstance('GeometryNodeCurveHandleTypeSelection', [], [0], []), 
	'hash_value' : NodeInstance('FunctionNodeHashValue', [0, 1], [0], []), 
	'hash_value_color' : NodeInstance('FunctionNodeHashValue', [0, 1], [0], [('data_type', 'RGBA')]), 
	'hash_value_float' : NodeInstance('FunctionNodeHashValue', [0, 1], [0], [('data_type', 'FLOAT')]), 
	'hash_value_integer' : NodeInstance('FunctionNodeHashValue', [0, 1], [0], [('data_type', 'INT')]), 
	'hash_value_matrix' : NodeInstance('FunctionNodeHashValue', [0, 1], [0], [('data_type', 'MATRIX')]), 
	'hash_value_rotation' : NodeInstance('FunctionNodeHashValue', [0, 1], [0], [('data_type', 'ROTATION')]), 
	'hash_value_string' : NodeInstance('FunctionNodeHashValue', [0, 1], [0], [('data_type', 'STRING')]), 
	'hash_value_vector' : NodeInstance('FunctionNodeHashValue', [0, 1], [0], [('data_type', 'VECTOR')]), 
	'ico_sphere' : NodeInstance('GeometryNodeMeshIcoSphere', [0, 1], [0, 1], []), 
	'id' : NodeInstance('GeometryNodeInputID', [], [0], []), 
	'image' : NodeInstance('GeometryNodeInputImage', [], [0], []), 
	'image_info' : NodeInstance('GeometryNodeImageInfo', [0, 1], [0, 1, 2, 3, 4], []), 
	'image_texture' : NodeInstance('GeometryNodeImageTexture', [0, 1, 2], [0, 1], []), 
	'image_texture_closest_clip' : NodeInstance('GeometryNodeImageTexture', [0, 1, 2], [0, 1], [('interpolation', 'Closest'), ('extension', 'CLIP')]), 
	'image_texture_closest_extend' : NodeInstance('GeometryNodeImageTexture', [0, 1, 2], [0, 1], [('interpolation', 'Closest'), ('extension', 'EXTEND')]), 
	'image_texture_closest_mirror' : NodeInstance('GeometryNodeImageTexture', [0, 1, 2], [0, 1], [('interpolation', 'Closest'), ('extension', 'MIRROR')]), 
	'image_texture_closest_repeat' : NodeInstance('GeometryNodeImageTexture', [0, 1, 2], [0, 1], [('interpolation', 'Closest'), ('extension', 'REPEAT')]), 
	'image_texture_cubic_clip' : NodeInstance('GeometryNodeImageTexture', [0, 1, 2], [0, 1], [('interpolation', 'Cubic'), ('extension', 'CLIP')]), 
	'image_texture_cubic_extend' : NodeInstance('GeometryNodeImageTexture', [0, 1, 2], [0, 1], [('interpolation', 'Cubic'), ('extension', 'EXTEND')]), 
	'image_texture_cubic_mirror' : NodeInstance('GeometryNodeImageTexture', [0, 1, 2], [0, 1], [('interpolation', 'Cubic'), ('extension', 'MIRROR')]), 
	'image_texture_cubic_repeat' : NodeInstance('GeometryNodeImageTexture', [0, 1, 2], [0, 1], [('interpolation', 'Cubic'), ('extension', 'REPEAT')]), 
	'image_texture_linear_clip' : NodeInstance('GeometryNodeImageTexture', [0, 1, 2], [0, 1], [('interpolation', 'Linear'), ('extension', 'CLIP')]), 
	'image_texture_linear_extend' : NodeInstance('GeometryNodeImageTexture', [0, 1, 2], [0, 1], [('interpolation', 'Linear'), ('extension', 'EXTEND')]), 
	'image_texture_linear_mirror' : NodeInstance('GeometryNodeImageTexture', [0, 1, 2], [0, 1], [('interpolation', 'Linear'), ('extension', 'MIRROR')]), 
	'image_texture_linear_repeat' : NodeInstance('GeometryNodeImageTexture', [0, 1, 2], [0, 1], [('interpolation', 'Linear'), ('extension', 'REPEAT')]), 
	'import_obj' : NodeInstance('GeometryNodeImportOBJ', [0], [0], []), 
	'import_ply' : NodeInstance('GeometryNodeImportPLY', [0], [0], []), 
	'import_stl' : NodeInstance('GeometryNodeImportSTL', [0], [0], []), 
	'index' : NodeInstance('GeometryNodeInputIndex', [], [0], []), 
	'index_of_nearest' : NodeInstance('GeometryNodeIndexOfNearest', [0, 1], [0, 1], []), 
	'index_switch' : NodeInstance('GeometryNodeIndexSwitch', [0, 1, 2, 3], [0], []), 
	'index_switch_boolean' : NodeInstance('GeometryNodeIndexSwitch', [0, 1, 2, 3], [0], [('data_type', 'BOOLEAN')]), 
	'index_switch_collection' : NodeInstance('GeometryNodeIndexSwitch', [0, 1, 2, 3], [0], [('data_type', 'COLLECTION')]), 
	'index_switch_color' : NodeInstance('GeometryNodeIndexSwitch', [0, 1, 2, 3], [0], [('data_type', 'RGBA')]), 
	'index_switch_float' : NodeInstance('GeometryNodeIndexSwitch', [0, 1, 2, 3], [0], [('data_type', 'FLOAT')]), 
	'index_switch_geometry' : NodeInstance('GeometryNodeIndexSwitch', [0, 1, 2, 3], [0], [('data_type', 'GEOMETRY')]), 
	'index_switch_image' : NodeInstance('GeometryNodeIndexSwitch', [0, 1, 2, 3], [0], [('data_type', 'IMAGE')]), 
	'index_switch_integer' : NodeInstance('GeometryNodeIndexSwitch', [0, 1, 2, 3], [0], [('data_type', 'INT')]), 
	'index_switch_material' : NodeInstance('GeometryNodeIndexSwitch', [0, 1, 2, 3], [0], [('data_type', 'MATERIAL')]), 
	'index_switch_matrix' : NodeInstance('GeometryNodeIndexSwitch', [0, 1, 2, 3], [0], [('data_type', 'MATRIX')]), 
	'index_switch_menu' : NodeInstance('GeometryNodeIndexSwitch', [0, 1, 2, 3], [0], [('data_type', 'MENU')]), 
	'index_switch_object' : NodeInstance('GeometryNodeIndexSwitch', [0, 1, 2, 3], [0], [('data_type', 'OBJECT')]), 
	'index_switch_rotation' : NodeInstance('GeometryNodeIndexSwitch', [0, 1, 2, 3], [0], [('data_type', 'ROTATION')]), 
	'index_switch_string' : NodeInstance('GeometryNodeIndexSwitch', [0, 1, 2, 3], [0], [('data_type', 'STRING')]), 
	'index_switch_vector' : NodeInstance('GeometryNodeIndexSwitch', [0, 1, 2, 3], [0], [('data_type', 'VECTOR')]), 
	'instance_on_points' : NodeInstance('GeometryNodeInstanceOnPoints', [0, 1, 2, 3, 4, 5, 6], [0], []), 
	'instance_rotation' : NodeInstance('GeometryNodeInputInstanceRotation', [], [0], []), 
	'instance_scale' : NodeInstance('GeometryNodeInputInstanceScale', [], [0], []), 
	'instance_transform' : NodeInstance('GeometryNodeInstanceTransform', [], [0], []), 
	'instances_to_points' : NodeInstance('GeometryNodeInstancesToPoints', [0, 1, 2, 3], [0], []), 
	'integer' : NodeInstance('FunctionNodeInputInt', [], [0], []), 
	'integer_math' : NodeInstance('FunctionNodeIntegerMath', [0, 1], [0], []), 
	'integer_math_absolute' : NodeInstance('FunctionNodeIntegerMath', [0], [0], [('operation', 'ABSOLUTE')]), 
	'integer_math_add' : NodeInstance('FunctionNodeIntegerMath', [0, 1], [0], [('operation', 'ADD')]), 
	'integer_math_divide' : NodeInstance('FunctionNodeIntegerMath', [0, 1], [0], [('operation', 'DIVIDE')]), 
	'integer_math_divide_ceiling' : NodeInstance('FunctionNodeIntegerMath', [0, 1], [0], [('operation', 'DIVIDE_CEIL')]), 
	'integer_math_divide_floor' : NodeInstance('FunctionNodeIntegerMath', [0, 1], [0], [('operation', 'DIVIDE_FLOOR')]), 
	'integer_math_divide_round' : NodeInstance('FunctionNodeIntegerMath', [0, 1], [0], [('operation', 'DIVIDE_ROUND')]), 
	'integer_math_floored_modulo' : NodeInstance('FunctionNodeIntegerMath', [0, 1], [0], [('operation', 'FLOORED_MODULO')]), 
	'integer_math_greatest_common_divisor' : NodeInstance('FunctionNodeIntegerMath', [0, 1], [0], [('operation', 'GCD')]), 
	'integer_math_least_common_multiple' : NodeInstance('FunctionNodeIntegerMath', [0, 1], [0], [('operation', 'LCM')]), 
	'integer_math_maximum' : NodeInstance('FunctionNodeIntegerMath', [0, 1], [0], [('operation', 'MAXIMUM')]), 
	'integer_math_minimum' : NodeInstance('FunctionNodeIntegerMath', [0, 1], [0], [('operation', 'MINIMUM')]), 
	'integer_math_modulo' : NodeInstance('FunctionNodeIntegerMath', [0, 1], [0], [('operation', 'MODULO')]), 
	'integer_math_multiply' : NodeInstance('FunctionNodeIntegerMath', [0, 1], [0], [('operation', 'MULTIPLY')]), 
	'integer_math_multiply_add' : NodeInstance('FunctionNodeIntegerMath', [0, 1, 2], [0], [('operation', 'MULTIPLY_ADD')]), 
	'integer_math_negate' : NodeInstance('FunctionNodeIntegerMath', [0], [0], [('operation', 'NEGATE')]), 
	'integer_math_power' : NodeInstance('FunctionNodeIntegerMath', [0, 1], [0], [('operation', 'POWER')]), 
	'integer_math_sign' : NodeInstance('FunctionNodeIntegerMath', [0], [0], [('operation', 'SIGN')]), 
	'integer_math_subtract' : NodeInstance('FunctionNodeIntegerMath', [0, 1], [0], [('operation', 'SUBTRACT')]), 
	'interpolate_curves' : NodeInstance('GeometryNodeInterpolateCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2], []), 
	'invert_matrix' : NodeInstance('FunctionNodeInvertMatrix', [0], [0, 1], []), 
	'invert_rotation' : NodeInstance('FunctionNodeInvertRotation', [0], [0], []), 
	'is_edge_smooth' : NodeInstance('GeometryNodeInputEdgeSmooth', [], [0], []), 
	'is_face_planar' : NodeInstance('GeometryNodeInputMeshFaceIsPlanar', [0], [0], []), 
	'is_face_smooth' : NodeInstance('GeometryNodeInputShadeSmooth', [], [0], []), 
	'is_spline_cyclic' : NodeInstance('GeometryNodeInputSplineCyclic', [], [0], []), 
	'is_viewport' : NodeInstance('GeometryNodeIsViewport', [], [0], []), 
	'join_geometry' : NodeInstance('GeometryNodeJoinGeometry', [0], [0], []), 
	'join_strings' : NodeInstance('GeometryNodeStringJoin', [0, 1], [0], []), 
	'linear_gizmo' : NodeInstance('GeometryNodeGizmoLinear', [0, 1, 2], [0], []), 
	'linear_gizmo_primary_arrow' : NodeInstance('GeometryNodeGizmoLinear', [0, 1, 2], [0], [('color_id', 'PRIMARY'), ('draw_style', 'ARROW')]), 
	'linear_gizmo_primary_box' : NodeInstance('GeometryNodeGizmoLinear', [0, 1, 2], [0], [('color_id', 'PRIMARY'), ('draw_style', 'BOX')]), 
	'linear_gizmo_primary_cross' : NodeInstance('GeometryNodeGizmoLinear', [0, 1, 2], [0], [('color_id', 'PRIMARY'), ('draw_style', 'CROSS')]), 
	'linear_gizmo_secondary_arrow' : NodeInstance('GeometryNodeGizmoLinear', [0, 1, 2], [0], [('color_id', 'SECONDARY'), ('draw_style', 'ARROW')]), 
	'linear_gizmo_secondary_box' : NodeInstance('GeometryNodeGizmoLinear', [0, 1, 2], [0], [('color_id', 'SECONDARY'), ('draw_style', 'BOX')]), 
	'linear_gizmo_secondary_cross' : NodeInstance('GeometryNodeGizmoLinear', [0, 1, 2], [0], [('color_id', 'SECONDARY'), ('draw_style', 'CROSS')]), 
	'linear_gizmo_x_arrow' : NodeInstance('GeometryNodeGizmoLinear', [0, 1, 2], [0], [('color_id', 'X'), ('draw_style', 'ARROW')]), 
	'linear_gizmo_x_box' : NodeInstance('GeometryNodeGizmoLinear', [0, 1, 2], [0], [('color_id', 'X'), ('draw_style', 'BOX')]), 
	'linear_gizmo_x_cross' : NodeInstance('GeometryNodeGizmoLinear', [0, 1, 2], [0], [('color_id', 'X'), ('draw_style', 'CROSS')]), 
	'linear_gizmo_y_arrow' : NodeInstance('GeometryNodeGizmoLinear', [0, 1, 2], [0], [('color_id', 'Y'), ('draw_style', 'ARROW')]), 
	'linear_gizmo_y_box' : NodeInstance('GeometryNodeGizmoLinear', [0, 1, 2], [0], [('color_id', 'Y'), ('draw_style', 'BOX')]), 
	'linear_gizmo_y_cross' : NodeInstance('GeometryNodeGizmoLinear', [0, 1, 2], [0], [('color_id', 'Y'), ('draw_style', 'CROSS')]), 
	'linear_gizmo_z_arrow' : NodeInstance('GeometryNodeGizmoLinear', [0, 1, 2], [0], [('color_id', 'Z'), ('draw_style', 'ARROW')]), 
	'linear_gizmo_z_box' : NodeInstance('GeometryNodeGizmoLinear', [0, 1, 2], [0], [('color_id', 'Z'), ('draw_style', 'BOX')]), 
	'linear_gizmo_z_cross' : NodeInstance('GeometryNodeGizmoLinear', [0, 1, 2], [0], [('color_id', 'Z'), ('draw_style', 'CROSS')]), 
	'material' : NodeInstance('GeometryNodeInputMaterial', [], [0], []), 
	'material_index' : NodeInstance('GeometryNodeInputMaterialIndex', [], [0], []), 
	'material_selection' : NodeInstance('GeometryNodeMaterialSelection', [0], [0], []), 
	'matrix_determinant' : NodeInstance('FunctionNodeMatrixDeterminant', [0], [0], []), 
	'menu_switch' : NodeInstance('GeometryNodeMenuSwitch', [0, 1, 2, 3], [0], []), 
	'menu_switch_boolean' : NodeInstance('GeometryNodeMenuSwitch', [0, 1, 2, 3], [0], [('data_type', 'BOOLEAN')]), 
	'menu_switch_collection' : NodeInstance('GeometryNodeMenuSwitch', [0, 1, 2, 3], [0], [('data_type', 'COLLECTION')]), 
	'menu_switch_color' : NodeInstance('GeometryNodeMenuSwitch', [0, 1, 2, 3], [0], [('data_type', 'RGBA')]), 
	'menu_switch_float' : NodeInstance('GeometryNodeMenuSwitch', [0, 1, 2, 3], [0], [('data_type', 'FLOAT')]), 
	'menu_switch_geometry' : NodeInstance('GeometryNodeMenuSwitch', [0, 1, 2, 3], [0], [('data_type', 'GEOMETRY')]), 
	'menu_switch_image' : NodeInstance('GeometryNodeMenuSwitch', [0, 1, 2, 3], [0], [('data_type', 'IMAGE')]), 
	'menu_switch_integer' : NodeInstance('GeometryNodeMenuSwitch', [0, 1, 2, 3], [0], [('data_type', 'INT')]), 
	'menu_switch_material' : NodeInstance('GeometryNodeMenuSwitch', [0, 1, 2, 3], [0], [('data_type', 'MATERIAL')]), 
	'menu_switch_matrix' : NodeInstance('GeometryNodeMenuSwitch', [0, 1, 2, 3], [0], [('data_type', 'MATRIX')]), 
	'menu_switch_object' : NodeInstance('GeometryNodeMenuSwitch', [0, 1, 2, 3], [0], [('data_type', 'OBJECT')]), 
	'menu_switch_rotation' : NodeInstance('GeometryNodeMenuSwitch', [0, 1, 2, 3], [0], [('data_type', 'ROTATION')]), 
	'menu_switch_string' : NodeInstance('GeometryNodeMenuSwitch', [0, 1, 2, 3], [0], [('data_type', 'STRING')]), 
	'menu_switch_vector' : NodeInstance('GeometryNodeMenuSwitch', [0, 1, 2, 3], [0], [('data_type', 'VECTOR')]), 
	'merge_by_distance' : NodeInstance('GeometryNodeMergeByDistance', [0, 1, 2], [0], []), 
	'merge_by_distance_all' : NodeInstance('GeometryNodeMergeByDistance', [0, 1, 2], [0], [('mode', 'ALL')]), 
	'merge_by_distance_connected' : NodeInstance('GeometryNodeMergeByDistance', [0, 1, 2], [0], [('mode', 'CONNECTED')]), 
	'merge_layers' : NodeInstance('GeometryNodeMergeLayers', [0, 1], [0], []), 
	'merge_layers_by_group_id' : NodeInstance('GeometryNodeMergeLayers', [0, 1, 2], [0], [('mode', 'MERGE_BY_ID')]), 
	'merge_layers_by_name' : NodeInstance('GeometryNodeMergeLayers', [0, 1], [0], [('mode', 'MERGE_BY_NAME')]), 
	'mesh_boolean' : NodeInstance('GeometryNodeMeshBoolean', [0, 1, 2, 3], [0], []), 
	'mesh_boolean_difference_exact' : NodeInstance('GeometryNodeMeshBoolean', [0, 1, 2, 3], [0, 1], [('operation', 'DIFFERENCE'), ('solver', 'EXACT')]), 
	'mesh_boolean_difference_float' : NodeInstance('GeometryNodeMeshBoolean', [0, 1, 2, 3], [0], [('operation', 'DIFFERENCE'), ('solver', 'FLOAT')]), 
	'mesh_boolean_intersect_exact' : NodeInstance('GeometryNodeMeshBoolean', [1, 2, 3], [0, 1], [('operation', 'INTERSECT'), ('solver', 'EXACT')]), 
	'mesh_boolean_intersect_float' : NodeInstance('GeometryNodeMeshBoolean', [1, 2, 3], [0], [('operation', 'INTERSECT'), ('solver', 'FLOAT')]), 
	'mesh_boolean_union_exact' : NodeInstance('GeometryNodeMeshBoolean', [1, 2, 3], [0, 1], [('operation', 'UNION'), ('solver', 'EXACT')]), 
	'mesh_boolean_union_float' : NodeInstance('GeometryNodeMeshBoolean', [1, 2, 3], [0], [('operation', 'UNION'), ('solver', 'FLOAT')]), 
	'mesh_circle' : NodeInstance('GeometryNodeMeshCircle', [0, 1], [0], []), 
	'mesh_circle_n_gon' : NodeInstance('GeometryNodeMeshCircle', [0, 1], [0], [('fill_type', 'NGON')]), 
	'mesh_circle_none' : NodeInstance('GeometryNodeMeshCircle', [0, 1], [0], [('fill_type', 'NONE')]), 
	'mesh_circle_triangles' : NodeInstance('GeometryNodeMeshCircle', [0, 1], [0], [('fill_type', 'TRIANGLE_FAN')]), 
	'mesh_island' : NodeInstance('GeometryNodeInputMeshIsland', [], [0, 1], []), 
	'mesh_line' : NodeInstance('GeometryNodeMeshLine', [0, 2, 3], [0], []), 
	'mesh_line_end_points_count' : NodeInstance('GeometryNodeMeshLine', [0, 2, 3], [0], [('mode', 'END_POINTS'), ('count_mode', 'TOTAL')]), 
	'mesh_line_end_points_resolution' : NodeInstance('GeometryNodeMeshLine', [1, 2, 3], [0], [('mode', 'END_POINTS'), ('count_mode', 'RESOLUTION')]), 
	'mesh_line_offset_count' : NodeInstance('GeometryNodeMeshLine', [0, 2, 3], [0], [('mode', 'OFFSET'), ('count_mode', 'TOTAL')]), 
	'mesh_line_offset_resolution' : NodeInstance('GeometryNodeMeshLine', [0, 2, 3], [0], [('mode', 'OFFSET'), ('count_mode', 'RESOLUTION')]), 
	'mesh_to_curve' : NodeInstance('GeometryNodeMeshToCurve', [0, 1], [0], []), 
	'mesh_to_density_grid' : NodeInstance('GeometryNodeMeshToDensityGrid', [0, 1, 2, 3], [0], []), 
	'mesh_to_points' : NodeInstance('GeometryNodeMeshToPoints', [0, 1, 2, 3], [0], []), 
	'mesh_to_points_corners' : NodeInstance('GeometryNodeMeshToPoints', [0, 1, 2, 3], [0], [('mode', 'CORNERS')]), 
	'mesh_to_points_edges' : NodeInstance('GeometryNodeMeshToPoints', [0, 1, 2, 3], [0], [('mode', 'EDGES')]), 
	'mesh_to_points_faces' : NodeInstance('GeometryNodeMeshToPoints', [0, 1, 2, 3], [0], [('mode', 'FACES')]), 
	'mesh_to_points_vertices' : NodeInstance('GeometryNodeMeshToPoints', [0, 1, 2, 3], [0], [('mode', 'VERTICES')]), 
	'mesh_to_sdf_grid' : NodeInstance('GeometryNodeMeshToSDFGrid', [0, 1, 2], [0], []), 
	'mesh_to_volume' : NodeInstance('GeometryNodeMeshToVolume', [0, 1, 3, 4], [0], []), 
	'mesh_to_volume_amount' : NodeInstance('GeometryNodeMeshToVolume', [0, 1, 3, 4], [0], [('resolution_mode', 'VOXEL_AMOUNT')]), 
	'mesh_to_volume_size' : NodeInstance('GeometryNodeMeshToVolume', [0, 1, 2, 4], [0], [('resolution_mode', 'VOXEL_SIZE')]), 
	'mouse_position' : NodeInstance('GeometryNodeToolMousePosition', [], [0, 1, 2, 3], []), 
	'multiply_matrices' : NodeInstance('FunctionNodeMatrixMultiply', [0, 1], [0], []), 
	'named_attribute' : NodeInstance('GeometryNodeInputNamedAttribute', [0], [0, 1], []), 
	'named_attribute_4x4_matrix' : NodeInstance('GeometryNodeInputNamedAttribute', [0], [0, 1], [('data_type', 'FLOAT4X4')]), 
	'named_attribute_boolean' : NodeInstance('GeometryNodeInputNamedAttribute', [0], [0, 1], [('data_type', 'BOOLEAN')]), 
	'named_attribute_color' : NodeInstance('GeometryNodeInputNamedAttribute', [0], [0, 1], [('data_type', 'FLOAT_COLOR')]), 
	'named_attribute_float' : NodeInstance('GeometryNodeInputNamedAttribute', [0], [0, 1], [('data_type', 'FLOAT')]), 
	'named_attribute_integer' : NodeInstance('GeometryNodeInputNamedAttribute', [0], [0, 1], [('data_type', 'INT')]), 
	'named_attribute_quaternion' : NodeInstance('GeometryNodeInputNamedAttribute', [0], [0, 1], [('data_type', 'QUATERNION')]), 
	'named_attribute_vector' : NodeInstance('GeometryNodeInputNamedAttribute', [0], [0, 1], [('data_type', 'FLOAT_VECTOR')]), 
	'named_layer_selection' : NodeInstance('GeometryNodeInputNamedLayerSelection', [0], [0], []), 
	'normal' : NodeInstance('GeometryNodeInputNormal', [], [0], []), 
	'object' : NodeInstance('GeometryNodeInputObject', [], [0], []), 
	'object_info' : NodeInstance('GeometryNodeObjectInfo', [0, 1], [0, 1, 2, 3, 4], []), 
	'object_info_original' : NodeInstance('GeometryNodeObjectInfo', [0, 1], [0, 1, 2, 3, 4], [('transform_space', 'ORIGINAL')]), 
	'object_info_relative' : NodeInstance('GeometryNodeObjectInfo', [0, 1], [0, 1, 2, 3, 4], [('transform_space', 'RELATIVE')]), 
	'offset_corner_in_face' : NodeInstance('GeometryNodeOffsetCornerInFace', [0, 1], [0], []), 
	'offset_point_in_curve' : NodeInstance('GeometryNodeOffsetPointInCurve', [0, 1], [0, 1], []), 
	'pack_uv_islands' : NodeInstance('GeometryNodeUVPackIslands', [0, 1, 2, 3], [0], []), 
	'points' : NodeInstance('GeometryNodePoints', [0, 1, 2], [0], []), 
	'points_of_curve' : NodeInstance('GeometryNodePointsOfCurve', [0, 1, 2], [0, 1], []), 
	'points_to_curves' : NodeInstance('GeometryNodePointsToCurves', [0, 1, 2], [0], []), 
	'points_to_sdf_grid' : NodeInstance('GeometryNodePointsToSDFGrid', [0, 1, 2], [0], []), 
	'points_to_vertices' : NodeInstance('GeometryNodePointsToVertices', [0, 1], [0], []), 
	'points_to_volume' : NodeInstance('GeometryNodePointsToVolume', [0, 1, 3, 4], [0], []), 
	'points_to_volume_amount' : NodeInstance('GeometryNodePointsToVolume', [0, 1, 3, 4], [0], [('resolution_mode', 'VOXEL_AMOUNT')]), 
	'points_to_volume_size' : NodeInstance('GeometryNodePointsToVolume', [0, 1, 2, 4], [0], [('resolution_mode', 'VOXEL_SIZE')]), 
	'position' : NodeInstance('GeometryNodeInputPosition', [], [0], []), 
	'project_point' : NodeInstance('FunctionNodeProjectPoint', [0, 1], [0], []), 
	'quadratic_bézier' : NodeInstance('GeometryNodeCurveQuadraticBezier', [0, 1, 2, 3], [0], []), 
	'quadrilateral' : NodeInstance('GeometryNodeCurvePrimitiveQuadrilateral', [0, 1], [0], []), 
	'quadrilateral_kite' : NodeInstance('GeometryNodeCurvePrimitiveQuadrilateral', [0, 5, 6], [0], [('mode', 'KITE')]), 
	'quadrilateral_parallelogram' : NodeInstance('GeometryNodeCurvePrimitiveQuadrilateral', [0, 1, 4], [0], [('mode', 'PARALLELOGRAM')]), 
	'quadrilateral_points' : NodeInstance('GeometryNodeCurvePrimitiveQuadrilateral', [0, 7, 8, 9, 10], [0], [('mode', 'POINTS')]), 
	'quadrilateral_rectangle' : NodeInstance('GeometryNodeCurvePrimitiveQuadrilateral', [0, 1], [0], [('mode', 'RECTANGLE')]), 
	'quadrilateral_trapezoid' : NodeInstance('GeometryNodeCurvePrimitiveQuadrilateral', [0, 1, 2, 3, 4], [0], [('mode', 'TRAPEZOID')]), 
	'quaternion_to_rotation' : NodeInstance('FunctionNodeQuaternionToRotation', [0, 1, 2, 3], [0], []), 
	'radius' : NodeInstance('GeometryNodeInputRadius', [], [0], []), 
	'random_value' : NodeInstance('FunctionNodeRandomValue', [2, 3, 7, 8], [1], []), 
	'random_value_boolean' : NodeInstance('FunctionNodeRandomValue', [6, 7, 8], [3], [('data_type', 'BOOLEAN')]), 
	'random_value_float' : NodeInstance('FunctionNodeRandomValue', [2, 3, 7, 8], [1], [('data_type', 'FLOAT')]), 
	'random_value_integer' : NodeInstance('FunctionNodeRandomValue', [4, 5, 7, 8], [2], [('data_type', 'INT')]), 
	'random_value_vector' : NodeInstance('FunctionNodeRandomValue', [0, 1, 7, 8], [0], [('data_type', 'FLOAT_VECTOR')]), 
	'raycast' : NodeInstance('GeometryNodeRaycast', [0, 1, 2, 3, 4], [0, 1, 2, 3, 4], []), 
	'raycast_interpolated_4x4_matrix' : NodeInstance('GeometryNodeRaycast', [0, 1, 2, 3, 4], [0, 1, 2, 3, 4], [('mapping', 'INTERPOLATED'), ('data_type', 'FLOAT4X4')]), 
	'raycast_interpolated_boolean' : NodeInstance('GeometryNodeRaycast', [0, 1, 2, 3, 4], [0, 1, 2, 3, 4], [('mapping', 'INTERPOLATED'), ('data_type', 'BOOLEAN')]), 
	'raycast_interpolated_color' : NodeInstance('GeometryNodeRaycast', [0, 1, 2, 3, 4], [0, 1, 2, 3, 4], [('mapping', 'INTERPOLATED'), ('data_type', 'FLOAT_COLOR')]), 
	'raycast_interpolated_float' : NodeInstance('GeometryNodeRaycast', [0, 1, 2, 3, 4], [0, 1, 2, 3, 4], [('mapping', 'INTERPOLATED'), ('data_type', 'FLOAT')]), 
	'raycast_interpolated_integer' : NodeInstance('GeometryNodeRaycast', [0, 1, 2, 3, 4], [0, 1, 2, 3, 4], [('mapping', 'INTERPOLATED'), ('data_type', 'INT')]), 
	'raycast_interpolated_quaternion' : NodeInstance('GeometryNodeRaycast', [0, 1, 2, 3, 4], [0, 1, 2, 3, 4], [('mapping', 'INTERPOLATED'), ('data_type', 'QUATERNION')]), 
	'raycast_interpolated_vector' : NodeInstance('GeometryNodeRaycast', [0, 1, 2, 3, 4], [0, 1, 2, 3, 4], [('mapping', 'INTERPOLATED'), ('data_type', 'FLOAT_VECTOR')]), 
	'raycast_nearest_4x4_matrix' : NodeInstance('GeometryNodeRaycast', [0, 1, 2, 3, 4], [0, 1, 2, 3, 4], [('mapping', 'NEAREST'), ('data_type', 'FLOAT4X4')]), 
	'raycast_nearest_boolean' : NodeInstance('GeometryNodeRaycast', [0, 1, 2, 3, 4], [0, 1, 2, 3, 4], [('mapping', 'NEAREST'), ('data_type', 'BOOLEAN')]), 
	'raycast_nearest_color' : NodeInstance('GeometryNodeRaycast', [0, 1, 2, 3, 4], [0, 1, 2, 3, 4], [('mapping', 'NEAREST'), ('data_type', 'FLOAT_COLOR')]), 
	'raycast_nearest_float' : NodeInstance('GeometryNodeRaycast', [0, 1, 2, 3, 4], [0, 1, 2, 3, 4], [('mapping', 'NEAREST'), ('data_type', 'FLOAT')]), 
	'raycast_nearest_integer' : NodeInstance('GeometryNodeRaycast', [0, 1, 2, 3, 4], [0, 1, 2, 3, 4], [('mapping', 'NEAREST'), ('data_type', 'INT')]), 
	'raycast_nearest_quaternion' : NodeInstance('GeometryNodeRaycast', [0, 1, 2, 3, 4], [0, 1, 2, 3, 4], [('mapping', 'NEAREST'), ('data_type', 'QUATERNION')]), 
	'raycast_nearest_vector' : NodeInstance('GeometryNodeRaycast', [0, 1, 2, 3, 4], [0, 1, 2, 3, 4], [('mapping', 'NEAREST'), ('data_type', 'FLOAT_VECTOR')]), 
	'realize_instances' : NodeInstance('GeometryNodeRealizeInstances', [0, 1, 2, 3], [0], []), 
	'remove_named_attribute' : NodeInstance('GeometryNodeRemoveAttribute', [0, 1], [0], []), 
	'remove_named_attribute_exact' : NodeInstance('GeometryNodeRemoveAttribute', [0, 1], [0], [('pattern_mode', 'EXACT')]), 
	'remove_named_attribute_wildcard' : NodeInstance('GeometryNodeRemoveAttribute', [0, 1], [0], [('pattern_mode', 'WILDCARD')]), 
	'repeat_input' : NodeInstance('GeometryNodeRepeatInput', [0, 1], [0, 1], []), 
	'repeat_output' : NodeInstance('GeometryNodeRepeatOutput', [0, 1], [0, 1], []), 
	'replace_material' : NodeInstance('GeometryNodeReplaceMaterial', [0, 1, 2], [0], []), 
	'replace_string' : NodeInstance('FunctionNodeReplaceString', [0, 1, 2], [0], []), 
	'resample_curve' : NodeInstance('GeometryNodeResampleCurve', [0, 1, 2], [0], []), 
	'resample_curve_count' : NodeInstance('GeometryNodeResampleCurve', [0, 1, 2], [0], [('mode', 'COUNT')]), 
	'resample_curve_evaluated' : NodeInstance('GeometryNodeResampleCurve', [0, 1], [0], [('mode', 'EVALUATED')]), 
	'resample_curve_length' : NodeInstance('GeometryNodeResampleCurve', [0, 1, 3], [0], [('mode', 'LENGTH')]), 
	'reverse_curve' : NodeInstance('GeometryNodeReverseCurve', [0, 1], [0], []), 
	'rotate_euler' : NodeInstance('FunctionNodeRotateEuler', [0, 1], [0], []), 
	'rotate_euler_axis_angle_local' : NodeInstance('FunctionNodeRotateEuler', [0, 2, 3], [0], [('rotation_type', 'AXIS_ANGLE'), ('space', 'LOCAL')]), 
	'rotate_euler_axis_angle_object' : NodeInstance('FunctionNodeRotateEuler', [0, 2, 3], [0], [('rotation_type', 'AXIS_ANGLE'), ('space', 'OBJECT')]), 
	'rotate_euler_euler_local' : NodeInstance('FunctionNodeRotateEuler', [0, 1], [0], [('rotation_type', 'EULER'), ('space', 'LOCAL')]), 
	'rotate_euler_euler_object' : NodeInstance('FunctionNodeRotateEuler', [0, 1], [0], [('rotation_type', 'EULER'), ('space', 'OBJECT')]), 
	'rotate_instances' : NodeInstance('GeometryNodeRotateInstances', [0, 1, 2, 3, 4], [0], []), 
	'rotate_rotation' : NodeInstance('FunctionNodeRotateRotation', [0, 1], [0], []), 
	'rotate_rotation_global' : NodeInstance('FunctionNodeRotateRotation', [0, 1], [0], [('rotation_space', 'GLOBAL')]), 
	'rotate_rotation_local' : NodeInstance('FunctionNodeRotateRotation', [0, 1], [0], [('rotation_space', 'LOCAL')]), 
	'rotate_vector' : NodeInstance('FunctionNodeRotateVector', [0, 1], [0], []), 
	'rotation' : NodeInstance('FunctionNodeInputRotation', [], [0], []), 
	'rotation_to_axis_angle' : NodeInstance('FunctionNodeRotationToAxisAngle', [0], [0, 1], []), 
	'rotation_to_euler' : NodeInstance('FunctionNodeRotationToEuler', [0], [0], []), 
	'rotation_to_quaternion' : NodeInstance('FunctionNodeRotationToQuaternion', [0], [0, 1, 2, 3], []), 
	'sample_curve' : NodeInstance('GeometryNodeSampleCurve', [0, 1, 2, 4], [0, 1, 2, 3], []), 
	'sample_curve_factor_4x4_matrix' : NodeInstance('GeometryNodeSampleCurve', [0, 1, 2, 4], [0, 1, 2, 3], [('mode', 'FACTOR'), ('data_type', 'FLOAT4X4')]), 
	'sample_curve_factor_boolean' : NodeInstance('GeometryNodeSampleCurve', [0, 1, 2, 4], [0, 1, 2, 3], [('mode', 'FACTOR'), ('data_type', 'BOOLEAN')]), 
	'sample_curve_factor_color' : NodeInstance('GeometryNodeSampleCurve', [0, 1, 2, 4], [0, 1, 2, 3], [('mode', 'FACTOR'), ('data_type', 'FLOAT_COLOR')]), 
	'sample_curve_factor_float' : NodeInstance('GeometryNodeSampleCurve', [0, 1, 2, 4], [0, 1, 2, 3], [('mode', 'FACTOR'), ('data_type', 'FLOAT')]), 
	'sample_curve_factor_integer' : NodeInstance('GeometryNodeSampleCurve', [0, 1, 2, 4], [0, 1, 2, 3], [('mode', 'FACTOR'), ('data_type', 'INT')]), 
	'sample_curve_factor_quaternion' : NodeInstance('GeometryNodeSampleCurve', [0, 1, 2, 4], [0, 1, 2, 3], [('mode', 'FACTOR'), ('data_type', 'QUATERNION')]), 
	'sample_curve_factor_vector' : NodeInstance('GeometryNodeSampleCurve', [0, 1, 2, 4], [0, 1, 2, 3], [('mode', 'FACTOR'), ('data_type', 'FLOAT_VECTOR')]), 
	'sample_curve_length_4x4_matrix' : NodeInstance('GeometryNodeSampleCurve', [0, 1, 3, 4], [0, 1, 2, 3], [('mode', 'LENGTH'), ('data_type', 'FLOAT4X4')]), 
	'sample_curve_length_boolean' : NodeInstance('GeometryNodeSampleCurve', [0, 1, 3, 4], [0, 1, 2, 3], [('mode', 'LENGTH'), ('data_type', 'BOOLEAN')]), 
	'sample_curve_length_color' : NodeInstance('GeometryNodeSampleCurve', [0, 1, 3, 4], [0, 1, 2, 3], [('mode', 'LENGTH'), ('data_type', 'FLOAT_COLOR')]), 
	'sample_curve_length_float' : NodeInstance('GeometryNodeSampleCurve', [0, 1, 3, 4], [0, 1, 2, 3], [('mode', 'LENGTH'), ('data_type', 'FLOAT')]), 
	'sample_curve_length_integer' : NodeInstance('GeometryNodeSampleCurve', [0, 1, 3, 4], [0, 1, 2, 3], [('mode', 'LENGTH'), ('data_type', 'INT')]), 
	'sample_curve_length_quaternion' : NodeInstance('GeometryNodeSampleCurve', [0, 1, 3, 4], [0, 1, 2, 3], [('mode', 'LENGTH'), ('data_type', 'QUATERNION')]), 
	'sample_curve_length_vector' : NodeInstance('GeometryNodeSampleCurve', [0, 1, 3, 4], [0, 1, 2, 3], [('mode', 'LENGTH'), ('data_type', 'FLOAT_VECTOR')]), 
	'sample_grid' : NodeInstance('GeometryNodeSampleGrid', [0, 1], [0], []), 
	'sample_grid_boolean_nearest_neighbor' : NodeInstance('GeometryNodeSampleGrid', [0, 1], [0], [('data_type', 'BOOLEAN'), ('interpolation_mode', 'NEAREST')]), 
	'sample_grid_boolean_trilinear' : NodeInstance('GeometryNodeSampleGrid', [0, 1], [0], [('data_type', 'BOOLEAN'), ('interpolation_mode', 'TRILINEAR')]), 
	'sample_grid_boolean_triquadratic' : NodeInstance('GeometryNodeSampleGrid', [0, 1], [0], [('data_type', 'BOOLEAN'), ('interpolation_mode', 'TRIQUADRATIC')]), 
	'sample_grid_float_nearest_neighbor' : NodeInstance('GeometryNodeSampleGrid', [0, 1], [0], [('data_type', 'FLOAT'), ('interpolation_mode', 'NEAREST')]), 
	'sample_grid_float_trilinear' : NodeInstance('GeometryNodeSampleGrid', [0, 1], [0], [('data_type', 'FLOAT'), ('interpolation_mode', 'TRILINEAR')]), 
	'sample_grid_float_triquadratic' : NodeInstance('GeometryNodeSampleGrid', [0, 1], [0], [('data_type', 'FLOAT'), ('interpolation_mode', 'TRIQUADRATIC')]), 
	'sample_grid_index' : NodeInstance('GeometryNodeSampleGridIndex', [0, 1, 2, 3], [0], []), 
	'sample_grid_index_boolean' : NodeInstance('GeometryNodeSampleGridIndex', [0, 1, 2, 3], [0], [('data_type', 'BOOLEAN')]), 
	'sample_grid_index_float' : NodeInstance('GeometryNodeSampleGridIndex', [0, 1, 2, 3], [0], [('data_type', 'FLOAT')]), 
	'sample_grid_index_integer' : NodeInstance('GeometryNodeSampleGridIndex', [0, 1, 2, 3], [0], [('data_type', 'INT')]), 
	'sample_grid_index_vector' : NodeInstance('GeometryNodeSampleGridIndex', [0, 1, 2, 3], [0], [('data_type', 'VECTOR')]), 
	'sample_grid_integer_nearest_neighbor' : NodeInstance('GeometryNodeSampleGrid', [0, 1], [0], [('data_type', 'INT'), ('interpolation_mode', 'NEAREST')]), 
	'sample_grid_integer_trilinear' : NodeInstance('GeometryNodeSampleGrid', [0, 1], [0], [('data_type', 'INT'), ('interpolation_mode', 'TRILINEAR')]), 
	'sample_grid_integer_triquadratic' : NodeInstance('GeometryNodeSampleGrid', [0, 1], [0], [('data_type', 'INT'), ('interpolation_mode', 'TRIQUADRATIC')]), 
	'sample_grid_vector_nearest_neighbor' : NodeInstance('GeometryNodeSampleGrid', [0, 1], [0], [('data_type', 'VECTOR'), ('interpolation_mode', 'NEAREST')]), 
	'sample_grid_vector_trilinear' : NodeInstance('GeometryNodeSampleGrid', [0, 1], [0], [('data_type', 'VECTOR'), ('interpolation_mode', 'TRILINEAR')]), 
	'sample_grid_vector_triquadratic' : NodeInstance('GeometryNodeSampleGrid', [0, 1], [0], [('data_type', 'VECTOR'), ('interpolation_mode', 'TRIQUADRATIC')]), 
	'sample_index' : NodeInstance('GeometryNodeSampleIndex', [0, 1, 2], [0], []), 
	'sample_index_4x4_matrix_edge' : NodeInstance('GeometryNodeSampleIndex', [0, 1, 2], [0], [('data_type', 'FLOAT4X4'), ('domain', 'EDGE')]), 
	'sample_index_4x4_matrix_face' : NodeInstance('GeometryNodeSampleIndex', [0, 1, 2], [0], [('data_type', 'FLOAT4X4'), ('domain', 'FACE')]), 
	'sample_index_4x4_matrix_face_corner' : NodeInstance('GeometryNodeSampleIndex', [0, 1, 2], [0], [('data_type', 'FLOAT4X4'), ('domain', 'CORNER')]), 
	'sample_index_4x4_matrix_instance' : NodeInstance('GeometryNodeSampleIndex', [0, 1, 2], [0], [('data_type', 'FLOAT4X4'), ('domain', 'INSTANCE')]), 
	'sample_index_4x4_matrix_layer' : NodeInstance('GeometryNodeSampleIndex', [0, 1, 2], [0], [('data_type', 'FLOAT4X4'), ('domain', 'LAYER')]), 
	'sample_index_4x4_matrix_point' : NodeInstance('GeometryNodeSampleIndex', [0, 1, 2], [0], [('data_type', 'FLOAT4X4'), ('domain', 'POINT')]), 
	'sample_index_4x4_matrix_spline' : NodeInstance('GeometryNodeSampleIndex', [0, 1, 2], [0], [('data_type', 'FLOAT4X4'), ('domain', 'CURVE')]), 
	'sample_index_boolean_edge' : NodeInstance('GeometryNodeSampleIndex', [0, 1, 2], [0], [('data_type', 'BOOLEAN'), ('domain', 'EDGE')]), 
	'sample_index_boolean_face' : NodeInstance('GeometryNodeSampleIndex', [0, 1, 2], [0], [('data_type', 'BOOLEAN'), ('domain', 'FACE')]), 
	'sample_index_boolean_face_corner' : NodeInstance('GeometryNodeSampleIndex', [0, 1, 2], [0], [('data_type', 'BOOLEAN'), ('domain', 'CORNER')]), 
	'sample_index_boolean_instance' : NodeInstance('GeometryNodeSampleIndex', [0, 1, 2], [0], [('data_type', 'BOOLEAN'), ('domain', 'INSTANCE')]), 
	'sample_index_boolean_layer' : NodeInstance('GeometryNodeSampleIndex', [0, 1, 2], [0], [('data_type', 'BOOLEAN'), ('domain', 'LAYER')]), 
	'sample_index_boolean_point' : NodeInstance('GeometryNodeSampleIndex', [0, 1, 2], [0], [('data_type', 'BOOLEAN'), ('domain', 'POINT')]), 
	'sample_index_boolean_spline' : NodeInstance('GeometryNodeSampleIndex', [0, 1, 2], [0], [('data_type', 'BOOLEAN'), ('domain', 'CURVE')]), 
	'sample_index_color_edge' : NodeInstance('GeometryNodeSampleIndex', [0, 1, 2], [0], [('data_type', 'FLOAT_COLOR'), ('domain', 'EDGE')]), 
	'sample_index_color_face' : NodeInstance('GeometryNodeSampleIndex', [0, 1, 2], [0], [('data_type', 'FLOAT_COLOR'), ('domain', 'FACE')]), 
	'sample_index_color_face_corner' : NodeInstance('GeometryNodeSampleIndex', [0, 1, 2], [0], [('data_type', 'FLOAT_COLOR'), ('domain', 'CORNER')]), 
	'sample_index_color_instance' : NodeInstance('GeometryNodeSampleIndex', [0, 1, 2], [0], [('data_type', 'FLOAT_COLOR'), ('domain', 'INSTANCE')]), 
	'sample_index_color_layer' : NodeInstance('GeometryNodeSampleIndex', [0, 1, 2], [0], [('data_type', 'FLOAT_COLOR'), ('domain', 'LAYER')]), 
	'sample_index_color_point' : NodeInstance('GeometryNodeSampleIndex', [0, 1, 2], [0], [('data_type', 'FLOAT_COLOR'), ('domain', 'POINT')]), 
	'sample_index_color_spline' : NodeInstance('GeometryNodeSampleIndex', [0, 1, 2], [0], [('data_type', 'FLOAT_COLOR'), ('domain', 'CURVE')]), 
	'sample_index_float_edge' : NodeInstance('GeometryNodeSampleIndex', [0, 1, 2], [0], [('data_type', 'FLOAT'), ('domain', 'EDGE')]), 
	'sample_index_float_face' : NodeInstance('GeometryNodeSampleIndex', [0, 1, 2], [0], [('data_type', 'FLOAT'), ('domain', 'FACE')]), 
	'sample_index_float_face_corner' : NodeInstance('GeometryNodeSampleIndex', [0, 1, 2], [0], [('data_type', 'FLOAT'), ('domain', 'CORNER')]), 
	'sample_index_float_instance' : NodeInstance('GeometryNodeSampleIndex', [0, 1, 2], [0], [('data_type', 'FLOAT'), ('domain', 'INSTANCE')]), 
	'sample_index_float_layer' : NodeInstance('GeometryNodeSampleIndex', [0, 1, 2], [0], [('data_type', 'FLOAT'), ('domain', 'LAYER')]), 
	'sample_index_float_point' : NodeInstance('GeometryNodeSampleIndex', [0, 1, 2], [0], [('data_type', 'FLOAT'), ('domain', 'POINT')]), 
	'sample_index_float_spline' : NodeInstance('GeometryNodeSampleIndex', [0, 1, 2], [0], [('data_type', 'FLOAT'), ('domain', 'CURVE')]), 
	'sample_index_integer_edge' : NodeInstance('GeometryNodeSampleIndex', [0, 1, 2], [0], [('data_type', 'INT'), ('domain', 'EDGE')]), 
	'sample_index_integer_face' : NodeInstance('GeometryNodeSampleIndex', [0, 1, 2], [0], [('data_type', 'INT'), ('domain', 'FACE')]), 
	'sample_index_integer_face_corner' : NodeInstance('GeometryNodeSampleIndex', [0, 1, 2], [0], [('data_type', 'INT'), ('domain', 'CORNER')]), 
	'sample_index_integer_instance' : NodeInstance('GeometryNodeSampleIndex', [0, 1, 2], [0], [('data_type', 'INT'), ('domain', 'INSTANCE')]), 
	'sample_index_integer_layer' : NodeInstance('GeometryNodeSampleIndex', [0, 1, 2], [0], [('data_type', 'INT'), ('domain', 'LAYER')]), 
	'sample_index_integer_point' : NodeInstance('GeometryNodeSampleIndex', [0, 1, 2], [0], [('data_type', 'INT'), ('domain', 'POINT')]), 
	'sample_index_integer_spline' : NodeInstance('GeometryNodeSampleIndex', [0, 1, 2], [0], [('data_type', 'INT'), ('domain', 'CURVE')]), 
	'sample_index_quaternion_edge' : NodeInstance('GeometryNodeSampleIndex', [0, 1, 2], [0], [('data_type', 'QUATERNION'), ('domain', 'EDGE')]), 
	'sample_index_quaternion_face' : NodeInstance('GeometryNodeSampleIndex', [0, 1, 2], [0], [('data_type', 'QUATERNION'), ('domain', 'FACE')]), 
	'sample_index_quaternion_face_corner' : NodeInstance('GeometryNodeSampleIndex', [0, 1, 2], [0], [('data_type', 'QUATERNION'), ('domain', 'CORNER')]), 
	'sample_index_quaternion_instance' : NodeInstance('GeometryNodeSampleIndex', [0, 1, 2], [0], [('data_type', 'QUATERNION'), ('domain', 'INSTANCE')]), 
	'sample_index_quaternion_layer' : NodeInstance('GeometryNodeSampleIndex', [0, 1, 2], [0], [('data_type', 'QUATERNION'), ('domain', 'LAYER')]), 
	'sample_index_quaternion_point' : NodeInstance('GeometryNodeSampleIndex', [0, 1, 2], [0], [('data_type', 'QUATERNION'), ('domain', 'POINT')]), 
	'sample_index_quaternion_spline' : NodeInstance('GeometryNodeSampleIndex', [0, 1, 2], [0], [('data_type', 'QUATERNION'), ('domain', 'CURVE')]), 
	'sample_index_vector_edge' : NodeInstance('GeometryNodeSampleIndex', [0, 1, 2], [0], [('data_type', 'FLOAT_VECTOR'), ('domain', 'EDGE')]), 
	'sample_index_vector_face' : NodeInstance('GeometryNodeSampleIndex', [0, 1, 2], [0], [('data_type', 'FLOAT_VECTOR'), ('domain', 'FACE')]), 
	'sample_index_vector_face_corner' : NodeInstance('GeometryNodeSampleIndex', [0, 1, 2], [0], [('data_type', 'FLOAT_VECTOR'), ('domain', 'CORNER')]), 
	'sample_index_vector_instance' : NodeInstance('GeometryNodeSampleIndex', [0, 1, 2], [0], [('data_type', 'FLOAT_VECTOR'), ('domain', 'INSTANCE')]), 
	'sample_index_vector_layer' : NodeInstance('GeometryNodeSampleIndex', [0, 1, 2], [0], [('data_type', 'FLOAT_VECTOR'), ('domain', 'LAYER')]), 
	'sample_index_vector_point' : NodeInstance('GeometryNodeSampleIndex', [0, 1, 2], [0], [('data_type', 'FLOAT_VECTOR'), ('domain', 'POINT')]), 
	'sample_index_vector_spline' : NodeInstance('GeometryNodeSampleIndex', [0, 1, 2], [0], [('data_type', 'FLOAT_VECTOR'), ('domain', 'CURVE')]), 
	'sample_nearest' : NodeInstance('GeometryNodeSampleNearest', [0, 1], [0], []), 
	'sample_nearest_edge' : NodeInstance('GeometryNodeSampleNearest', [0, 1], [0], [('domain', 'EDGE')]), 
	'sample_nearest_face' : NodeInstance('GeometryNodeSampleNearest', [0, 1], [0], [('domain', 'FACE')]), 
	'sample_nearest_face_corner' : NodeInstance('GeometryNodeSampleNearest', [0, 1], [0], [('domain', 'CORNER')]), 
	'sample_nearest_point' : NodeInstance('GeometryNodeSampleNearest', [0, 1], [0], [('domain', 'POINT')]), 
	'sample_nearest_surface' : NodeInstance('GeometryNodeSampleNearestSurface', [0, 1, 2, 3, 4], [0, 1], []), 
	'sample_nearest_surface_4x4_matrix' : NodeInstance('GeometryNodeSampleNearestSurface', [0, 1, 2, 3, 4], [0, 1], [('data_type', 'FLOAT4X4')]), 
	'sample_nearest_surface_boolean' : NodeInstance('GeometryNodeSampleNearestSurface', [0, 1, 2, 3, 4], [0, 1], [('data_type', 'BOOLEAN')]), 
	'sample_nearest_surface_color' : NodeInstance('GeometryNodeSampleNearestSurface', [0, 1, 2, 3, 4], [0, 1], [('data_type', 'FLOAT_COLOR')]), 
	'sample_nearest_surface_float' : NodeInstance('GeometryNodeSampleNearestSurface', [0, 1, 2, 3, 4], [0, 1], [('data_type', 'FLOAT')]), 
	'sample_nearest_surface_integer' : NodeInstance('GeometryNodeSampleNearestSurface', [0, 1, 2, 3, 4], [0, 1], [('data_type', 'INT')]), 
	'sample_nearest_surface_quaternion' : NodeInstance('GeometryNodeSampleNearestSurface', [0, 1, 2, 3, 4], [0, 1], [('data_type', 'QUATERNION')]), 
	'sample_nearest_surface_vector' : NodeInstance('GeometryNodeSampleNearestSurface', [0, 1, 2, 3, 4], [0, 1], [('data_type', 'FLOAT_VECTOR')]), 
	'sample_uv_surface' : NodeInstance('GeometryNodeSampleUVSurface', [0, 1, 2, 3], [0, 1], []), 
	'sample_uv_surface_4x4_matrix' : NodeInstance('GeometryNodeSampleUVSurface', [0, 1, 2, 3], [0, 1], [('data_type', 'FLOAT4X4')]), 
	'sample_uv_surface_boolean' : NodeInstance('GeometryNodeSampleUVSurface', [0, 1, 2, 3], [0, 1], [('data_type', 'BOOLEAN')]), 
	'sample_uv_surface_color' : NodeInstance('GeometryNodeSampleUVSurface', [0, 1, 2, 3], [0, 1], [('data_type', 'FLOAT_COLOR')]), 
	'sample_uv_surface_float' : NodeInstance('GeometryNodeSampleUVSurface', [0, 1, 2, 3], [0, 1], [('data_type', 'FLOAT')]), 
	'sample_uv_surface_integer' : NodeInstance('GeometryNodeSampleUVSurface', [0, 1, 2, 3], [0, 1], [('data_type', 'INT')]), 
	'sample_uv_surface_quaternion' : NodeInstance('GeometryNodeSampleUVSurface', [0, 1, 2, 3], [0, 1], [('data_type', 'QUATERNION')]), 
	'sample_uv_surface_vector' : NodeInstance('GeometryNodeSampleUVSurface', [0, 1, 2, 3], [0, 1], [('data_type', 'FLOAT_VECTOR')]), 
	'scale_elements' : NodeInstance('GeometryNodeScaleElements', [0, 1, 2, 3], [0], []), 
	'scale_elements_edge_single_axis' : NodeInstance('GeometryNodeScaleElements', [0, 1, 2, 3, 4], [0], [('domain', 'EDGE'), ('scale_mode', 'SINGLE_AXIS')]), 
	'scale_elements_edge_uniform' : NodeInstance('GeometryNodeScaleElements', [0, 1, 2, 3], [0], [('domain', 'EDGE'), ('scale_mode', 'UNIFORM')]), 
	'scale_elements_face_single_axis' : NodeInstance('GeometryNodeScaleElements', [0, 1, 2, 3, 4], [0], [('domain', 'FACE'), ('scale_mode', 'SINGLE_AXIS')]), 
	'scale_elements_face_uniform' : NodeInstance('GeometryNodeScaleElements', [0, 1, 2, 3], [0], [('domain', 'FACE'), ('scale_mode', 'UNIFORM')]), 
	'scale_instances' : NodeInstance('GeometryNodeScaleInstances', [0, 1, 2, 3, 4], [0], []), 
	'scene_time' : NodeInstance('GeometryNodeInputSceneTime', [], [0, 1], []), 
	'sdf_grid_boolean' : NodeInstance('GeometryNodeSDFGridBoolean', [0, 1], [0], []), 
	'sdf_grid_boolean_difference' : NodeInstance('GeometryNodeSDFGridBoolean', [0, 1], [0], [('operation', 'DIFFERENCE')]), 
	'sdf_grid_boolean_intersect' : NodeInstance('GeometryNodeSDFGridBoolean', [1], [0], [('operation', 'INTERSECT')]), 
	'sdf_grid_boolean_union' : NodeInstance('GeometryNodeSDFGridBoolean', [1], [0], [('operation', 'UNION')]), 
	'selection' : NodeInstance('GeometryNodeToolSelection', [], [0, 1], []), 
	'self_object' : NodeInstance('GeometryNodeSelfObject', [], [0], []), 
	'separate_color' : NodeInstance('FunctionNodeSeparateColor', [0], [0, 1, 2, 3], []), 
	'separate_color_hsl' : NodeInstance('FunctionNodeSeparateColor', [0], [0, 1, 2, 3], [('mode', 'HSL')]), 
	'separate_color_hsv' : NodeInstance('FunctionNodeSeparateColor', [0], [0, 1, 2, 3], [('mode', 'HSV')]), 
	'separate_color_rgb' : NodeInstance('FunctionNodeSeparateColor', [0], [0, 1, 2, 3], [('mode', 'RGB')]), 
	'separate_components' : NodeInstance('GeometryNodeSeparateComponents', [0], [0, 1, 2, 3, 4, 5], []), 
	'separate_geometry' : NodeInstance('GeometryNodeSeparateGeometry', [0, 1], [0, 1], []), 
	'separate_geometry_edge' : NodeInstance('GeometryNodeSeparateGeometry', [0, 1], [0, 1], [('domain', 'EDGE')]), 
	'separate_geometry_face' : NodeInstance('GeometryNodeSeparateGeometry', [0, 1], [0, 1], [('domain', 'FACE')]), 
	'separate_geometry_instance' : NodeInstance('GeometryNodeSeparateGeometry', [0, 1], [0, 1], [('domain', 'INSTANCE')]), 
	'separate_geometry_layer' : NodeInstance('GeometryNodeSeparateGeometry', [0, 1], [0, 1], [('domain', 'LAYER')]), 
	'separate_geometry_point' : NodeInstance('GeometryNodeSeparateGeometry', [0, 1], [0, 1], [('domain', 'POINT')]), 
	'separate_geometry_spline' : NodeInstance('GeometryNodeSeparateGeometry', [0, 1], [0, 1], [('domain', 'CURVE')]), 
	'separate_matrix' : NodeInstance('FunctionNodeSeparateMatrix', [0], [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15], []), 
	'separate_transform' : NodeInstance('FunctionNodeSeparateTransform', [0], [0, 1, 2], []), 
	'set_curve_normal' : NodeInstance('GeometryNodeSetCurveNormal', [0, 1], [0], []), 
	'set_curve_normal_free' : NodeInstance('GeometryNodeSetCurveNormal', [0, 1, 2], [0], [('mode', 'FREE')]), 
	'set_curve_normal_minimum_twist' : NodeInstance('GeometryNodeSetCurveNormal', [0, 1], [0], [('mode', 'MINIMUM_TWIST')]), 
	'set_curve_normal_z_up' : NodeInstance('GeometryNodeSetCurveNormal', [0, 1], [0], [('mode', 'Z_UP')]), 
	'set_curve_radius' : NodeInstance('GeometryNodeSetCurveRadius', [0, 1, 2], [0], []), 
	'set_curve_tilt' : NodeInstance('GeometryNodeSetCurveTilt', [0, 1, 2], [0], []), 
	'set_face_set' : NodeInstance('GeometryNodeToolSetFaceSet', [0, 1, 2], [0], []), 
	'set_geometry_name' : NodeInstance('GeometryNodeSetGeometryName', [0, 1], [0], []), 
	'set_handle_positions' : NodeInstance('GeometryNodeSetCurveHandlePositions', [0, 1, 2, 3], [0], []), 
	'set_handle_positions_left' : NodeInstance('GeometryNodeSetCurveHandlePositions', [0, 1, 2, 3], [0], [('mode', 'LEFT')]), 
	'set_handle_positions_right' : NodeInstance('GeometryNodeSetCurveHandlePositions', [0, 1, 2, 3], [0], [('mode', 'RIGHT')]), 
	'set_handle_type' : NodeInstance('GeometryNodeCurveSetHandles', [0, 1], [0], []), 
	'set_id' : NodeInstance('GeometryNodeSetID', [0, 1, 2], [0], []), 
	'set_instance_transform' : NodeInstance('GeometryNodeSetInstanceTransform', [0, 1, 2], [0], []), 
	'set_material' : NodeInstance('GeometryNodeSetMaterial', [0, 1, 2], [0], []), 
	'set_material_index' : NodeInstance('GeometryNodeSetMaterialIndex', [0, 1, 2], [0], []), 
	'set_point_radius' : NodeInstance('GeometryNodeSetPointRadius', [0, 1, 2], [0], []), 
	'set_position' : NodeInstance('GeometryNodeSetPosition', [0, 1, 2, 3], [0], []), 
	'set_selection' : NodeInstance('GeometryNodeToolSetSelection', [0, 1], [0], []), 
	'set_selection_edge_boolean' : NodeInstance('GeometryNodeToolSetSelection', [0, 1], [0], [('domain', 'EDGE'), ('selection_type', 'BOOLEAN')]), 
	'set_selection_edge_float' : NodeInstance('GeometryNodeToolSetSelection', [0, 1], [0], [('domain', 'EDGE'), ('selection_type', 'FLOAT')]), 
	'set_selection_face_boolean' : NodeInstance('GeometryNodeToolSetSelection', [0, 1], [0], [('domain', 'FACE'), ('selection_type', 'BOOLEAN')]), 
	'set_selection_face_float' : NodeInstance('GeometryNodeToolSetSelection', [0, 1], [0], [('domain', 'FACE'), ('selection_type', 'FLOAT')]), 
	'set_selection_point_boolean' : NodeInstance('GeometryNodeToolSetSelection', [0, 1], [0], [('domain', 'POINT'), ('selection_type', 'BOOLEAN')]), 
	'set_selection_point_float' : NodeInstance('GeometryNodeToolSetSelection', [0, 1], [0], [('domain', 'POINT'), ('selection_type', 'FLOAT')]), 
	'set_selection_spline_boolean' : NodeInstance('GeometryNodeToolSetSelection', [0, 1], [0], [('domain', 'CURVE'), ('selection_type', 'BOOLEAN')]), 
	'set_selection_spline_float' : NodeInstance('GeometryNodeToolSetSelection', [0, 1], [0], [('domain', 'CURVE'), ('selection_type', 'FLOAT')]), 
	'set_shade_smooth' : NodeInstance('GeometryNodeSetShadeSmooth', [0, 1, 2], [0], []), 
	'set_shade_smooth_edge' : NodeInstance('GeometryNodeSetShadeSmooth', [0, 1, 2], [0], [('domain', 'EDGE')]), 
	'set_shade_smooth_face' : NodeInstance('GeometryNodeSetShadeSmooth', [0, 1, 2], [0], [('domain', 'FACE')]), 
	'set_spline_cyclic' : NodeInstance('GeometryNodeSetSplineCyclic', [0, 1, 2], [0], []), 
	'set_spline_resolution' : NodeInstance('GeometryNodeSetSplineResolution', [0, 1, 2], [0], []), 
	'set_spline_type' : NodeInstance('GeometryNodeCurveSplineType', [0, 1], [0], []), 
	'set_spline_type_bézier' : NodeInstance('GeometryNodeCurveSplineType', [0, 1], [0], [('spline_type', 'BEZIER')]), 
	'set_spline_type_catmull_rom' : NodeInstance('GeometryNodeCurveSplineType', [0, 1], [0], [('spline_type', 'CATMULL_ROM')]), 
	'set_spline_type_nurbs' : NodeInstance('GeometryNodeCurveSplineType', [0, 1], [0], [('spline_type', 'NURBS')]), 
	'set_spline_type_poly' : NodeInstance('GeometryNodeCurveSplineType', [0, 1], [0], [('spline_type', 'POLY')]), 
	'shortest_edge_paths' : NodeInstance('GeometryNodeInputShortestEdgePaths', [0, 1], [0, 1], []), 
	'simulation_input' : NodeInstance('GeometryNodeSimulationInput', [], [0], []), 
	'simulation_output' : NodeInstance('GeometryNodeSimulationOutput', [0, 1, 2], [0, 1], []), 
	'slice_string' : NodeInstance('FunctionNodeSliceString', [0, 1, 2], [0], []), 
	'sort_elements' : NodeInstance('GeometryNodeSortElements', [0, 1, 2, 3], [0], []), 
	'sort_elements_edge' : NodeInstance('GeometryNodeSortElements', [0, 1, 2, 3], [0], [('domain', 'EDGE')]), 
	'sort_elements_face' : NodeInstance('GeometryNodeSortElements', [0, 1, 2, 3], [0], [('domain', 'FACE')]), 
	'sort_elements_instance' : NodeInstance('GeometryNodeSortElements', [0, 1, 2, 3], [0], [('domain', 'INSTANCE')]), 
	'sort_elements_point' : NodeInstance('GeometryNodeSortElements', [0, 1, 2, 3], [0], [('domain', 'POINT')]), 
	'sort_elements_spline' : NodeInstance('GeometryNodeSortElements', [0, 1, 2, 3], [0], [('domain', 'CURVE')]), 
	'special_characters' : NodeInstance('FunctionNodeInputSpecialCharacters', [], [0, 1], []), 
	'spiral' : NodeInstance('GeometryNodeCurveSpiral', [0, 1, 2, 3, 4, 5], [0], []), 
	'spline_length' : NodeInstance('GeometryNodeSplineLength', [], [0, 1], []), 
	'spline_parameter' : NodeInstance('GeometryNodeSplineParameter', [], [0, 1, 2], []), 
	'spline_resolution' : NodeInstance('GeometryNodeInputSplineResolution', [], [0], []), 
	'split_edges' : NodeInstance('GeometryNodeSplitEdges', [0, 1], [0], []), 
	'split_to_instances' : NodeInstance('GeometryNodeSplitToInstances', [0, 1, 2], [0, 1], []), 
	'split_to_instances_edge' : NodeInstance('GeometryNodeSplitToInstances', [0, 1, 2], [0, 1], [('domain', 'EDGE')]), 
	'split_to_instances_face' : NodeInstance('GeometryNodeSplitToInstances', [0, 1, 2], [0, 1], [('domain', 'FACE')]), 
	'split_to_instances_instance' : NodeInstance('GeometryNodeSplitToInstances', [0, 1, 2], [0, 1], [('domain', 'INSTANCE')]), 
	'split_to_instances_layer' : NodeInstance('GeometryNodeSplitToInstances', [0, 1, 2], [0, 1], [('domain', 'LAYER')]), 
	'split_to_instances_point' : NodeInstance('GeometryNodeSplitToInstances', [0, 1, 2], [0, 1], [('domain', 'POINT')]), 
	'split_to_instances_spline' : NodeInstance('GeometryNodeSplitToInstances', [0, 1, 2], [0, 1], [('domain', 'CURVE')]), 
	'star' : NodeInstance('GeometryNodeCurveStar', [0, 1, 2, 3], [0, 1], []), 
	'store_named_attribute' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], []), 
	'store_named_attribute_2d_vector_edge' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'FLOAT2'), ('domain', 'EDGE')]), 
	'store_named_attribute_2d_vector_face' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'FLOAT2'), ('domain', 'FACE')]), 
	'store_named_attribute_2d_vector_face_corner' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'FLOAT2'), ('domain', 'CORNER')]), 
	'store_named_attribute_2d_vector_instance' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'FLOAT2'), ('domain', 'INSTANCE')]), 
	'store_named_attribute_2d_vector_layer' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'FLOAT2'), ('domain', 'LAYER')]), 
	'store_named_attribute_2d_vector_point' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'FLOAT2'), ('domain', 'POINT')]), 
	'store_named_attribute_2d_vector_spline' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'FLOAT2'), ('domain', 'CURVE')]), 
	'store_named_attribute_4x4_matrix_edge' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'FLOAT4X4'), ('domain', 'EDGE')]), 
	'store_named_attribute_4x4_matrix_face' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'FLOAT4X4'), ('domain', 'FACE')]), 
	'store_named_attribute_4x4_matrix_face_corner' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'FLOAT4X4'), ('domain', 'CORNER')]), 
	'store_named_attribute_4x4_matrix_instance' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'FLOAT4X4'), ('domain', 'INSTANCE')]), 
	'store_named_attribute_4x4_matrix_layer' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'FLOAT4X4'), ('domain', 'LAYER')]), 
	'store_named_attribute_4x4_matrix_point' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'FLOAT4X4'), ('domain', 'POINT')]), 
	'store_named_attribute_4x4_matrix_spline' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'FLOAT4X4'), ('domain', 'CURVE')]), 
	'store_named_attribute_8_bit_integer_edge' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'INT8'), ('domain', 'EDGE')]), 
	'store_named_attribute_8_bit_integer_face' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'INT8'), ('domain', 'FACE')]), 
	'store_named_attribute_8_bit_integer_face_corner' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'INT8'), ('domain', 'CORNER')]), 
	'store_named_attribute_8_bit_integer_instance' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'INT8'), ('domain', 'INSTANCE')]), 
	'store_named_attribute_8_bit_integer_layer' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'INT8'), ('domain', 'LAYER')]), 
	'store_named_attribute_8_bit_integer_point' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'INT8'), ('domain', 'POINT')]), 
	'store_named_attribute_8_bit_integer_spline' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'INT8'), ('domain', 'CURVE')]), 
	'store_named_attribute_boolean_edge' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'BOOLEAN'), ('domain', 'EDGE')]), 
	'store_named_attribute_boolean_face' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'BOOLEAN'), ('domain', 'FACE')]), 
	'store_named_attribute_boolean_face_corner' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'BOOLEAN'), ('domain', 'CORNER')]), 
	'store_named_attribute_boolean_instance' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'BOOLEAN'), ('domain', 'INSTANCE')]), 
	'store_named_attribute_boolean_layer' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'BOOLEAN'), ('domain', 'LAYER')]), 
	'store_named_attribute_boolean_point' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'BOOLEAN'), ('domain', 'POINT')]), 
	'store_named_attribute_boolean_spline' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'BOOLEAN'), ('domain', 'CURVE')]), 
	'store_named_attribute_byte_color_edge' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'BYTE_COLOR'), ('domain', 'EDGE')]), 
	'store_named_attribute_byte_color_face' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'BYTE_COLOR'), ('domain', 'FACE')]), 
	'store_named_attribute_byte_color_face_corner' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'BYTE_COLOR'), ('domain', 'CORNER')]), 
	'store_named_attribute_byte_color_instance' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'BYTE_COLOR'), ('domain', 'INSTANCE')]), 
	'store_named_attribute_byte_color_layer' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'BYTE_COLOR'), ('domain', 'LAYER')]), 
	'store_named_attribute_byte_color_point' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'BYTE_COLOR'), ('domain', 'POINT')]), 
	'store_named_attribute_byte_color_spline' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'BYTE_COLOR'), ('domain', 'CURVE')]), 
	'store_named_attribute_color_edge' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'FLOAT_COLOR'), ('domain', 'EDGE')]), 
	'store_named_attribute_color_face' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'FLOAT_COLOR'), ('domain', 'FACE')]), 
	'store_named_attribute_color_face_corner' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'FLOAT_COLOR'), ('domain', 'CORNER')]), 
	'store_named_attribute_color_instance' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'FLOAT_COLOR'), ('domain', 'INSTANCE')]), 
	'store_named_attribute_color_layer' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'FLOAT_COLOR'), ('domain', 'LAYER')]), 
	'store_named_attribute_color_point' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'FLOAT_COLOR'), ('domain', 'POINT')]), 
	'store_named_attribute_color_spline' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'FLOAT_COLOR'), ('domain', 'CURVE')]), 
	'store_named_attribute_float_edge' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'FLOAT'), ('domain', 'EDGE')]), 
	'store_named_attribute_float_face' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'FLOAT'), ('domain', 'FACE')]), 
	'store_named_attribute_float_face_corner' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'FLOAT'), ('domain', 'CORNER')]), 
	'store_named_attribute_float_instance' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'FLOAT'), ('domain', 'INSTANCE')]), 
	'store_named_attribute_float_layer' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'FLOAT'), ('domain', 'LAYER')]), 
	'store_named_attribute_float_point' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'FLOAT'), ('domain', 'POINT')]), 
	'store_named_attribute_float_spline' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'FLOAT'), ('domain', 'CURVE')]), 
	'store_named_attribute_integer_edge' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'INT'), ('domain', 'EDGE')]), 
	'store_named_attribute_integer_face' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'INT'), ('domain', 'FACE')]), 
	'store_named_attribute_integer_face_corner' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'INT'), ('domain', 'CORNER')]), 
	'store_named_attribute_integer_instance' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'INT'), ('domain', 'INSTANCE')]), 
	'store_named_attribute_integer_layer' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'INT'), ('domain', 'LAYER')]), 
	'store_named_attribute_integer_point' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'INT'), ('domain', 'POINT')]), 
	'store_named_attribute_integer_spline' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'INT'), ('domain', 'CURVE')]), 
	'store_named_attribute_quaternion_edge' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'QUATERNION'), ('domain', 'EDGE')]), 
	'store_named_attribute_quaternion_face' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'QUATERNION'), ('domain', 'FACE')]), 
	'store_named_attribute_quaternion_face_corner' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'QUATERNION'), ('domain', 'CORNER')]), 
	'store_named_attribute_quaternion_instance' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'QUATERNION'), ('domain', 'INSTANCE')]), 
	'store_named_attribute_quaternion_layer' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'QUATERNION'), ('domain', 'LAYER')]), 
	'store_named_attribute_quaternion_point' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'QUATERNION'), ('domain', 'POINT')]), 
	'store_named_attribute_quaternion_spline' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'QUATERNION'), ('domain', 'CURVE')]), 
	'store_named_attribute_vector_edge' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'FLOAT_VECTOR'), ('domain', 'EDGE')]), 
	'store_named_attribute_vector_face' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'FLOAT_VECTOR'), ('domain', 'FACE')]), 
	'store_named_attribute_vector_face_corner' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'FLOAT_VECTOR'), ('domain', 'CORNER')]), 
	'store_named_attribute_vector_instance' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'FLOAT_VECTOR'), ('domain', 'INSTANCE')]), 
	'store_named_attribute_vector_layer' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'FLOAT_VECTOR'), ('domain', 'LAYER')]), 
	'store_named_attribute_vector_point' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'FLOAT_VECTOR'), ('domain', 'POINT')]), 
	'store_named_attribute_vector_spline' : NodeInstance('GeometryNodeStoreNamedAttribute', [0, 1, 2, 3], [0], [('data_type', 'FLOAT_VECTOR'), ('domain', 'CURVE')]), 
	'store_named_grid' : NodeInstance('GeometryNodeStoreNamedGrid', [0, 1, 2], [0], []), 
	'store_named_grid_2d_vector' : NodeInstance('GeometryNodeStoreNamedGrid', [0, 1, 2], [0], [('data_type', 'FLOAT2')]), 
	'store_named_grid_float' : NodeInstance('GeometryNodeStoreNamedGrid', [0, 1, 2], [0], [('data_type', 'FLOAT')]), 
	'store_named_grid_vector' : NodeInstance('GeometryNodeStoreNamedGrid', [0, 1, 2], [0], [('data_type', 'FLOAT_VECTOR')]), 
	'string' : NodeInstance('FunctionNodeInputString', [], [0], []), 
	'string_length' : NodeInstance('FunctionNodeStringLength', [0], [0], []), 
	'string_to_curves' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], []), 
	'string_to_curves_overflow_center_bottom_baseline_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'CENTER'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_overflow_center_bottom_baseline_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'CENTER'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_overflow_center_bottom_baseline_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'CENTER'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_overflow_center_bottom_baseline_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'CENTER'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_overflow_center_bottom_baseline_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'CENTER'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_overflow_center_bottom_baseline_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'CENTER'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_overflow_center_bottom_baseline_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'CENTER'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_overflow_center_bottom_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'CENTER'), ('align_y', 'BOTTOM'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_overflow_center_bottom_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'CENTER'), ('align_y', 'BOTTOM'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_overflow_center_bottom_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'CENTER'), ('align_y', 'BOTTOM'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_overflow_center_bottom_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'CENTER'), ('align_y', 'BOTTOM'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_overflow_center_bottom_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'CENTER'), ('align_y', 'BOTTOM'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_overflow_center_bottom_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'CENTER'), ('align_y', 'BOTTOM'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_overflow_center_bottom_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'CENTER'), ('align_y', 'BOTTOM'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_overflow_center_middle_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'CENTER'), ('align_y', 'MIDDLE'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_overflow_center_middle_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'CENTER'), ('align_y', 'MIDDLE'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_overflow_center_middle_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'CENTER'), ('align_y', 'MIDDLE'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_overflow_center_middle_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'CENTER'), ('align_y', 'MIDDLE'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_overflow_center_middle_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'CENTER'), ('align_y', 'MIDDLE'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_overflow_center_middle_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'CENTER'), ('align_y', 'MIDDLE'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_overflow_center_middle_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'CENTER'), ('align_y', 'MIDDLE'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_overflow_center_top_baseline_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'CENTER'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_overflow_center_top_baseline_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'CENTER'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_overflow_center_top_baseline_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'CENTER'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_overflow_center_top_baseline_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'CENTER'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_overflow_center_top_baseline_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'CENTER'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_overflow_center_top_baseline_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'CENTER'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_overflow_center_top_baseline_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'CENTER'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_overflow_center_top_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'CENTER'), ('align_y', 'TOP'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_overflow_center_top_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'CENTER'), ('align_y', 'TOP'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_overflow_center_top_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'CENTER'), ('align_y', 'TOP'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_overflow_center_top_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'CENTER'), ('align_y', 'TOP'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_overflow_center_top_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'CENTER'), ('align_y', 'TOP'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_overflow_center_top_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'CENTER'), ('align_y', 'TOP'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_overflow_center_top_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'CENTER'), ('align_y', 'TOP'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_overflow_flush_bottom_baseline_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'FLUSH'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_overflow_flush_bottom_baseline_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'FLUSH'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_overflow_flush_bottom_baseline_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'FLUSH'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_overflow_flush_bottom_baseline_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'FLUSH'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_overflow_flush_bottom_baseline_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'FLUSH'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_overflow_flush_bottom_baseline_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'FLUSH'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_overflow_flush_bottom_baseline_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'FLUSH'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_overflow_flush_bottom_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'FLUSH'), ('align_y', 'BOTTOM'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_overflow_flush_bottom_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'FLUSH'), ('align_y', 'BOTTOM'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_overflow_flush_bottom_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'FLUSH'), ('align_y', 'BOTTOM'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_overflow_flush_bottom_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'FLUSH'), ('align_y', 'BOTTOM'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_overflow_flush_bottom_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'FLUSH'), ('align_y', 'BOTTOM'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_overflow_flush_bottom_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'FLUSH'), ('align_y', 'BOTTOM'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_overflow_flush_bottom_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'FLUSH'), ('align_y', 'BOTTOM'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_overflow_flush_middle_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'FLUSH'), ('align_y', 'MIDDLE'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_overflow_flush_middle_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'FLUSH'), ('align_y', 'MIDDLE'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_overflow_flush_middle_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'FLUSH'), ('align_y', 'MIDDLE'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_overflow_flush_middle_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'FLUSH'), ('align_y', 'MIDDLE'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_overflow_flush_middle_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'FLUSH'), ('align_y', 'MIDDLE'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_overflow_flush_middle_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'FLUSH'), ('align_y', 'MIDDLE'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_overflow_flush_middle_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'FLUSH'), ('align_y', 'MIDDLE'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_overflow_flush_top_baseline_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'FLUSH'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_overflow_flush_top_baseline_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'FLUSH'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_overflow_flush_top_baseline_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'FLUSH'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_overflow_flush_top_baseline_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'FLUSH'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_overflow_flush_top_baseline_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'FLUSH'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_overflow_flush_top_baseline_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'FLUSH'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_overflow_flush_top_baseline_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'FLUSH'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_overflow_flush_top_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'FLUSH'), ('align_y', 'TOP'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_overflow_flush_top_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'FLUSH'), ('align_y', 'TOP'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_overflow_flush_top_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'FLUSH'), ('align_y', 'TOP'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_overflow_flush_top_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'FLUSH'), ('align_y', 'TOP'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_overflow_flush_top_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'FLUSH'), ('align_y', 'TOP'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_overflow_flush_top_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'FLUSH'), ('align_y', 'TOP'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_overflow_flush_top_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'FLUSH'), ('align_y', 'TOP'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_overflow_justify_bottom_baseline_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'JUSTIFY'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_overflow_justify_bottom_baseline_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'JUSTIFY'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_overflow_justify_bottom_baseline_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'JUSTIFY'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_overflow_justify_bottom_baseline_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'JUSTIFY'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_overflow_justify_bottom_baseline_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'JUSTIFY'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_overflow_justify_bottom_baseline_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'JUSTIFY'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_overflow_justify_bottom_baseline_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'JUSTIFY'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_overflow_justify_bottom_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'JUSTIFY'), ('align_y', 'BOTTOM'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_overflow_justify_bottom_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'JUSTIFY'), ('align_y', 'BOTTOM'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_overflow_justify_bottom_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'JUSTIFY'), ('align_y', 'BOTTOM'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_overflow_justify_bottom_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'JUSTIFY'), ('align_y', 'BOTTOM'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_overflow_justify_bottom_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'JUSTIFY'), ('align_y', 'BOTTOM'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_overflow_justify_bottom_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'JUSTIFY'), ('align_y', 'BOTTOM'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_overflow_justify_bottom_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'JUSTIFY'), ('align_y', 'BOTTOM'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_overflow_justify_middle_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'JUSTIFY'), ('align_y', 'MIDDLE'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_overflow_justify_middle_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'JUSTIFY'), ('align_y', 'MIDDLE'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_overflow_justify_middle_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'JUSTIFY'), ('align_y', 'MIDDLE'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_overflow_justify_middle_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'JUSTIFY'), ('align_y', 'MIDDLE'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_overflow_justify_middle_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'JUSTIFY'), ('align_y', 'MIDDLE'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_overflow_justify_middle_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'JUSTIFY'), ('align_y', 'MIDDLE'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_overflow_justify_middle_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'JUSTIFY'), ('align_y', 'MIDDLE'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_overflow_justify_top_baseline_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'JUSTIFY'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_overflow_justify_top_baseline_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'JUSTIFY'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_overflow_justify_top_baseline_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'JUSTIFY'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_overflow_justify_top_baseline_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'JUSTIFY'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_overflow_justify_top_baseline_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'JUSTIFY'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_overflow_justify_top_baseline_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'JUSTIFY'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_overflow_justify_top_baseline_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'JUSTIFY'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_overflow_justify_top_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'JUSTIFY'), ('align_y', 'TOP'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_overflow_justify_top_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'JUSTIFY'), ('align_y', 'TOP'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_overflow_justify_top_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'JUSTIFY'), ('align_y', 'TOP'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_overflow_justify_top_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'JUSTIFY'), ('align_y', 'TOP'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_overflow_justify_top_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'JUSTIFY'), ('align_y', 'TOP'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_overflow_justify_top_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'JUSTIFY'), ('align_y', 'TOP'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_overflow_justify_top_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'JUSTIFY'), ('align_y', 'TOP'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_overflow_left_bottom_baseline_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'LEFT'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_overflow_left_bottom_baseline_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'LEFT'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_overflow_left_bottom_baseline_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'LEFT'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_overflow_left_bottom_baseline_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'LEFT'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_overflow_left_bottom_baseline_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'LEFT'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_overflow_left_bottom_baseline_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'LEFT'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_overflow_left_bottom_baseline_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'LEFT'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_overflow_left_bottom_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'LEFT'), ('align_y', 'BOTTOM'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_overflow_left_bottom_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'LEFT'), ('align_y', 'BOTTOM'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_overflow_left_bottom_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'LEFT'), ('align_y', 'BOTTOM'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_overflow_left_bottom_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'LEFT'), ('align_y', 'BOTTOM'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_overflow_left_bottom_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'LEFT'), ('align_y', 'BOTTOM'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_overflow_left_bottom_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'LEFT'), ('align_y', 'BOTTOM'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_overflow_left_bottom_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'LEFT'), ('align_y', 'BOTTOM'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_overflow_left_middle_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'LEFT'), ('align_y', 'MIDDLE'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_overflow_left_middle_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'LEFT'), ('align_y', 'MIDDLE'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_overflow_left_middle_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'LEFT'), ('align_y', 'MIDDLE'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_overflow_left_middle_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'LEFT'), ('align_y', 'MIDDLE'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_overflow_left_middle_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'LEFT'), ('align_y', 'MIDDLE'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_overflow_left_middle_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'LEFT'), ('align_y', 'MIDDLE'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_overflow_left_middle_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'LEFT'), ('align_y', 'MIDDLE'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_overflow_left_top_baseline_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'LEFT'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_overflow_left_top_baseline_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'LEFT'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_overflow_left_top_baseline_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'LEFT'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_overflow_left_top_baseline_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'LEFT'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_overflow_left_top_baseline_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'LEFT'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_overflow_left_top_baseline_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'LEFT'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_overflow_left_top_baseline_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'LEFT'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_overflow_left_top_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'LEFT'), ('align_y', 'TOP'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_overflow_left_top_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'LEFT'), ('align_y', 'TOP'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_overflow_left_top_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'LEFT'), ('align_y', 'TOP'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_overflow_left_top_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'LEFT'), ('align_y', 'TOP'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_overflow_left_top_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'LEFT'), ('align_y', 'TOP'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_overflow_left_top_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'LEFT'), ('align_y', 'TOP'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_overflow_left_top_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'LEFT'), ('align_y', 'TOP'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_overflow_right_bottom_baseline_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'RIGHT'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_overflow_right_bottom_baseline_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'RIGHT'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_overflow_right_bottom_baseline_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'RIGHT'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_overflow_right_bottom_baseline_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'RIGHT'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_overflow_right_bottom_baseline_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'RIGHT'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_overflow_right_bottom_baseline_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'RIGHT'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_overflow_right_bottom_baseline_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'RIGHT'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_overflow_right_bottom_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'RIGHT'), ('align_y', 'BOTTOM'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_overflow_right_bottom_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'RIGHT'), ('align_y', 'BOTTOM'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_overflow_right_bottom_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'RIGHT'), ('align_y', 'BOTTOM'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_overflow_right_bottom_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'RIGHT'), ('align_y', 'BOTTOM'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_overflow_right_bottom_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'RIGHT'), ('align_y', 'BOTTOM'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_overflow_right_bottom_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'RIGHT'), ('align_y', 'BOTTOM'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_overflow_right_bottom_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'RIGHT'), ('align_y', 'BOTTOM'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_overflow_right_middle_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'RIGHT'), ('align_y', 'MIDDLE'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_overflow_right_middle_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'RIGHT'), ('align_y', 'MIDDLE'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_overflow_right_middle_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'RIGHT'), ('align_y', 'MIDDLE'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_overflow_right_middle_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'RIGHT'), ('align_y', 'MIDDLE'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_overflow_right_middle_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'RIGHT'), ('align_y', 'MIDDLE'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_overflow_right_middle_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'RIGHT'), ('align_y', 'MIDDLE'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_overflow_right_middle_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'RIGHT'), ('align_y', 'MIDDLE'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_overflow_right_top_baseline_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'RIGHT'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_overflow_right_top_baseline_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'RIGHT'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_overflow_right_top_baseline_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'RIGHT'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_overflow_right_top_baseline_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'RIGHT'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_overflow_right_top_baseline_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'RIGHT'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_overflow_right_top_baseline_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'RIGHT'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_overflow_right_top_baseline_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'RIGHT'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_overflow_right_top_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'RIGHT'), ('align_y', 'TOP'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_overflow_right_top_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'RIGHT'), ('align_y', 'TOP'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_overflow_right_top_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'RIGHT'), ('align_y', 'TOP'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_overflow_right_top_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'RIGHT'), ('align_y', 'TOP'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_overflow_right_top_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'RIGHT'), ('align_y', 'TOP'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_overflow_right_top_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'RIGHT'), ('align_y', 'TOP'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_overflow_right_top_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5], [0, 2, 3], [('overflow', 'OVERFLOW'), ('align_x', 'RIGHT'), ('align_y', 'TOP'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_scale_to_fit_center_bottom_baseline_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'CENTER'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_scale_to_fit_center_bottom_baseline_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'CENTER'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_scale_to_fit_center_bottom_baseline_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'CENTER'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_scale_to_fit_center_bottom_baseline_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'CENTER'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_scale_to_fit_center_bottom_baseline_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'CENTER'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_scale_to_fit_center_bottom_baseline_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'CENTER'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_scale_to_fit_center_bottom_baseline_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'CENTER'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_scale_to_fit_center_bottom_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'CENTER'), ('align_y', 'BOTTOM'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_scale_to_fit_center_bottom_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'CENTER'), ('align_y', 'BOTTOM'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_scale_to_fit_center_bottom_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'CENTER'), ('align_y', 'BOTTOM'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_scale_to_fit_center_bottom_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'CENTER'), ('align_y', 'BOTTOM'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_scale_to_fit_center_bottom_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'CENTER'), ('align_y', 'BOTTOM'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_scale_to_fit_center_bottom_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'CENTER'), ('align_y', 'BOTTOM'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_scale_to_fit_center_bottom_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'CENTER'), ('align_y', 'BOTTOM'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_scale_to_fit_center_middle_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'CENTER'), ('align_y', 'MIDDLE'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_scale_to_fit_center_middle_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'CENTER'), ('align_y', 'MIDDLE'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_scale_to_fit_center_middle_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'CENTER'), ('align_y', 'MIDDLE'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_scale_to_fit_center_middle_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'CENTER'), ('align_y', 'MIDDLE'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_scale_to_fit_center_middle_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'CENTER'), ('align_y', 'MIDDLE'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_scale_to_fit_center_middle_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'CENTER'), ('align_y', 'MIDDLE'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_scale_to_fit_center_middle_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'CENTER'), ('align_y', 'MIDDLE'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_scale_to_fit_center_top_baseline_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'CENTER'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_scale_to_fit_center_top_baseline_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'CENTER'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_scale_to_fit_center_top_baseline_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'CENTER'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_scale_to_fit_center_top_baseline_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'CENTER'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_scale_to_fit_center_top_baseline_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'CENTER'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_scale_to_fit_center_top_baseline_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'CENTER'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_scale_to_fit_center_top_baseline_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'CENTER'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_scale_to_fit_center_top_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'CENTER'), ('align_y', 'TOP'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_scale_to_fit_center_top_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'CENTER'), ('align_y', 'TOP'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_scale_to_fit_center_top_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'CENTER'), ('align_y', 'TOP'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_scale_to_fit_center_top_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'CENTER'), ('align_y', 'TOP'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_scale_to_fit_center_top_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'CENTER'), ('align_y', 'TOP'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_scale_to_fit_center_top_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'CENTER'), ('align_y', 'TOP'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_scale_to_fit_center_top_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'CENTER'), ('align_y', 'TOP'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_scale_to_fit_flush_bottom_baseline_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'FLUSH'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_scale_to_fit_flush_bottom_baseline_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'FLUSH'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_scale_to_fit_flush_bottom_baseline_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'FLUSH'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_scale_to_fit_flush_bottom_baseline_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'FLUSH'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_scale_to_fit_flush_bottom_baseline_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'FLUSH'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_scale_to_fit_flush_bottom_baseline_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'FLUSH'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_scale_to_fit_flush_bottom_baseline_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'FLUSH'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_scale_to_fit_flush_bottom_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'FLUSH'), ('align_y', 'BOTTOM'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_scale_to_fit_flush_bottom_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'FLUSH'), ('align_y', 'BOTTOM'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_scale_to_fit_flush_bottom_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'FLUSH'), ('align_y', 'BOTTOM'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_scale_to_fit_flush_bottom_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'FLUSH'), ('align_y', 'BOTTOM'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_scale_to_fit_flush_bottom_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'FLUSH'), ('align_y', 'BOTTOM'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_scale_to_fit_flush_bottom_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'FLUSH'), ('align_y', 'BOTTOM'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_scale_to_fit_flush_bottom_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'FLUSH'), ('align_y', 'BOTTOM'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_scale_to_fit_flush_middle_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'FLUSH'), ('align_y', 'MIDDLE'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_scale_to_fit_flush_middle_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'FLUSH'), ('align_y', 'MIDDLE'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_scale_to_fit_flush_middle_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'FLUSH'), ('align_y', 'MIDDLE'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_scale_to_fit_flush_middle_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'FLUSH'), ('align_y', 'MIDDLE'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_scale_to_fit_flush_middle_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'FLUSH'), ('align_y', 'MIDDLE'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_scale_to_fit_flush_middle_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'FLUSH'), ('align_y', 'MIDDLE'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_scale_to_fit_flush_middle_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'FLUSH'), ('align_y', 'MIDDLE'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_scale_to_fit_flush_top_baseline_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'FLUSH'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_scale_to_fit_flush_top_baseline_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'FLUSH'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_scale_to_fit_flush_top_baseline_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'FLUSH'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_scale_to_fit_flush_top_baseline_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'FLUSH'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_scale_to_fit_flush_top_baseline_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'FLUSH'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_scale_to_fit_flush_top_baseline_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'FLUSH'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_scale_to_fit_flush_top_baseline_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'FLUSH'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_scale_to_fit_flush_top_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'FLUSH'), ('align_y', 'TOP'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_scale_to_fit_flush_top_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'FLUSH'), ('align_y', 'TOP'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_scale_to_fit_flush_top_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'FLUSH'), ('align_y', 'TOP'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_scale_to_fit_flush_top_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'FLUSH'), ('align_y', 'TOP'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_scale_to_fit_flush_top_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'FLUSH'), ('align_y', 'TOP'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_scale_to_fit_flush_top_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'FLUSH'), ('align_y', 'TOP'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_scale_to_fit_flush_top_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'FLUSH'), ('align_y', 'TOP'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_scale_to_fit_justify_bottom_baseline_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'JUSTIFY'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_scale_to_fit_justify_bottom_baseline_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'JUSTIFY'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_scale_to_fit_justify_bottom_baseline_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'JUSTIFY'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_scale_to_fit_justify_bottom_baseline_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'JUSTIFY'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_scale_to_fit_justify_bottom_baseline_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'JUSTIFY'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_scale_to_fit_justify_bottom_baseline_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'JUSTIFY'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_scale_to_fit_justify_bottom_baseline_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'JUSTIFY'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_scale_to_fit_justify_bottom_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'JUSTIFY'), ('align_y', 'BOTTOM'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_scale_to_fit_justify_bottom_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'JUSTIFY'), ('align_y', 'BOTTOM'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_scale_to_fit_justify_bottom_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'JUSTIFY'), ('align_y', 'BOTTOM'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_scale_to_fit_justify_bottom_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'JUSTIFY'), ('align_y', 'BOTTOM'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_scale_to_fit_justify_bottom_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'JUSTIFY'), ('align_y', 'BOTTOM'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_scale_to_fit_justify_bottom_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'JUSTIFY'), ('align_y', 'BOTTOM'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_scale_to_fit_justify_bottom_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'JUSTIFY'), ('align_y', 'BOTTOM'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_scale_to_fit_justify_middle_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'JUSTIFY'), ('align_y', 'MIDDLE'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_scale_to_fit_justify_middle_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'JUSTIFY'), ('align_y', 'MIDDLE'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_scale_to_fit_justify_middle_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'JUSTIFY'), ('align_y', 'MIDDLE'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_scale_to_fit_justify_middle_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'JUSTIFY'), ('align_y', 'MIDDLE'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_scale_to_fit_justify_middle_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'JUSTIFY'), ('align_y', 'MIDDLE'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_scale_to_fit_justify_middle_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'JUSTIFY'), ('align_y', 'MIDDLE'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_scale_to_fit_justify_middle_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'JUSTIFY'), ('align_y', 'MIDDLE'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_scale_to_fit_justify_top_baseline_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'JUSTIFY'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_scale_to_fit_justify_top_baseline_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'JUSTIFY'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_scale_to_fit_justify_top_baseline_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'JUSTIFY'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_scale_to_fit_justify_top_baseline_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'JUSTIFY'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_scale_to_fit_justify_top_baseline_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'JUSTIFY'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_scale_to_fit_justify_top_baseline_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'JUSTIFY'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_scale_to_fit_justify_top_baseline_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'JUSTIFY'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_scale_to_fit_justify_top_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'JUSTIFY'), ('align_y', 'TOP'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_scale_to_fit_justify_top_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'JUSTIFY'), ('align_y', 'TOP'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_scale_to_fit_justify_top_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'JUSTIFY'), ('align_y', 'TOP'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_scale_to_fit_justify_top_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'JUSTIFY'), ('align_y', 'TOP'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_scale_to_fit_justify_top_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'JUSTIFY'), ('align_y', 'TOP'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_scale_to_fit_justify_top_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'JUSTIFY'), ('align_y', 'TOP'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_scale_to_fit_justify_top_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'JUSTIFY'), ('align_y', 'TOP'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_scale_to_fit_left_bottom_baseline_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'LEFT'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_scale_to_fit_left_bottom_baseline_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'LEFT'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_scale_to_fit_left_bottom_baseline_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'LEFT'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_scale_to_fit_left_bottom_baseline_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'LEFT'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_scale_to_fit_left_bottom_baseline_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'LEFT'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_scale_to_fit_left_bottom_baseline_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'LEFT'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_scale_to_fit_left_bottom_baseline_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'LEFT'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_scale_to_fit_left_bottom_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'LEFT'), ('align_y', 'BOTTOM'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_scale_to_fit_left_bottom_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'LEFT'), ('align_y', 'BOTTOM'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_scale_to_fit_left_bottom_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'LEFT'), ('align_y', 'BOTTOM'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_scale_to_fit_left_bottom_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'LEFT'), ('align_y', 'BOTTOM'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_scale_to_fit_left_bottom_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'LEFT'), ('align_y', 'BOTTOM'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_scale_to_fit_left_bottom_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'LEFT'), ('align_y', 'BOTTOM'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_scale_to_fit_left_bottom_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'LEFT'), ('align_y', 'BOTTOM'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_scale_to_fit_left_middle_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'LEFT'), ('align_y', 'MIDDLE'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_scale_to_fit_left_middle_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'LEFT'), ('align_y', 'MIDDLE'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_scale_to_fit_left_middle_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'LEFT'), ('align_y', 'MIDDLE'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_scale_to_fit_left_middle_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'LEFT'), ('align_y', 'MIDDLE'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_scale_to_fit_left_middle_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'LEFT'), ('align_y', 'MIDDLE'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_scale_to_fit_left_middle_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'LEFT'), ('align_y', 'MIDDLE'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_scale_to_fit_left_middle_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'LEFT'), ('align_y', 'MIDDLE'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_scale_to_fit_left_top_baseline_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'LEFT'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_scale_to_fit_left_top_baseline_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'LEFT'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_scale_to_fit_left_top_baseline_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'LEFT'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_scale_to_fit_left_top_baseline_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'LEFT'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_scale_to_fit_left_top_baseline_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'LEFT'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_scale_to_fit_left_top_baseline_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'LEFT'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_scale_to_fit_left_top_baseline_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'LEFT'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_scale_to_fit_left_top_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'LEFT'), ('align_y', 'TOP'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_scale_to_fit_left_top_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'LEFT'), ('align_y', 'TOP'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_scale_to_fit_left_top_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'LEFT'), ('align_y', 'TOP'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_scale_to_fit_left_top_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'LEFT'), ('align_y', 'TOP'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_scale_to_fit_left_top_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'LEFT'), ('align_y', 'TOP'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_scale_to_fit_left_top_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'LEFT'), ('align_y', 'TOP'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_scale_to_fit_left_top_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'LEFT'), ('align_y', 'TOP'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_scale_to_fit_right_bottom_baseline_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'RIGHT'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_scale_to_fit_right_bottom_baseline_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'RIGHT'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_scale_to_fit_right_bottom_baseline_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'RIGHT'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_scale_to_fit_right_bottom_baseline_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'RIGHT'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_scale_to_fit_right_bottom_baseline_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'RIGHT'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_scale_to_fit_right_bottom_baseline_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'RIGHT'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_scale_to_fit_right_bottom_baseline_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'RIGHT'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_scale_to_fit_right_bottom_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'RIGHT'), ('align_y', 'BOTTOM'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_scale_to_fit_right_bottom_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'RIGHT'), ('align_y', 'BOTTOM'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_scale_to_fit_right_bottom_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'RIGHT'), ('align_y', 'BOTTOM'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_scale_to_fit_right_bottom_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'RIGHT'), ('align_y', 'BOTTOM'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_scale_to_fit_right_bottom_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'RIGHT'), ('align_y', 'BOTTOM'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_scale_to_fit_right_bottom_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'RIGHT'), ('align_y', 'BOTTOM'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_scale_to_fit_right_bottom_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'RIGHT'), ('align_y', 'BOTTOM'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_scale_to_fit_right_middle_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'RIGHT'), ('align_y', 'MIDDLE'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_scale_to_fit_right_middle_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'RIGHT'), ('align_y', 'MIDDLE'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_scale_to_fit_right_middle_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'RIGHT'), ('align_y', 'MIDDLE'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_scale_to_fit_right_middle_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'RIGHT'), ('align_y', 'MIDDLE'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_scale_to_fit_right_middle_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'RIGHT'), ('align_y', 'MIDDLE'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_scale_to_fit_right_middle_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'RIGHT'), ('align_y', 'MIDDLE'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_scale_to_fit_right_middle_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'RIGHT'), ('align_y', 'MIDDLE'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_scale_to_fit_right_top_baseline_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'RIGHT'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_scale_to_fit_right_top_baseline_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'RIGHT'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_scale_to_fit_right_top_baseline_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'RIGHT'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_scale_to_fit_right_top_baseline_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'RIGHT'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_scale_to_fit_right_top_baseline_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'RIGHT'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_scale_to_fit_right_top_baseline_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'RIGHT'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_scale_to_fit_right_top_baseline_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'RIGHT'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_scale_to_fit_right_top_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'RIGHT'), ('align_y', 'TOP'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_scale_to_fit_right_top_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'RIGHT'), ('align_y', 'TOP'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_scale_to_fit_right_top_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'RIGHT'), ('align_y', 'TOP'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_scale_to_fit_right_top_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'RIGHT'), ('align_y', 'TOP'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_scale_to_fit_right_top_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'RIGHT'), ('align_y', 'TOP'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_scale_to_fit_right_top_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'RIGHT'), ('align_y', 'TOP'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_scale_to_fit_right_top_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 2, 3], [('overflow', 'SCALE_TO_FIT'), ('align_x', 'RIGHT'), ('align_y', 'TOP'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_truncate_center_bottom_baseline_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'CENTER'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_truncate_center_bottom_baseline_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'CENTER'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_truncate_center_bottom_baseline_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'CENTER'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_truncate_center_bottom_baseline_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'CENTER'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_truncate_center_bottom_baseline_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'CENTER'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_truncate_center_bottom_baseline_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'CENTER'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_truncate_center_bottom_baseline_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'CENTER'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_truncate_center_bottom_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'CENTER'), ('align_y', 'BOTTOM'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_truncate_center_bottom_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'CENTER'), ('align_y', 'BOTTOM'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_truncate_center_bottom_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'CENTER'), ('align_y', 'BOTTOM'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_truncate_center_bottom_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'CENTER'), ('align_y', 'BOTTOM'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_truncate_center_bottom_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'CENTER'), ('align_y', 'BOTTOM'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_truncate_center_bottom_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'CENTER'), ('align_y', 'BOTTOM'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_truncate_center_bottom_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'CENTER'), ('align_y', 'BOTTOM'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_truncate_center_middle_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'CENTER'), ('align_y', 'MIDDLE'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_truncate_center_middle_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'CENTER'), ('align_y', 'MIDDLE'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_truncate_center_middle_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'CENTER'), ('align_y', 'MIDDLE'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_truncate_center_middle_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'CENTER'), ('align_y', 'MIDDLE'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_truncate_center_middle_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'CENTER'), ('align_y', 'MIDDLE'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_truncate_center_middle_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'CENTER'), ('align_y', 'MIDDLE'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_truncate_center_middle_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'CENTER'), ('align_y', 'MIDDLE'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_truncate_center_top_baseline_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'CENTER'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_truncate_center_top_baseline_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'CENTER'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_truncate_center_top_baseline_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'CENTER'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_truncate_center_top_baseline_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'CENTER'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_truncate_center_top_baseline_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'CENTER'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_truncate_center_top_baseline_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'CENTER'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_truncate_center_top_baseline_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'CENTER'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_truncate_center_top_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'CENTER'), ('align_y', 'TOP'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_truncate_center_top_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'CENTER'), ('align_y', 'TOP'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_truncate_center_top_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'CENTER'), ('align_y', 'TOP'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_truncate_center_top_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'CENTER'), ('align_y', 'TOP'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_truncate_center_top_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'CENTER'), ('align_y', 'TOP'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_truncate_center_top_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'CENTER'), ('align_y', 'TOP'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_truncate_center_top_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'CENTER'), ('align_y', 'TOP'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_truncate_flush_bottom_baseline_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'FLUSH'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_truncate_flush_bottom_baseline_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'FLUSH'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_truncate_flush_bottom_baseline_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'FLUSH'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_truncate_flush_bottom_baseline_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'FLUSH'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_truncate_flush_bottom_baseline_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'FLUSH'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_truncate_flush_bottom_baseline_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'FLUSH'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_truncate_flush_bottom_baseline_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'FLUSH'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_truncate_flush_bottom_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'FLUSH'), ('align_y', 'BOTTOM'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_truncate_flush_bottom_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'FLUSH'), ('align_y', 'BOTTOM'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_truncate_flush_bottom_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'FLUSH'), ('align_y', 'BOTTOM'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_truncate_flush_bottom_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'FLUSH'), ('align_y', 'BOTTOM'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_truncate_flush_bottom_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'FLUSH'), ('align_y', 'BOTTOM'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_truncate_flush_bottom_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'FLUSH'), ('align_y', 'BOTTOM'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_truncate_flush_bottom_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'FLUSH'), ('align_y', 'BOTTOM'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_truncate_flush_middle_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'FLUSH'), ('align_y', 'MIDDLE'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_truncate_flush_middle_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'FLUSH'), ('align_y', 'MIDDLE'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_truncate_flush_middle_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'FLUSH'), ('align_y', 'MIDDLE'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_truncate_flush_middle_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'FLUSH'), ('align_y', 'MIDDLE'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_truncate_flush_middle_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'FLUSH'), ('align_y', 'MIDDLE'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_truncate_flush_middle_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'FLUSH'), ('align_y', 'MIDDLE'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_truncate_flush_middle_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'FLUSH'), ('align_y', 'MIDDLE'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_truncate_flush_top_baseline_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'FLUSH'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_truncate_flush_top_baseline_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'FLUSH'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_truncate_flush_top_baseline_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'FLUSH'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_truncate_flush_top_baseline_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'FLUSH'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_truncate_flush_top_baseline_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'FLUSH'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_truncate_flush_top_baseline_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'FLUSH'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_truncate_flush_top_baseline_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'FLUSH'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_truncate_flush_top_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'FLUSH'), ('align_y', 'TOP'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_truncate_flush_top_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'FLUSH'), ('align_y', 'TOP'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_truncate_flush_top_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'FLUSH'), ('align_y', 'TOP'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_truncate_flush_top_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'FLUSH'), ('align_y', 'TOP'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_truncate_flush_top_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'FLUSH'), ('align_y', 'TOP'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_truncate_flush_top_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'FLUSH'), ('align_y', 'TOP'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_truncate_flush_top_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'FLUSH'), ('align_y', 'TOP'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_truncate_justify_bottom_baseline_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'JUSTIFY'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_truncate_justify_bottom_baseline_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'JUSTIFY'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_truncate_justify_bottom_baseline_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'JUSTIFY'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_truncate_justify_bottom_baseline_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'JUSTIFY'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_truncate_justify_bottom_baseline_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'JUSTIFY'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_truncate_justify_bottom_baseline_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'JUSTIFY'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_truncate_justify_bottom_baseline_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'JUSTIFY'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_truncate_justify_bottom_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'JUSTIFY'), ('align_y', 'BOTTOM'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_truncate_justify_bottom_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'JUSTIFY'), ('align_y', 'BOTTOM'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_truncate_justify_bottom_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'JUSTIFY'), ('align_y', 'BOTTOM'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_truncate_justify_bottom_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'JUSTIFY'), ('align_y', 'BOTTOM'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_truncate_justify_bottom_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'JUSTIFY'), ('align_y', 'BOTTOM'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_truncate_justify_bottom_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'JUSTIFY'), ('align_y', 'BOTTOM'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_truncate_justify_bottom_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'JUSTIFY'), ('align_y', 'BOTTOM'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_truncate_justify_middle_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'JUSTIFY'), ('align_y', 'MIDDLE'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_truncate_justify_middle_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'JUSTIFY'), ('align_y', 'MIDDLE'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_truncate_justify_middle_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'JUSTIFY'), ('align_y', 'MIDDLE'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_truncate_justify_middle_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'JUSTIFY'), ('align_y', 'MIDDLE'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_truncate_justify_middle_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'JUSTIFY'), ('align_y', 'MIDDLE'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_truncate_justify_middle_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'JUSTIFY'), ('align_y', 'MIDDLE'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_truncate_justify_middle_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'JUSTIFY'), ('align_y', 'MIDDLE'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_truncate_justify_top_baseline_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'JUSTIFY'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_truncate_justify_top_baseline_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'JUSTIFY'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_truncate_justify_top_baseline_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'JUSTIFY'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_truncate_justify_top_baseline_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'JUSTIFY'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_truncate_justify_top_baseline_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'JUSTIFY'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_truncate_justify_top_baseline_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'JUSTIFY'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_truncate_justify_top_baseline_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'JUSTIFY'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_truncate_justify_top_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'JUSTIFY'), ('align_y', 'TOP'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_truncate_justify_top_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'JUSTIFY'), ('align_y', 'TOP'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_truncate_justify_top_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'JUSTIFY'), ('align_y', 'TOP'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_truncate_justify_top_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'JUSTIFY'), ('align_y', 'TOP'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_truncate_justify_top_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'JUSTIFY'), ('align_y', 'TOP'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_truncate_justify_top_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'JUSTIFY'), ('align_y', 'TOP'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_truncate_justify_top_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'JUSTIFY'), ('align_y', 'TOP'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_truncate_left_bottom_baseline_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'LEFT'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_truncate_left_bottom_baseline_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'LEFT'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_truncate_left_bottom_baseline_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'LEFT'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_truncate_left_bottom_baseline_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'LEFT'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_truncate_left_bottom_baseline_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'LEFT'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_truncate_left_bottom_baseline_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'LEFT'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_truncate_left_bottom_baseline_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'LEFT'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_truncate_left_bottom_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'LEFT'), ('align_y', 'BOTTOM'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_truncate_left_bottom_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'LEFT'), ('align_y', 'BOTTOM'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_truncate_left_bottom_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'LEFT'), ('align_y', 'BOTTOM'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_truncate_left_bottom_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'LEFT'), ('align_y', 'BOTTOM'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_truncate_left_bottom_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'LEFT'), ('align_y', 'BOTTOM'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_truncate_left_bottom_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'LEFT'), ('align_y', 'BOTTOM'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_truncate_left_bottom_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'LEFT'), ('align_y', 'BOTTOM'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_truncate_left_middle_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'LEFT'), ('align_y', 'MIDDLE'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_truncate_left_middle_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'LEFT'), ('align_y', 'MIDDLE'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_truncate_left_middle_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'LEFT'), ('align_y', 'MIDDLE'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_truncate_left_middle_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'LEFT'), ('align_y', 'MIDDLE'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_truncate_left_middle_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'LEFT'), ('align_y', 'MIDDLE'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_truncate_left_middle_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'LEFT'), ('align_y', 'MIDDLE'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_truncate_left_middle_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'LEFT'), ('align_y', 'MIDDLE'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_truncate_left_top_baseline_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'LEFT'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_truncate_left_top_baseline_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'LEFT'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_truncate_left_top_baseline_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'LEFT'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_truncate_left_top_baseline_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'LEFT'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_truncate_left_top_baseline_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'LEFT'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_truncate_left_top_baseline_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'LEFT'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_truncate_left_top_baseline_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'LEFT'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_truncate_left_top_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'LEFT'), ('align_y', 'TOP'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_truncate_left_top_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'LEFT'), ('align_y', 'TOP'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_truncate_left_top_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'LEFT'), ('align_y', 'TOP'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_truncate_left_top_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'LEFT'), ('align_y', 'TOP'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_truncate_left_top_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'LEFT'), ('align_y', 'TOP'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_truncate_left_top_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'LEFT'), ('align_y', 'TOP'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_truncate_left_top_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'LEFT'), ('align_y', 'TOP'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_truncate_right_bottom_baseline_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'RIGHT'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_truncate_right_bottom_baseline_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'RIGHT'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_truncate_right_bottom_baseline_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'RIGHT'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_truncate_right_bottom_baseline_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'RIGHT'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_truncate_right_bottom_baseline_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'RIGHT'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_truncate_right_bottom_baseline_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'RIGHT'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_truncate_right_bottom_baseline_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'RIGHT'), ('align_y', 'BOTTOM_BASELINE'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_truncate_right_bottom_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'RIGHT'), ('align_y', 'BOTTOM'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_truncate_right_bottom_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'RIGHT'), ('align_y', 'BOTTOM'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_truncate_right_bottom_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'RIGHT'), ('align_y', 'BOTTOM'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_truncate_right_bottom_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'RIGHT'), ('align_y', 'BOTTOM'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_truncate_right_bottom_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'RIGHT'), ('align_y', 'BOTTOM'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_truncate_right_bottom_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'RIGHT'), ('align_y', 'BOTTOM'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_truncate_right_bottom_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'RIGHT'), ('align_y', 'BOTTOM'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_truncate_right_middle_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'RIGHT'), ('align_y', 'MIDDLE'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_truncate_right_middle_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'RIGHT'), ('align_y', 'MIDDLE'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_truncate_right_middle_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'RIGHT'), ('align_y', 'MIDDLE'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_truncate_right_middle_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'RIGHT'), ('align_y', 'MIDDLE'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_truncate_right_middle_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'RIGHT'), ('align_y', 'MIDDLE'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_truncate_right_middle_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'RIGHT'), ('align_y', 'MIDDLE'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_truncate_right_middle_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'RIGHT'), ('align_y', 'MIDDLE'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_truncate_right_top_baseline_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'RIGHT'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_truncate_right_top_baseline_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'RIGHT'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_truncate_right_top_baseline_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'RIGHT'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_truncate_right_top_baseline_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'RIGHT'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_truncate_right_top_baseline_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'RIGHT'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_truncate_right_top_baseline_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'RIGHT'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_truncate_right_top_baseline_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'RIGHT'), ('align_y', 'TOP_BASELINE'), ('pivot_mode', 'TOP_RIGHT')]), 
	'string_to_curves_truncate_right_top_bottom_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'RIGHT'), ('align_y', 'TOP'), ('pivot_mode', 'BOTTOM_CENTER')]), 
	'string_to_curves_truncate_right_top_bottom_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'RIGHT'), ('align_y', 'TOP'), ('pivot_mode', 'BOTTOM_LEFT')]), 
	'string_to_curves_truncate_right_top_bottom_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'RIGHT'), ('align_y', 'TOP'), ('pivot_mode', 'BOTTOM_RIGHT')]), 
	'string_to_curves_truncate_right_top_midpoint' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'RIGHT'), ('align_y', 'TOP'), ('pivot_mode', 'MIDPOINT')]), 
	'string_to_curves_truncate_right_top_top_center' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'RIGHT'), ('align_y', 'TOP'), ('pivot_mode', 'TOP_CENTER')]), 
	'string_to_curves_truncate_right_top_top_left' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'RIGHT'), ('align_y', 'TOP'), ('pivot_mode', 'TOP_LEFT')]), 
	'string_to_curves_truncate_right_top_top_right' : NodeInstance('GeometryNodeStringToCurves', [0, 1, 2, 3, 4, 5, 6], [0, 1, 2, 3], [('overflow', 'TRUNCATE'), ('align_x', 'RIGHT'), ('align_y', 'TOP'), ('pivot_mode', 'TOP_RIGHT')]), 
	'subdivide_curve' : NodeInstance('GeometryNodeSubdivideCurve', [0, 1], [0], []), 
	'subdivide_mesh' : NodeInstance('GeometryNodeSubdivideMesh', [0, 1], [0], []), 
	'subdivision_surface' : NodeInstance('GeometryNodeSubdivisionSurface', [0, 1, 2, 3, 4], [0], []), 
	'subdivision_surface_all_all' : NodeInstance('GeometryNodeSubdivisionSurface', [0, 1, 2, 3, 4], [0], [('uv_smooth', 'SMOOTH_ALL'), ('boundary_smooth', 'ALL')]), 
	'subdivision_surface_all_keep_corners' : NodeInstance('GeometryNodeSubdivisionSurface', [0, 1, 2, 3, 4], [0], [('uv_smooth', 'SMOOTH_ALL'), ('boundary_smooth', 'PRESERVE_CORNERS')]), 
	'subdivision_surface_keep_boundaries_all' : NodeInstance('GeometryNodeSubdivisionSurface', [0, 1, 2, 3, 4], [0], [('uv_smooth', 'PRESERVE_BOUNDARIES'), ('boundary_smooth', 'ALL')]), 
	'subdivision_surface_keep_boundaries_keep_corners' : NodeInstance('GeometryNodeSubdivisionSurface', [0, 1, 2, 3, 4], [0], [('uv_smooth', 'PRESERVE_BOUNDARIES'), ('boundary_smooth', 'PRESERVE_CORNERS')]), 
	'subdivision_surface_keep_corners_all' : NodeInstance('GeometryNodeSubdivisionSurface', [0, 1, 2, 3, 4], [0], [('uv_smooth', 'PRESERVE_CORNERS'), ('boundary_smooth', 'ALL')]), 
	'subdivision_surface_keep_corners_junctions_all' : NodeInstance('GeometryNodeSubdivisionSurface', [0, 1, 2, 3, 4], [0], [('uv_smooth', 'PRESERVE_CORNERS_AND_JUNCTIONS'), ('boundary_smooth', 'ALL')]), 
	'subdivision_surface_keep_corners_junctions_concave_all' : NodeInstance('GeometryNodeSubdivisionSurface', [0, 1, 2, 3, 4], [0], [('uv_smooth', 'PRESERVE_CORNERS_JUNCTIONS_AND_CONCAVE'), ('boundary_smooth', 'ALL')]), 
	'subdivision_surface_keep_corners_junctions_concave_keep_corners' : NodeInstance('GeometryNodeSubdivisionSurface', [0, 1, 2, 3, 4], [0], [('uv_smooth', 'PRESERVE_CORNERS_JUNCTIONS_AND_CONCAVE'), ('boundary_smooth', 'PRESERVE_CORNERS')]), 
	'subdivision_surface_keep_corners_junctions_keep_corners' : NodeInstance('GeometryNodeSubdivisionSurface', [0, 1, 2, 3, 4], [0], [('uv_smooth', 'PRESERVE_CORNERS_AND_JUNCTIONS'), ('boundary_smooth', 'PRESERVE_CORNERS')]), 
	'subdivision_surface_keep_corners_keep_corners' : NodeInstance('GeometryNodeSubdivisionSurface', [0, 1, 2, 3, 4], [0], [('uv_smooth', 'PRESERVE_CORNERS'), ('boundary_smooth', 'PRESERVE_CORNERS')]), 
	'subdivision_surface_none_all' : NodeInstance('GeometryNodeSubdivisionSurface', [0, 1, 2, 3, 4], [0], [('uv_smooth', 'NONE'), ('boundary_smooth', 'ALL')]), 
	'subdivision_surface_none_keep_corners' : NodeInstance('GeometryNodeSubdivisionSurface', [0, 1, 2, 3, 4], [0], [('uv_smooth', 'NONE'), ('boundary_smooth', 'PRESERVE_CORNERS')]), 
	'switch' : NodeInstance('GeometryNodeSwitch', [0, 1, 2], [0], []), 
	'switch_boolean' : NodeInstance('GeometryNodeSwitch', [0, 1, 2], [0], [('input_type', 'BOOLEAN')]), 
	'switch_collection' : NodeInstance('GeometryNodeSwitch', [0, 1, 2], [0], [('input_type', 'COLLECTION')]), 
	'switch_color' : NodeInstance('GeometryNodeSwitch', [0, 1, 2], [0], [('input_type', 'RGBA')]), 
	'switch_float' : NodeInstance('GeometryNodeSwitch', [0, 1, 2], [0], [('input_type', 'FLOAT')]), 
	'switch_geometry' : NodeInstance('GeometryNodeSwitch', [0, 1, 2], [0], [('input_type', 'GEOMETRY')]), 
	'switch_image' : NodeInstance('GeometryNodeSwitch', [0, 1, 2], [0], [('input_type', 'IMAGE')]), 
	'switch_integer' : NodeInstance('GeometryNodeSwitch', [0, 1, 2], [0], [('input_type', 'INT')]), 
	'switch_material' : NodeInstance('GeometryNodeSwitch', [0, 1, 2], [0], [('input_type', 'MATERIAL')]), 
	'switch_matrix' : NodeInstance('GeometryNodeSwitch', [0, 1, 2], [0], [('input_type', 'MATRIX')]), 
	'switch_menu' : NodeInstance('GeometryNodeSwitch', [0, 1, 2], [0], [('input_type', 'MENU')]), 
	'switch_object' : NodeInstance('GeometryNodeSwitch', [0, 1, 2], [0], [('input_type', 'OBJECT')]), 
	'switch_rotation' : NodeInstance('GeometryNodeSwitch', [0, 1, 2], [0], [('input_type', 'ROTATION')]), 
	'switch_string' : NodeInstance('GeometryNodeSwitch', [0, 1, 2], [0], [('input_type', 'STRING')]), 
	'switch_vector' : NodeInstance('GeometryNodeSwitch', [0, 1, 2], [0], [('input_type', 'VECTOR')]), 
	'transform_direction' : NodeInstance('FunctionNodeTransformDirection', [0, 1], [0], []), 
	'transform_geometry' : NodeInstance('GeometryNodeTransform', [0, 1, 2, 3], [0], []), 
	'transform_geometry_components' : NodeInstance('GeometryNodeTransform', [0, 1, 2, 3], [0], [('mode', 'COMPONENTS')]), 
	'transform_geometry_matrix' : NodeInstance('GeometryNodeTransform', [0, 4], [0], [('mode', 'MATRIX')]), 
	'transform_gizmo' : NodeInstance('GeometryNodeGizmoTransform', [0, 1, 2], [0], []), 
	'transform_point' : NodeInstance('FunctionNodeTransformPoint', [0, 1], [0], []), 
	'translate_instances' : NodeInstance('GeometryNodeTranslateInstances', [0, 1, 2, 3], [0], []), 
	'transpose_matrix' : NodeInstance('FunctionNodeTransposeMatrix', [0], [0], []), 
	'triangulate' : NodeInstance('GeometryNodeTriangulate', [0, 1], [0], []), 
	'triangulate_beauty_beauty' : NodeInstance('GeometryNodeTriangulate', [0, 1], [0], [('quad_method', 'BEAUTY'), ('ngon_method', 'BEAUTY')]), 
	'triangulate_beauty_clip' : NodeInstance('GeometryNodeTriangulate', [0, 1], [0], [('quad_method', 'BEAUTY'), ('ngon_method', 'CLIP')]), 
	'triangulate_fixed_alternate_beauty' : NodeInstance('GeometryNodeTriangulate', [0, 1], [0], [('quad_method', 'FIXED_ALTERNATE'), ('ngon_method', 'BEAUTY')]), 
	'triangulate_fixed_alternate_clip' : NodeInstance('GeometryNodeTriangulate', [0, 1], [0], [('quad_method', 'FIXED_ALTERNATE'), ('ngon_method', 'CLIP')]), 
	'triangulate_fixed_beauty' : NodeInstance('GeometryNodeTriangulate', [0, 1], [0], [('quad_method', 'FIXED'), ('ngon_method', 'BEAUTY')]), 
	'triangulate_fixed_clip' : NodeInstance('GeometryNodeTriangulate', [0, 1], [0], [('quad_method', 'FIXED'), ('ngon_method', 'CLIP')]), 
	'triangulate_longest_diagonal_beauty' : NodeInstance('GeometryNodeTriangulate', [0, 1], [0], [('quad_method', 'LONGEST_DIAGONAL'), ('ngon_method', 'BEAUTY')]), 
	'triangulate_longest_diagonal_clip' : NodeInstance('GeometryNodeTriangulate', [0, 1], [0], [('quad_method', 'LONGEST_DIAGONAL'), ('ngon_method', 'CLIP')]), 
	'triangulate_shortest_diagonal_beauty' : NodeInstance('GeometryNodeTriangulate', [0, 1], [0], [('quad_method', 'SHORTEST_DIAGONAL'), ('ngon_method', 'BEAUTY')]), 
	'triangulate_shortest_diagonal_clip' : NodeInstance('GeometryNodeTriangulate', [0, 1], [0], [('quad_method', 'SHORTEST_DIAGONAL'), ('ngon_method', 'CLIP')]), 
	'trim_curve' : NodeInstance('GeometryNodeTrimCurve', [0, 1, 2, 3], [0], []), 
	'trim_curve_factor' : NodeInstance('GeometryNodeTrimCurve', [0, 1, 2, 3], [0], [('mode', 'FACTOR')]), 
	'trim_curve_length' : NodeInstance('GeometryNodeTrimCurve', [0, 1, 4, 5], [0], [('mode', 'LENGTH')]), 
	'uv_sphere' : NodeInstance('GeometryNodeMeshUVSphere', [0, 1, 2], [0, 1], []), 
	'uv_unwrap' : NodeInstance('GeometryNodeUVUnwrap', [0, 1, 2, 3], [0], []), 
	'uv_unwrap_angle_based' : NodeInstance('GeometryNodeUVUnwrap', [0, 1, 2, 3], [0], [('method', 'ANGLE_BASED')]), 
	'uv_unwrap_conformal' : NodeInstance('GeometryNodeUVUnwrap', [0, 1, 2, 3], [0], [('method', 'CONFORMAL')]), 
	'value_to_string' : NodeInstance('FunctionNodeValueToString', [0, 1], [0], []), 
	'value_to_string_float' : NodeInstance('FunctionNodeValueToString', [0, 1], [0], [('data_type', 'FLOAT')]), 
	'value_to_string_integer' : NodeInstance('FunctionNodeValueToString', [0], [0], [('data_type', 'INT')]), 
	'vector' : NodeInstance('FunctionNodeInputVector', [], [0], []), 
	'vertex_neighbors' : NodeInstance('GeometryNodeInputMeshVertexNeighbors', [], [0, 1], []), 
	'vertex_of_corner' : NodeInstance('GeometryNodeVertexOfCorner', [0], [0], []), 
	'viewer' : NodeInstance('GeometryNodeViewer', [0, 1], [], []), 
	'viewer_4x4_matrix_auto' : NodeInstance('GeometryNodeViewer', [0, 1], [], [('data_type', 'FLOAT4X4'), ('domain', 'AUTO')]), 
	'viewer_4x4_matrix_edge' : NodeInstance('GeometryNodeViewer', [0, 1], [], [('data_type', 'FLOAT4X4'), ('domain', 'EDGE')]), 
	'viewer_4x4_matrix_face' : NodeInstance('GeometryNodeViewer', [0, 1], [], [('data_type', 'FLOAT4X4'), ('domain', 'FACE')]), 
	'viewer_4x4_matrix_face_corner' : NodeInstance('GeometryNodeViewer', [0, 1], [], [('data_type', 'FLOAT4X4'), ('domain', 'CORNER')]), 
	'viewer_4x4_matrix_instance' : NodeInstance('GeometryNodeViewer', [0, 1], [], [('data_type', 'FLOAT4X4'), ('domain', 'INSTANCE')]), 
	'viewer_4x4_matrix_layer' : NodeInstance('GeometryNodeViewer', [0, 1], [], [('data_type', 'FLOAT4X4'), ('domain', 'LAYER')]), 
	'viewer_4x4_matrix_point' : NodeInstance('GeometryNodeViewer', [0, 1], [], [('data_type', 'FLOAT4X4'), ('domain', 'POINT')]), 
	'viewer_4x4_matrix_spline' : NodeInstance('GeometryNodeViewer', [0, 1], [], [('data_type', 'FLOAT4X4'), ('domain', 'CURVE')]), 
	'viewer_boolean_auto' : NodeInstance('GeometryNodeViewer', [0, 1], [], [('data_type', 'BOOLEAN'), ('domain', 'AUTO')]), 
	'viewer_boolean_edge' : NodeInstance('GeometryNodeViewer', [0, 1], [], [('data_type', 'BOOLEAN'), ('domain', 'EDGE')]), 
	'viewer_boolean_face' : NodeInstance('GeometryNodeViewer', [0, 1], [], [('data_type', 'BOOLEAN'), ('domain', 'FACE')]), 
	'viewer_boolean_face_corner' : NodeInstance('GeometryNodeViewer', [0, 1], [], [('data_type', 'BOOLEAN'), ('domain', 'CORNER')]), 
	'viewer_boolean_instance' : NodeInstance('GeometryNodeViewer', [0, 1], [], [('data_type', 'BOOLEAN'), ('domain', 'INSTANCE')]), 
	'viewer_boolean_layer' : NodeInstance('GeometryNodeViewer', [0, 1], [], [('data_type', 'BOOLEAN'), ('domain', 'LAYER')]), 
	'viewer_boolean_point' : NodeInstance('GeometryNodeViewer', [0, 1], [], [('data_type', 'BOOLEAN'), ('domain', 'POINT')]), 
	'viewer_boolean_spline' : NodeInstance('GeometryNodeViewer', [0, 1], [], [('data_type', 'BOOLEAN'), ('domain', 'CURVE')]), 
	'viewer_color_auto' : NodeInstance('GeometryNodeViewer', [0, 1], [], [('data_type', 'FLOAT_COLOR'), ('domain', 'AUTO')]), 
	'viewer_color_edge' : NodeInstance('GeometryNodeViewer', [0, 1], [], [('data_type', 'FLOAT_COLOR'), ('domain', 'EDGE')]), 
	'viewer_color_face' : NodeInstance('GeometryNodeViewer', [0, 1], [], [('data_type', 'FLOAT_COLOR'), ('domain', 'FACE')]), 
	'viewer_color_face_corner' : NodeInstance('GeometryNodeViewer', [0, 1], [], [('data_type', 'FLOAT_COLOR'), ('domain', 'CORNER')]), 
	'viewer_color_instance' : NodeInstance('GeometryNodeViewer', [0, 1], [], [('data_type', 'FLOAT_COLOR'), ('domain', 'INSTANCE')]), 
	'viewer_color_layer' : NodeInstance('GeometryNodeViewer', [0, 1], [], [('data_type', 'FLOAT_COLOR'), ('domain', 'LAYER')]), 
	'viewer_color_point' : NodeInstance('GeometryNodeViewer', [0, 1], [], [('data_type', 'FLOAT_COLOR'), ('domain', 'POINT')]), 
	'viewer_color_spline' : NodeInstance('GeometryNodeViewer', [0, 1], [], [('data_type', 'FLOAT_COLOR'), ('domain', 'CURVE')]), 
	'viewer_float_auto' : NodeInstance('GeometryNodeViewer', [0, 1], [], [('data_type', 'FLOAT'), ('domain', 'AUTO')]), 
	'viewer_float_edge' : NodeInstance('GeometryNodeViewer', [0, 1], [], [('data_type', 'FLOAT'), ('domain', 'EDGE')]), 
	'viewer_float_face' : NodeInstance('GeometryNodeViewer', [0, 1], [], [('data_type', 'FLOAT'), ('domain', 'FACE')]), 
	'viewer_float_face_corner' : NodeInstance('GeometryNodeViewer', [0, 1], [], [('data_type', 'FLOAT'), ('domain', 'CORNER')]), 
	'viewer_float_instance' : NodeInstance('GeometryNodeViewer', [0, 1], [], [('data_type', 'FLOAT'), ('domain', 'INSTANCE')]), 
	'viewer_float_layer' : NodeInstance('GeometryNodeViewer', [0, 1], [], [('data_type', 'FLOAT'), ('domain', 'LAYER')]), 
	'viewer_float_point' : NodeInstance('GeometryNodeViewer', [0, 1], [], [('data_type', 'FLOAT'), ('domain', 'POINT')]), 
	'viewer_float_spline' : NodeInstance('GeometryNodeViewer', [0, 1], [], [('data_type', 'FLOAT'), ('domain', 'CURVE')]), 
	'viewer_integer_auto' : NodeInstance('GeometryNodeViewer', [0, 1], [], [('data_type', 'INT'), ('domain', 'AUTO')]), 
	'viewer_integer_edge' : NodeInstance('GeometryNodeViewer', [0, 1], [], [('data_type', 'INT'), ('domain', 'EDGE')]), 
	'viewer_integer_face' : NodeInstance('GeometryNodeViewer', [0, 1], [], [('data_type', 'INT'), ('domain', 'FACE')]), 
	'viewer_integer_face_corner' : NodeInstance('GeometryNodeViewer', [0, 1], [], [('data_type', 'INT'), ('domain', 'CORNER')]), 
	'viewer_integer_instance' : NodeInstance('GeometryNodeViewer', [0, 1], [], [('data_type', 'INT'), ('domain', 'INSTANCE')]), 
	'viewer_integer_layer' : NodeInstance('GeometryNodeViewer', [0, 1], [], [('data_type', 'INT'), ('domain', 'LAYER')]), 
	'viewer_integer_point' : NodeInstance('GeometryNodeViewer', [0, 1], [], [('data_type', 'INT'), ('domain', 'POINT')]), 
	'viewer_integer_spline' : NodeInstance('GeometryNodeViewer', [0, 1], [], [('data_type', 'INT'), ('domain', 'CURVE')]), 
	'viewer_quaternion_auto' : NodeInstance('GeometryNodeViewer', [0, 1], [], [('data_type', 'QUATERNION'), ('domain', 'AUTO')]), 
	'viewer_quaternion_edge' : NodeInstance('GeometryNodeViewer', [0, 1], [], [('data_type', 'QUATERNION'), ('domain', 'EDGE')]), 
	'viewer_quaternion_face' : NodeInstance('GeometryNodeViewer', [0, 1], [], [('data_type', 'QUATERNION'), ('domain', 'FACE')]), 
	'viewer_quaternion_face_corner' : NodeInstance('GeometryNodeViewer', [0, 1], [], [('data_type', 'QUATERNION'), ('domain', 'CORNER')]), 
	'viewer_quaternion_instance' : NodeInstance('GeometryNodeViewer', [0, 1], [], [('data_type', 'QUATERNION'), ('domain', 'INSTANCE')]), 
	'viewer_quaternion_layer' : NodeInstance('GeometryNodeViewer', [0, 1], [], [('data_type', 'QUATERNION'), ('domain', 'LAYER')]), 
	'viewer_quaternion_point' : NodeInstance('GeometryNodeViewer', [0, 1], [], [('data_type', 'QUATERNION'), ('domain', 'POINT')]), 
	'viewer_quaternion_spline' : NodeInstance('GeometryNodeViewer', [0, 1], [], [('data_type', 'QUATERNION'), ('domain', 'CURVE')]), 
	'viewer_vector_auto' : NodeInstance('GeometryNodeViewer', [0, 1], [], [('data_type', 'FLOAT_VECTOR'), ('domain', 'AUTO')]), 
	'viewer_vector_edge' : NodeInstance('GeometryNodeViewer', [0, 1], [], [('data_type', 'FLOAT_VECTOR'), ('domain', 'EDGE')]), 
	'viewer_vector_face' : NodeInstance('GeometryNodeViewer', [0, 1], [], [('data_type', 'FLOAT_VECTOR'), ('domain', 'FACE')]), 
	'viewer_vector_face_corner' : NodeInstance('GeometryNodeViewer', [0, 1], [], [('data_type', 'FLOAT_VECTOR'), ('domain', 'CORNER')]), 
	'viewer_vector_instance' : NodeInstance('GeometryNodeViewer', [0, 1], [], [('data_type', 'FLOAT_VECTOR'), ('domain', 'INSTANCE')]), 
	'viewer_vector_layer' : NodeInstance('GeometryNodeViewer', [0, 1], [], [('data_type', 'FLOAT_VECTOR'), ('domain', 'LAYER')]), 
	'viewer_vector_point' : NodeInstance('GeometryNodeViewer', [0, 1], [], [('data_type', 'FLOAT_VECTOR'), ('domain', 'POINT')]), 
	'viewer_vector_spline' : NodeInstance('GeometryNodeViewer', [0, 1], [], [('data_type', 'FLOAT_VECTOR'), ('domain', 'CURVE')]), 
	'viewport_transform' : NodeInstance('GeometryNodeViewportTransform', [], [0, 1, 2], []), 
	'volume_cube' : NodeInstance('GeometryNodeVolumeCube', [0, 1, 2, 3, 4, 5, 6], [0], []), 
	'volume_to_mesh' : NodeInstance('GeometryNodeVolumeToMesh', [0, 3, 4], [0], []), 
	'volume_to_mesh_amount' : NodeInstance('GeometryNodeVolumeToMesh', [0, 2, 3, 4], [0], [('resolution_mode', 'VOXEL_AMOUNT')]), 
	'volume_to_mesh_grid' : NodeInstance('GeometryNodeVolumeToMesh', [0, 3, 4], [0], [('resolution_mode', 'GRID')]), 
	'volume_to_mesh_size' : NodeInstance('GeometryNodeVolumeToMesh', [0, 1, 3, 4], [0], [('resolution_mode', 'VOXEL_SIZE')]), 
	'warning' : NodeInstance('GeometryNodeWarning', [0, 1], [0], []), 
	'warning_error' : NodeInstance('GeometryNodeWarning', [0, 1], [0], [('warning_type', 'ERROR')]), 
	'warning_info' : NodeInstance('GeometryNodeWarning', [0, 1], [0], [('warning_type', 'INFO')]), 
	'warning_warning' : NodeInstance('GeometryNodeWarning', [0, 1], [0], [('warning_type', 'WARNING')]), 
}

shader_node_aliases = {
	'add_shader' : NodeInstance('ShaderNodeAddShader', [0, 1], [0], []), 
	'ambient_occlusion' : NodeInstance('ShaderNodeAmbientOcclusion', [0, 1, 2], [0, 1], []), 
	'aov_output' : NodeInstance('ShaderNodeOutputAOV', [0, 1], [], []), 
	'attribute' : NodeInstance('ShaderNodeAttribute', [], [0, 1, 2, 3], []), 
	'attribute_geometry' : NodeInstance('ShaderNodeAttribute', [], [0, 1, 2, 3], [('attribute_type', 'GEOMETRY')]), 
	'attribute_instancer' : NodeInstance('ShaderNodeAttribute', [], [0, 1, 2, 3], [('attribute_type', 'INSTANCER')]), 
	'attribute_object' : NodeInstance('ShaderNodeAttribute', [], [0, 1, 2, 3], [('attribute_type', 'OBJECT')]), 
	'attribute_view_layer' : NodeInstance('ShaderNodeAttribute', [], [0, 1, 2, 3], [('attribute_type', 'VIEW_LAYER')]), 
	'background' : NodeInstance('ShaderNodeBackground', [0, 1], [0], []), 
	'bevel' : NodeInstance('ShaderNodeBevel', [0, 1], [0], []), 
	'brightness_contrast' : NodeInstance('ShaderNodeBrightContrast', [0, 1, 2], [0], []), 
	'bump' : NodeInstance('ShaderNodeBump', [0, 1, 2, 3], [0], []), 
	'camera_data' : NodeInstance('ShaderNodeCameraData', [], [0, 1, 2], []), 
	'color_attribute' : NodeInstance('ShaderNodeVertexColor', [], [0, 1], []), 
	'combine_color' : NodeInstance('ShaderNodeCombineColor', [0, 1, 2], [0], []), 
	'combine_color_hsl' : NodeInstance('ShaderNodeCombineColor', [0, 1, 2], [0], [('mode', 'HSL')]), 
	'combine_color_hsv' : NodeInstance('ShaderNodeCombineColor', [0, 1, 2], [0], [('mode', 'HSV')]), 
	'combine_color_rgb' : NodeInstance('ShaderNodeCombineColor', [0, 1, 2], [0], [('mode', 'RGB')]), 
	'curves_info' : NodeInstance('ShaderNodeHairInfo', [], [0, 1, 2, 3, 4, 5], []), 
	'diffuse_bsdf' : NodeInstance('ShaderNodeBsdfDiffuse', [0, 1, 2], [0], []), 
	'displacement' : NodeInstance('ShaderNodeDisplacement', [0, 1, 2, 3], [0], []), 
	'displacement_object_space' : NodeInstance('ShaderNodeDisplacement', [0, 1, 2, 3], [0], [('space', 'OBJECT')]), 
	'displacement_world_space' : NodeInstance('ShaderNodeDisplacement', [0, 1, 2, 3], [0], [('space', 'WORLD')]), 
	'emission' : NodeInstance('ShaderNodeEmission', [0, 1], [0], []), 
	'environment_texture' : NodeInstance('ShaderNodeTexEnvironment', [0], [0], []), 
	'environment_texture_equirectangular_closest' : NodeInstance('ShaderNodeTexEnvironment', [0], [0], [('projection', 'EQUIRECTANGULAR'), ('interpolation', 'Closest')]), 
	'environment_texture_equirectangular_cubic' : NodeInstance('ShaderNodeTexEnvironment', [0], [0], [('projection', 'EQUIRECTANGULAR'), ('interpolation', 'Cubic')]), 
	'environment_texture_equirectangular_linear' : NodeInstance('ShaderNodeTexEnvironment', [0], [0], [('projection', 'EQUIRECTANGULAR'), ('interpolation', 'Linear')]), 
	'environment_texture_equirectangular_smart' : NodeInstance('ShaderNodeTexEnvironment', [0], [0], [('projection', 'EQUIRECTANGULAR'), ('interpolation', 'Smart')]), 
	'environment_texture_mirror_ball_closest' : NodeInstance('ShaderNodeTexEnvironment', [0], [0], [('projection', 'MIRROR_BALL'), ('interpolation', 'Closest')]), 
	'environment_texture_mirror_ball_cubic' : NodeInstance('ShaderNodeTexEnvironment', [0], [0], [('projection', 'MIRROR_BALL'), ('interpolation', 'Cubic')]), 
	'environment_texture_mirror_ball_linear' : NodeInstance('ShaderNodeTexEnvironment', [0], [0], [('projection', 'MIRROR_BALL'), ('interpolation', 'Linear')]), 
	'environment_texture_mirror_ball_smart' : NodeInstance('ShaderNodeTexEnvironment', [0], [0], [('projection', 'MIRROR_BALL'), ('interpolation', 'Smart')]), 
	'fresnel' : NodeInstance('ShaderNodeFresnel', [0, 1], [0], []), 
	'gamma' : NodeInstance('ShaderNodeGamma', [0, 1], [0], []), 
	'geometry' : NodeInstance('ShaderNodeNewGeometry', [], [0, 1, 2, 3, 4, 5, 6, 7, 8], []), 
	'glass_bsdf' : NodeInstance('ShaderNodeBsdfGlass', [0, 1, 2, 3], [0], []), 
	'glass_bsdf_beckmann' : NodeInstance('ShaderNodeBsdfGlass', [0, 1, 2, 3], [0], [('distribution', 'BECKMANN')]), 
	'glass_bsdf_ggx' : NodeInstance('ShaderNodeBsdfGlass', [0, 1, 2, 3], [0], [('distribution', 'GGX')]), 
	'glass_bsdf_multiscatter_ggx' : NodeInstance('ShaderNodeBsdfGlass', [0, 1, 2, 3], [0], [('distribution', 'MULTI_GGX')]), 
	'glossy_bsdf' : NodeInstance('ShaderNodeBsdfAnisotropic', [0, 1, 2, 3, 4, 5], [0], []), 
	'glossy_bsdf_ashikhmin_shirley' : NodeInstance('ShaderNodeBsdfAnisotropic', [0, 1, 2, 3, 4, 5], [0], [('distribution', 'ASHIKHMIN_SHIRLEY')]), 
	'glossy_bsdf_beckmann' : NodeInstance('ShaderNodeBsdfAnisotropic', [0, 1, 2, 3, 4, 5], [0], [('distribution', 'BECKMANN')]), 
	'glossy_bsdf_ggx' : NodeInstance('ShaderNodeBsdfAnisotropic', [0, 1, 2, 3, 4, 5], [0], [('distribution', 'GGX')]), 
	'glossy_bsdf_multiscatter_ggx' : NodeInstance('ShaderNodeBsdfAnisotropic', [0, 1, 2, 3, 4, 5], [0], [('distribution', 'MULTI_GGX')]), 
	'hair_bsdf' : NodeInstance('ShaderNodeBsdfHair', [0, 1, 2, 3, 4], [0], []), 
	'hair_bsdf_reflection' : NodeInstance('ShaderNodeBsdfHair', [0, 1, 2, 3, 4], [0], [('component', 'Reflection')]), 
	'hair_bsdf_transmission' : NodeInstance('ShaderNodeBsdfHair', [0, 1, 2, 3, 4], [0], [('component', 'Transmission')]), 
	'holdout' : NodeInstance('ShaderNodeHoldout', [], [0], []), 
	'hue_saturation_value' : NodeInstance('ShaderNodeHueSaturation', [0, 1, 2, 3, 4], [0], []), 
	'ies_texture' : NodeInstance('ShaderNodeTexIES', [0, 1], [0], []), 
	'ies_texture_external' : NodeInstance('ShaderNodeTexIES', [0, 1], [0], [('mode', 'EXTERNAL')]), 
	'ies_texture_internal' : NodeInstance('ShaderNodeTexIES', [0, 1], [0], [('mode', 'INTERNAL')]), 
	'image_texture' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], []), 
	'image_texture_box_closest_clip' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'BOX'), ('interpolation', 'Closest'), ('extension', 'CLIP')]), 
	'image_texture_box_closest_extend' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'BOX'), ('interpolation', 'Closest'), ('extension', 'EXTEND')]), 
	'image_texture_box_closest_mirror' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'BOX'), ('interpolation', 'Closest'), ('extension', 'MIRROR')]), 
	'image_texture_box_closest_repeat' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'BOX'), ('interpolation', 'Closest'), ('extension', 'REPEAT')]), 
	'image_texture_box_cubic_clip' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'BOX'), ('interpolation', 'Cubic'), ('extension', 'CLIP')]), 
	'image_texture_box_cubic_extend' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'BOX'), ('interpolation', 'Cubic'), ('extension', 'EXTEND')]), 
	'image_texture_box_cubic_mirror' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'BOX'), ('interpolation', 'Cubic'), ('extension', 'MIRROR')]), 
	'image_texture_box_cubic_repeat' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'BOX'), ('interpolation', 'Cubic'), ('extension', 'REPEAT')]), 
	'image_texture_box_linear_clip' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'BOX'), ('interpolation', 'Linear'), ('extension', 'CLIP')]), 
	'image_texture_box_linear_extend' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'BOX'), ('interpolation', 'Linear'), ('extension', 'EXTEND')]), 
	'image_texture_box_linear_mirror' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'BOX'), ('interpolation', 'Linear'), ('extension', 'MIRROR')]), 
	'image_texture_box_linear_repeat' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'BOX'), ('interpolation', 'Linear'), ('extension', 'REPEAT')]), 
	'image_texture_box_smart_clip' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'BOX'), ('interpolation', 'Smart'), ('extension', 'CLIP')]), 
	'image_texture_box_smart_extend' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'BOX'), ('interpolation', 'Smart'), ('extension', 'EXTEND')]), 
	'image_texture_box_smart_mirror' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'BOX'), ('interpolation', 'Smart'), ('extension', 'MIRROR')]), 
	'image_texture_box_smart_repeat' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'BOX'), ('interpolation', 'Smart'), ('extension', 'REPEAT')]), 
	'image_texture_flat_closest_clip' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'FLAT'), ('interpolation', 'Closest'), ('extension', 'CLIP')]), 
	'image_texture_flat_closest_extend' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'FLAT'), ('interpolation', 'Closest'), ('extension', 'EXTEND')]), 
	'image_texture_flat_closest_mirror' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'FLAT'), ('interpolation', 'Closest'), ('extension', 'MIRROR')]), 
	'image_texture_flat_closest_repeat' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'FLAT'), ('interpolation', 'Closest'), ('extension', 'REPEAT')]), 
	'image_texture_flat_cubic_clip' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'FLAT'), ('interpolation', 'Cubic'), ('extension', 'CLIP')]), 
	'image_texture_flat_cubic_extend' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'FLAT'), ('interpolation', 'Cubic'), ('extension', 'EXTEND')]), 
	'image_texture_flat_cubic_mirror' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'FLAT'), ('interpolation', 'Cubic'), ('extension', 'MIRROR')]), 
	'image_texture_flat_cubic_repeat' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'FLAT'), ('interpolation', 'Cubic'), ('extension', 'REPEAT')]), 
	'image_texture_flat_linear_clip' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'FLAT'), ('interpolation', 'Linear'), ('extension', 'CLIP')]), 
	'image_texture_flat_linear_extend' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'FLAT'), ('interpolation', 'Linear'), ('extension', 'EXTEND')]), 
	'image_texture_flat_linear_mirror' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'FLAT'), ('interpolation', 'Linear'), ('extension', 'MIRROR')]), 
	'image_texture_flat_linear_repeat' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'FLAT'), ('interpolation', 'Linear'), ('extension', 'REPEAT')]), 
	'image_texture_flat_smart_clip' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'FLAT'), ('interpolation', 'Smart'), ('extension', 'CLIP')]), 
	'image_texture_flat_smart_extend' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'FLAT'), ('interpolation', 'Smart'), ('extension', 'EXTEND')]), 
	'image_texture_flat_smart_mirror' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'FLAT'), ('interpolation', 'Smart'), ('extension', 'MIRROR')]), 
	'image_texture_flat_smart_repeat' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'FLAT'), ('interpolation', 'Smart'), ('extension', 'REPEAT')]), 
	'image_texture_sphere_closest_clip' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'SPHERE'), ('interpolation', 'Closest'), ('extension', 'CLIP')]), 
	'image_texture_sphere_closest_extend' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'SPHERE'), ('interpolation', 'Closest'), ('extension', 'EXTEND')]), 
	'image_texture_sphere_closest_mirror' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'SPHERE'), ('interpolation', 'Closest'), ('extension', 'MIRROR')]), 
	'image_texture_sphere_closest_repeat' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'SPHERE'), ('interpolation', 'Closest'), ('extension', 'REPEAT')]), 
	'image_texture_sphere_cubic_clip' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'SPHERE'), ('interpolation', 'Cubic'), ('extension', 'CLIP')]), 
	'image_texture_sphere_cubic_extend' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'SPHERE'), ('interpolation', 'Cubic'), ('extension', 'EXTEND')]), 
	'image_texture_sphere_cubic_mirror' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'SPHERE'), ('interpolation', 'Cubic'), ('extension', 'MIRROR')]), 
	'image_texture_sphere_cubic_repeat' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'SPHERE'), ('interpolation', 'Cubic'), ('extension', 'REPEAT')]), 
	'image_texture_sphere_linear_clip' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'SPHERE'), ('interpolation', 'Linear'), ('extension', 'CLIP')]), 
	'image_texture_sphere_linear_extend' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'SPHERE'), ('interpolation', 'Linear'), ('extension', 'EXTEND')]), 
	'image_texture_sphere_linear_mirror' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'SPHERE'), ('interpolation', 'Linear'), ('extension', 'MIRROR')]), 
	'image_texture_sphere_linear_repeat' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'SPHERE'), ('interpolation', 'Linear'), ('extension', 'REPEAT')]), 
	'image_texture_sphere_smart_clip' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'SPHERE'), ('interpolation', 'Smart'), ('extension', 'CLIP')]), 
	'image_texture_sphere_smart_extend' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'SPHERE'), ('interpolation', 'Smart'), ('extension', 'EXTEND')]), 
	'image_texture_sphere_smart_mirror' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'SPHERE'), ('interpolation', 'Smart'), ('extension', 'MIRROR')]), 
	'image_texture_sphere_smart_repeat' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'SPHERE'), ('interpolation', 'Smart'), ('extension', 'REPEAT')]), 
	'image_texture_tube_closest_clip' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'TUBE'), ('interpolation', 'Closest'), ('extension', 'CLIP')]), 
	'image_texture_tube_closest_extend' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'TUBE'), ('interpolation', 'Closest'), ('extension', 'EXTEND')]), 
	'image_texture_tube_closest_mirror' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'TUBE'), ('interpolation', 'Closest'), ('extension', 'MIRROR')]), 
	'image_texture_tube_closest_repeat' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'TUBE'), ('interpolation', 'Closest'), ('extension', 'REPEAT')]), 
	'image_texture_tube_cubic_clip' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'TUBE'), ('interpolation', 'Cubic'), ('extension', 'CLIP')]), 
	'image_texture_tube_cubic_extend' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'TUBE'), ('interpolation', 'Cubic'), ('extension', 'EXTEND')]), 
	'image_texture_tube_cubic_mirror' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'TUBE'), ('interpolation', 'Cubic'), ('extension', 'MIRROR')]), 
	'image_texture_tube_cubic_repeat' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'TUBE'), ('interpolation', 'Cubic'), ('extension', 'REPEAT')]), 
	'image_texture_tube_linear_clip' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'TUBE'), ('interpolation', 'Linear'), ('extension', 'CLIP')]), 
	'image_texture_tube_linear_extend' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'TUBE'), ('interpolation', 'Linear'), ('extension', 'EXTEND')]), 
	'image_texture_tube_linear_mirror' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'TUBE'), ('interpolation', 'Linear'), ('extension', 'MIRROR')]), 
	'image_texture_tube_linear_repeat' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'TUBE'), ('interpolation', 'Linear'), ('extension', 'REPEAT')]), 
	'image_texture_tube_smart_clip' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'TUBE'), ('interpolation', 'Smart'), ('extension', 'CLIP')]), 
	'image_texture_tube_smart_extend' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'TUBE'), ('interpolation', 'Smart'), ('extension', 'EXTEND')]), 
	'image_texture_tube_smart_mirror' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'TUBE'), ('interpolation', 'Smart'), ('extension', 'MIRROR')]), 
	'image_texture_tube_smart_repeat' : NodeInstance('ShaderNodeTexImage', [0], [0, 1], [('projection', 'TUBE'), ('interpolation', 'Smart'), ('extension', 'REPEAT')]), 
	'invert_color' : NodeInstance('ShaderNodeInvert', [0, 1], [0], []), 
	'layer_weight' : NodeInstance('ShaderNodeLayerWeight', [0, 1], [0, 1], []), 
	'light_falloff' : NodeInstance('ShaderNodeLightFalloff', [0, 1], [0, 1, 2], []), 
	'light_output' : NodeInstance('ShaderNodeOutputLight', [0], [], []), 
	'light_output_all' : NodeInstance('ShaderNodeOutputLight', [0], [], [('target', 'ALL')]), 
	'light_output_cycles' : NodeInstance('ShaderNodeOutputLight', [0], [], [('target', 'CYCLES')]), 
	'light_output_eevee' : NodeInstance('ShaderNodeOutputLight', [0], [], [('target', 'EEVEE')]), 
	'light_path' : NodeInstance('ShaderNodeLightPath', [], [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12], []), 
	'line_style_output' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], []), 
	'line_style_output_all_add' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'ALL'), ('blend_type', 'ADD')]), 
	'line_style_output_all_color' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'ALL'), ('blend_type', 'COLOR')]), 
	'line_style_output_all_color_burn' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'ALL'), ('blend_type', 'BURN')]), 
	'line_style_output_all_color_dodge' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'ALL'), ('blend_type', 'DODGE')]), 
	'line_style_output_all_darken' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'ALL'), ('blend_type', 'DARKEN')]), 
	'line_style_output_all_difference' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'ALL'), ('blend_type', 'DIFFERENCE')]), 
	'line_style_output_all_divide' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'ALL'), ('blend_type', 'DIVIDE')]), 
	'line_style_output_all_exclusion' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'ALL'), ('blend_type', 'EXCLUSION')]), 
	'line_style_output_all_hue' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'ALL'), ('blend_type', 'HUE')]), 
	'line_style_output_all_lighten' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'ALL'), ('blend_type', 'LIGHTEN')]), 
	'line_style_output_all_linear_light' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'ALL'), ('blend_type', 'LINEAR_LIGHT')]), 
	'line_style_output_all_mix' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'ALL'), ('blend_type', 'MIX')]), 
	'line_style_output_all_multiply' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'ALL'), ('blend_type', 'MULTIPLY')]), 
	'line_style_output_all_overlay' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'ALL'), ('blend_type', 'OVERLAY')]), 
	'line_style_output_all_saturation' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'ALL'), ('blend_type', 'SATURATION')]), 
	'line_style_output_all_screen' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'ALL'), ('blend_type', 'SCREEN')]), 
	'line_style_output_all_soft_light' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'ALL'), ('blend_type', 'SOFT_LIGHT')]), 
	'line_style_output_all_subtract' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'ALL'), ('blend_type', 'SUBTRACT')]), 
	'line_style_output_all_value' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'ALL'), ('blend_type', 'VALUE')]), 
	'line_style_output_cycles_add' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'CYCLES'), ('blend_type', 'ADD')]), 
	'line_style_output_cycles_color' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'CYCLES'), ('blend_type', 'COLOR')]), 
	'line_style_output_cycles_color_burn' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'CYCLES'), ('blend_type', 'BURN')]), 
	'line_style_output_cycles_color_dodge' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'CYCLES'), ('blend_type', 'DODGE')]), 
	'line_style_output_cycles_darken' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'CYCLES'), ('blend_type', 'DARKEN')]), 
	'line_style_output_cycles_difference' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'CYCLES'), ('blend_type', 'DIFFERENCE')]), 
	'line_style_output_cycles_divide' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'CYCLES'), ('blend_type', 'DIVIDE')]), 
	'line_style_output_cycles_exclusion' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'CYCLES'), ('blend_type', 'EXCLUSION')]), 
	'line_style_output_cycles_hue' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'CYCLES'), ('blend_type', 'HUE')]), 
	'line_style_output_cycles_lighten' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'CYCLES'), ('blend_type', 'LIGHTEN')]), 
	'line_style_output_cycles_linear_light' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'CYCLES'), ('blend_type', 'LINEAR_LIGHT')]), 
	'line_style_output_cycles_mix' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'CYCLES'), ('blend_type', 'MIX')]), 
	'line_style_output_cycles_multiply' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'CYCLES'), ('blend_type', 'MULTIPLY')]), 
	'line_style_output_cycles_overlay' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'CYCLES'), ('blend_type', 'OVERLAY')]), 
	'line_style_output_cycles_saturation' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'CYCLES'), ('blend_type', 'SATURATION')]), 
	'line_style_output_cycles_screen' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'CYCLES'), ('blend_type', 'SCREEN')]), 
	'line_style_output_cycles_soft_light' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'CYCLES'), ('blend_type', 'SOFT_LIGHT')]), 
	'line_style_output_cycles_subtract' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'CYCLES'), ('blend_type', 'SUBTRACT')]), 
	'line_style_output_cycles_value' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'CYCLES'), ('blend_type', 'VALUE')]), 
	'line_style_output_eevee_add' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'EEVEE'), ('blend_type', 'ADD')]), 
	'line_style_output_eevee_color' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'EEVEE'), ('blend_type', 'COLOR')]), 
	'line_style_output_eevee_color_burn' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'EEVEE'), ('blend_type', 'BURN')]), 
	'line_style_output_eevee_color_dodge' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'EEVEE'), ('blend_type', 'DODGE')]), 
	'line_style_output_eevee_darken' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'EEVEE'), ('blend_type', 'DARKEN')]), 
	'line_style_output_eevee_difference' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'EEVEE'), ('blend_type', 'DIFFERENCE')]), 
	'line_style_output_eevee_divide' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'EEVEE'), ('blend_type', 'DIVIDE')]), 
	'line_style_output_eevee_exclusion' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'EEVEE'), ('blend_type', 'EXCLUSION')]), 
	'line_style_output_eevee_hue' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'EEVEE'), ('blend_type', 'HUE')]), 
	'line_style_output_eevee_lighten' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'EEVEE'), ('blend_type', 'LIGHTEN')]), 
	'line_style_output_eevee_linear_light' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'EEVEE'), ('blend_type', 'LINEAR_LIGHT')]), 
	'line_style_output_eevee_mix' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'EEVEE'), ('blend_type', 'MIX')]), 
	'line_style_output_eevee_multiply' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'EEVEE'), ('blend_type', 'MULTIPLY')]), 
	'line_style_output_eevee_overlay' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'EEVEE'), ('blend_type', 'OVERLAY')]), 
	'line_style_output_eevee_saturation' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'EEVEE'), ('blend_type', 'SATURATION')]), 
	'line_style_output_eevee_screen' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'EEVEE'), ('blend_type', 'SCREEN')]), 
	'line_style_output_eevee_soft_light' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'EEVEE'), ('blend_type', 'SOFT_LIGHT')]), 
	'line_style_output_eevee_subtract' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'EEVEE'), ('blend_type', 'SUBTRACT')]), 
	'line_style_output_eevee_value' : NodeInstance('ShaderNodeOutputLineStyle', [0, 1, 2, 3], [], [('target', 'EEVEE'), ('blend_type', 'VALUE')]), 
	'mapping' : NodeInstance('ShaderNodeMapping', [0, 1, 2, 3], [0], []), 
	'mapping_normal' : NodeInstance('ShaderNodeMapping', [0, 2, 3], [0], [('vector_type', 'NORMAL')]), 
	'mapping_point' : NodeInstance('ShaderNodeMapping', [0, 1, 2, 3], [0], [('vector_type', 'POINT')]), 
	'mapping_texture' : NodeInstance('ShaderNodeMapping', [0, 1, 2, 3], [0], [('vector_type', 'TEXTURE')]), 
	'mapping_vector' : NodeInstance('ShaderNodeMapping', [0, 2, 3], [0], [('vector_type', 'VECTOR')]), 
	'material_output' : NodeInstance('ShaderNodeOutputMaterial', [0, 1, 2, 3], [], []), 
	'material_output_all' : NodeInstance('ShaderNodeOutputMaterial', [0, 1, 2, 3], [], [('target', 'ALL')]), 
	'material_output_cycles' : NodeInstance('ShaderNodeOutputMaterial', [0, 1, 2, 3], [], [('target', 'CYCLES')]), 
	'material_output_eevee' : NodeInstance('ShaderNodeOutputMaterial', [0, 1, 2, 3], [], [('target', 'EEVEE')]), 
	'metallic_bsdf' : NodeInstance('ShaderNodeBsdfMetallic', [0, 1, 4, 5, 6, 7, 8], [0], []), 
	'metallic_bsdf_beckmann_f82_tint' : NodeInstance('ShaderNodeBsdfMetallic', [0, 1, 4, 5, 6, 7, 8], [0], [('distribution', 'BECKMANN'), ('fresnel_type', 'F82')]), 
	'metallic_bsdf_beckmann_physical_conductor' : NodeInstance('ShaderNodeBsdfMetallic', [2, 3, 4, 5, 6, 7, 8], [0], [('distribution', 'BECKMANN'), ('fresnel_type', 'PHYSICAL_CONDUCTOR')]), 
	'metallic_bsdf_ggx_f82_tint' : NodeInstance('ShaderNodeBsdfMetallic', [0, 1, 4, 5, 6, 7, 8], [0], [('distribution', 'GGX'), ('fresnel_type', 'F82')]), 
	'metallic_bsdf_ggx_physical_conductor' : NodeInstance('ShaderNodeBsdfMetallic', [2, 3, 4, 5, 6, 7, 8], [0], [('distribution', 'GGX'), ('fresnel_type', 'PHYSICAL_CONDUCTOR')]), 
	'metallic_bsdf_multiscatter_ggx_f82_tint' : NodeInstance('ShaderNodeBsdfMetallic', [0, 1, 4, 5, 6, 7, 8], [0], [('distribution', 'MULTI_GGX'), ('fresnel_type', 'F82')]), 
	'metallic_bsdf_multiscatter_ggx_physical_conductor' : NodeInstance('ShaderNodeBsdfMetallic', [2, 3, 4, 5, 6, 7, 8], [0], [('distribution', 'MULTI_GGX'), ('fresnel_type', 'PHYSICAL_CONDUCTOR')]), 
	'mix_shader' : NodeInstance('ShaderNodeMixShader', [0, 1, 2], [0], []), 
	'normal' : NodeInstance('ShaderNodeNormal', [0], [0, 1], []), 
	'normal_map' : NodeInstance('ShaderNodeNormalMap', [0, 1], [0], []), 
	'normal_map_blender_object_space' : NodeInstance('ShaderNodeNormalMap', [0, 1], [0], [('space', 'BLENDER_OBJECT')]), 
	'normal_map_blender_world_space' : NodeInstance('ShaderNodeNormalMap', [0, 1], [0], [('space', 'BLENDER_WORLD')]), 
	'normal_map_object_space' : NodeInstance('ShaderNodeNormalMap', [0, 1], [0], [('space', 'OBJECT')]), 
	'normal_map_tangent_space' : NodeInstance('ShaderNodeNormalMap', [0, 1], [0], [('space', 'TANGENT')]), 
	'normal_map_world_space' : NodeInstance('ShaderNodeNormalMap', [0, 1], [0], [('space', 'WORLD')]), 
	'object_info' : NodeInstance('ShaderNodeObjectInfo', [], [0, 1, 2, 3, 4, 5], []), 
	'particle_info' : NodeInstance('ShaderNodeParticleInfo', [], [0, 1, 2, 3, 4, 5, 6, 7], []), 
	'point_density' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], []), 
	'point_density_object_vertices_object_space_closest_particle_age_vertex_color' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'OBJECT'), ('space', 'OBJECT'), ('interpolation', 'Closest'), ('particle_color_source', 'PARTICLE_AGE'), ('vertex_color_source', 'VERTEX_COLOR')]), 
	'point_density_object_vertices_object_space_closest_particle_age_vertex_normal' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'OBJECT'), ('space', 'OBJECT'), ('interpolation', 'Closest'), ('particle_color_source', 'PARTICLE_AGE'), ('vertex_color_source', 'VERTEX_NORMAL')]), 
	'point_density_object_vertices_object_space_closest_particle_age_vertex_weight' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'OBJECT'), ('space', 'OBJECT'), ('interpolation', 'Closest'), ('particle_color_source', 'PARTICLE_AGE'), ('vertex_color_source', 'VERTEX_WEIGHT')]), 
	'point_density_object_vertices_object_space_closest_particle_speed_vertex_color' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'OBJECT'), ('space', 'OBJECT'), ('interpolation', 'Closest'), ('particle_color_source', 'PARTICLE_SPEED'), ('vertex_color_source', 'VERTEX_COLOR')]), 
	'point_density_object_vertices_object_space_closest_particle_speed_vertex_normal' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'OBJECT'), ('space', 'OBJECT'), ('interpolation', 'Closest'), ('particle_color_source', 'PARTICLE_SPEED'), ('vertex_color_source', 'VERTEX_NORMAL')]), 
	'point_density_object_vertices_object_space_closest_particle_speed_vertex_weight' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'OBJECT'), ('space', 'OBJECT'), ('interpolation', 'Closest'), ('particle_color_source', 'PARTICLE_SPEED'), ('vertex_color_source', 'VERTEX_WEIGHT')]), 
	'point_density_object_vertices_object_space_closest_particle_velocity_vertex_color' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'OBJECT'), ('space', 'OBJECT'), ('interpolation', 'Closest'), ('particle_color_source', 'PARTICLE_VELOCITY'), ('vertex_color_source', 'VERTEX_COLOR')]), 
	'point_density_object_vertices_object_space_closest_particle_velocity_vertex_normal' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'OBJECT'), ('space', 'OBJECT'), ('interpolation', 'Closest'), ('particle_color_source', 'PARTICLE_VELOCITY'), ('vertex_color_source', 'VERTEX_NORMAL')]), 
	'point_density_object_vertices_object_space_closest_particle_velocity_vertex_weight' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'OBJECT'), ('space', 'OBJECT'), ('interpolation', 'Closest'), ('particle_color_source', 'PARTICLE_VELOCITY'), ('vertex_color_source', 'VERTEX_WEIGHT')]), 
	'point_density_object_vertices_object_space_cubic_particle_age_vertex_color' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'OBJECT'), ('space', 'OBJECT'), ('interpolation', 'Cubic'), ('particle_color_source', 'PARTICLE_AGE'), ('vertex_color_source', 'VERTEX_COLOR')]), 
	'point_density_object_vertices_object_space_cubic_particle_age_vertex_normal' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'OBJECT'), ('space', 'OBJECT'), ('interpolation', 'Cubic'), ('particle_color_source', 'PARTICLE_AGE'), ('vertex_color_source', 'VERTEX_NORMAL')]), 
	'point_density_object_vertices_object_space_cubic_particle_age_vertex_weight' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'OBJECT'), ('space', 'OBJECT'), ('interpolation', 'Cubic'), ('particle_color_source', 'PARTICLE_AGE'), ('vertex_color_source', 'VERTEX_WEIGHT')]), 
	'point_density_object_vertices_object_space_cubic_particle_speed_vertex_color' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'OBJECT'), ('space', 'OBJECT'), ('interpolation', 'Cubic'), ('particle_color_source', 'PARTICLE_SPEED'), ('vertex_color_source', 'VERTEX_COLOR')]), 
	'point_density_object_vertices_object_space_cubic_particle_speed_vertex_normal' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'OBJECT'), ('space', 'OBJECT'), ('interpolation', 'Cubic'), ('particle_color_source', 'PARTICLE_SPEED'), ('vertex_color_source', 'VERTEX_NORMAL')]), 
	'point_density_object_vertices_object_space_cubic_particle_speed_vertex_weight' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'OBJECT'), ('space', 'OBJECT'), ('interpolation', 'Cubic'), ('particle_color_source', 'PARTICLE_SPEED'), ('vertex_color_source', 'VERTEX_WEIGHT')]), 
	'point_density_object_vertices_object_space_cubic_particle_velocity_vertex_color' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'OBJECT'), ('space', 'OBJECT'), ('interpolation', 'Cubic'), ('particle_color_source', 'PARTICLE_VELOCITY'), ('vertex_color_source', 'VERTEX_COLOR')]), 
	'point_density_object_vertices_object_space_cubic_particle_velocity_vertex_normal' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'OBJECT'), ('space', 'OBJECT'), ('interpolation', 'Cubic'), ('particle_color_source', 'PARTICLE_VELOCITY'), ('vertex_color_source', 'VERTEX_NORMAL')]), 
	'point_density_object_vertices_object_space_cubic_particle_velocity_vertex_weight' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'OBJECT'), ('space', 'OBJECT'), ('interpolation', 'Cubic'), ('particle_color_source', 'PARTICLE_VELOCITY'), ('vertex_color_source', 'VERTEX_WEIGHT')]), 
	'point_density_object_vertices_object_space_linear_particle_age_vertex_color' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'OBJECT'), ('space', 'OBJECT'), ('interpolation', 'Linear'), ('particle_color_source', 'PARTICLE_AGE'), ('vertex_color_source', 'VERTEX_COLOR')]), 
	'point_density_object_vertices_object_space_linear_particle_age_vertex_normal' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'OBJECT'), ('space', 'OBJECT'), ('interpolation', 'Linear'), ('particle_color_source', 'PARTICLE_AGE'), ('vertex_color_source', 'VERTEX_NORMAL')]), 
	'point_density_object_vertices_object_space_linear_particle_age_vertex_weight' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'OBJECT'), ('space', 'OBJECT'), ('interpolation', 'Linear'), ('particle_color_source', 'PARTICLE_AGE'), ('vertex_color_source', 'VERTEX_WEIGHT')]), 
	'point_density_object_vertices_object_space_linear_particle_speed_vertex_color' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'OBJECT'), ('space', 'OBJECT'), ('interpolation', 'Linear'), ('particle_color_source', 'PARTICLE_SPEED'), ('vertex_color_source', 'VERTEX_COLOR')]), 
	'point_density_object_vertices_object_space_linear_particle_speed_vertex_normal' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'OBJECT'), ('space', 'OBJECT'), ('interpolation', 'Linear'), ('particle_color_source', 'PARTICLE_SPEED'), ('vertex_color_source', 'VERTEX_NORMAL')]), 
	'point_density_object_vertices_object_space_linear_particle_speed_vertex_weight' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'OBJECT'), ('space', 'OBJECT'), ('interpolation', 'Linear'), ('particle_color_source', 'PARTICLE_SPEED'), ('vertex_color_source', 'VERTEX_WEIGHT')]), 
	'point_density_object_vertices_object_space_linear_particle_velocity_vertex_color' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'OBJECT'), ('space', 'OBJECT'), ('interpolation', 'Linear'), ('particle_color_source', 'PARTICLE_VELOCITY'), ('vertex_color_source', 'VERTEX_COLOR')]), 
	'point_density_object_vertices_object_space_linear_particle_velocity_vertex_normal' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'OBJECT'), ('space', 'OBJECT'), ('interpolation', 'Linear'), ('particle_color_source', 'PARTICLE_VELOCITY'), ('vertex_color_source', 'VERTEX_NORMAL')]), 
	'point_density_object_vertices_object_space_linear_particle_velocity_vertex_weight' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'OBJECT'), ('space', 'OBJECT'), ('interpolation', 'Linear'), ('particle_color_source', 'PARTICLE_VELOCITY'), ('vertex_color_source', 'VERTEX_WEIGHT')]), 
	'point_density_object_vertices_world_space_closest_particle_age_vertex_color' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'OBJECT'), ('space', 'WORLD'), ('interpolation', 'Closest'), ('particle_color_source', 'PARTICLE_AGE'), ('vertex_color_source', 'VERTEX_COLOR')]), 
	'point_density_object_vertices_world_space_closest_particle_age_vertex_normal' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'OBJECT'), ('space', 'WORLD'), ('interpolation', 'Closest'), ('particle_color_source', 'PARTICLE_AGE'), ('vertex_color_source', 'VERTEX_NORMAL')]), 
	'point_density_object_vertices_world_space_closest_particle_age_vertex_weight' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'OBJECT'), ('space', 'WORLD'), ('interpolation', 'Closest'), ('particle_color_source', 'PARTICLE_AGE'), ('vertex_color_source', 'VERTEX_WEIGHT')]), 
	'point_density_object_vertices_world_space_closest_particle_speed_vertex_color' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'OBJECT'), ('space', 'WORLD'), ('interpolation', 'Closest'), ('particle_color_source', 'PARTICLE_SPEED'), ('vertex_color_source', 'VERTEX_COLOR')]), 
	'point_density_object_vertices_world_space_closest_particle_speed_vertex_normal' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'OBJECT'), ('space', 'WORLD'), ('interpolation', 'Closest'), ('particle_color_source', 'PARTICLE_SPEED'), ('vertex_color_source', 'VERTEX_NORMAL')]), 
	'point_density_object_vertices_world_space_closest_particle_speed_vertex_weight' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'OBJECT'), ('space', 'WORLD'), ('interpolation', 'Closest'), ('particle_color_source', 'PARTICLE_SPEED'), ('vertex_color_source', 'VERTEX_WEIGHT')]), 
	'point_density_object_vertices_world_space_closest_particle_velocity_vertex_color' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'OBJECT'), ('space', 'WORLD'), ('interpolation', 'Closest'), ('particle_color_source', 'PARTICLE_VELOCITY'), ('vertex_color_source', 'VERTEX_COLOR')]), 
	'point_density_object_vertices_world_space_closest_particle_velocity_vertex_normal' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'OBJECT'), ('space', 'WORLD'), ('interpolation', 'Closest'), ('particle_color_source', 'PARTICLE_VELOCITY'), ('vertex_color_source', 'VERTEX_NORMAL')]), 
	'point_density_object_vertices_world_space_closest_particle_velocity_vertex_weight' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'OBJECT'), ('space', 'WORLD'), ('interpolation', 'Closest'), ('particle_color_source', 'PARTICLE_VELOCITY'), ('vertex_color_source', 'VERTEX_WEIGHT')]), 
	'point_density_object_vertices_world_space_cubic_particle_age_vertex_color' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'OBJECT'), ('space', 'WORLD'), ('interpolation', 'Cubic'), ('particle_color_source', 'PARTICLE_AGE'), ('vertex_color_source', 'VERTEX_COLOR')]), 
	'point_density_object_vertices_world_space_cubic_particle_age_vertex_normal' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'OBJECT'), ('space', 'WORLD'), ('interpolation', 'Cubic'), ('particle_color_source', 'PARTICLE_AGE'), ('vertex_color_source', 'VERTEX_NORMAL')]), 
	'point_density_object_vertices_world_space_cubic_particle_age_vertex_weight' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'OBJECT'), ('space', 'WORLD'), ('interpolation', 'Cubic'), ('particle_color_source', 'PARTICLE_AGE'), ('vertex_color_source', 'VERTEX_WEIGHT')]), 
	'point_density_object_vertices_world_space_cubic_particle_speed_vertex_color' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'OBJECT'), ('space', 'WORLD'), ('interpolation', 'Cubic'), ('particle_color_source', 'PARTICLE_SPEED'), ('vertex_color_source', 'VERTEX_COLOR')]), 
	'point_density_object_vertices_world_space_cubic_particle_speed_vertex_normal' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'OBJECT'), ('space', 'WORLD'), ('interpolation', 'Cubic'), ('particle_color_source', 'PARTICLE_SPEED'), ('vertex_color_source', 'VERTEX_NORMAL')]), 
	'point_density_object_vertices_world_space_cubic_particle_speed_vertex_weight' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'OBJECT'), ('space', 'WORLD'), ('interpolation', 'Cubic'), ('particle_color_source', 'PARTICLE_SPEED'), ('vertex_color_source', 'VERTEX_WEIGHT')]), 
	'point_density_object_vertices_world_space_cubic_particle_velocity_vertex_color' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'OBJECT'), ('space', 'WORLD'), ('interpolation', 'Cubic'), ('particle_color_source', 'PARTICLE_VELOCITY'), ('vertex_color_source', 'VERTEX_COLOR')]), 
	'point_density_object_vertices_world_space_cubic_particle_velocity_vertex_normal' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'OBJECT'), ('space', 'WORLD'), ('interpolation', 'Cubic'), ('particle_color_source', 'PARTICLE_VELOCITY'), ('vertex_color_source', 'VERTEX_NORMAL')]), 
	'point_density_object_vertices_world_space_cubic_particle_velocity_vertex_weight' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'OBJECT'), ('space', 'WORLD'), ('interpolation', 'Cubic'), ('particle_color_source', 'PARTICLE_VELOCITY'), ('vertex_color_source', 'VERTEX_WEIGHT')]), 
	'point_density_object_vertices_world_space_linear_particle_age_vertex_color' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'OBJECT'), ('space', 'WORLD'), ('interpolation', 'Linear'), ('particle_color_source', 'PARTICLE_AGE'), ('vertex_color_source', 'VERTEX_COLOR')]), 
	'point_density_object_vertices_world_space_linear_particle_age_vertex_normal' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'OBJECT'), ('space', 'WORLD'), ('interpolation', 'Linear'), ('particle_color_source', 'PARTICLE_AGE'), ('vertex_color_source', 'VERTEX_NORMAL')]), 
	'point_density_object_vertices_world_space_linear_particle_age_vertex_weight' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'OBJECT'), ('space', 'WORLD'), ('interpolation', 'Linear'), ('particle_color_source', 'PARTICLE_AGE'), ('vertex_color_source', 'VERTEX_WEIGHT')]), 
	'point_density_object_vertices_world_space_linear_particle_speed_vertex_color' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'OBJECT'), ('space', 'WORLD'), ('interpolation', 'Linear'), ('particle_color_source', 'PARTICLE_SPEED'), ('vertex_color_source', 'VERTEX_COLOR')]), 
	'point_density_object_vertices_world_space_linear_particle_speed_vertex_normal' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'OBJECT'), ('space', 'WORLD'), ('interpolation', 'Linear'), ('particle_color_source', 'PARTICLE_SPEED'), ('vertex_color_source', 'VERTEX_NORMAL')]), 
	'point_density_object_vertices_world_space_linear_particle_speed_vertex_weight' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'OBJECT'), ('space', 'WORLD'), ('interpolation', 'Linear'), ('particle_color_source', 'PARTICLE_SPEED'), ('vertex_color_source', 'VERTEX_WEIGHT')]), 
	'point_density_object_vertices_world_space_linear_particle_velocity_vertex_color' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'OBJECT'), ('space', 'WORLD'), ('interpolation', 'Linear'), ('particle_color_source', 'PARTICLE_VELOCITY'), ('vertex_color_source', 'VERTEX_COLOR')]), 
	'point_density_object_vertices_world_space_linear_particle_velocity_vertex_normal' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'OBJECT'), ('space', 'WORLD'), ('interpolation', 'Linear'), ('particle_color_source', 'PARTICLE_VELOCITY'), ('vertex_color_source', 'VERTEX_NORMAL')]), 
	'point_density_object_vertices_world_space_linear_particle_velocity_vertex_weight' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'OBJECT'), ('space', 'WORLD'), ('interpolation', 'Linear'), ('particle_color_source', 'PARTICLE_VELOCITY'), ('vertex_color_source', 'VERTEX_WEIGHT')]), 
	'point_density_particle_system_object_space_closest_particle_age_vertex_color' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'PARTICLE_SYSTEM'), ('space', 'OBJECT'), ('interpolation', 'Closest'), ('particle_color_source', 'PARTICLE_AGE'), ('vertex_color_source', 'VERTEX_COLOR')]), 
	'point_density_particle_system_object_space_closest_particle_age_vertex_normal' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'PARTICLE_SYSTEM'), ('space', 'OBJECT'), ('interpolation', 'Closest'), ('particle_color_source', 'PARTICLE_AGE'), ('vertex_color_source', 'VERTEX_NORMAL')]), 
	'point_density_particle_system_object_space_closest_particle_age_vertex_weight' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'PARTICLE_SYSTEM'), ('space', 'OBJECT'), ('interpolation', 'Closest'), ('particle_color_source', 'PARTICLE_AGE'), ('vertex_color_source', 'VERTEX_WEIGHT')]), 
	'point_density_particle_system_object_space_closest_particle_speed_vertex_color' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'PARTICLE_SYSTEM'), ('space', 'OBJECT'), ('interpolation', 'Closest'), ('particle_color_source', 'PARTICLE_SPEED'), ('vertex_color_source', 'VERTEX_COLOR')]), 
	'point_density_particle_system_object_space_closest_particle_speed_vertex_normal' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'PARTICLE_SYSTEM'), ('space', 'OBJECT'), ('interpolation', 'Closest'), ('particle_color_source', 'PARTICLE_SPEED'), ('vertex_color_source', 'VERTEX_NORMAL')]), 
	'point_density_particle_system_object_space_closest_particle_speed_vertex_weight' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'PARTICLE_SYSTEM'), ('space', 'OBJECT'), ('interpolation', 'Closest'), ('particle_color_source', 'PARTICLE_SPEED'), ('vertex_color_source', 'VERTEX_WEIGHT')]), 
	'point_density_particle_system_object_space_closest_particle_velocity_vertex_color' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'PARTICLE_SYSTEM'), ('space', 'OBJECT'), ('interpolation', 'Closest'), ('particle_color_source', 'PARTICLE_VELOCITY'), ('vertex_color_source', 'VERTEX_COLOR')]), 
	'point_density_particle_system_object_space_closest_particle_velocity_vertex_normal' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'PARTICLE_SYSTEM'), ('space', 'OBJECT'), ('interpolation', 'Closest'), ('particle_color_source', 'PARTICLE_VELOCITY'), ('vertex_color_source', 'VERTEX_NORMAL')]), 
	'point_density_particle_system_object_space_closest_particle_velocity_vertex_weight' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'PARTICLE_SYSTEM'), ('space', 'OBJECT'), ('interpolation', 'Closest'), ('particle_color_source', 'PARTICLE_VELOCITY'), ('vertex_color_source', 'VERTEX_WEIGHT')]), 
	'point_density_particle_system_object_space_cubic_particle_age_vertex_color' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'PARTICLE_SYSTEM'), ('space', 'OBJECT'), ('interpolation', 'Cubic'), ('particle_color_source', 'PARTICLE_AGE'), ('vertex_color_source', 'VERTEX_COLOR')]), 
	'point_density_particle_system_object_space_cubic_particle_age_vertex_normal' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'PARTICLE_SYSTEM'), ('space', 'OBJECT'), ('interpolation', 'Cubic'), ('particle_color_source', 'PARTICLE_AGE'), ('vertex_color_source', 'VERTEX_NORMAL')]), 
	'point_density_particle_system_object_space_cubic_particle_age_vertex_weight' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'PARTICLE_SYSTEM'), ('space', 'OBJECT'), ('interpolation', 'Cubic'), ('particle_color_source', 'PARTICLE_AGE'), ('vertex_color_source', 'VERTEX_WEIGHT')]), 
	'point_density_particle_system_object_space_cubic_particle_speed_vertex_color' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'PARTICLE_SYSTEM'), ('space', 'OBJECT'), ('interpolation', 'Cubic'), ('particle_color_source', 'PARTICLE_SPEED'), ('vertex_color_source', 'VERTEX_COLOR')]), 
	'point_density_particle_system_object_space_cubic_particle_speed_vertex_normal' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'PARTICLE_SYSTEM'), ('space', 'OBJECT'), ('interpolation', 'Cubic'), ('particle_color_source', 'PARTICLE_SPEED'), ('vertex_color_source', 'VERTEX_NORMAL')]), 
	'point_density_particle_system_object_space_cubic_particle_speed_vertex_weight' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'PARTICLE_SYSTEM'), ('space', 'OBJECT'), ('interpolation', 'Cubic'), ('particle_color_source', 'PARTICLE_SPEED'), ('vertex_color_source', 'VERTEX_WEIGHT')]), 
	'point_density_particle_system_object_space_cubic_particle_velocity_vertex_color' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'PARTICLE_SYSTEM'), ('space', 'OBJECT'), ('interpolation', 'Cubic'), ('particle_color_source', 'PARTICLE_VELOCITY'), ('vertex_color_source', 'VERTEX_COLOR')]), 
	'point_density_particle_system_object_space_cubic_particle_velocity_vertex_normal' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'PARTICLE_SYSTEM'), ('space', 'OBJECT'), ('interpolation', 'Cubic'), ('particle_color_source', 'PARTICLE_VELOCITY'), ('vertex_color_source', 'VERTEX_NORMAL')]), 
	'point_density_particle_system_object_space_cubic_particle_velocity_vertex_weight' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'PARTICLE_SYSTEM'), ('space', 'OBJECT'), ('interpolation', 'Cubic'), ('particle_color_source', 'PARTICLE_VELOCITY'), ('vertex_color_source', 'VERTEX_WEIGHT')]), 
	'point_density_particle_system_object_space_linear_particle_age_vertex_color' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'PARTICLE_SYSTEM'), ('space', 'OBJECT'), ('interpolation', 'Linear'), ('particle_color_source', 'PARTICLE_AGE'), ('vertex_color_source', 'VERTEX_COLOR')]), 
	'point_density_particle_system_object_space_linear_particle_age_vertex_normal' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'PARTICLE_SYSTEM'), ('space', 'OBJECT'), ('interpolation', 'Linear'), ('particle_color_source', 'PARTICLE_AGE'), ('vertex_color_source', 'VERTEX_NORMAL')]), 
	'point_density_particle_system_object_space_linear_particle_age_vertex_weight' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'PARTICLE_SYSTEM'), ('space', 'OBJECT'), ('interpolation', 'Linear'), ('particle_color_source', 'PARTICLE_AGE'), ('vertex_color_source', 'VERTEX_WEIGHT')]), 
	'point_density_particle_system_object_space_linear_particle_speed_vertex_color' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'PARTICLE_SYSTEM'), ('space', 'OBJECT'), ('interpolation', 'Linear'), ('particle_color_source', 'PARTICLE_SPEED'), ('vertex_color_source', 'VERTEX_COLOR')]), 
	'point_density_particle_system_object_space_linear_particle_speed_vertex_normal' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'PARTICLE_SYSTEM'), ('space', 'OBJECT'), ('interpolation', 'Linear'), ('particle_color_source', 'PARTICLE_SPEED'), ('vertex_color_source', 'VERTEX_NORMAL')]), 
	'point_density_particle_system_object_space_linear_particle_speed_vertex_weight' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'PARTICLE_SYSTEM'), ('space', 'OBJECT'), ('interpolation', 'Linear'), ('particle_color_source', 'PARTICLE_SPEED'), ('vertex_color_source', 'VERTEX_WEIGHT')]), 
	'point_density_particle_system_object_space_linear_particle_velocity_vertex_color' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'PARTICLE_SYSTEM'), ('space', 'OBJECT'), ('interpolation', 'Linear'), ('particle_color_source', 'PARTICLE_VELOCITY'), ('vertex_color_source', 'VERTEX_COLOR')]), 
	'point_density_particle_system_object_space_linear_particle_velocity_vertex_normal' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'PARTICLE_SYSTEM'), ('space', 'OBJECT'), ('interpolation', 'Linear'), ('particle_color_source', 'PARTICLE_VELOCITY'), ('vertex_color_source', 'VERTEX_NORMAL')]), 
	'point_density_particle_system_object_space_linear_particle_velocity_vertex_weight' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'PARTICLE_SYSTEM'), ('space', 'OBJECT'), ('interpolation', 'Linear'), ('particle_color_source', 'PARTICLE_VELOCITY'), ('vertex_color_source', 'VERTEX_WEIGHT')]), 
	'point_density_particle_system_world_space_closest_particle_age_vertex_color' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'PARTICLE_SYSTEM'), ('space', 'WORLD'), ('interpolation', 'Closest'), ('particle_color_source', 'PARTICLE_AGE'), ('vertex_color_source', 'VERTEX_COLOR')]), 
	'point_density_particle_system_world_space_closest_particle_age_vertex_normal' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'PARTICLE_SYSTEM'), ('space', 'WORLD'), ('interpolation', 'Closest'), ('particle_color_source', 'PARTICLE_AGE'), ('vertex_color_source', 'VERTEX_NORMAL')]), 
	'point_density_particle_system_world_space_closest_particle_age_vertex_weight' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'PARTICLE_SYSTEM'), ('space', 'WORLD'), ('interpolation', 'Closest'), ('particle_color_source', 'PARTICLE_AGE'), ('vertex_color_source', 'VERTEX_WEIGHT')]), 
	'point_density_particle_system_world_space_closest_particle_speed_vertex_color' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'PARTICLE_SYSTEM'), ('space', 'WORLD'), ('interpolation', 'Closest'), ('particle_color_source', 'PARTICLE_SPEED'), ('vertex_color_source', 'VERTEX_COLOR')]), 
	'point_density_particle_system_world_space_closest_particle_speed_vertex_normal' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'PARTICLE_SYSTEM'), ('space', 'WORLD'), ('interpolation', 'Closest'), ('particle_color_source', 'PARTICLE_SPEED'), ('vertex_color_source', 'VERTEX_NORMAL')]), 
	'point_density_particle_system_world_space_closest_particle_speed_vertex_weight' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'PARTICLE_SYSTEM'), ('space', 'WORLD'), ('interpolation', 'Closest'), ('particle_color_source', 'PARTICLE_SPEED'), ('vertex_color_source', 'VERTEX_WEIGHT')]), 
	'point_density_particle_system_world_space_closest_particle_velocity_vertex_color' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'PARTICLE_SYSTEM'), ('space', 'WORLD'), ('interpolation', 'Closest'), ('particle_color_source', 'PARTICLE_VELOCITY'), ('vertex_color_source', 'VERTEX_COLOR')]), 
	'point_density_particle_system_world_space_closest_particle_velocity_vertex_normal' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'PARTICLE_SYSTEM'), ('space', 'WORLD'), ('interpolation', 'Closest'), ('particle_color_source', 'PARTICLE_VELOCITY'), ('vertex_color_source', 'VERTEX_NORMAL')]), 
	'point_density_particle_system_world_space_closest_particle_velocity_vertex_weight' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'PARTICLE_SYSTEM'), ('space', 'WORLD'), ('interpolation', 'Closest'), ('particle_color_source', 'PARTICLE_VELOCITY'), ('vertex_color_source', 'VERTEX_WEIGHT')]), 
	'point_density_particle_system_world_space_cubic_particle_age_vertex_color' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'PARTICLE_SYSTEM'), ('space', 'WORLD'), ('interpolation', 'Cubic'), ('particle_color_source', 'PARTICLE_AGE'), ('vertex_color_source', 'VERTEX_COLOR')]), 
	'point_density_particle_system_world_space_cubic_particle_age_vertex_normal' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'PARTICLE_SYSTEM'), ('space', 'WORLD'), ('interpolation', 'Cubic'), ('particle_color_source', 'PARTICLE_AGE'), ('vertex_color_source', 'VERTEX_NORMAL')]), 
	'point_density_particle_system_world_space_cubic_particle_age_vertex_weight' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'PARTICLE_SYSTEM'), ('space', 'WORLD'), ('interpolation', 'Cubic'), ('particle_color_source', 'PARTICLE_AGE'), ('vertex_color_source', 'VERTEX_WEIGHT')]), 
	'point_density_particle_system_world_space_cubic_particle_speed_vertex_color' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'PARTICLE_SYSTEM'), ('space', 'WORLD'), ('interpolation', 'Cubic'), ('particle_color_source', 'PARTICLE_SPEED'), ('vertex_color_source', 'VERTEX_COLOR')]), 
	'point_density_particle_system_world_space_cubic_particle_speed_vertex_normal' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'PARTICLE_SYSTEM'), ('space', 'WORLD'), ('interpolation', 'Cubic'), ('particle_color_source', 'PARTICLE_SPEED'), ('vertex_color_source', 'VERTEX_NORMAL')]), 
	'point_density_particle_system_world_space_cubic_particle_speed_vertex_weight' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'PARTICLE_SYSTEM'), ('space', 'WORLD'), ('interpolation', 'Cubic'), ('particle_color_source', 'PARTICLE_SPEED'), ('vertex_color_source', 'VERTEX_WEIGHT')]), 
	'point_density_particle_system_world_space_cubic_particle_velocity_vertex_color' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'PARTICLE_SYSTEM'), ('space', 'WORLD'), ('interpolation', 'Cubic'), ('particle_color_source', 'PARTICLE_VELOCITY'), ('vertex_color_source', 'VERTEX_COLOR')]), 
	'point_density_particle_system_world_space_cubic_particle_velocity_vertex_normal' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'PARTICLE_SYSTEM'), ('space', 'WORLD'), ('interpolation', 'Cubic'), ('particle_color_source', 'PARTICLE_VELOCITY'), ('vertex_color_source', 'VERTEX_NORMAL')]), 
	'point_density_particle_system_world_space_cubic_particle_velocity_vertex_weight' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'PARTICLE_SYSTEM'), ('space', 'WORLD'), ('interpolation', 'Cubic'), ('particle_color_source', 'PARTICLE_VELOCITY'), ('vertex_color_source', 'VERTEX_WEIGHT')]), 
	'point_density_particle_system_world_space_linear_particle_age_vertex_color' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'PARTICLE_SYSTEM'), ('space', 'WORLD'), ('interpolation', 'Linear'), ('particle_color_source', 'PARTICLE_AGE'), ('vertex_color_source', 'VERTEX_COLOR')]), 
	'point_density_particle_system_world_space_linear_particle_age_vertex_normal' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'PARTICLE_SYSTEM'), ('space', 'WORLD'), ('interpolation', 'Linear'), ('particle_color_source', 'PARTICLE_AGE'), ('vertex_color_source', 'VERTEX_NORMAL')]), 
	'point_density_particle_system_world_space_linear_particle_age_vertex_weight' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'PARTICLE_SYSTEM'), ('space', 'WORLD'), ('interpolation', 'Linear'), ('particle_color_source', 'PARTICLE_AGE'), ('vertex_color_source', 'VERTEX_WEIGHT')]), 
	'point_density_particle_system_world_space_linear_particle_speed_vertex_color' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'PARTICLE_SYSTEM'), ('space', 'WORLD'), ('interpolation', 'Linear'), ('particle_color_source', 'PARTICLE_SPEED'), ('vertex_color_source', 'VERTEX_COLOR')]), 
	'point_density_particle_system_world_space_linear_particle_speed_vertex_normal' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'PARTICLE_SYSTEM'), ('space', 'WORLD'), ('interpolation', 'Linear'), ('particle_color_source', 'PARTICLE_SPEED'), ('vertex_color_source', 'VERTEX_NORMAL')]), 
	'point_density_particle_system_world_space_linear_particle_speed_vertex_weight' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'PARTICLE_SYSTEM'), ('space', 'WORLD'), ('interpolation', 'Linear'), ('particle_color_source', 'PARTICLE_SPEED'), ('vertex_color_source', 'VERTEX_WEIGHT')]), 
	'point_density_particle_system_world_space_linear_particle_velocity_vertex_color' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'PARTICLE_SYSTEM'), ('space', 'WORLD'), ('interpolation', 'Linear'), ('particle_color_source', 'PARTICLE_VELOCITY'), ('vertex_color_source', 'VERTEX_COLOR')]), 
	'point_density_particle_system_world_space_linear_particle_velocity_vertex_normal' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'PARTICLE_SYSTEM'), ('space', 'WORLD'), ('interpolation', 'Linear'), ('particle_color_source', 'PARTICLE_VELOCITY'), ('vertex_color_source', 'VERTEX_NORMAL')]), 
	'point_density_particle_system_world_space_linear_particle_velocity_vertex_weight' : NodeInstance('ShaderNodeTexPointDensity', [0], [0, 1], [('point_source', 'PARTICLE_SYSTEM'), ('space', 'WORLD'), ('interpolation', 'Linear'), ('particle_color_source', 'PARTICLE_VELOCITY'), ('vertex_color_source', 'VERTEX_WEIGHT')]), 
	'point_info' : NodeInstance('ShaderNodePointInfo', [], [0, 1, 2], []), 
	'principled_bsdf' : NodeInstance('ShaderNodeBsdfPrincipled', [0, 1, 2, 3, 4, 5, 7, 8, 9, 10, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30], [0], []), 
	'principled_bsdf_ggx_christensen_burley' : NodeInstance('ShaderNodeBsdfPrincipled', [0, 1, 2, 3, 4, 5, 7, 8, 9, 10, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30], [0], [('distribution', 'GGX'), ('subsurface_method', 'BURLEY')]), 
	'principled_bsdf_ggx_random_walk' : NodeInstance('ShaderNodeBsdfPrincipled', [0, 1, 2, 3, 4, 5, 7, 8, 9, 10, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30], [0], [('distribution', 'GGX'), ('subsurface_method', 'RANDOM_WALK')]), 
	'principled_bsdf_ggx_random_walk_skin' : NodeInstance('ShaderNodeBsdfPrincipled', [0, 1, 2, 3, 4, 5, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30], [0], [('distribution', 'GGX'), ('subsurface_method', 'RANDOM_WALK_SKIN')]), 
	'principled_bsdf_multiscatter_ggx_christensen_burley' : NodeInstance('ShaderNodeBsdfPrincipled', [0, 1, 2, 3, 4, 5, 7, 8, 9, 10, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30], [0], [('distribution', 'MULTI_GGX'), ('subsurface_method', 'BURLEY')]), 
	'principled_bsdf_multiscatter_ggx_random_walk' : NodeInstance('ShaderNodeBsdfPrincipled', [0, 1, 2, 3, 4, 5, 7, 8, 9, 10, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30], [0], [('distribution', 'MULTI_GGX'), ('subsurface_method', 'RANDOM_WALK')]), 
	'principled_bsdf_multiscatter_ggx_random_walk_skin' : NodeInstance('ShaderNodeBsdfPrincipled', [0, 1, 2, 3, 4, 5, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26, 27, 28, 29, 30], [0], [('distribution', 'MULTI_GGX'), ('subsurface_method', 'RANDOM_WALK_SKIN')]), 
	'principled_hair_bsdf' : NodeInstance('ShaderNodeBsdfHairPrincipled', [0, 6, 7, 8, 9, 10, 12, 13], [0], []), 
	'principled_hair_bsdf_chiang_absorption_coefficient' : NodeInstance('ShaderNodeBsdfHairPrincipled', [4, 6, 7, 8, 9, 10, 12, 13], [0], [('model', 'CHIANG'), ('parametrization', 'ABSORPTION')]), 
	'principled_hair_bsdf_chiang_direct_coloring' : NodeInstance('ShaderNodeBsdfHairPrincipled', [0, 6, 7, 8, 9, 10, 12, 13], [0], [('model', 'CHIANG'), ('parametrization', 'COLOR')]), 
	'principled_hair_bsdf_chiang_melanin_concentration' : NodeInstance('ShaderNodeBsdfHairPrincipled', [1, 2, 3, 6, 7, 8, 9, 10, 11, 12, 13], [0], [('model', 'CHIANG'), ('parametrization', 'MELANIN')]), 
	'principled_hair_bsdf_huang_absorption_coefficient' : NodeInstance('ShaderNodeBsdfHairPrincipled', [4, 5, 6, 9, 10, 12, 13, 15, 16, 17], [0], [('model', 'HUANG'), ('parametrization', 'ABSORPTION')]), 
	'principled_hair_bsdf_huang_direct_coloring' : NodeInstance('ShaderNodeBsdfHairPrincipled', [0, 5, 6, 9, 10, 12, 13, 15, 16, 17], [0], [('model', 'HUANG'), ('parametrization', 'COLOR')]), 
	'principled_hair_bsdf_huang_melanin_concentration' : NodeInstance('ShaderNodeBsdfHairPrincipled', [1, 2, 3, 5, 6, 9, 10, 11, 12, 13, 15, 16, 17], [0], [('model', 'HUANG'), ('parametrization', 'MELANIN')]), 
	'principled_volume' : NodeInstance('ShaderNodeVolumePrincipled', [0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11], [0], []), 
	'ray_portal_bsdf' : NodeInstance('ShaderNodeBsdfRayPortal', [0, 1, 2], [0], []), 
	'refraction_bsdf' : NodeInstance('ShaderNodeBsdfRefraction', [0, 1, 2, 3], [0], []), 
	'refraction_bsdf_beckmann' : NodeInstance('ShaderNodeBsdfRefraction', [0, 1, 2, 3], [0], [('distribution', 'BECKMANN')]), 
	'refraction_bsdf_ggx' : NodeInstance('ShaderNodeBsdfRefraction', [0, 1, 2, 3], [0], [('distribution', 'GGX')]), 
	'rgb' : NodeInstance('ShaderNodeRGB', [], [0], []), 
	'rgb_to_bw' : NodeInstance('ShaderNodeRGBToBW', [0], [0], []), 
	'script' : NodeInstance('ShaderNodeScript', [], [], []), 
	'script_external' : NodeInstance('ShaderNodeScript', [], [], [('mode', 'EXTERNAL')]), 
	'script_internal' : NodeInstance('ShaderNodeScript', [], [], [('mode', 'INTERNAL')]), 
	'separate_color' : NodeInstance('ShaderNodeSeparateColor', [0], [0, 1, 2], []), 
	'separate_color_hsl' : NodeInstance('ShaderNodeSeparateColor', [0], [0, 1, 2], [('mode', 'HSL')]), 
	'separate_color_hsv' : NodeInstance('ShaderNodeSeparateColor', [0], [0, 1, 2], [('mode', 'HSV')]), 
	'separate_color_rgb' : NodeInstance('ShaderNodeSeparateColor', [0], [0, 1, 2], [('mode', 'RGB')]), 
	'shader_to_rgb' : NodeInstance('ShaderNodeShaderToRGB', [0], [0, 1], []), 
	'sheen_bsdf' : NodeInstance('ShaderNodeBsdfSheen', [0, 1, 2], [0], []), 
	'sheen_bsdf_ashikhmin' : NodeInstance('ShaderNodeBsdfSheen', [0, 1, 2], [0], [('distribution', 'ASHIKHMIN')]), 
	'sheen_bsdf_microfiber' : NodeInstance('ShaderNodeBsdfSheen', [0, 1, 2], [0], [('distribution', 'MICROFIBER')]), 
	'sky_texture' : NodeInstance('ShaderNodeTexSky', [], [0], []), 
	'sky_texture_hosek___wilkie' : NodeInstance('ShaderNodeTexSky', [0], [0], [('sky_type', 'HOSEK_WILKIE')]), 
	'sky_texture_nishita' : NodeInstance('ShaderNodeTexSky', [], [0], [('sky_type', 'NISHITA')]), 
	'sky_texture_preetham' : NodeInstance('ShaderNodeTexSky', [0], [0], [('sky_type', 'PREETHAM')]), 
	'specular_bsdf' : NodeInstance('ShaderNodeEeveeSpecular', [0, 1, 2, 3, 4, 5, 6, 7, 8], [0], []), 
	'subsurface_scattering' : NodeInstance('ShaderNodeSubsurfaceScattering', [0, 1, 2, 3, 4, 5, 6], [0], []), 
	'subsurface_scattering_christensen_burley' : NodeInstance('ShaderNodeSubsurfaceScattering', [0, 1, 2, 6], [0], [('falloff', 'BURLEY')]), 
	'subsurface_scattering_random_walk' : NodeInstance('ShaderNodeSubsurfaceScattering', [0, 1, 2, 3, 4, 5, 6], [0], [('falloff', 'RANDOM_WALK')]), 
	'subsurface_scattering_random_walk_skin' : NodeInstance('ShaderNodeSubsurfaceScattering', [0, 1, 2, 3, 5, 6], [0], [('falloff', 'RANDOM_WALK_SKIN')]), 
	'tangent' : NodeInstance('ShaderNodeTangent', [], [0], []), 
	'tangent_radial_x' : NodeInstance('ShaderNodeTangent', [], [0], [('direction_type', 'RADIAL'), ('axis', 'X')]), 
	'tangent_radial_y' : NodeInstance('ShaderNodeTangent', [], [0], [('direction_type', 'RADIAL'), ('axis', 'Y')]), 
	'tangent_radial_z' : NodeInstance('ShaderNodeTangent', [], [0], [('direction_type', 'RADIAL'), ('axis', 'Z')]), 
	'tangent_uv_map_x' : NodeInstance('ShaderNodeTangent', [], [0], [('direction_type', 'UV_MAP'), ('axis', 'X')]), 
	'tangent_uv_map_y' : NodeInstance('ShaderNodeTangent', [], [0], [('direction_type', 'UV_MAP'), ('axis', 'Y')]), 
	'tangent_uv_map_z' : NodeInstance('ShaderNodeTangent', [], [0], [('direction_type', 'UV_MAP'), ('axis', 'Z')]), 
	'texture_coordinate' : NodeInstance('ShaderNodeTexCoord', [], [0, 1, 2, 3, 4, 5, 6], []), 
	'toon_bsdf' : NodeInstance('ShaderNodeBsdfToon', [0, 1, 2, 3], [0], []), 
	'toon_bsdf_diffuse' : NodeInstance('ShaderNodeBsdfToon', [0, 1, 2, 3], [0], [('component', 'DIFFUSE')]), 
	'toon_bsdf_glossy' : NodeInstance('ShaderNodeBsdfToon', [0, 1, 2, 3], [0], [('component', 'GLOSSY')]), 
	'translucent_bsdf' : NodeInstance('ShaderNodeBsdfTranslucent', [0, 1], [0], []), 
	'transparent_bsdf' : NodeInstance('ShaderNodeBsdfTransparent', [0], [0], []), 
	'uv_along_stroke' : NodeInstance('ShaderNodeUVAlongStroke', [], [0], []), 
	'uv_map' : NodeInstance('ShaderNodeUVMap', [], [0], []), 
	'vector_displacement' : NodeInstance('ShaderNodeVectorDisplacement', [0, 1, 2], [0], []), 
	'vector_displacement_object_space' : NodeInstance('ShaderNodeVectorDisplacement', [0, 1, 2], [0], [('space', 'OBJECT')]), 
	'vector_displacement_tangent_space' : NodeInstance('ShaderNodeVectorDisplacement', [0, 1, 2], [0], [('space', 'TANGENT')]), 
	'vector_displacement_world_space' : NodeInstance('ShaderNodeVectorDisplacement', [0, 1, 2], [0], [('space', 'WORLD')]), 
	'vector_transform' : NodeInstance('ShaderNodeVectorTransform', [0], [0], []), 
	'vector_transform_normal_camera_camera' : NodeInstance('ShaderNodeVectorTransform', [0], [0], [('vector_type', 'NORMAL'), ('convert_from', 'CAMERA'), ('convert_to', 'CAMERA')]), 
	'vector_transform_normal_camera_object' : NodeInstance('ShaderNodeVectorTransform', [0], [0], [('vector_type', 'NORMAL'), ('convert_from', 'CAMERA'), ('convert_to', 'OBJECT')]), 
	'vector_transform_normal_camera_world' : NodeInstance('ShaderNodeVectorTransform', [0], [0], [('vector_type', 'NORMAL'), ('convert_from', 'CAMERA'), ('convert_to', 'WORLD')]), 
	'vector_transform_normal_object_camera' : NodeInstance('ShaderNodeVectorTransform', [0], [0], [('vector_type', 'NORMAL'), ('convert_from', 'OBJECT'), ('convert_to', 'CAMERA')]), 
	'vector_transform_normal_object_object' : NodeInstance('ShaderNodeVectorTransform', [0], [0], [('vector_type', 'NORMAL'), ('convert_from', 'OBJECT'), ('convert_to', 'OBJECT')]), 
	'vector_transform_normal_object_world' : NodeInstance('ShaderNodeVectorTransform', [0], [0], [('vector_type', 'NORMAL'), ('convert_from', 'OBJECT'), ('convert_to', 'WORLD')]), 
	'vector_transform_normal_world_camera' : NodeInstance('ShaderNodeVectorTransform', [0], [0], [('vector_type', 'NORMAL'), ('convert_from', 'WORLD'), ('convert_to', 'CAMERA')]), 
	'vector_transform_normal_world_object' : NodeInstance('ShaderNodeVectorTransform', [0], [0], [('vector_type', 'NORMAL'), ('convert_from', 'WORLD'), ('convert_to', 'OBJECT')]), 
	'vector_transform_normal_world_world' : NodeInstance('ShaderNodeVectorTransform', [0], [0], [('vector_type', 'NORMAL'), ('convert_from', 'WORLD'), ('convert_to', 'WORLD')]), 
	'vector_transform_point_camera_camera' : NodeInstance('ShaderNodeVectorTransform', [0], [0], [('vector_type', 'POINT'), ('convert_from', 'CAMERA'), ('convert_to', 'CAMERA')]), 
	'vector_transform_point_camera_object' : NodeInstance('ShaderNodeVectorTransform', [0], [0], [('vector_type', 'POINT'), ('convert_from', 'CAMERA'), ('convert_to', 'OBJECT')]), 
	'vector_transform_point_camera_world' : NodeInstance('ShaderNodeVectorTransform', [0], [0], [('vector_type', 'POINT'), ('convert_from', 'CAMERA'), ('convert_to', 'WORLD')]), 
	'vector_transform_point_object_camera' : NodeInstance('ShaderNodeVectorTransform', [0], [0], [('vector_type', 'POINT'), ('convert_from', 'OBJECT'), ('convert_to', 'CAMERA')]), 
	'vector_transform_point_object_object' : NodeInstance('ShaderNodeVectorTransform', [0], [0], [('vector_type', 'POINT'), ('convert_from', 'OBJECT'), ('convert_to', 'OBJECT')]), 
	'vector_transform_point_object_world' : NodeInstance('ShaderNodeVectorTransform', [0], [0], [('vector_type', 'POINT'), ('convert_from', 'OBJECT'), ('convert_to', 'WORLD')]), 
	'vector_transform_point_world_camera' : NodeInstance('ShaderNodeVectorTransform', [0], [0], [('vector_type', 'POINT'), ('convert_from', 'WORLD'), ('convert_to', 'CAMERA')]), 
	'vector_transform_point_world_object' : NodeInstance('ShaderNodeVectorTransform', [0], [0], [('vector_type', 'POINT'), ('convert_from', 'WORLD'), ('convert_to', 'OBJECT')]), 
	'vector_transform_point_world_world' : NodeInstance('ShaderNodeVectorTransform', [0], [0], [('vector_type', 'POINT'), ('convert_from', 'WORLD'), ('convert_to', 'WORLD')]), 
	'vector_transform_vector_camera_camera' : NodeInstance('ShaderNodeVectorTransform', [0], [0], [('vector_type', 'VECTOR'), ('convert_from', 'CAMERA'), ('convert_to', 'CAMERA')]), 
	'vector_transform_vector_camera_object' : NodeInstance('ShaderNodeVectorTransform', [0], [0], [('vector_type', 'VECTOR'), ('convert_from', 'CAMERA'), ('convert_to', 'OBJECT')]), 
	'vector_transform_vector_camera_world' : NodeInstance('ShaderNodeVectorTransform', [0], [0], [('vector_type', 'VECTOR'), ('convert_from', 'CAMERA'), ('convert_to', 'WORLD')]), 
	'vector_transform_vector_object_camera' : NodeInstance('ShaderNodeVectorTransform', [0], [0], [('vector_type', 'VECTOR'), ('convert_from', 'OBJECT'), ('convert_to', 'CAMERA')]), 
	'vector_transform_vector_object_object' : NodeInstance('ShaderNodeVectorTransform', [0], [0], [('vector_type', 'VECTOR'), ('convert_from', 'OBJECT'), ('convert_to', 'OBJECT')]), 
	'vector_transform_vector_object_world' : NodeInstance('ShaderNodeVectorTransform', [0], [0], [('vector_type', 'VECTOR'), ('convert_from', 'OBJECT'), ('convert_to', 'WORLD')]), 
	'vector_transform_vector_world_camera' : NodeInstance('ShaderNodeVectorTransform', [0], [0], [('vector_type', 'VECTOR'), ('convert_from', 'WORLD'), ('convert_to', 'CAMERA')]), 
	'vector_transform_vector_world_object' : NodeInstance('ShaderNodeVectorTransform', [0], [0], [('vector_type', 'VECTOR'), ('convert_from', 'WORLD'), ('convert_to', 'OBJECT')]), 
	'vector_transform_vector_world_world' : NodeInstance('ShaderNodeVectorTransform', [0], [0], [('vector_type', 'VECTOR'), ('convert_from', 'WORLD'), ('convert_to', 'WORLD')]), 
	'volume_absorption' : NodeInstance('ShaderNodeVolumeAbsorption', [0, 1], [0], []), 
	'volume_info' : NodeInstance('ShaderNodeVolumeInfo', [], [0, 1, 2, 3], []), 
	'volume_scatter' : NodeInstance('ShaderNodeVolumeScatter', [0, 1, 2], [0], []), 
	'volume_scatter_draine' : NodeInstance('ShaderNodeVolumeScatter', [0, 1, 2, 5], [0], [('phase', 'DRAINE')]), 
	'volume_scatter_fournier_forand' : NodeInstance('ShaderNodeVolumeScatter', [0, 1, 3, 4], [0], [('phase', 'FOURNIER_FORAND')]), 
	'volume_scatter_henyey_greenstein' : NodeInstance('ShaderNodeVolumeScatter', [0, 1, 2], [0], [('phase', 'HENYEY_GREENSTEIN')]), 
	'volume_scatter_mie' : NodeInstance('ShaderNodeVolumeScatter', [0, 1, 6], [0], [('phase', 'MIE')]), 
	'volume_scatter_rayleigh' : NodeInstance('ShaderNodeVolumeScatter', [0, 1], [0], [('phase', 'RAYLEIGH')]), 
	'wavelength' : NodeInstance('ShaderNodeWavelength', [0], [0], []), 
	'wireframe' : NodeInstance('ShaderNodeWireframe', [0], [0], []), 
	'world_output' : NodeInstance('ShaderNodeOutputWorld', [0, 1], [], []), 
	'world_output_all' : NodeInstance('ShaderNodeOutputWorld', [0, 1], [], [('target', 'ALL')]), 
	'world_output_cycles' : NodeInstance('ShaderNodeOutputWorld', [0, 1], [], [('target', 'CYCLES')]), 
	'world_output_eevee' : NodeInstance('ShaderNodeOutputWorld', [0, 1], [], [('target', 'EEVEE')]), 
}

# fmt: on

# End auto generated

instances: dict[str, list[str]] = {
    "add": ["math_add", "vector_math_add"],
    "sub": ["math_subtract", "vector_math_subtract"],
    "mul": [
        "math_multiply",
        "vector_math_multiply",
        "vector_math_scale",
    ],
    "div": ["math_divide", "vector_math_divide"],
    "mul_add": ["math_multiply_add", "vector_math_multiply_add"],
    "pow": ["math_power"],
    "log": ["math_logarithm"],
    "sqrt": ["math_square_root"],
    "inv_sqrt": ["math_inverse_square_root"],
    "abs": ["math_absolute", "vector_math_absolute"],
    "exp": ["math_exponent"],
    "min": ["math_minimum", "vector_math_minimum"],
    "max": ["math_maximum", "vector_math_maximum"],
    "less_than": ["math_less_than"],
    "greater_than": ["math_greater_than"],
    "sign": ["math_sign"],
    "smin": ["math_smooth_minimum"],
    "smax": ["math_smooth_maximum"],
    "round": ["math_round"],
    "floor": ["math_floor", "vector_math_floor"],
    "ceil": ["math_ceil", "vector_math_ceil"],
    "truncate": ["math_truncate"],
    "fract": ["math_fraction", "vector_math_fraction"],
    "mod": ["math_truncated_modulo", "vector_math_modulo"],
    "wrap": ["math_wrap", "vector_math_wrap"],
    "snap": ["math_snap", "vector_math_snap"],
    "ping_pong": ["math_ping_pong"],
    "sin": ["math_sine", "vector_math_sine"],
    "cos": ["math_cosine", "vector_math_cosine"],
    "tan": ["math_tangent", "vector_math_tangent"],
    "asin": ["math_arcsine"],
    "acos": ["math_arccosine"],
    "atan": ["math_arctangent"],
    "atan2": ["math_arctan2"],
    "sinh": ["math_hyperbolic_sine"],
    "cosh": ["math_hyperbolic_cosine"],
    "tanh": ["math_hyperbolic_tangent"],
    "to_radians": ["math_to_radians"],
    "to_degrees": ["math_to_degrees"],
    "vec3": ["combine_xyz"],
    "sep_xyz": ["separate_xyz"],
    "cross": ["vector_math_cross_product"],
    "project": ["vector_math_project"],
    "reflect": ["vector_math_reflect"],
    "face_forward": ["vector_math_faceforward"],
    "dot": ["vector_math_dot_product"],
    "dist": ["vector_math_distance"],
    "length": ["vector_math_length"],
    "scale": ["vector_math_scale"],
    "normalize": ["vector_math_normalize"],
    "map": ["map_range_linear_float", "map_range_linear_vector"],
    "map_stepped": [
        "map_range_stepped_linear_float",
        "map_range_stepped_linear_vector",
    ],
    "smoothstep": ["map_range_smooth_step_float", "map_range_smooth_step_vector"],
    "smootherstep": ["map_range_smoother_step_float", "map_range_smoother_step_vector"],
    "mix": ["mix_float_uniform_mix", "mix_vector_uniform_mix", "mix_color_uniform_mix"],
    "white_noise": ["white_noise_texture_1d", "white_noise_texture_3d"],
    "white_noise_2d": ["white_noise_texture_2d"],
    "white_noise_4d": ["white_noise_texture_4d"],
    "noise": ["noise_texture_1d", "noise_texture_3d"],
    "noise_2d": ["noise_texture_2d"],
    "noise_4d": ["noise_texture_4d"],
    "voronoi": ["voronoi_texture_1d_euclidean_f1", "voronoi_texture_3d_euclidean_f1"],
    "voronoi_2d": ["voronoi_texture_2d_euclidean_f1"],
    "voronoi_4d": ["voronoi_texture_4d_euclidean_f1"],
}
